package com.taobao.weex.ui.component;

import android.animation.Animator;
import android.animation.AnimatorSet;
import android.animation.ObjectAnimator;
import android.animation.StateListAnimator;
import android.content.Context;
import android.content.Intent;
import android.content.res.ColorStateList;
import android.graphics.Canvas;
import android.graphics.Outline;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.LayerDrawable;
import android.graphics.drawable.RippleDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.Pair;
import android.view.Menu;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewOutlineProvider;
import android.widget.FrameLayout;
import androidx.core.view.AccessibilityDelegateCompat;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import androidx.interpolator.view.animation.FastOutLinearInInterpolator;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.parser.JSONLexer;
import com.taobao.weex.ComponentObserver;
import com.taobao.weex.IWXActivityStateListener;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXAccessibilityRoleAdapter;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.bridge.Invoker;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.IWXObject;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXPerformance;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.dom.transition.WXTransition;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.tracing.Stopwatch;
import com.taobao.weex.tracing.WXTracing;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.WXRenderManager;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.action.GraphicActionAnimation;
import com.taobao.weex.ui.action.GraphicActionUpdateStyle;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.animation.WXAnimationBean;
import com.taobao.weex.ui.component.basic.WXBasicComponent;
import com.taobao.weex.ui.component.binding.Statements;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.component.list.template.jni.NativeRenderObjectUtils;
import com.taobao.weex.ui.component.pesudo.OnActivePseudoListner;
import com.taobao.weex.ui.component.pesudo.PesudoStatus;
import com.taobao.weex.ui.component.pesudo.TouchActivePseudoListener;
import com.taobao.weex.ui.flat.FlatComponent;
import com.taobao.weex.ui.flat.FlatGUIContext;
import com.taobao.weex.ui.flat.widget.AndroidViewWidget;
import com.taobao.weex.ui.flat.widget.Widget;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXDataStructureUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXReflectionUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.feature.uniapp.dom.AbsCSSShorthand;
import io.dcloud.feature.uniapp.ui.AbsAnimationHolder;
import io.dcloud.feature.uniapp.ui.action.UniMethodData;
import io.dcloud.feature.uniapp.ui.component.AbsBasicComponent;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowData;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowLayer;
import io.dcloud.feature.uniapp.ui.shadow.UniNormalBoxShadowDrawable;
import io.dcloud.feature.uniapp.utils.UniBoxShadowUtil;
import io.dcloud.weex.ViewHover;
import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
/* loaded from: classes.dex */
public abstract class WXComponent<T extends View> extends WXBasicComponent<T> implements IWXObject, IWXActivityStateListener, OnActivePseudoListner {
    public static final String PROP_FIXED_SIZE = "fixedSize";
    public static final String PROP_FS_MATCH_PARENT = "m";
    public static final String PROP_FS_WRAP_CONTENT = "w";
    public static final String ROOT = "_root";
    public static final int STATE_ALL_FINISH = 2;
    public static final int STATE_DOM_FINISH = 0;
    public static final int STATE_UI_FINISH = 1;
    public static final String TYPE = "type";
    public static final int TYPE_COMMON = 0;
    public static final int TYPE_VIRTUAL = 1;
    private int[] EMPTY_STATE_SET;
    private int[] ENABLED_STATE_SET;
    private int[] FOCUSED_ENABLED_STATE_SET;
    private long PRESSED_ANIM_DELAY;
    private long PRESSED_ANIM_DURATION;
    private int[] PRESSED_ENABLED_STATE_SET;
    private ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> animations;
    protected ContentBoxMeasurement contentBoxMeasurement;
    public int interactionAbsoluteX;
    public int interactionAbsoluteY;
    public boolean isIgnoreInteraction;
    private boolean isLastLayoutDirectionRTL;
    private boolean isPreventGesture;
    private boolean isUsing;
    private int mAbsoluteX;
    private int mAbsoluteY;
    private AbsAnimationHolder mAnimationHolder;
    private Set<String> mAppendEvents;
    private BorderDrawable mBackgroundDrawable;
    private UniBoxShadowData mBoxShadowData;
    private UniNormalBoxShadowDrawable mBoxShadowDrawable;
    private WXComponent<T>.OnClickListenerImp mClickEventListener;
    private Context mContext;
    public int mDeepInComponentTree;
    private float mElevation;
    private int mFixedProp;
    private List<OnFocusChangeListener> mFocusChangeListeners;
    protected WXGesture mGesture;
    private Set<String> mGestureType;
    private boolean mHasAddFocusListener;
    private IFComponentHolder mHolder;
    T mHost;
    private List<OnClickListener> mHostClickListeners;
    private ViewHover mHover;
    private UniInsetBoxShadowLayer mInsetBoxShadowDrawable;
    private WXSDKInstance mInstance;
    public boolean mIsAddElementToTree;
    private boolean mIsDestroyed;
    private boolean mIsDisabled;
    private String mLastBoxShadowId;
    private boolean mLazy;
    private boolean mNeedLayoutOnAnimation;
    private volatile WXVContainer mParent;
    private ConcurrentLinkedQueue<UniMethodData> mPendingComponetMethodQueue;
    private PesudoStatus mPesudoStatus;
    private int mPreRealHeight;
    private int mPreRealLeft;
    private int mPreRealRight;
    private int mPreRealTop;
    private int mPreRealWidth;
    private GraphicSize mPseudoResetGraphicSize;
    private Drawable mRippleBackground;
    private int mStickyOffset;
    public WXTracing.TraceInfo mTraceInfo;
    private WXTransition mTransition;
    private int mType;
    private String mViewTreeKey;
    private boolean waste;

    /* loaded from: classes.dex */
    public static class MeasureOutput {
        public int height;
        public int width;
    }

    /* loaded from: classes.dex */
    public interface OnClickListener {
        void onHostViewClick();
    }

    /* loaded from: classes.dex */
    public interface OnFocusChangeListener {
        void onFocusChange(boolean hasFocus);
    }

    @Target({ElementType.PARAMETER})
    @Retention(RetentionPolicy.SOURCE)
    /* loaded from: classes.dex */
    public @interface RenderState {
    }

    protected void appendEventToDOM(String type) {
    }

    public String getAttrByKey(String key) {
        return "default";
    }

    public int getLayoutTopOffsetForSibling() {
        return 0;
    }

    protected T initComponentHostView(Context context) {
        return null;
    }

    protected void layoutDirectionDidChanged(boolean isRTL) {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public boolean onActivityBack() {
        return false;
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityCreate() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityPause() {
    }

    public void onActivityResult(int requestCode, int resultCode, Intent data) {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStart() {
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityStop() {
    }

    protected void onCreate() {
    }

    public boolean onCreateOptionsMenu(Menu menu) {
        return false;
    }

    protected void onInvokeUnknownMethod(String method, JSONArray args) {
    }

    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
    }

    public void refreshData(WXComponent component) {
    }

    @Deprecated
    public void registerActivityStateListener() {
    }

    public void removeVirtualComponent() {
    }

    @Deprecated
    public WXComponent(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, isLazy, basicComponentData);
    }

    @Deprecated
    public WXComponent(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        this(instance, parent, 0, basicComponentData);
    }

    public WXComponent(WXSDKInstance instance, WXVContainer parent, int type, BasicComponentData basicComponentData) {
        super(basicComponentData);
        this.mFixedProp = 0;
        this.mAbsoluteY = 0;
        this.mAbsoluteX = 0;
        this.isLastLayoutDirectionRTL = false;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealTop = 0;
        this.mStickyOffset = 0;
        this.isUsing = false;
        this.mIsDestroyed = false;
        this.mIsDisabled = false;
        this.mType = 0;
        this.mNeedLayoutOnAnimation = false;
        this.mDeepInComponentTree = 0;
        this.mIsAddElementToTree = false;
        this.interactionAbsoluteX = 0;
        this.interactionAbsoluteY = 0;
        this.mHasAddFocusListener = false;
        this.mTraceInfo = new WXTracing.TraceInfo();
        this.waste = false;
        this.isIgnoreInteraction = false;
        this.mPendingComponetMethodQueue = new ConcurrentLinkedQueue<>();
        this.PRESSED_ANIM_DURATION = 100L;
        this.PRESSED_ANIM_DELAY = 100L;
        this.ENABLED_STATE_SET = new int[]{16842910};
        this.EMPTY_STATE_SET = new int[0];
        this.PRESSED_ENABLED_STATE_SET = new int[]{16842919, 16842910};
        this.FOCUSED_ENABLED_STATE_SET = new int[]{16842908, 16842910};
        this.mElevation = 0.0f;
        this.mLazy = false;
        this.isPreventGesture = false;
        this.mInstance = instance;
        this.mContext = instance.getContext();
        this.mParent = parent;
        this.mType = type;
        if (instance != null) {
            setViewPortWidth(instance.getInstanceViewPortWidthWithFloat());
        }
        onCreate();
        ComponentObserver componentObserver = getInstance().getComponentObserver();
        if (componentObserver != null) {
            componentObserver.onCreate(this);
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    protected final void bindComponent(AbsBasicComponent component) {
        super.bindComponent(component);
        if (getInstance() != null) {
            setViewPortWidth(getInstance().getInstanceViewPortWidthWithFloat());
        }
        WXComponent wXComponent = (WXComponent) component;
        this.mParent = wXComponent.getParent();
        this.mType = wXComponent.getType();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setContentBoxMeasurement(final ContentBoxMeasurement contentBoxMeasurement) {
        this.contentBoxMeasurement = contentBoxMeasurement;
        this.mInstance.addContentBoxMeasurement(getRenderObjectPtr(), contentBoxMeasurement);
        WXBridgeManager.getInstance().bindMeasurementToRenderObject(getRenderObjectPtr());
    }

    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        lp.setMargins(left, top, right, bottom);
        if (lp instanceof FrameLayout.LayoutParams) {
            ((FrameLayout.LayoutParams) lp).gravity = 51;
        }
    }

    public void updateStyles(WXComponent component) {
        if (component != null) {
            updateProperties(component.getStyles());
            applyBorder(component);
        }
    }

    public void updateStyles(Map<String, Object> styles) {
        if (styles != null) {
            updateProperties(styles);
            applyBorder(this);
        }
    }

    public void updateAttrs(AbsBasicComponent component) {
        if (component != null) {
            updateProperties(component.getAttrs());
        }
    }

    public void updateAttrs(Map<String, Object> attrs) {
        if (attrs != null) {
            updateProperties(attrs);
        }
    }

    private void applyBorder(AbsBasicComponent component) {
        AbsCSSShorthand border = component.getBorder();
        float f = border.get(CSSShorthand.EDGE.LEFT);
        float f2 = border.get(CSSShorthand.EDGE.TOP);
        float f3 = border.get(CSSShorthand.EDGE.RIGHT);
        float f4 = border.get(CSSShorthand.EDGE.BOTTOM);
        if (this.mHost == null) {
            return;
        }
        setBorderWidth(Constants.Name.BORDER_LEFT_WIDTH, f);
        setBorderWidth(Constants.Name.BORDER_TOP_WIDTH, f2);
        setBorderWidth(Constants.Name.BORDER_RIGHT_WIDTH, f3);
        setBorderWidth(Constants.Name.BORDER_BOTTOM_WIDTH, f4);
    }

    public void setPadding(AbsCSSShorthand padding, AbsCSSShorthand border) {
        int i = (int) (padding.get(CSSShorthand.EDGE.LEFT) + border.get(CSSShorthand.EDGE.LEFT));
        int i2 = (int) (padding.get(CSSShorthand.EDGE.TOP) + border.get(CSSShorthand.EDGE.TOP));
        int i3 = (int) (padding.get(CSSShorthand.EDGE.RIGHT) + border.get(CSSShorthand.EDGE.RIGHT));
        int i4 = (int) (padding.get(CSSShorthand.EDGE.BOTTOM) + border.get(CSSShorthand.EDGE.BOTTOM));
        if (this instanceof FlatComponent) {
            FlatComponent flatComponent = (FlatComponent) this;
            if (!flatComponent.promoteToView(true)) {
                flatComponent.getOrCreateFlatWidget().setContentBox(i, i2, i3, i4);
                return;
            }
        }
        if (this.mHost != null) {
            UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
            if (uniBoxShadowData != null) {
                if (uniBoxShadowData.getNormalLeft() > 0) {
                    int normalLeft = this.mBoxShadowData.getNormalLeft() / 2;
                    i += normalLeft;
                    i3 += normalLeft;
                }
                if (this.mBoxShadowData.getNormalTop() > 0) {
                    int normalTop = this.mBoxShadowData.getNormalTop() / 2;
                    i2 += normalTop;
                    i4 += normalTop;
                }
            }
            this.mHost.setPadding(i, i2, i3, i4);
        }
    }

    public void applyComponentEvents() {
        applyEvents();
    }

    private void applyEvents() {
        if (getEvents() == null || getEvents().isEmpty()) {
            return;
        }
        WXEvent events = getEvents();
        int size = events.size();
        for (int i = 0; i < size && i < events.size(); i++) {
            addEvent((String) events.get(i));
        }
        setActiveTouchListener();
    }

    public void addEvent(final String type) {
        if (this.mAppendEvents == null) {
            this.mAppendEvents = new HashSet();
        }
        if (TextUtils.isEmpty(type) || this.mAppendEvents.contains(type)) {
            return;
        }
        View realView = getRealView();
        if (type.equals(Constants.Event.LAYEROVERFLOW)) {
            addLayerOverFlowListener(getRef());
        }
        if (type.equals(Constants.Event.CLICK)) {
            if (realView == null) {
                return;
            }
            if (this.mClickEventListener == null) {
                this.mClickEventListener = new OnClickListenerImp();
            }
            addClickListener(this.mClickEventListener);
        } else if (type.equals(Constants.Event.FOCUS) || type.equals(Constants.Event.BLUR)) {
            if (!this.mHasAddFocusListener) {
                this.mHasAddFocusListener = true;
                addFocusChangeListener(new OnFocusChangeListener() { // from class: com.taobao.weex.ui.component.WXComponent.1
                    @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
                    public void onFocusChange(boolean hasFocus) {
                        HashMap hashMap = new HashMap();
                        hashMap.put("timeStamp", Long.valueOf(System.currentTimeMillis()));
                        WXComponent.this.fireEvent(hasFocus ? Constants.Event.FOCUS : Constants.Event.BLUR, hashMap);
                    }
                });
            }
        } else if (!needGestureDetector(type)) {
            Scrollable parentScroller = getParentScroller();
            if (parentScroller == null) {
                return;
            }
            if (type.equals(Constants.Event.APPEAR)) {
                parentScroller.bindAppearEvent(this);
            } else if (type.equals(Constants.Event.DISAPPEAR)) {
                parentScroller.bindDisappearEvent(this);
            }
        } else if (realView == null) {
            return;
        } else {
            if (realView instanceof WXGestureObservable) {
                if (this.mGesture == null) {
                    this.mGesture = new WXGesture(this, this.mContext);
                    this.mGesture.setPreventMoveEvent(WXUtils.getBoolean(getAttrs().get(Constants.Name.PREVENT_MOVE_EVENT), false).booleanValue());
                }
                if (this.mGestureType == null) {
                    this.mGestureType = new HashSet();
                }
                if (!ViewHover.VIEW_HOVER_EVENT.equals(type)) {
                    this.mGestureType.add(type);
                }
                ((WXGestureObservable) realView).registerGestureListener(this.mGesture);
            } else {
                WXLogUtils.e(realView.getClass().getSimpleName() + " don't implement WXGestureObservable, so no gesture is supported.");
            }
        }
        this.mAppendEvents.add(type);
    }

    public void interceptFocusAndBlurEvent() {
        this.mHasAddFocusListener = true;
    }

    public void bindHolder(IFComponentHolder holder) {
        this.mHolder = holder;
    }

    public WXSDKInstance getInstance() {
        return this.mInstance;
    }

    public Context getContext() {
        return this.mContext;
    }

    protected final WXComponent findComponent(String ref) {
        if (this.mInstance == null || ref == null) {
            return null;
        }
        return WXSDKManager.getInstance().getWXRenderManager().getWXComponent(this.mInstance.getInstanceId(), ref);
    }

    public void postAnimation(AbsAnimationHolder holder) {
        this.mAnimationHolder = holder;
    }

    public boolean isFlatUIEnabled() {
        return this.mParent != null && this.mParent.isFlatUIEnabled();
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class OnClickListenerImp implements OnClickListener {
        private OnClickListenerImp() {
        }

        @Override // com.taobao.weex.ui.component.WXComponent.OnClickListener
        public void onHostViewClick() {
            HashMap newHashMapWithExpectedSize = WXDataStructureUtil.newHashMapWithExpectedSize(1);
            HashMap newHashMapWithExpectedSize2 = WXDataStructureUtil.newHashMapWithExpectedSize(4);
            int[] iArr = new int[2];
            WXComponent.this.mHost.getLocationOnScreen(iArr);
            newHashMapWithExpectedSize2.put(Constants.Name.X, Float.valueOf(WXViewUtils.getWebPxByWidth(iArr[0], WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            newHashMapWithExpectedSize2.put(Constants.Name.Y, Float.valueOf(WXViewUtils.getWebPxByWidth(iArr[1], WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            newHashMapWithExpectedSize2.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth(WXComponent.this.getLayoutWidth(), WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            newHashMapWithExpectedSize2.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth(WXComponent.this.getLayoutHeight(), WXComponent.this.mInstance.getInstanceViewPortWidthWithFloat())));
            newHashMapWithExpectedSize.put("position", newHashMapWithExpectedSize2);
            WXComponent.this.fireEvent(Constants.Event.CLICK, newHashMapWithExpectedSize);
        }
    }

    public String getInstanceId() {
        return this.mInstance.getInstanceId();
    }

    public Rect getComponentSize() {
        Rect rect = new Rect();
        if (this.mHost != null && this.mInstance.getContainerView() != null) {
            int[] iArr = new int[2];
            int[] iArr2 = new int[2];
            this.mHost.getLocationOnScreen(iArr);
            this.mInstance.getContainerView().getLocationOnScreen(iArr2);
            int i = iArr[0] - iArr2[0];
            int i2 = (iArr[1] - this.mStickyOffset) - iArr2[1];
            rect.set(i, i2, ((int) getLayoutWidth()) + i, ((int) getLayoutHeight()) + i2);
        }
        return rect;
    }

    public final void invoke(String method, JSONArray args) {
        if (getHostView() == null || getRealView() == null) {
            this.mPendingComponetMethodQueue.offer(new UniMethodData(method, args));
            return;
        }
        Invoker methodInvoker = this.mHolder.getMethodInvoker(method);
        if (methodInvoker != null) {
            try {
                getInstance().getNativeInvokeHelper().invoke(this, methodInvoker, args);
                return;
            } catch (Exception e) {
                WXLogUtils.e("[WXComponent] updateProperties :class:" + getClass() + "method:" + methodInvoker.toString() + " function " + WXLogUtils.getStackTrace(e));
                return;
            }
        }
        onInvokeUnknownMethod(method, args);
    }

    public final void fireEvent(String type) {
        fireEvent(type, null);
    }

    public final void fireEvent(String type, Map<String, Object> params) {
        if (WXUtils.getBoolean(getAttrs().get("fireEventSyn"), false).booleanValue()) {
            fireEventWait(type, params);
        } else {
            fireEvent(type, params, null, null);
        }
    }

    public final EventResult fireEventWait(String type, Map<String, Object> params) {
        final CountDownLatch countDownLatch = new CountDownLatch(1);
        EventResult eventResult = new EventResult() { // from class: com.taobao.weex.ui.component.WXComponent.2
            @Override // com.taobao.weex.bridge.EventResult
            public void onCallback(Object result) {
                super.onCallback(result);
                countDownLatch.countDown();
            }
        };
        try {
            fireEvent(type, params, null, eventResult);
            countDownLatch.await(50L, TimeUnit.MILLISECONDS);
            return eventResult;
        } catch (Exception e) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("fireEventWait", e);
            }
            return eventResult;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void fireEvent(String type, Map<String, Object> params, Map<String, Object> domChanges) {
        fireEvent(type, params, domChanges, null);
    }

    private final void fireEvent(String type, Map<String, Object> params, Map<String, Object> domChanges, EventResult callback) {
        String componentId;
        if (this.mInstance != null) {
            List<Object> list = null;
            if (getEvents() != null && getEvents().getEventBindingArgsValues() != null) {
                list = getEvents().getEventBindingArgsValues().get(type);
            }
            List<Object> list2 = list;
            if (params != null && (componentId = Statements.getComponentId(this)) != null) {
                params.put("componentId", componentId);
            }
            this.mInstance.fireEvent(getRef(), type, params, domChanges, list2, callback);
        }
    }

    public Object findTypeParent(AbsBasicComponent component, Class type) {
        if (component.getClass() == type) {
            return component;
        }
        WXComponent wXComponent = (WXComponent) component;
        if (wXComponent.getParent() != null) {
            findTypeParent(wXComponent.getParent(), type);
            return null;
        }
        return null;
    }

    public boolean isLazy() {
        if (this.mLazy) {
            return true;
        }
        return this.mParent != null && this.mParent.isLazy();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void addFocusChangeListener(OnFocusChangeListener l) {
        View realView;
        if (l == null || (realView = getRealView()) == null) {
            return;
        }
        if (this.mFocusChangeListeners == null) {
            this.mFocusChangeListeners = new ArrayList();
            realView.setFocusable(true);
            realView.setOnFocusChangeListener(new View.OnFocusChangeListener() { // from class: com.taobao.weex.ui.component.WXComponent.3
                @Override // android.view.View.OnFocusChangeListener
                public void onFocusChange(View v, boolean hasFocus) {
                    for (OnFocusChangeListener onFocusChangeListener : WXComponent.this.mFocusChangeListeners) {
                        if (onFocusChangeListener != null) {
                            onFocusChangeListener.onFocusChange(hasFocus);
                        }
                    }
                }
            });
        }
        this.mFocusChangeListeners.add(l);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public boolean ismHasFocusChangeListener(OnFocusChangeListener l) {
        List<OnFocusChangeListener> list = this.mFocusChangeListeners;
        if (list != null) {
            return list.contains(l);
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final void addClickListener(OnClickListener l) {
        View realView;
        if (l == null || (realView = getRealView()) == null) {
            return;
        }
        if (this.mHostClickListeners == null) {
            this.mHostClickListeners = new ArrayList();
        }
        if (!realView.hasOnClickListeners()) {
            realView.setClickable(true);
            realView.setOnClickListener(new View.OnClickListener() { // from class: com.taobao.weex.ui.component.WXComponent.4
                @Override // android.view.View.OnClickListener
                public void onClick(View v) {
                    if (WXComponent.this.mGesture == null || !WXComponent.this.mGesture.isTouchEventConsumedByAdvancedGesture()) {
                        for (OnClickListener onClickListener : WXComponent.this.mHostClickListeners) {
                            if (onClickListener != null) {
                                onClickListener.onHostViewClick();
                            }
                        }
                    }
                }
            });
        }
        this.mHostClickListeners.add(l);
    }

    protected final void removeClickListener(OnClickListener l) {
        this.mHostClickListeners.remove(l);
    }

    public void bindData(WXComponent component) {
        bindComponentData(component);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void bindComponentData(AbsBasicComponent component) {
        if (isLazy()) {
            return;
        }
        if (component == null) {
            component = this;
        }
        WXComponent wXComponent = (WXComponent) component;
        bindComponent(wXComponent);
        updateStyles(wXComponent);
        updateAttrs(component);
        updateExtra(component.getExtra());
    }

    public void applyLayoutAndEvent(AbsBasicComponent component) {
        if (isLazy()) {
            return;
        }
        if (component == null) {
            component = this;
        }
        WXComponent wXComponent = (WXComponent) component;
        bindComponent(wXComponent);
        setSafeLayout(wXComponent);
        setPadding(component.getPadding(), component.getBorder());
        applyEvents();
    }

    public void setDemission(GraphicSize size, GraphicPosition position) {
        setLayoutPosition(position);
        setLayoutSize(size);
    }

    public void updateDemission(float top, float bottom, float left, float right, float height, float width) {
        getLayoutPosition().update(top, bottom, left, right);
        getLayoutSize().update(width, height);
    }

    public void applyLayoutOnly() {
        if (isLazy()) {
            return;
        }
        setSafeLayout(this);
        setPadding(getPadding(), getBorder());
    }

    @Deprecated
    public void updateProperties(Map<String, Object> props) {
        if (props != null) {
            if ((this.mHost != null || isVirtualComponent()) && getInstance() != null) {
                for (Map.Entry<String, Object> entry : props.entrySet()) {
                    String key = entry.getKey();
                    Object value = entry.getValue();
                    String string = WXUtils.getString(value, null);
                    if (key == null) {
                        WXExceptionUtils.commitCriticalExceptionRT(getInstanceId(), WXErrorCode.WX_RENDER_ERR_NULL_KEY, "updateProperties", WXErrorCode.WX_RENDER_ERR_NULL_KEY.getErrorMsg(), null);
                    } else {
                        if (TextUtils.isEmpty(string)) {
                            value = convertEmptyProperty(key, string);
                        }
                        if (setProperty(key, value)) {
                            continue;
                        } else if (this.mHolder == null || getInstance() == null) {
                            return;
                        } else {
                            Invoker propertyInvoker = this.mHolder.getPropertyInvoker(key);
                            if (propertyInvoker != null) {
                                try {
                                    Type[] parameterTypes = propertyInvoker.getParameterTypes();
                                    if (parameterTypes.length != 1) {
                                        WXLogUtils.e("[WXComponent] setX method only one parameter：" + propertyInvoker);
                                        return;
                                    }
                                    propertyInvoker.invoke(this, WXReflectionUtils.parseArgument(parameterTypes[0], value));
                                } catch (Exception e) {
                                    WXLogUtils.e("[WXComponent] updateProperties :class:" + getClass() + "method:" + propertyInvoker.toString() + " function " + WXLogUtils.getStackTrace(e));
                                }
                            } else {
                                continue;
                            }
                        }
                    }
                }
                readyToRender();
                if (!(this instanceof FlatComponent) || this.mBackgroundDrawable == null) {
                    return;
                }
                FlatComponent flatComponent = (FlatComponent) this;
                if (flatComponent.promoteToView(true) || (flatComponent.getOrCreateFlatWidget() instanceof AndroidViewWidget)) {
                    return;
                }
                flatComponent.getOrCreateFlatWidget().setBackgroundAndBorder(this.mBackgroundDrawable);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    public boolean setProperty(String key, Object param) {
        if (key != null && getInstance() != null) {
            key.hashCode();
            char c = 65535;
            switch (key.hashCode()) {
                case -1989576717:
                    if (key.equals(Constants.Name.BORDER_RIGHT_COLOR)) {
                        c = 0;
                        break;
                    }
                    break;
                case -1974639039:
                    if (key.equals(Constants.Name.BORDER_RIGHT_STYLE)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1971292586:
                    if (key.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                        c = 2;
                        break;
                    }
                    break;
                case -1501175880:
                    if (key.equals(Constants.Name.PADDING_LEFT)) {
                        c = 3;
                        break;
                    }
                    break;
                case -1470826662:
                    if (key.equals(Constants.Name.BORDER_TOP_COLOR)) {
                        c = 4;
                        break;
                    }
                    break;
                case -1455888984:
                    if (key.equals(Constants.Name.BORDER_TOP_STYLE)) {
                        c = 5;
                        break;
                    }
                    break;
                case -1452542531:
                    if (key.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                        c = 6;
                        break;
                    }
                    break;
                case -1383228885:
                    if (key.equals("bottom")) {
                        c = 7;
                        break;
                    }
                    break;
                case -1375815020:
                    if (key.equals(Constants.Name.MIN_WIDTH)) {
                        c = '\b';
                        break;
                    }
                    break;
                case -1308858324:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                        c = '\t';
                        break;
                    }
                    break;
                case -1293920646:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_STYLE)) {
                        c = '\n';
                        break;
                    }
                    break;
                case -1290574193:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                        c = 11;
                        break;
                    }
                    break;
                case -1267206133:
                    if (key.equals("opacity")) {
                        c = '\f';
                        break;
                    }
                    break;
                case -1228066334:
                    if (key.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                        c = '\r';
                        break;
                    }
                    break;
                case -1221029593:
                    if (key.equals("height")) {
                        c = 14;
                        break;
                    }
                    break;
                case -1111969773:
                    if (key.equals(Constants.Name.ARIA_HIDDEN)) {
                        c = 15;
                        break;
                    }
                    break;
                case -1081309778:
                    if (key.equals("margin")) {
                        c = 16;
                        break;
                    }
                    break;
                case -1063257157:
                    if (key.equals(Constants.Name.ALIGN_ITEMS)) {
                        c = 17;
                        break;
                    }
                    break;
                case -1044792121:
                    if (key.equals(Constants.Name.MARGIN_TOP)) {
                        c = 18;
                        break;
                    }
                    break;
                case -975171706:
                    if (key.equals(Constants.Name.FLEX_DIRECTION)) {
                        c = 19;
                        break;
                    }
                    break;
                case -906066005:
                    if (key.equals(Constants.Name.MAX_HEIGHT)) {
                        c = 20;
                        break;
                    }
                    break;
                case -863700117:
                    if (key.equals(Constants.Name.ARIA_LABEL)) {
                        c = 21;
                        break;
                    }
                    break;
                case -806339567:
                    if (key.equals("padding")) {
                        c = 22;
                        break;
                    }
                    break;
                case -289173127:
                    if (key.equals(Constants.Name.MARGIN_BOTTOM)) {
                        c = 23;
                        break;
                    }
                    break;
                case -242276144:
                    if (key.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                        c = 24;
                        break;
                    }
                    break;
                case -227338466:
                    if (key.equals(Constants.Name.BORDER_LEFT_STYLE)) {
                        c = 25;
                        break;
                    }
                    break;
                case -223992013:
                    if (key.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                        c = JSONLexer.EOI;
                        break;
                    }
                    break;
                case -133587431:
                    if (key.equals(Constants.Name.MIN_HEIGHT)) {
                        c = 27;
                        break;
                    }
                    break;
                case 115029:
                    if (key.equals("top")) {
                        c = 28;
                        break;
                    }
                    break;
                case 3145721:
                    if (key.equals(Constants.Name.FLEX)) {
                        c = 29;
                        break;
                    }
                    break;
                case 3317767:
                    if (key.equals("left")) {
                        c = 30;
                        break;
                    }
                    break;
                case 3506294:
                    if (key.equals(Constants.Name.ROLE)) {
                        c = 31;
                        break;
                    }
                    break;
                case 90130308:
                    if (key.equals(Constants.Name.PADDING_TOP)) {
                        c = ' ';
                        break;
                    }
                    break;
                case 108511772:
                    if (key.equals("right")) {
                        c = '!';
                        break;
                    }
                    break;
                case 113126854:
                    if (key.equals("width")) {
                        c = Operators.QUOTE;
                        break;
                    }
                    break;
                case 202355100:
                    if (key.equals(Constants.Name.PADDING_BOTTOM)) {
                        c = '#';
                        break;
                    }
                    break;
                case 270940796:
                    if (key.equals(Constants.Name.DISABLED)) {
                        c = Operators.DOLLAR;
                        break;
                    }
                    break;
                case 333432965:
                    if (key.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                        c = WXUtils.PERCENT;
                        break;
                    }
                    break;
                case 400381634:
                    if (key.equals(Constants.Name.MAX_WIDTH)) {
                        c = '&';
                        break;
                    }
                    break;
                case 581268560:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                        c = Operators.SINGLE_QUOTE;
                        break;
                    }
                    break;
                case 588239831:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                        c = Operators.BRACKET_START;
                        break;
                    }
                    break;
                case 713848971:
                    if (key.equals(Constants.Name.PADDING_RIGHT)) {
                        c = Operators.BRACKET_END;
                        break;
                    }
                    break;
                case 717381201:
                    if (key.equals(Constants.Name.PREVENT_MOVE_EVENT)) {
                        c = '*';
                        break;
                    }
                    break;
                case 722830999:
                    if (key.equals(Constants.Name.BORDER_COLOR)) {
                        c = '+';
                        break;
                    }
                    break;
                case 737768677:
                    if (key.equals(Constants.Name.BORDER_STYLE)) {
                        c = Operators.ARRAY_SEPRATOR;
                        break;
                    }
                    break;
                case 741115130:
                    if (key.equals(Constants.Name.BORDER_WIDTH)) {
                        c = '-';
                        break;
                    }
                    break;
                case 743055051:
                    if (key.equals(Constants.Name.BOX_SHADOW)) {
                        c = Operators.DOT;
                        break;
                    }
                    break;
                case 747463061:
                    if (key.equals(PROP_FIXED_SIZE)) {
                        c = '/';
                        break;
                    }
                    break;
                case 747804969:
                    if (key.equals("position")) {
                        c = '0';
                        break;
                    }
                    break;
                case 975087886:
                    if (key.equals(Constants.Name.MARGIN_RIGHT)) {
                        c = '1';
                        break;
                    }
                    break;
                case 1287124693:
                    if (key.equals("backgroundColor")) {
                        c = '2';
                        break;
                    }
                    break;
                case 1292595405:
                    if (key.equals(Constants.Name.BACKGROUND_IMAGE)) {
                        c = '3';
                        break;
                    }
                    break;
                case 1349188574:
                    if (key.equals(Constants.Name.BORDER_RADIUS)) {
                        c = '4';
                        break;
                    }
                    break;
                case 1744216035:
                    if (key.equals(Constants.Name.FLEX_WRAP)) {
                        c = '5';
                        break;
                    }
                    break;
                case 1767100401:
                    if (key.equals(Constants.Name.ALIGN_SELF)) {
                        c = '6';
                        break;
                    }
                    break;
                case 1860657097:
                    if (key.equals(Constants.Name.JUSTIFY_CONTENT)) {
                        c = '7';
                        break;
                    }
                    break;
                case 1941332754:
                    if (key.equals(Constants.Name.VISIBILITY)) {
                        c = '8';
                        break;
                    }
                    break;
                case 1970934485:
                    if (key.equals(Constants.Name.MARGIN_LEFT)) {
                        c = '9';
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                case 4:
                case '\t':
                case 24:
                case '+':
                    String string = WXUtils.getString(param, null);
                    if (string != null) {
                        setBorderColor(key, string);
                        break;
                    }
                    break;
                case 1:
                case 5:
                case '\n':
                case 25:
                case ',':
                    String string2 = WXUtils.getString(param, null);
                    if (string2 != null) {
                        setBorderStyle(key, string2);
                    }
                    return true;
                case 2:
                case 3:
                case 6:
                case 7:
                case '\b':
                case 11:
                case 14:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 22:
                case 23:
                case 26:
                case 27:
                case 28:
                case 29:
                case 30:
                case ' ':
                case '!':
                case '\"':
                case '#':
                case '&':
                case ')':
                case '-':
                case '1':
                case '5':
                case '6':
                case '7':
                case '9':
                    break;
                case '\f':
                    Float f = WXUtils.getFloat(param, Float.valueOf(1.0f));
                    if (f != null) {
                        setOpacity(f.floatValue());
                        break;
                    }
                    break;
                case '\r':
                case '%':
                case '\'':
                case '(':
                case '4':
                    Float f2 = WXUtils.getFloat(param, null);
                    if (f2 != null) {
                        setBorderRadius(key, f2.floatValue());
                    }
                    return true;
                case 15:
                    setAriaHidden(WXUtils.getBoolean(param, false).booleanValue());
                    return true;
                case 21:
                    setAriaLabel(WXUtils.getString(param, ""));
                    return true;
                case 31:
                    setRole(WXUtils.getString(param, ""));
                    return true;
                case '$':
                    Boolean bool = WXUtils.getBoolean(param, null);
                    if (bool != null) {
                        setDisabled(bool.booleanValue());
                        setPseudoClassStatus(Constants.PSEUDO.DISABLED, bool.booleanValue());
                    }
                    return true;
                case '*':
                    WXGesture wXGesture = this.mGesture;
                    if (wXGesture != null) {
                        wXGesture.setPreventMoveEvent(WXUtils.getBoolean(param, false).booleanValue());
                    }
                    return true;
                case '.':
                    try {
                        getHostView();
                    } catch (Throwable th) {
                        th.printStackTrace();
                    }
                    return true;
                case '/':
                    setFixedSize(WXUtils.getString(param, PROP_FS_MATCH_PARENT));
                    return true;
                case '0':
                    String string3 = WXUtils.getString(param, null);
                    if (string3 != null) {
                        setSticky(string3);
                    }
                    return true;
                case '2':
                    String string4 = WXUtils.getString(param, null);
                    if (string4 != null) {
                        setBackgroundColor(string4);
                    }
                    return true;
                case '3':
                    String string5 = WXUtils.getString(param, null);
                    if (string5 != null && this.mHost != null) {
                        setBackgroundImage(string5);
                    }
                    return true;
                case '8':
                    String string6 = WXUtils.getString(param, null);
                    if (string6 != null) {
                        setVisibility(string6);
                    }
                    return true;
                default:
                    return false;
            }
            return true;
        }
        return true;
    }

    @WXComponentProp(name = Constants.Name.ELEVATION)
    public void setElevation(String str) {
        initElevation(str);
    }

    protected void initElevation(String str) {
        if (TextUtils.isEmpty(str) || Build.VERSION.SDK_INT <= 20) {
            return;
        }
        this.mElevation = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(str, Float.valueOf(0.0f)).floatValue(), this.mInstance.getInstanceViewPortWidthWithFloat());
        if (this.mBoxShadowData != null) {
            clearBoxShadow();
        }
        if (Build.VERSION.SDK_INT == 21) {
            getHostView().setElevation(this.mElevation);
            return;
        }
        StateListAnimator stateListAnimator = new StateListAnimator();
        AnimatorSet animatorSet = new AnimatorSet();
        animatorSet.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
        animatorSet.setInterpolator(new FastOutLinearInInterpolator());
        stateListAnimator.addState(this.PRESSED_ENABLED_STATE_SET, animatorSet);
        AnimatorSet animatorSet2 = new AnimatorSet();
        animatorSet2.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
        animatorSet2.setInterpolator(new FastOutLinearInInterpolator());
        stateListAnimator.addState(this.FOCUSED_ENABLED_STATE_SET, animatorSet2);
        AnimatorSet animatorSet3 = new AnimatorSet();
        ArrayList arrayList = new ArrayList();
        arrayList.add(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, this.mElevation).setDuration(0L));
        if (Build.VERSION.SDK_INT >= 22 && Build.VERSION.SDK_INT <= 24) {
            arrayList.add(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, getHostView().getTranslationZ()).setDuration(this.PRESSED_ANIM_DELAY));
        }
        arrayList.add(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(this.PRESSED_ANIM_DURATION));
        animatorSet3.playSequentially((Animator[]) arrayList.toArray(new ObjectAnimator[0]));
        animatorSet3.setInterpolator(new FastOutLinearInInterpolator());
        stateListAnimator.addState(this.ENABLED_STATE_SET, animatorSet3);
        AnimatorSet animatorSet4 = new AnimatorSet();
        animatorSet4.play(ObjectAnimator.ofFloat(getHostView(), Constants.Name.ELEVATION, 0.0f).setDuration(0L)).with(ObjectAnimator.ofFloat(getHostView(), View.TRANSLATION_Z, 0.0f).setDuration(0L));
        animatorSet4.setInterpolator(new FastOutLinearInInterpolator());
        stateListAnimator.addState(this.EMPTY_STATE_SET, animatorSet4);
        getHostView().setStateListAnimator(stateListAnimator);
    }

    protected BorderDrawable getOrCreateBorder() {
        if (this.mBackgroundDrawable == null) {
            this.mBackgroundDrawable = new BorderDrawable();
            T t = this.mHost;
            if (t != null) {
                WXViewUtils.setBackGround(t, null, this);
                if (this.mRippleBackground == null) {
                    if (this.mBoxShadowDrawable != null) {
                        WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mBoxShadowDrawable, this.mBackgroundDrawable}), this);
                    } else if (this.mInsetBoxShadowDrawable != null) {
                        WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mBackgroundDrawable, this.mInsetBoxShadowDrawable}), this);
                    } else {
                        WXViewUtils.setBackGround(this.mHost, this.mBackgroundDrawable, this);
                    }
                } else if (this.mBoxShadowDrawable != null) {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBoxShadowDrawable, this.mBackgroundDrawable}), this);
                } else if (this.mInsetBoxShadowDrawable != null) {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable}), this);
                } else {
                    WXViewUtils.setBackGround(this.mHost, new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable}), this);
                }
            }
        }
        return this.mBackgroundDrawable;
    }

    public void setSafeLayout(WXComponent component) {
        if (TextUtils.isEmpty(component.getComponentType()) || TextUtils.isEmpty(component.getRef()) || component.getLayoutPosition() == null || component.getLayoutSize() == null) {
            return;
        }
        setLayout(component);
    }

    public void setLayout(WXComponent component) {
        int top;
        int left;
        setLayoutSize(component.getLayoutSize());
        setLayoutPosition(component.getLayoutPosition());
        setPaddings(component.getPadding());
        setMargins(component.getMargin());
        setBorders(component.getBorder());
        boolean isLayoutRTL = component.isLayoutRTL();
        setIsLayoutRTL(isLayoutRTL);
        if (isLayoutRTL != component.isLastLayoutDirectionRTL) {
            component.isLastLayoutDirectionRTL = isLayoutRTL;
            layoutDirectionDidChanged(isLayoutRTL);
        }
        try {
            if (getLayoutSize().getWidth() != 0.0f && getLayoutSize().getHeight() != 0.0f) {
                parseAnimation();
            }
        } catch (Exception unused) {
        }
        boolean z = this.mParent == null;
        int childrenLayoutTopOffset = z ? 0 : this.mParent.getChildrenLayoutTopOffset();
        CSSShorthand cSSShorthand = z ? new CSSShorthand() : this.mParent.getPadding();
        CSSShorthand cSSShorthand2 = z ? new CSSShorthand() : this.mParent.getBorder();
        int width = (int) getLayoutSize().getWidth();
        int height = (int) getLayoutSize().getHeight();
        if (isFixed()) {
            left = (int) (getLayoutPosition().getLeft() - getInstance().getRenderContainerPaddingLeft());
            top = ((int) (getLayoutPosition().getTop() - getInstance().getRenderContainerPaddingTop())) + childrenLayoutTopOffset;
        } else {
            top = ((int) ((getLayoutPosition().getTop() - cSSShorthand.get(CSSShorthand.EDGE.TOP)) - cSSShorthand2.get(CSSShorthand.EDGE.TOP))) + childrenLayoutTopOffset;
            left = (int) ((getLayoutPosition().getLeft() - cSSShorthand.get(CSSShorthand.EDGE.LEFT)) - cSSShorthand2.get(CSSShorthand.EDGE.LEFT));
        }
        int i = (int) getMargin().get(CSSShorthand.EDGE.RIGHT);
        int i2 = (int) getMargin().get(CSSShorthand.EDGE.BOTTOM);
        Point point = new Point((int) getLayoutPosition().getLeft(), (int) getLayoutPosition().getTop());
        if (this.mPreRealWidth == width && this.mPreRealHeight == height && this.mPreRealLeft == left && this.mPreRealRight == i && this.mPreRealTop == top) {
            return;
        }
        if ((this instanceof WXCell) && height >= WXPerformance.VIEW_LIMIT_HEIGHT && width >= WXPerformance.VIEW_LIMIT_WIDTH) {
            this.mInstance.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_CELL_EXCEED_NUM, 1.0d);
            this.mInstance.getWXPerformance().cellExceedNum++;
        }
        this.mAbsoluteY = (int) (z ? 0.0f : this.mParent.getAbsoluteY() + getCSSLayoutTop());
        this.mAbsoluteX = (int) (z ? 0.0f : this.mParent.getAbsoluteX() + getCSSLayoutLeft());
        T t = this.mHost;
        if (t == null) {
            return;
        }
        if (!(t instanceof ViewGroup) && this.mAbsoluteY + height > this.mInstance.getWeexHeight() + 1) {
            if (!this.mInstance.mEnd) {
                this.mInstance.onOldFsRenderTimeLogic();
            }
            if (!this.mInstance.isNewFsEnd) {
                this.mInstance.isNewFsEnd = true;
                this.mInstance.getApmForInstance().arriveNewFsRenderTime();
            }
        }
        MeasureOutput measure = measure(width, height);
        setComponentLayoutParams(measure.width, measure.height, left, top, i, i2, point);
    }

    private void setComponentLayoutParams(int realWidth, int realHeight, int realLeft, int realTop, int realRight, int realBottom, Point rawOffset) {
        int i;
        int i2;
        int i3;
        int i4;
        Widget androidViewWidget;
        if (getInstance() == null || getInstance().isDestroy()) {
            return;
        }
        updateBoxShadow(realWidth, realHeight, false);
        UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
        if (uniBoxShadowData == null || uniBoxShadowData.getNormalShadows().size() <= 0) {
            i = realWidth;
            i2 = realHeight;
            i3 = realLeft;
            i4 = realTop;
        } else {
            int normalMaxWidth = this.mBoxShadowData.getNormalMaxWidth();
            i = normalMaxWidth;
            i2 = this.mBoxShadowData.getNormalMaxHeight();
            i3 = realLeft - (this.mBoxShadowData.getNormalLeft() / 2);
            i4 = realTop - (this.mBoxShadowData.getNormalTop() / 2);
        }
        FlatGUIContext flatUIContext = getInstance().getFlatUIContext();
        if (flatUIContext != null && flatUIContext.getFlatComponentAncestor(this) != null) {
            if (this instanceof FlatComponent) {
                FlatComponent flatComponent = (FlatComponent) this;
                if (!flatComponent.promoteToView(true)) {
                    androidViewWidget = flatComponent.getOrCreateFlatWidget();
                    setWidgetParams(androidViewWidget, flatUIContext, rawOffset, i, i2, i3, realRight, i4, realBottom);
                }
            }
            androidViewWidget = flatUIContext.getAndroidViewWidget(this);
            setWidgetParams(androidViewWidget, flatUIContext, rawOffset, i, i2, i3, realRight, i4, realBottom);
        } else if (this.mHost != null) {
            if (isFixed()) {
                setFixedHostLayoutParams(this.mHost, i, i2, i3, realRight, i4, realBottom);
            } else {
                setHostLayoutParams(this.mHost, i, i2, i3, realRight, i4, realBottom);
            }
            recordInteraction(realWidth, realHeight);
            this.mPreRealWidth = realWidth;
            this.mPreRealHeight = realHeight;
            this.mPreRealLeft = realLeft;
            this.mPreRealRight = realRight;
            this.mPreRealTop = realTop;
            onFinishLayout();
        }
    }

    private void recordInteraction(int realWidth, int realHeight) {
        if (this.mIsAddElementToTree) {
            boolean z = false;
            this.mIsAddElementToTree = false;
            if (this.mParent == null) {
                this.interactionAbsoluteX = 0;
                this.interactionAbsoluteY = 0;
            } else {
                float cSSLayoutTop = getCSSLayoutTop();
                float cSSLayoutLeft = getCSSLayoutLeft();
                if (!isFixed()) {
                    cSSLayoutLeft += this.mParent.interactionAbsoluteX;
                }
                this.interactionAbsoluteX = (int) cSSLayoutLeft;
                if (!isFixed()) {
                    cSSLayoutTop += this.mParent.interactionAbsoluteY;
                }
                this.interactionAbsoluteY = (int) cSSLayoutTop;
            }
            if (getInstance().getApmForInstance().instanceRect == null) {
                getInstance().getApmForInstance().instanceRect = new Rect();
            }
            Rect rect = getInstance().getApmForInstance().instanceRect;
            rect.set(0, 0, this.mInstance.getWeexWidth(), this.mInstance.getWeexHeight());
            this.mInstance.onChangeElement(this, !((rect.contains(this.interactionAbsoluteX, this.interactionAbsoluteY) || rect.contains(this.interactionAbsoluteX + realWidth, this.interactionAbsoluteY) || rect.contains(this.interactionAbsoluteX, this.interactionAbsoluteY + realHeight) || rect.contains(this.interactionAbsoluteX + realWidth, this.interactionAbsoluteY + realHeight)) ? true : true));
        }
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Removed duplicated region for block: B:26:0x00ae  */
    /* JADX WARN: Removed duplicated region for block: B:30:? A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void setWidgetParams(Widget widget, FlatGUIContext UIImp, Point rawoffset, int width, int height, int left, int right, int top, int bottom) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        Point point = new Point();
        if (this.mParent != null) {
            if ((this.mParent instanceof FlatComponent) && UIImp.getFlatComponentAncestor(this.mParent) != null && UIImp.getAndroidViewWidget(this.mParent) == null) {
                point.set(rawoffset.x, rawoffset.y);
                i = left;
                i2 = top;
            } else {
                i = left;
                i2 = top;
                point.set(i, i2);
            }
            if ((this.mParent instanceof FlatComponent) && UIImp.getFlatComponentAncestor(this.mParent) != null && UIImp.getAndroidViewWidget(this.mParent) == null) {
                Point locInFlatContainer = ((FlatComponent) this.mParent).getOrCreateFlatWidget().getLocInFlatContainer();
                point.offset(locInFlatContainer.x, locInFlatContainer.y);
            }
            ViewGroup.LayoutParams childLayoutParams = this.mParent.getChildLayoutParams(this, this.mHost, width, height, left, right, top, bottom);
            if (childLayoutParams instanceof ViewGroup.MarginLayoutParams) {
                i3 = childLayoutParams.width;
                i4 = childLayoutParams.height;
                ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) childLayoutParams;
                int i7 = marginLayoutParams.leftMargin;
                i5 = marginLayoutParams.rightMargin;
                int i8 = marginLayoutParams.topMargin;
                i6 = marginLayoutParams.bottomMargin;
                i = i7;
                i2 = i8;
                widget.setLayout(i3, i4, i, i5, i2, i6, point);
                if (widget instanceof AndroidViewWidget) {
                    return;
                }
                AndroidViewWidget androidViewWidget = (AndroidViewWidget) widget;
                if (androidViewWidget.getView() != null) {
                    setHostLayoutParams(androidViewWidget.getView(), i3, i4, point.x, i5, point.y, i6);
                    return;
                }
                return;
            }
        } else {
            i = left;
            i2 = top;
        }
        i3 = width;
        i4 = height;
        i5 = right;
        i6 = bottom;
        widget.setLayout(i3, i4, i, i5, i2, i6, point);
        if (widget instanceof AndroidViewWidget) {
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setHostLayoutParams(T host, int width, int height, int left, int right, int top, int bottom) {
        FrameLayout.LayoutParams layoutParams;
        if (this.mParent == null) {
            FrameLayout.LayoutParams layoutParams2 = new FrameLayout.LayoutParams(width, height);
            setMarginsSupportRTL(layoutParams2, left, top, right, bottom);
            layoutParams = layoutParams2;
        } else {
            layoutParams = this.mParent.getChildLayoutParams(this, host, width, height, left, right, top, bottom);
        }
        if (layoutParams != null) {
            host.setLayoutParams(layoutParams);
        }
    }

    private void setFixedHostLayoutParams(T host, int width, int height, int left, int right, int top, int bottom) {
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-2, -2);
        layoutParams.width = width;
        layoutParams.height = height;
        setMarginsSupportRTL(layoutParams, left, top, right, bottom);
        host.setLayoutParams(layoutParams);
        this.mInstance.moveFixedView(host);
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("Weex_Fixed_Style", "WXComponent:setLayout :" + left + Operators.SPACE_STR + top + Operators.SPACE_STR + width + Operators.SPACE_STR + height);
            StringBuilder sb = new StringBuilder();
            sb.append("WXComponent:setLayout Left:");
            sb.append(getStyles().getLeft());
            sb.append(Operators.SPACE_STR);
            sb.append((int) getStyles().getTop());
            WXLogUtils.d("Weex_Fixed_Style", sb.toString());
        }
    }

    protected void updateBoxShadow(int width, int height, boolean isRender) {
        UniBoxShadowData parseBoxShadow;
        LayerDrawable layerDrawable;
        int top;
        int left;
        if (!UniBoxShadowUtil.isBoxShadowEnabled() || this.mElevation > 0.0f || getStyles().get(Constants.Name.ELEVATION) != null || getAttrs().get(Constants.Name.ELEVATION) != null) {
            WXLogUtils.w("BoxShadow", "box-shadow disabled");
            if (this.mBoxShadowData != null) {
                clearBoxShadow();
            }
        } else if (getStyles() != null) {
            Object obj = getStyles().get(Constants.Name.BOX_SHADOW);
            Object obj2 = getAttrs().get(Constants.Name.SHADOW_QUALITY);
            if (obj != null && width > 0 && height > 0) {
                float floatValue = WXUtils.getFloat(obj2, Float.valueOf(0.5f)).floatValue();
                float instanceViewPortWidthWithFloat = getInstance().getInstanceViewPortWidthWithFloat();
                float[] fArr = {0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
                WXStyle styles = getStyles();
                if (styles != null) {
                    float floatValue2 = WXUtils.getFloat(styles.get(Constants.Name.BORDER_TOP_LEFT_RADIUS), Float.valueOf(0.0f)).floatValue();
                    fArr[0] = WXViewUtils.getRealSubPxByWidth(floatValue2, instanceViewPortWidthWithFloat);
                    fArr[1] = WXViewUtils.getRealSubPxByWidth(floatValue2, instanceViewPortWidthWithFloat);
                    float floatValue3 = WXUtils.getFloat(styles.get(Constants.Name.BORDER_TOP_RIGHT_RADIUS), Float.valueOf(0.0f)).floatValue();
                    fArr[2] = WXViewUtils.getRealSubPxByWidth(floatValue3, instanceViewPortWidthWithFloat);
                    fArr[3] = WXViewUtils.getRealSubPxByWidth(floatValue3, instanceViewPortWidthWithFloat);
                    float floatValue4 = WXUtils.getFloat(styles.get(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS), Float.valueOf(0.0f)).floatValue();
                    fArr[4] = WXViewUtils.getRealSubPxByWidth(floatValue4, instanceViewPortWidthWithFloat);
                    fArr[5] = WXViewUtils.getRealSubPxByWidth(floatValue4, instanceViewPortWidthWithFloat);
                    float floatValue5 = WXUtils.getFloat(styles.get(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS), Float.valueOf(0.0f)).floatValue();
                    fArr[6] = WXViewUtils.getRealSubPxByWidth(floatValue5, instanceViewPortWidthWithFloat);
                    fArr[7] = WXViewUtils.getRealSubPxByWidth(floatValue5, instanceViewPortWidthWithFloat);
                    if (styles.containsKey(Constants.Name.BORDER_RADIUS)) {
                        float floatValue6 = WXUtils.getFloat(styles.get(Constants.Name.BORDER_RADIUS), Float.valueOf(0.0f)).floatValue();
                        for (int i = 0; i < 8; i++) {
                            fArr[i] = WXViewUtils.getRealSubPxByWidth(floatValue6, instanceViewPortWidthWithFloat);
                        }
                    }
                }
                UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
                if ((uniBoxShadowData == null || !uniBoxShadowData.equalsUniBoxShadowData(obj.toString(), width, height, fArr)) && (parseBoxShadow = UniBoxShadowUtil.parseBoxShadow(width, height, obj.toString(), fArr, instanceViewPortWidthWithFloat, floatValue)) != null) {
                    this.mBoxShadowData = parseBoxShadow;
                    UniNormalBoxShadowDrawable normalBoxShadowDrawable = UniBoxShadowUtil.getNormalBoxShadowDrawable(parseBoxShadow, getContext().getResources());
                    UniInsetBoxShadowLayer insetBoxShadowDrawable = UniBoxShadowUtil.getInsetBoxShadowDrawable(parseBoxShadow);
                    if (normalBoxShadowDrawable == null && insetBoxShadowDrawable == null) {
                        return;
                    }
                    if (normalBoxShadowDrawable != null && parseBoxShadow != null && isRender && this.mHost != null) {
                        int normalMaxWidth = parseBoxShadow.getNormalMaxWidth();
                        int normalMaxHeight = parseBoxShadow.getNormalMaxHeight();
                        boolean z = this.mParent == null;
                        CSSShorthand cSSShorthand = z ? new CSSShorthand() : this.mParent.getPadding();
                        CSSShorthand cSSShorthand2 = z ? new CSSShorthand() : this.mParent.getBorder();
                        int childrenLayoutTopOffset = z ? 0 : this.mParent.getChildrenLayoutTopOffset();
                        if (isFixed()) {
                            left = (int) (getLayoutPosition().getLeft() - getInstance().getRenderContainerPaddingLeft());
                            top = ((int) (getLayoutPosition().getTop() - getInstance().getRenderContainerPaddingTop())) + childrenLayoutTopOffset;
                        } else {
                            top = ((int) ((getLayoutPosition().getTop() - cSSShorthand.get(CSSShorthand.EDGE.TOP)) - cSSShorthand2.get(CSSShorthand.EDGE.TOP))) + childrenLayoutTopOffset;
                            left = (int) ((getLayoutPosition().getLeft() - cSSShorthand.get(CSSShorthand.EDGE.LEFT)) - cSSShorthand2.get(CSSShorthand.EDGE.LEFT));
                        }
                        int i2 = (int) getMargin().get(CSSShorthand.EDGE.RIGHT);
                        int i3 = (int) getMargin().get(CSSShorthand.EDGE.BOTTOM);
                        int normalLeft = left - (parseBoxShadow.getNormalLeft() / 2);
                        int normalTop = top - (parseBoxShadow.getNormalTop() / 2);
                        if (isFixed()) {
                            setFixedHostLayoutParams(this.mHost, normalMaxWidth, normalMaxHeight, normalLeft, i2, normalTop, i3);
                        } else {
                            setHostLayoutParams(this.mHost, normalMaxWidth, normalMaxHeight, normalLeft, i2, normalTop, i3);
                        }
                        setPadding(getPadding(), getBorder());
                    }
                    if (this.mBackgroundDrawable != null) {
                        clearBoxShadow();
                        if (this.mRippleBackground == null) {
                            if (normalBoxShadowDrawable != null) {
                                layerDrawable = new LayerDrawable(new Drawable[]{normalBoxShadowDrawable, this.mBackgroundDrawable});
                            } else if (insetBoxShadowDrawable != null) {
                                layerDrawable = new LayerDrawable(new Drawable[]{this.mBackgroundDrawable, insetBoxShadowDrawable});
                            } else {
                                layerDrawable = new LayerDrawable(new Drawable[]{this.mBackgroundDrawable});
                            }
                        } else if (normalBoxShadowDrawable != null) {
                            layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, normalBoxShadowDrawable, this.mBackgroundDrawable});
                        } else if (insetBoxShadowDrawable != null) {
                            layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable, insetBoxShadowDrawable});
                        } else {
                            layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable});
                        }
                        WXViewUtils.setBackGround(getHostView(), layerDrawable, this);
                        this.mBoxShadowData = parseBoxShadow;
                        this.mBoxShadowDrawable = normalBoxShadowDrawable;
                        this.mInsetBoxShadowDrawable = insetBoxShadowDrawable;
                        this.mBackgroundDrawable.updateBoxShadowData(parseBoxShadow);
                        return;
                    }
                    clearBoxShadow();
                    this.mBoxShadowData = parseBoxShadow;
                    this.mBoxShadowDrawable = normalBoxShadowDrawable;
                    this.mInsetBoxShadowDrawable = insetBoxShadowDrawable;
                    getOrCreateBorder().updateBoxShadowData(parseBoxShadow);
                }
            }
        } else {
            WXLogUtils.w("Can not resolve styles");
        }
    }

    protected void clearBoxShadow() {
        if (!UniBoxShadowUtil.isBoxShadowEnabled()) {
            WXLogUtils.w("BoxShadow", "box-shadow disabled");
            return;
        }
        BorderDrawable borderDrawable = this.mBackgroundDrawable;
        if (borderDrawable != null) {
            borderDrawable.updateBoxShadowData(null);
        }
        if (getHostView() != null && this.mBackgroundDrawable != null && (getHostView().getBackground() instanceof LayerDrawable)) {
            if (this.mRippleBackground == null) {
                WXViewUtils.setBackGround(getHostView(), new LayerDrawable(new Drawable[]{this.mBackgroundDrawable}), this);
            } else {
                WXViewUtils.setBackGround(getHostView(), new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable}), this);
            }
        }
        if (this.mBoxShadowData != null) {
            this.mBoxShadowData = null;
        }
        UniNormalBoxShadowDrawable uniNormalBoxShadowDrawable = this.mBoxShadowDrawable;
        if (uniNormalBoxShadowDrawable != null) {
            if (uniNormalBoxShadowDrawable.getBitmap() != null) {
                this.mBoxShadowDrawable.getBitmap().recycle();
            }
            this.mBoxShadowDrawable = null;
        }
        if (this.mInsetBoxShadowDrawable != null) {
            this.mInsetBoxShadowDrawable = null;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void onFinishLayout() {
        Object obj = getStyles() != null ? getStyles().get(Constants.Name.BACKGROUND_IMAGE) : null;
        if (obj != null) {
            setBackgroundImage(obj.toString());
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public MeasureOutput measure(int width, int height) {
        MeasureOutput measureOutput = new MeasureOutput();
        int i = this.mFixedProp;
        if (i != 0) {
            measureOutput.width = i;
            measureOutput.height = this.mFixedProp;
        } else {
            measureOutput.width = width;
            measureOutput.height = height;
        }
        return measureOutput;
    }

    protected void setAriaHidden(boolean isHidden) {
        T hostView = getHostView();
        if (hostView == null || Build.VERSION.SDK_INT < 16) {
            return;
        }
        hostView.setImportantForAccessibility(isHidden ? 2 : 1);
    }

    protected void setAriaLabel(String label) {
        T hostView = getHostView();
        if (hostView != null) {
            hostView.setContentDescription(label);
        }
    }

    protected void setRole(final String roleKey) {
        T hostView = getHostView();
        if (hostView == null || TextUtils.isEmpty(roleKey)) {
            return;
        }
        IWXAccessibilityRoleAdapter accessibilityRoleAdapter = WXSDKManager.getInstance().getAccessibilityRoleAdapter();
        if (accessibilityRoleAdapter != null) {
            roleKey = accessibilityRoleAdapter.getRole(roleKey);
        }
        ViewCompat.setAccessibilityDelegate(hostView, new AccessibilityDelegateCompat() { // from class: com.taobao.weex.ui.component.WXComponent.5
            @Override // androidx.core.view.AccessibilityDelegateCompat
            public void onInitializeAccessibilityNodeInfo(View host, AccessibilityNodeInfoCompat info) {
                try {
                    super.onInitializeAccessibilityNodeInfo(host, info);
                    info.setRoleDescription(roleKey);
                } catch (Throwable unused) {
                    WXLogUtils.e("SetRole failed!");
                }
            }
        });
    }

    private void setFixedSize(String fixedSize) {
        ViewGroup.LayoutParams layoutParams;
        if (PROP_FS_MATCH_PARENT.equals(fixedSize)) {
            this.mFixedProp = -1;
        } else if (PROP_FS_WRAP_CONTENT.equals(fixedSize)) {
            this.mFixedProp = -2;
        } else {
            this.mFixedProp = 0;
            return;
        }
        T t = this.mHost;
        if (t == null || (layoutParams = t.getLayoutParams()) == null) {
            return;
        }
        layoutParams.height = this.mFixedProp;
        layoutParams.width = this.mFixedProp;
        this.mHost.setLayoutParams(layoutParams);
    }

    public View getRealView() {
        return this.mHost;
    }

    private boolean needGestureDetector(String type) {
        if (this.mHost != null) {
            for (WXGestureType.LowLevelGesture lowLevelGesture : WXGestureType.LowLevelGesture.values()) {
                if (type.equals(lowLevelGesture.toString())) {
                    return true;
                }
            }
            for (WXGestureType.HighLevelGesture highLevelGesture : WXGestureType.HighLevelGesture.values()) {
                if (type.equals(highLevelGesture.toString())) {
                    return true;
                }
            }
        }
        return WXGesture.isStopPropagation(type) || type.equals(ViewHover.VIEW_HOVER_EVENT) || isPreventGesture();
    }

    public Scrollable getParentScroller() {
        WXComponent<T> wXComponent = this;
        do {
            wXComponent = wXComponent.getParent();
            if (wXComponent == null) {
                return null;
            }
            if (wXComponent instanceof Scrollable) {
                return (Scrollable) wXComponent;
            }
        } while (!wXComponent.getRef().equals(ROOT));
        return null;
    }

    public Scrollable getFirstScroller() {
        if (this instanceof Scrollable) {
            return (Scrollable) this;
        }
        return null;
    }

    public WXVContainer getParent() {
        return this.mParent;
    }

    public final void createView() {
        if (isLazy()) {
            return;
        }
        createViewImpl();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void createViewImpl() {
        Context context = this.mContext;
        if (context != null) {
            T initComponentHostView = initComponentHostView(context);
            this.mHost = initComponentHostView;
            if (initComponentHostView == null && !isVirtualComponent()) {
                initView();
            }
            T t = this.mHost;
            if (t != null) {
                if (t.getId() == -1) {
                    this.mHost.setId(WXViewUtils.generateViewId());
                }
                ComponentObserver componentObserver = getInstance().getComponentObserver();
                if (componentObserver != null) {
                    componentObserver.onViewCreated(this, this.mHost);
                }
                invokePendingComponetMethod();
            }
            onHostViewInitialized(this.mHost);
            return;
        }
        WXLogUtils.e("createViewImpl", "Context is null");
    }

    private final void invokePendingComponetMethod() {
        if (this.mPendingComponetMethodQueue.size() > 0) {
            WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.ui.component.WXComponent.6
                @Override // java.lang.Runnable
                public void run() {
                    while (!WXComponent.this.mPendingComponetMethodQueue.isEmpty()) {
                        UniMethodData uniMethodData = (UniMethodData) WXComponent.this.mPendingComponetMethodQueue.poll();
                        if (uniMethodData != null) {
                            WXComponent.this.invoke(uniMethodData.getMethod(), uniMethodData.getArgs());
                        }
                    }
                }
            });
        }
    }

    @Deprecated
    protected void initView() {
        Context context = this.mContext;
        if (context != null) {
            T initComponentHostView = initComponentHostView(context);
            this.mHost = initComponentHostView;
            if (initComponentHostView != null) {
                invokePendingComponetMethod();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void onHostViewInitialized(T host) {
        AbsAnimationHolder absAnimationHolder = this.mAnimationHolder;
        if (absAnimationHolder != null) {
            absAnimationHolder.execute(this.mInstance, this);
        }
        setActiveTouchListener();
    }

    public T getHostView() {
        return this.mHost;
    }

    @Deprecated
    public View getView() {
        return this.mHost;
    }

    public int getAbsoluteY() {
        return this.mAbsoluteY;
    }

    public int getAbsoluteX() {
        return this.mAbsoluteX;
    }

    public void removeEvent(String type) {
        if (TextUtils.isEmpty(type)) {
            return;
        }
        if (type.equals(Constants.Event.LAYEROVERFLOW)) {
            removeLayerOverFlowListener(getRef());
        }
        if (getEvents() != null) {
            getEvents().remove(type);
        }
        Set<String> set = this.mAppendEvents;
        if (set != null) {
            set.remove(type);
        }
        Set<String> set2 = this.mGestureType;
        if (set2 != null) {
            set2.remove(type);
        }
        removeEventFromView(type);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void removeEventFromView(String type) {
        if (type.equals(Constants.Event.CLICK) && getRealView() != null && this.mHostClickListeners != null) {
            if (this.mClickEventListener == null) {
                this.mClickEventListener = new OnClickListenerImp();
            }
            this.mHostClickListeners.remove(this.mClickEventListener);
            if (this.mHostClickListeners.size() < 1) {
                getRealView().setOnClickListener(null);
                getRealView().setClickable(false);
            }
        }
        Scrollable parentScroller = getParentScroller();
        if (type.equals(Constants.Event.APPEAR) && parentScroller != null) {
            parentScroller.unbindAppearEvent(this);
        }
        if (!type.equals(Constants.Event.DISAPPEAR) || parentScroller == null) {
            return;
        }
        parentScroller.unbindDisappearEvent(this);
    }

    public void removeAllEvent() {
        if (getEvents().size() < 1) {
            return;
        }
        WXEvent events = getEvents();
        int size = events.size();
        for (int i = 0; i < size && i < events.size(); i++) {
            String str = (String) events.get(i);
            if (str != null) {
                removeEventFromView(str);
            }
        }
        Set<String> set = this.mAppendEvents;
        if (set != null) {
            set.clear();
        }
        Set<String> set2 = this.mGestureType;
        if (set2 != null) {
            set2.clear();
        }
        this.mGesture = null;
        if (getRealView() != null && (getRealView() instanceof WXGestureObservable)) {
            ((WXGestureObservable) getRealView()).registerGestureListener(null);
        }
        T t = this.mHost;
        if (t != null) {
            t.setOnFocusChangeListener(null);
            List<OnClickListener> list = this.mHostClickListeners;
            if (list == null || list.size() <= 0) {
                return;
            }
            this.mHostClickListeners.clear();
            this.mHost.setOnClickListener(null);
        }
    }

    public final void removeStickyStyle() {
        Scrollable parentScroller;
        if (!isSticky() || (parentScroller = getParentScroller()) == null) {
            return;
        }
        parentScroller.unbindStickStyle(this);
    }

    public boolean isSticky() {
        return getStyles().isSticky();
    }

    public boolean isFixed() {
        return getStyles().isFixed();
    }

    public void setDisabled(boolean disabled) {
        this.mIsDisabled = disabled;
        T t = this.mHost;
        if (t == null) {
            return;
        }
        t.setEnabled(!disabled);
    }

    public boolean isDisabled() {
        return this.mIsDisabled;
    }

    public void setSticky(String sticky) {
        Scrollable parentScroller;
        if (TextUtils.isEmpty(sticky) || !sticky.equals("sticky") || (parentScroller = getParentScroller()) == null) {
            return;
        }
        parentScroller.bindStickStyle(this);
    }

    public void setBackgroundColor(String color) {
        LayerDrawable layerDrawable;
        if (TextUtils.isEmpty(color)) {
            return;
        }
        int color2 = WXResourceUtils.getColor(color);
        if (isRippleEnabled() && Build.VERSION.SDK_INT >= 21) {
            Drawable prepareBackgroundRipple = prepareBackgroundRipple();
            this.mRippleBackground = prepareBackgroundRipple;
            if (prepareBackgroundRipple != null) {
                if (this.mBackgroundDrawable == null) {
                    WXViewUtils.setBackGround(this.mHost, prepareBackgroundRipple, this);
                    return;
                }
                if (this.mBoxShadowDrawable != null) {
                    layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBoxShadowDrawable, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable});
                } else if (this.mInsetBoxShadowDrawable != null) {
                    layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable, this.mInsetBoxShadowDrawable});
                } else {
                    layerDrawable = new LayerDrawable(new Drawable[]{this.mRippleBackground, this.mBackgroundDrawable});
                }
                WXViewUtils.setBackGround(this.mHost, layerDrawable, this);
                return;
            }
        }
        if (color2 == 0 && this.mBackgroundDrawable == null) {
            return;
        }
        getOrCreateBorder().setColor(color2);
    }

    private Drawable prepareBackgroundRipple() {
        int i;
        try {
            if (getStyles() != null && getStyles().getPesudoResetStyles() != null) {
                Map<String, Object> pesudoResetStyles = getStyles().getPesudoResetStyles();
                Object obj = pesudoResetStyles.get("backgroundColor");
                if (obj != null) {
                    i = WXResourceUtils.getColor(obj.toString(), 0);
                    if (i == 0) {
                        return null;
                    }
                } else {
                    i = 0;
                }
                Object obj2 = pesudoResetStyles.get("backgroundColor:active");
                if (obj2 == null) {
                    return null;
                }
                int color = WXResourceUtils.getColor(obj2.toString(), i);
                if (Build.VERSION.SDK_INT >= 21) {
                    return new RippleDrawable(new ColorStateList(new int[][]{new int[0]}, new int[]{color}), new ColorDrawable(i), null) { // from class: com.taobao.weex.ui.component.WXComponent.7
                        @Override // android.graphics.drawable.RippleDrawable, android.graphics.drawable.LayerDrawable, android.graphics.drawable.Drawable
                        public void draw(Canvas canvas) {
                            if (WXComponent.this.mBackgroundDrawable != null) {
                                canvas.clipPath(WXComponent.this.mBackgroundDrawable.getContentPath(new RectF(0.0f, 0.0f, canvas.getWidth(), canvas.getHeight())));
                            }
                            super.draw(canvas);
                        }
                    };
                }
            }
        } catch (Throwable th) {
            WXLogUtils.w("Exception on create ripple: ", th);
        }
        return null;
    }

    public void setBackgroundImage(String bgImage) {
        if ("".equals(bgImage.trim())) {
            getOrCreateBorder().setImage(null);
            return;
        }
        getOrCreateBorder().setImage(WXResourceUtils.getShader(bgImage, getLayoutSize().getWidth(), getLayoutSize().getHeight()));
    }

    private boolean shouldCancelHardwareAccelerate() {
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        boolean z = true;
        if (wxConfigAdapter != null) {
            try {
                z = Boolean.parseBoolean(wxConfigAdapter.getConfig("android_weex_test_gpu", "cancel_hardware_accelerate", AbsoluteConst.TRUE));
            } catch (Exception e) {
                WXLogUtils.e(WXLogUtils.getStackTrace(e));
            }
            WXLogUtils.i("cancel_hardware_accelerate : " + z);
        }
        return z;
    }

    public void setOpacity(float opacity) {
        if (opacity < 0.0f || opacity > 1.0f || this.mHost.getAlpha() == opacity) {
            return;
        }
        int openGLRenderLimitValue = WXRenderManager.getOpenGLRenderLimitValue();
        if (isLayerTypeEnabled()) {
            this.mHost.setLayerType(2, null);
        }
        if (isLayerTypeEnabled() && shouldCancelHardwareAccelerate() && openGLRenderLimitValue > 0) {
            float f = openGLRenderLimitValue;
            if (getLayoutHeight() > f || getLayoutWidth() > f) {
                this.mHost.setLayerType(0, null);
            }
        }
        this.mHost.setAlpha(opacity);
    }

    public void setBorderRadius(String key, float borderRadius) {
        if (borderRadius >= 0.0f) {
            key.hashCode();
            char c = 65535;
            switch (key.hashCode()) {
                case -1228066334:
                    if (key.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                        c = 0;
                        break;
                    }
                    break;
                case 333432965:
                    if (key.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                        c = 1;
                        break;
                    }
                    break;
                case 581268560:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                        c = 2;
                        break;
                    }
                    break;
                case 588239831:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                        c = 3;
                        break;
                    }
                    break;
                case 1349188574:
                    if (key.equals(Constants.Name.BORDER_RADIUS)) {
                        c = 4;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_LEFT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
                    return;
                case 1:
                    getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_TOP_RIGHT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
                    return;
                case 2:
                    getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_LEFT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
                    return;
                case 3:
                    getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.BORDER_BOTTOM_RIGHT, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
                    return;
                case 4:
                    getOrCreateBorder().setBorderRadius(CSSShorthand.CORNER.ALL, WXViewUtils.getRealSubPxByWidth(borderRadius, this.mInstance.getInstanceViewPortWidthWithFloat()));
                    return;
                default:
                    return;
            }
        }
    }

    private void initOutlineProvider(final float radius) {
        if (useFeature() && (getHostView() instanceof BaseFrameLayout)) {
            getHostView().setOutlineProvider(new ViewOutlineProvider() { // from class: com.taobao.weex.ui.component.WXComponent.8
                @Override // android.view.ViewOutlineProvider
                public void getOutline(View view, Outline outline) {
                    if (WXComponent.this.getInstance().isDestroy()) {
                        return;
                    }
                    int width = view.getWidth();
                    int height = view.getHeight();
                    if (width == 0 || height == 0 || !WXComponent.this.getOrCreateBorder().isRounded()) {
                        return;
                    }
                    Rect rect = new Rect(0, 0, width, height);
                    float f = width / (radius * 2.0f);
                    if (!Float.isNaN(f) && f < 1.0f) {
                        outline.setRoundRect(rect, f * radius);
                    } else {
                        outline.setRoundRect(rect, radius);
                    }
                }
            });
            getHostView().setClipToOutline(true);
        }
    }

    public boolean useFeature() {
        return Build.VERSION.SDK_INT >= 24;
    }

    public void setBorderWidth(String key, float borderWidth) {
        if (borderWidth >= 0.0f) {
            key.hashCode();
            char c = 65535;
            switch (key.hashCode()) {
                case -1971292586:
                    if (key.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                        c = 0;
                        break;
                    }
                    break;
                case -1452542531:
                    if (key.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                        c = 1;
                        break;
                    }
                    break;
                case -1290574193:
                    if (key.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                        c = 2;
                        break;
                    }
                    break;
                case -223992013:
                    if (key.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                        c = 3;
                        break;
                    }
                    break;
                case 741115130:
                    if (key.equals(Constants.Name.BORDER_WIDTH)) {
                        c = 4;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.RIGHT, borderWidth);
                    return;
                case 1:
                    getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.TOP, borderWidth);
                    return;
                case 2:
                    getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.BOTTOM, borderWidth);
                    return;
                case 3:
                    getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.LEFT, borderWidth);
                    return;
                case 4:
                    getOrCreateBorder().setBorderWidth(CSSShorthand.EDGE.ALL, borderWidth);
                    return;
                default:
                    return;
            }
        }
    }

    public void setBorderStyle(String key, String borderStyle) {
        if (TextUtils.isEmpty(borderStyle)) {
            return;
        }
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -1974639039:
                if (key.equals(Constants.Name.BORDER_RIGHT_STYLE)) {
                    c = 0;
                    break;
                }
                break;
            case -1455888984:
                if (key.equals(Constants.Name.BORDER_TOP_STYLE)) {
                    c = 1;
                    break;
                }
                break;
            case -1293920646:
                if (key.equals(Constants.Name.BORDER_BOTTOM_STYLE)) {
                    c = 2;
                    break;
                }
                break;
            case -227338466:
                if (key.equals(Constants.Name.BORDER_LEFT_STYLE)) {
                    c = 3;
                    break;
                }
                break;
            case 737768677:
                if (key.equals(Constants.Name.BORDER_STYLE)) {
                    c = 4;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.RIGHT, borderStyle);
                return;
            case 1:
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.TOP, borderStyle);
                return;
            case 2:
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.BOTTOM, borderStyle);
                return;
            case 3:
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.LEFT, borderStyle);
                return;
            case 4:
                getOrCreateBorder().setBorderStyle(CSSShorthand.EDGE.ALL, borderStyle);
                return;
            default:
                return;
        }
    }

    public void setBorderColor(String key, String borderColor) {
        int color;
        if (TextUtils.isEmpty(borderColor) || (color = WXResourceUtils.getColor(borderColor)) == Integer.MIN_VALUE) {
            return;
        }
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -1989576717:
                if (key.equals(Constants.Name.BORDER_RIGHT_COLOR)) {
                    c = 0;
                    break;
                }
                break;
            case -1470826662:
                if (key.equals(Constants.Name.BORDER_TOP_COLOR)) {
                    c = 1;
                    break;
                }
                break;
            case -1308858324:
                if (key.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                    c = 2;
                    break;
                }
                break;
            case -242276144:
                if (key.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                    c = 3;
                    break;
                }
                break;
            case 722830999:
                if (key.equals(Constants.Name.BORDER_COLOR)) {
                    c = 4;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.RIGHT, color);
                return;
            case 1:
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.TOP, color);
                return;
            case 2:
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.BOTTOM, color);
                return;
            case 3:
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.LEFT, color);
                return;
            case 4:
                getOrCreateBorder().setBorderColor(CSSShorthand.EDGE.ALL, color);
                return;
            default:
                return;
        }
    }

    public String getVisibility() {
        try {
            return (String) getStyles().get(Constants.Name.VISIBILITY);
        } catch (Exception unused) {
            return "visible";
        }
    }

    public void setVisibility(String visibility) {
        View realView = getRealView();
        if (realView != null) {
            if (TextUtils.equals(visibility, "visible")) {
                realView.setVisibility(0);
            } else if (TextUtils.equals(visibility, "hidden")) {
                realView.setVisibility(8);
            }
        }
    }

    private void updateElevation() {
        float elevation = getAttrs().getElevation(getInstance().getInstanceViewPortWidthWithFloat());
        if (Float.isNaN(elevation)) {
            return;
        }
        ViewCompat.setElevation(getHostView(), elevation);
    }

    @Override // com.taobao.weex.IWXActivityStateListener
    public void onActivityDestroy() {
        ConcurrentLinkedQueue<UniMethodData> concurrentLinkedQueue = this.mPendingComponetMethodQueue;
        if (concurrentLinkedQueue != null) {
            concurrentLinkedQueue.clear();
        }
    }

    public void recycled() {
        if (isFixed()) {
        }
    }

    public void destroy() {
        T hostView;
        if (getInstance() == null) {
            return;
        }
        clearBoxShadow();
        ComponentObserver componentObserver = getInstance().getComponentObserver();
        if (componentObserver != null) {
            componentObserver.onPreDestory(this);
        }
        if (WXEnvironment.isApkDebugable() && !WXUtils.isUiThread()) {
            throw new WXRuntimeException("[WXComponent] destroy can only be called in main thread");
        }
        T t = this.mHost;
        if (t != null && t.getLayerType() == 2 && isLayerTypeEnabled()) {
            this.mHost.setLayerType(0, null);
        }
        removeAllEvent();
        removeStickyStyle();
        if (isFixed() && (hostView = getHostView()) != null) {
            getInstance().removeFixedView(hostView);
        }
        ContentBoxMeasurement contentBoxMeasurement = this.contentBoxMeasurement;
        if (contentBoxMeasurement != null) {
            contentBoxMeasurement.destroy();
            this.contentBoxMeasurement = null;
        }
        this.mIsDestroyed = true;
        ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> concurrentLinkedQueue = this.animations;
        if (concurrentLinkedQueue != null) {
            concurrentLinkedQueue.clear();
        }
        ViewHover viewHover = this.mHover;
        if (viewHover != null) {
            viewHover.destroy();
            this.mHover = null;
        }
        this.mInstance = null;
        List<OnFocusChangeListener> list = this.mFocusChangeListeners;
        if (list != null) {
            list.clear();
        }
        List<OnClickListener> list2 = this.mHostClickListeners;
        if (list2 != null) {
            list2.clear();
        }
    }

    public boolean isDestoryed() {
        return this.mIsDestroyed;
    }

    public View detachViewAndClearPreInfo() {
        T t = this.mHost;
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealTop = 0;
        return t;
    }

    public void clearPreLayout() {
        this.mPreRealLeft = 0;
        this.mPreRealRight = 0;
        this.mPreRealWidth = 0;
        this.mPreRealHeight = 0;
        this.mPreRealTop = 0;
    }

    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        View realView = getRealView();
        pointF.set(realView.getScrollX(), realView.getScrollY());
    }

    public boolean containsGesture(WXGestureType WXGestureType) {
        Set<String> set = this.mGestureType;
        return set != null && set.contains(WXGestureType.toString());
    }

    public boolean containsEvent(String event) {
        Set<String> set;
        return getEvents().contains(event) || ((set = this.mAppendEvents) != null && set.contains(event));
    }

    public void notifyAppearStateChange(String wxEventType, String direction) {
        if (containsEvent(Constants.Event.APPEAR) || containsEvent(Constants.Event.DISAPPEAR)) {
            HashMap hashMap = new HashMap();
            hashMap.put("direction", direction);
            fireEvent(wxEventType, hashMap);
        }
    }

    public boolean isUsing() {
        return this.isUsing;
    }

    public void setUsing(boolean using) {
        this.isUsing = using;
    }

    public void readyToRender() {
        if (this.mParent == null || getInstance() == null || !getInstance().isTrackComponent()) {
            return;
        }
        this.mParent.readyToRender();
    }

    public boolean isVirtualComponent() {
        return this.mType == 1;
    }

    public int getType() {
        return this.mType;
    }

    public boolean hasScrollParent(WXComponent component) {
        if (component.getParent() == null) {
            return true;
        }
        if (component.getParent() instanceof WXBaseScroller) {
            return false;
        }
        return hasScrollParent(component.getParent());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x00d2, code lost:
        if (r5.equals(com.taobao.weex.common.Constants.Name.BORDER_RIGHT_COLOR) == false) goto L3;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public Object convertEmptyProperty(String propName, Object originalValue) {
        propName.hashCode();
        char c = 0;
        switch (propName.hashCode()) {
            case -1989576717:
                break;
            case -1971292586:
                if (propName.equals(Constants.Name.BORDER_RIGHT_WIDTH)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -1470826662:
                if (propName.equals(Constants.Name.BORDER_TOP_COLOR)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1452542531:
                if (propName.equals(Constants.Name.BORDER_TOP_WIDTH)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -1308858324:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_COLOR)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -1290574193:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_WIDTH)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -1228066334:
                if (propName.equals(Constants.Name.BORDER_TOP_LEFT_RADIUS)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case -242276144:
                if (propName.equals(Constants.Name.BORDER_LEFT_COLOR)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case -223992013:
                if (propName.equals(Constants.Name.BORDER_LEFT_WIDTH)) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 333432965:
                if (propName.equals(Constants.Name.BORDER_TOP_RIGHT_RADIUS)) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 581268560:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_LEFT_RADIUS)) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case 588239831:
                if (propName.equals(Constants.Name.BORDER_BOTTOM_RIGHT_RADIUS)) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 722830999:
                if (propName.equals(Constants.Name.BORDER_COLOR)) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case 741115130:
                if (propName.equals(Constants.Name.BORDER_WIDTH)) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case 1287124693:
                if (propName.equals("backgroundColor")) {
                    c = 14;
                    break;
                }
                c = 65535;
                break;
            case 1349188574:
                if (propName.equals(Constants.Name.BORDER_RADIUS)) {
                    c = 15;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
            case 2:
            case 4:
            case 7:
            case '\f':
                return "black";
            case 1:
            case 3:
            case 5:
            case 6:
            case '\b':
            case '\t':
            case '\n':
            case 11:
            case '\r':
            case 15:
                return 0;
            case 14:
                return "transparent";
            default:
                return originalValue;
        }
    }

    private void setActiveTouchListener() {
        View realView;
        if (!getStyles().getPesudoStyles().containsKey(Constants.PSEUDO.ACTIVE) || (realView = getRealView()) == null) {
            return;
        }
        realView.setOnTouchListener(new TouchActivePseudoListener(this, !isConsumeTouch()));
    }

    protected boolean isConsumeTouch() {
        List<OnClickListener> list = this.mHostClickListeners;
        return (list != null && list.size() > 0) || this.mGesture != null;
    }

    @Override // com.taobao.weex.ui.component.pesudo.OnActivePseudoListner
    public void updateActivePseudo(boolean isSet) {
        if (getInstance() != null) {
            setPseudoClassStatus(Constants.PSEUDO.ACTIVE, isSet);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setPseudoClassStatus(String clzName, boolean status) {
        WXStyle styles = getStyles();
        Map<String, Map<String, Object>> pesudoStyles = styles.getPesudoStyles();
        if (pesudoStyles == null || pesudoStyles.size() == 0) {
            return;
        }
        if (this.mPesudoStatus == null) {
            this.mPesudoStatus = new PesudoStatus();
        }
        Map<String, Object> updateStatusAndGetUpdateStyles = this.mPesudoStatus.updateStatusAndGetUpdateStyles(clzName, status, pesudoStyles, styles.getPesudoResetStyles());
        if (updateStatusAndGetUpdateStyles != null) {
            if (status) {
                this.mPseudoResetGraphicSize = new GraphicSize(getLayoutSize().getWidth(), getLayoutSize().getHeight());
                if (updateStatusAndGetUpdateStyles.keySet().contains("width")) {
                    getLayoutSize().setWidth(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(styles.getPesudoResetStyles().get("width:active")), getViewPortWidthForFloat()));
                } else if (updateStatusAndGetUpdateStyles.keySet().contains("height")) {
                    getLayoutSize().setHeight(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(styles.getPesudoResetStyles().get("height:active")), getViewPortWidthForFloat()));
                }
            } else {
                GraphicSize graphicSize = this.mPseudoResetGraphicSize;
                if (graphicSize != null) {
                    setLayoutSize(graphicSize);
                }
            }
        }
        updateStyleByPesudo(updateStatusAndGetUpdateStyles);
    }

    private void updateStyleByPesudo(Map<String, Object> styles) {
        if (getInstance() == null) {
            return;
        }
        new GraphicActionUpdateStyle(getInstance(), getRef(), styles, getPadding(), getMargin(), getBorder(), true).executeActionOnRender();
        if (getLayoutWidth() == 0.0f && getLayoutHeight() == 0.0f) {
            return;
        }
        if (styles.containsKey("width")) {
            WXBridgeManager.getInstance().setStyleWidth(getInstanceId(), getRef(), getLayoutWidth());
        } else if (styles.containsKey("height")) {
            WXBridgeManager.getInstance().setStyleHeight(getInstanceId(), getRef(), getLayoutHeight());
        }
    }

    public int getStickyOffset() {
        return this.mStickyOffset;
    }

    public boolean canRecycled() {
        return !(isFixed() && isSticky()) && getAttrs().canRecycled();
    }

    public void setStickyOffset(int stickyOffset) {
        this.mStickyOffset = stickyOffset;
    }

    public boolean isLayerTypeEnabled() {
        return getInstance().isLayerTypeEnabled();
    }

    public void setNeedLayoutOnAnimation(boolean need) {
        this.mNeedLayoutOnAnimation = need;
    }

    public void notifyNativeSizeChanged(int w, int h) {
        if (this.mNeedLayoutOnAnimation) {
            UniBoxShadowData uniBoxShadowData = this.mBoxShadowData;
            if (uniBoxShadowData != null && uniBoxShadowData.getNormalShadows().size() > 0) {
                w -= this.mBoxShadowData.getNormalLeft();
                h -= this.mBoxShadowData.getNormalTop();
            }
            WXBridgeManager wXBridgeManager = WXBridgeManager.getInstance();
            wXBridgeManager.setStyleWidth(getInstanceId(), getRef(), w);
            wXBridgeManager.setStyleHeight(getInstanceId(), getRef(), h);
        }
    }

    public void onRenderFinish(int state) {
        if (WXTracing.isAvailable()) {
            double nanosToMillis = Stopwatch.nanosToMillis(this.mTraceInfo.uiThreadNanos);
            if (state == 2 || state == 0) {
                WXTracing.TraceEvent newEvent = WXTracing.newEvent("DomExecute", getInstanceId(), this.mTraceInfo.rootEventId);
                newEvent.ph = "X";
                newEvent.ts = this.mTraceInfo.domThreadStart;
                newEvent.tname = "DOMThread";
                newEvent.name = getComponentType();
                newEvent.classname = getClass().getSimpleName();
                if (getParent() != null) {
                    newEvent.parentRef = getParent().getRef();
                }
                newEvent.submit();
            }
            if (state == 2 || state == 1) {
                if (this.mTraceInfo.uiThreadStart != -1) {
                    WXTracing.TraceEvent newEvent2 = WXTracing.newEvent("UIExecute", getInstanceId(), this.mTraceInfo.rootEventId);
                    newEvent2.ph = "X";
                    newEvent2.duration = nanosToMillis;
                    newEvent2.ts = this.mTraceInfo.uiThreadStart;
                    newEvent2.name = getComponentType();
                    newEvent2.classname = getClass().getSimpleName();
                    if (getParent() != null) {
                        newEvent2.parentRef = getParent().getRef();
                    }
                    newEvent2.submit();
                } else if (WXEnvironment.isApkDebugable()) {
                    isLazy();
                }
            }
        }
    }

    protected boolean isRippleEnabled() {
        try {
            return WXUtils.getBoolean(getAttrs().get(Constants.Name.RIPPLE_ENABLED), false).booleanValue();
        } catch (Throwable unused) {
            return false;
        }
    }

    public boolean isWaste() {
        return this.waste;
    }

    public void setWaste(boolean waste) {
        if (this.waste != waste) {
            this.waste = waste;
            if (!WXBasicComponentType.RECYCLE_LIST.equals(getParent().getComponentType())) {
                NativeRenderObjectUtils.nativeRenderObjectChildWaste(getRenderObjectPtr(), waste);
            }
            if (waste) {
                getStyles().put(Constants.Name.VISIBILITY, (Object) "hidden");
                if (getHostView() == null) {
                    if (this.mLazy) {
                        return;
                    }
                    lazy(true);
                    return;
                }
                getHostView().setVisibility(8);
                return;
            }
            getStyles().put(Constants.Name.VISIBILITY, (Object) "visible");
            if (getHostView() == null) {
                if (this.mLazy) {
                    if (this.mParent != null && this.mParent.isLazy()) {
                        lazy(false);
                        return;
                    } else {
                        Statements.initLazyComponent(this, this.mParent);
                        return;
                    }
                }
                return;
            }
            getHostView().setVisibility(0);
        }
    }

    public String getViewTreeKey() {
        if (this.mViewTreeKey == null) {
            if (getParent() == null) {
                this.mViewTreeKey = hashCode() + "_" + getRef();
            } else {
                this.mViewTreeKey = hashCode() + "_" + getRef() + "_" + getParent().indexOf(this);
            }
        }
        return this.mViewTreeKey;
    }

    public WXTransition getTransition() {
        return this.mTransition;
    }

    public void setTransition(WXTransition transition) {
        this.mTransition = transition;
    }

    public void addAnimationForElement(Map<String, Object> animMap) {
        if (animMap == null || animMap.isEmpty()) {
            return;
        }
        if (this.animations == null) {
            this.animations = new ConcurrentLinkedQueue<>();
        }
        this.animations.add(new Pair<>(getRef(), animMap));
    }

    private void parseAnimation() {
        WXAnimationBean createAnimationBean;
        ConcurrentLinkedQueue<Pair<String, Map<String, Object>>> concurrentLinkedQueue = this.animations;
        if (concurrentLinkedQueue == null) {
            return;
        }
        Iterator<Pair<String, Map<String, Object>>> it = concurrentLinkedQueue.iterator();
        while (it.hasNext()) {
            Pair<String, Map<String, Object>> next = it.next();
            if (!TextUtils.isEmpty((CharSequence) next.first) && (createAnimationBean = createAnimationBean((String) next.first, (Map) next.second)) != null) {
                new GraphicActionAnimation(getInstance(), getRef(), createAnimationBean).executeAction();
            }
        }
        this.animations.clear();
    }

    private WXAnimationBean createAnimationBean(String ref, Map<String, Object> style) {
        if (style != null) {
            try {
                Object obj = style.get("transform");
                if ((obj instanceof String) && !TextUtils.isEmpty((String) obj)) {
                    String str = (String) style.get(Constants.Name.TRANSFORM_ORIGIN);
                    WXAnimationBean wXAnimationBean = new WXAnimationBean();
                    int layoutWidth = (int) getLayoutWidth();
                    int layoutHeight = (int) getLayoutHeight();
                    wXAnimationBean.styles = new WXAnimationBean.Style();
                    wXAnimationBean.styles.init(str, (String) obj, layoutWidth, layoutHeight, WXSDKManager.getInstanceViewPortWidth(getInstanceId()), getInstance());
                    return wXAnimationBean;
                }
            } catch (RuntimeException e) {
                WXLogUtils.e("", e);
            }
        }
        return null;
    }

    public void lazy(boolean lazy) {
        this.mLazy = lazy;
    }

    public long getRenderObjectPtr() {
        if (getBasicComponentData().isRenderPtrEmpty()) {
            getBasicComponentData().setRenderObjectPr(NativeRenderObjectUtils.nativeGetRenderObject(getInstanceId(), getRef()));
        }
        return getBasicComponentData().getRenderObjectPr();
    }

    public void updateNativeAttr(String key, Object value) {
        if (key == null) {
            return;
        }
        if (value == null) {
            value = "";
        }
        getBasicComponentData().getAttrs().put(key, value);
        NativeRenderObjectUtils.nativeUpdateRenderObjectAttr(getRenderObjectPtr(), key, value.toString());
    }

    public void nativeUpdateAttrs(Map<String, Object> dynamic) {
        for (Map.Entry<String, Object> entry : dynamic.entrySet()) {
            if (entry.getKey() != null) {
                updateNativeAttr(entry.getKey(), entry.getValue());
            }
        }
    }

    public void updateNativeStyle(String key, Object value) {
        if (key == null) {
            return;
        }
        if (value == null) {
            value = "";
        }
        getBasicComponentData().getStyles().put(key, value);
        NativeRenderObjectUtils.nativeUpdateRenderObjectStyle(getRenderObjectPtr(), key, value.toString());
    }

    public void updateNativeStyles(Map<String, Object> dynamic) {
        for (Map.Entry<String, Object> entry : dynamic.entrySet()) {
            if (entry.getKey() != null) {
                updateNativeStyle(entry.getKey(), entry.getValue());
            }
        }
    }

    public void addLayerOverFlowListener(String ref) {
        if (getInstance() != null) {
            getInstance().addLayerOverFlowListener(ref);
        }
    }

    public void removeLayerOverFlowListener(String ref) {
        if (getInstance() != null) {
            getInstance().removeLayerOverFlowListener(ref);
        }
    }

    @WXComponentProp(name = "hoverClass")
    public void hoverClass(String m) {
        JSONObject parseObject = JSON.parseObject(m);
        if (parseObject != null) {
            ViewHover viewHover = this.mHover;
            if (viewHover == null) {
                this.mHover = new ViewHover(this, parseObject);
            } else {
                viewHover.update(parseObject);
            }
            if (getEvents().contains(ViewHover.VIEW_HOVER_EVENT)) {
                return;
            }
            addEvent(ViewHover.VIEW_HOVER_EVENT);
        }
    }

    @WXComponentProp(name = "hoverStopPropagation")
    public void hoverStopPropagation(boolean is) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStopPropagation(is);
        if (!getEvents().contains(ViewHover.VIEW_HOVER_EVENT)) {
            addEvent(ViewHover.VIEW_HOVER_EVENT);
        }
        if (this.mParent == null || !is) {
            return;
        }
        this.mParent.setHoverReceiveTouch(false);
    }

    @WXComponentProp(name = "hoverStartTime")
    public void hoverStartTime(int n) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStartTime(n);
    }

    @WXComponentProp(name = "hoverStayTime")
    public void hoverStayTime(int n) {
        if (this.mHover == null) {
            this.mHover = new ViewHover(this);
        }
        this.mHover.setHoverStayTime(n);
    }

    public void setHoverClassStatus(boolean status) {
        Map<String, Object> updateStatusAndGetUpdateStyles = this.mHover.updateStatusAndGetUpdateStyles(status);
        if (updateStatusAndGetUpdateStyles != null) {
            if (status) {
                boolean contains = updateStatusAndGetUpdateStyles.keySet().contains("width");
                boolean contains2 = updateStatusAndGetUpdateStyles.keySet().contains("height");
                if (contains || contains2) {
                    this.mPseudoResetGraphicSize = new GraphicSize(getLayoutSize().getWidth(), getLayoutSize().getHeight());
                }
                if (contains) {
                    getLayoutSize().setWidth(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(updateStatusAndGetUpdateStyles.get("width")), getViewPortWidthForFloat()));
                } else if (contains2) {
                    getLayoutSize().setHeight(WXViewUtils.getRealPxByWidth(WXUtils.parseFloat(updateStatusAndGetUpdateStyles.get("height")), getViewPortWidthForFloat()));
                }
            } else {
                GraphicSize graphicSize = this.mPseudoResetGraphicSize;
                if (graphicSize != null) {
                    setLayoutSize(graphicSize);
                }
            }
        }
        updateStyleByPesudo(updateStatusAndGetUpdateStyles);
    }

    public void setHoverReceiveTouch(boolean receiveTouch) {
        if (getHover() != null) {
            getHover().setReceiveTouch(receiveTouch);
        }
        if (this.mParent != null) {
            this.mParent.setHoverReceiveTouch(receiveTouch);
        }
    }

    public ViewHover getHover() {
        return this.mHover;
    }

    public boolean isPreventGesture() {
        return this.isPreventGesture;
    }

    @WXComponentProp(name = "preventGesture")
    public void setPreventGesture(boolean enable) {
        this.isPreventGesture = enable;
        addEvent("preventGesture");
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public float getViewPortWidthForFloat() {
        if (getInstance() != null) {
            return getInstance().getInstanceViewPortWidthWithFloat();
        }
        return 720.0f;
    }
}
