package io.dcloud.feature.weex;

import android.app.Application;
import android.content.Context;
import android.content.Intent;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.view.ViewGroup;
import com.alibaba.android.bindingx.plugin.weex.BindingX;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.taobao.weex.IWXStatisticsListener;
import com.taobao.weex.InitConfig;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.RenderTypes;
import com.taobao.weex.common.WXConfig;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.ui.IFComponentHolder;
import com.taobao.weex.ui.SimpleComponentHolder;
import com.taobao.weex.ui.component.WXBasicComponentType;
import com.taobao.weex.utils.tools.TimeCalculator;
import io.dcloud.common.DHInterface.AbsMgr;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.DHInterface.ICallBack;
import io.dcloud.common.DHInterface.IConfusionMgr;
import io.dcloud.common.DHInterface.IMgr;
import io.dcloud.common.DHInterface.INativeAppInfo;
import io.dcloud.common.DHInterface.IUniInstanceMgr;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.io.DHFile;
import io.dcloud.common.adapter.io.UnicodeInputStream;
import io.dcloud.common.adapter.ui.webview.WebLoadEvent;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.MessageHandler;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.BaseInfo;
import io.dcloud.common.util.IOUtil;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.language.LanguageUtil;
import io.dcloud.feature.internal.sdk.SDK;
import io.dcloud.feature.uniapp.UniMoudlesLoader;
import io.dcloud.feature.uniapp.UniSDKInstance;
import io.dcloud.feature.weex.adapter.DCDefaultConfigAdapter;
import io.dcloud.feature.weex.adapter.DCVueBridgeAdapter;
import io.dcloud.feature.weex.adapter.DCWXHttpAdapter;
import io.dcloud.feature.weex.adapter.DefaultWebSocketAdapterFactory;
import io.dcloud.feature.weex.adapter.Fresco.DCGenericDraweeView;
import io.dcloud.feature.weex.adapter.Fresco.imagepipeline.OkHttpImagePipelineConfigFactory;
import io.dcloud.feature.weex.adapter.FrescoDrawableLoader;
import io.dcloud.feature.weex.adapter.FrescoImageAdapter;
import io.dcloud.feature.weex.adapter.FrescoImageComponent;
import io.dcloud.feature.weex.adapter.FrescoImageComponentU;
import io.dcloud.feature.weex.adapter.JSExceptionAdapter;
import io.dcloud.feature.weex.adapter.PlusUriAdapter;
import io.dcloud.feature.weex.adapter.ScalableViewComponent;
import io.dcloud.feature.weex.adapter.webview.WXDCWeb;
import io.dcloud.feature.weex.extend.DCCoverImageComponent;
import io.dcloud.feature.weex.extend.DCCoverViewComponent;
import io.dcloud.feature.weex.extend.DCTabBarModule;
import io.dcloud.feature.weex.extend.DCUniMPModule;
import io.dcloud.feature.weex.extend.DCWXSlider;
import io.dcloud.feature.weex.extend.DCWXView;
import io.dcloud.feature.weex.extend.PlusModule;
import io.dcloud.feature.weex.extend.PlusStorageModule;
import io.dcloud.feature.weex.extend.RandomBytesModule;
import io.dcloud.feature.weex.extend.WXEventModule;
import io.dcloud.feature.weex_websocket.UniWebSocketModule;
import io.dcloud.weex.MoudlesLoader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Locale;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public class WeexInstanceMgr implements IWXStatisticsListener, IUniInstanceMgr {
    static final String SERVICE_NAME = "weexPlus";
    private static WeexInstanceMgr instance;
    private AbsMgr featureMgr;
    private IConfusionMgr mConfusionMgr;
    private Handler mHandler;
    private ICallBack mRestartReadyCall;
    private StringBuffer sb;
    String TAG = "WeexInstanceMgr";
    private LinkedHashMap<String, WXViewWrapper> instanceHashMap = new LinkedHashMap<>(16);
    private HashMap<String, WXServiceWrapper> serviceWrapperMapsCache = new HashMap<>(3);
    private ArrayList<IWXStatisticsCallBack> callBacks = new ArrayList<>();
    private String mUniNViewModules = null;
    private ArrayList<ICallBack> mReladyCallBacks = new ArrayList<>();
    private String complier = "weex";
    private String render = "auto";
    private String jsSACName = "uni-app-config";
    private String control = AbsoluteConst.UNI_V3;
    private int mVueVersion = 2;
    private boolean isWeexInitEnd = false;
    private boolean isJsFrameworkReady = false;
    private Application mApplication = null;
    private boolean isAssetsRes = false;
    private boolean isJSFKFileNotFound = false;
    private boolean isUniServiceCreated = false;
    private String mPreUniAppid = null;
    private String mPreInstanceId = null;
    private Map<String, ICallBack> mPreUniMPCallBackMap = new HashMap();

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public interface EachListener<T> {
        void onEach(T t);
    }

    /* loaded from: classes.dex */
    public interface IWXStatisticsCallBack {
        void onJsFrameworkReady();
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onException(String instanceid, String errCode, String msg) {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onFirstScreen() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onFirstView() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHeadersReceived() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHttpFinish() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onHttpStart() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onJsFrameworkStart() {
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onSDKEngineInitialize() {
    }

    public static synchronized WeexInstanceMgr self() {
        WeexInstanceMgr weexInstanceMgr;
        synchronized (WeexInstanceMgr.class) {
            if (instance == null) {
                instance = new WeexInstanceMgr();
            }
            weexInstanceMgr = instance;
        }
        return weexInstanceMgr;
    }

    public void setUniNViewModules(String modules) {
        this.mUniNViewModules = modules;
        if (this.mReladyCallBacks.size() > 0) {
            Iterator<ICallBack> it = this.mReladyCallBacks.iterator();
            while (it.hasNext()) {
                it.next().onCallBack(0, modules);
            }
            this.mReladyCallBacks.clear();
        }
    }

    public String getUniNViewModules() {
        return this.mUniNViewModules;
    }

    public void setUniNViewModuleReladyCallBack(ICallBack callBack) {
        if (this.mReladyCallBacks.contains(callBack)) {
            return;
        }
        this.mReladyCallBacks.add(callBack);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void init(AbsMgr featureMgr) {
        this.featureMgr = featureMgr;
    }

    public String getUniMPFeature() {
        return "UniMP".toLowerCase(Locale.ENGLISH);
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void initWeexEnv(INativeAppInfo info) {
        if (info != null) {
            this.mConfusionMgr = info.getCofusionMgr();
            initWeexEnv(info.getApplication());
        }
    }

    public void initWeexEnv(Application application) {
        if (!SDK.isUniMPSDK()) {
            PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "registerReloadReceiver", null, new Class[]{Application.class}, new Object[]{application});
        }
        self().setApplication(application);
        if (WXSDKEngine.isInitialized()) {
            return;
        }
        InitConfig.Builder builder = new InitConfig.Builder();
        self().initAppForPath(application, null);
        self().initJSFramework(application, null);
        if (!SDK.isUniMPSDK()) {
            PlatformUtil.invokeMethod("io.dcloud.feature.weex.WeexDevtoolImpl", "initDebugEnvironment", null, new Class[]{Application.class}, new Object[]{application});
        }
        DCWXHttpAdapter dCWXHttpAdapter = new DCWXHttpAdapter();
        builder.setHttpAdapter(dCWXHttpAdapter);
        Fresco.initialize(application, OkHttpImagePipelineConfigFactory.newBuilder(application, dCWXHttpAdapter.getImageOkHttpClient()).build());
        JSON.setDefaultTypeKey("@type_ft");
        DCGenericDraweeView.initialize(Fresco.getDraweeControllerBuilderSupplier());
        builder.setImgAdapter(new FrescoImageAdapter());
        builder.setDrawableLoader(new FrescoDrawableLoader(application));
        builder.setURIAdapter(new PlusUriAdapter());
        builder.setDCVueBridgeAdapter(new DCVueBridgeAdapter());
        builder.setWebSocketAdapterFactory(new DefaultWebSocketAdapterFactory());
        builder.setJSExceptionAdapter(new JSExceptionAdapter());
        InitConfig build = builder.build();
        WXSDKManager.getInstance().setWxConfigAdapter(new DCDefaultConfigAdapter());
        WXSDKEngine.initialize(application, build);
        self().initStatisticsListener();
        try {
            String str = new String(PlatformUtil.getFileContent("io/dcloud/weexUniJs.js", 1));
            this.sb = new StringBuffer();
            String configParam = self().getConfigParam();
            StringBuffer stringBuffer = this.sb;
            stringBuffer.append("var plusContext = {};plusContext.getLocationHerf = function(plus){\n    return plus.weex.config.bundleUrl;\n};var param = " + configParam + ";");
            this.sb.append(str);
            WXSDKEngine.registerComponent("image", FrescoImageComponent.class);
            WXSDKEngine.registerComponent("cover-view", DCCoverViewComponent.class);
            WXSDKEngine.registerComponent("u-image", FrescoImageComponentU.class);
            WXSDKEngine.registerComponent("cover-image", DCCoverImageComponent.class);
            WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(ScalableViewComponent.class, new ScalableViewComponent.Ceator()), false, "u-scalable");
            WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(DCWXSlider.class, new DCWXSlider.Creator()), true, WXBasicComponentType.SLIDER);
            WXSDKEngine.registerComponent((IFComponentHolder) new SimpleComponentHolder(DCWXView.class, new DCWXView.Ceator()), false, WXBasicComponentType.VIEW);
            WXSDKEngine.registerComponent("u-web-view", WXDCWeb.class);
            WXSDKEngine.registerModule(IApp.ConfigProperty.CONFIG_PLUS, PlusModule.class);
            WXSDKEngine.registerModule("DCloud-Crypto", RandomBytesModule.class);
            WXSDKEngine.registerModule("plusstorage", PlusStorageModule.class);
            WXSDKEngine.registerModule("uni-tabview", DCTabBarModule.class);
            addComponentByName(WXBasicComponentType.DIV, ScalableViewComponent.class);
            if (PdrUtil.isUniMPHostForUniApp() && !SDK.isUniMPSDK()) {
                WXSDKEngine.registerModule("uniMP", DCUniMPModule.class);
            }
            WXSDKEngine.registerModule("event", WXEventModule.class);
            if (this.sb != null) {
                WXSDKEngine.registerService(SERVICE_NAME, this.sb.toString(), new HashMap());
            }
            if (!SDK.isUniMPSDK()) {
                self().registerUniappService(application, "");
            }
            WXEnvironment.setGlobalFontFamily("unincomponents", Typeface.createFromAsset(application.getAssets(), "fonts/unincomponents.ttf"));
            WXSDKEngine.registerModule("uni-webSocket", UniWebSocketModule.class);
            BindingX.register();
            registerReflexWeexPlugin(application);
            setWeexInitEnd(true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setApplication(Application mApplication) {
        this.mApplication = mApplication;
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void restartWeex(final Application application, final ICallBack callBack, final String appid) {
        if (((getControl().equals(AbsoluteConst.UNI_V3) && isWeexInitEnd() && !BaseInfo.isFirstRun) || (SDK.isUniMPSDK() && isWeexInitEnd())) && this.mPreInstanceId == null) {
            Logger.e(this.TAG, "restartWeex-------");
            if (this.instanceHashMap.size() > 0) {
                onActivityDestroy(false);
            }
            getHandler().post(new Runnable() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.1
                @Override // java.lang.Runnable
                public void run() {
                    WeexInstanceMgr.this.unRegisterUniappService();
                    WeexInstanceMgr.this.mRestartReadyCall = callBack;
                    WeexInstanceMgr.this.mApplication = application;
                    WeexInstanceMgr weexInstanceMgr = WeexInstanceMgr.this;
                    weexInstanceMgr.initAppForPath(weexInstanceMgr.mApplication, appid);
                    WeexInstanceMgr.this.setJsFrameworkReady(false);
                    WeexInstanceMgr.this.initJSFramework(application, appid);
                    WeexInstanceMgr.this.registerUniappService(application, appid);
                    WXSDKEngine.restartWeex();
                }
            });
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void loadWeexToAppid(Context context, String appid, boolean isErrorOpen) {
        int vueVersion = getVueVersion();
        initAppForPath(context, appid);
        initJSFramework(context, appid);
        if (getVueVersion() != vueVersion) {
            isErrorOpen = true;
        }
        if (!WXBridgeManager.getInstance().isJSFrameworkInit() || isErrorOpen) {
            setJsFrameworkReady(false);
            WXSDKEngine.restartWeex();
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void onCreateProcess(Application application, Boolean isMainProcess) {
        MoudlesLoader.getInstance().initHooksClass(application, isMainProcess);
    }

    public void initStatisticsListener() {
        WXSDKManager.getInstance().registerStatisticsListener(this);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void initJSFramework(Context application, String appid) {
        JSONObject jSONObject;
        JSONObject jSONObject2;
        InputStream appFileStream = getAppFileStream(application, appid, BaseInfo.sConfigXML);
        if (appFileStream != null) {
            try {
                JSONObject parseObject = JSON.parseObject(handleEncryptionInputStream(appFileStream, application, true));
                if (parseObject == null || !parseObject.containsKey(IApp.ConfigProperty.CONFIG_PLUS)) {
                    return;
                }
                JSONObject jSONObject3 = parseObject.getJSONObject(IApp.ConfigProperty.CONFIG_PLUS);
                if (jSONObject3 != null && jSONObject3.containsKey("uni-app")) {
                    JSONObject jSONObject4 = jSONObject3.getJSONObject("uni-app");
                    self().control = AbsoluteConst.UNI_V3;
                    if (jSONObject4.containsKey("renderer")) {
                        self().render = jSONObject4.getString("renderer");
                    }
                    if (jSONObject4.containsKey("nvueCompiler")) {
                        self().complier = jSONObject4.getString("nvueCompiler");
                    }
                    if (jSONObject4.containsKey("vueVersion")) {
                        self().mVueVersion = jSONObject4.getIntValue("vueVersion");
                    } else {
                        self().mVueVersion = 2;
                    }
                    if (jSONObject4.containsKey("useJSProcess")) {
                        if (AbsoluteConst.FALSE.equals(jSONObject4.getString("useJSProcess"))) {
                            WXBridgeManager.getInstance().setUseSingleProcess(true);
                        } else {
                            WXBridgeManager.getInstance().setUseSingleProcess(false);
                        }
                    }
                    if (jSONObject4.containsKey("webView") && (jSONObject2 = jSONObject4.getJSONObject("webView")) != null) {
                        try {
                            if (jSONObject2.containsKey("minUserAgentVersion")) {
                                BaseInfo.minUserAgentVersion = jSONObject2.getString("minUserAgentVersion");
                            }
                            if (jSONObject2.containsKey("x5")) {
                                JSONObject jSONObject5 = jSONObject2.getJSONObject("x5");
                                if (jSONObject5.containsKey("timeOut")) {
                                    BaseInfo.timeOut = jSONObject5.getIntValue("timeOut");
                                }
                                if (jSONObject5.containsKey("showTipsWithoutWifi")) {
                                    BaseInfo.showTipsWithoutWifi = jSONObject5.getBooleanValue("showTipsWithoutWifi");
                                }
                                if (jSONObject5.containsKey("allowDownloadWithoutWiFi")) {
                                    BaseInfo.allowDownloadWithoutWiFi = jSONObject5.getBooleanValue("allowDownloadWithoutWiFi");
                                }
                            }
                        } catch (Exception unused) {
                        }
                    }
                }
                if (jSONObject3 != null && jSONObject3.containsKey(IApp.ConfigProperty.CONFIG_UNISTATISTICS) && (jSONObject = jSONObject3.getJSONObject(IApp.ConfigProperty.CONFIG_UNISTATISTICS)) != null) {
                    JSONObject jSONObject6 = new JSONObject();
                    try {
                        if (jSONObject.containsKey(WebLoadEvent.ENABLE)) {
                            jSONObject6.put(WebLoadEvent.ENABLE, jSONObject.get(WebLoadEvent.ENABLE));
                        }
                        if (jSONObject.containsKey("version")) {
                            jSONObject6.put("version", jSONObject.get("version"));
                        }
                        if (jSONObject.containsKey("uniCloud")) {
                            jSONObject6.put("uniCloud", (Object) jSONObject.getJSONObject("uniCloud"));
                        }
                        AppRuntime.setUniStatistics(jSONObject6.toJSONString());
                    } catch (Exception unused2) {
                    }
                }
                if (jSONObject3 == null || !jSONObject3.containsKey("renderer")) {
                    return;
                }
                BaseInfo.renderer = jSONObject3.getString("renderer");
            } catch (Exception unused3) {
            }
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:45:0x0057 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:49:0x0047 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:51:? A[RETURN, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private InputStream getAppFileStream(Context context, String appid, String fileName) {
        boolean z;
        InputStream inputStream;
        String path;
        InputStream inputStream2 = null;
        try {
            AndroidResources.initAndroidResources(context);
            if (TextUtils.isEmpty(appid)) {
                BaseInfo.parseControl();
            } else {
                BaseInfo.sDefaultBootApp = appid;
            }
        } catch (Exception e) {
            e = e;
        }
        if (!BaseInfo.ISDEBUG && !DHFile.hasFile()) {
            z = false;
            String str = "apps/" + BaseInfo.sDefaultBootApp + "/www/" + fileName;
            if (this.isAssetsRes && !BaseInfo.SyncDebug) {
                if (!SDK.isUniMPSDK()) {
                    try {
                        inputStream = context.getResources().getAssets().open(str);
                    } catch (Exception unused) {
                    }
                    if (inputStream == null) {
                        try {
                            if (z) {
                                path = Environment.getExternalStorageDirectory().getPath() + "/Android/data/" + context.getPackageName();
                            } else {
                                path = context.getFilesDir().getPath();
                            }
                            File file = new File(path + "/" + str);
                            if (file.exists()) {
                                inputStream2 = new FileInputStream(file);
                            } else {
                                try {
                                    inputStream2 = context.getResources().getAssets().open(str);
                                } catch (Exception unused2) {
                                }
                            }
                            if (inputStream2 == null) {
                                return inputStream;
                            }
                        } catch (Exception e2) {
                            e = e2;
                            inputStream2 = inputStream;
                            e.printStackTrace();
                            return inputStream2;
                        }
                        return inputStream2;
                    }
                    return inputStream;
                }
            }
            inputStream = null;
            if (inputStream == null) {
            }
        }
        z = true;
        String str2 = "apps/" + BaseInfo.sDefaultBootApp + "/www/" + fileName;
        if (this.isAssetsRes) {
            if (!SDK.isUniMPSDK()) {
            }
        }
        inputStream = null;
        if (inputStream == null) {
        }
    }

    public void initAppForPath(Context context, String appid) {
        this.isAssetsRes = AppRuntime.isAppResourcesInAssetsPath(context, appid);
    }

    private String handleEncryptionInputStream(InputStream inputStream, Context context, boolean isCode) {
        System.currentTimeMillis();
        if (isCode) {
            inputStream = new UnicodeInputStream(inputStream, Charset.defaultCharset().name());
        }
        byte[] bArr = new byte[0];
        try {
            bArr = IOUtil.getBytes(inputStream);
        } catch (IOException e) {
            e.printStackTrace();
        }
        IConfusionMgr iConfusionMgr = this.mConfusionMgr;
        String handleEncryption = iConfusionMgr != null ? iConfusionMgr.handleEncryption(context.getApplicationContext(), bArr) : null;
        return TextUtils.isEmpty(handleEncryption) ? new String(bArr) : handleEncryption;
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void registerUniappService(Context context, String appid) {
        InputStream appFileStream;
        if (!self().control.equals(AbsoluteConst.UNI_V3) || (appFileStream = self().getAppFileStream(context, appid, "app-config-service.js")) == null) {
            return;
        }
        try {
            WXSDKEngine.registerService(this.jsSACName, handleEncryptionInputStream(appFileStream, context, false), new HashMap());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public boolean isUniAppAssetsRes() {
        return this.isAssetsRes;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void unRegisterUniappService() {
        WXSDKEngine.unRegisterService(this.jsSACName);
    }

    private void registerReflexWeexPlugin(Context context) {
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_amap.AMapPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex.map.google.GoogleMapPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_scroller.DCScrollerPluginImpl", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_barcode.BarcodePlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.utsplugin.UTSPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_livepusher.LivePusherPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_media.VideoPlayerPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_text.DCWXTextPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_input.DCWXInputRegister", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.gcanvas.GCanvasRegister", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_switch.DCWXSwitchPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        PlatformUtil.invokeMethod("io.dcloud.feature.weex_ad.DCWXAdPlugin", "initPlugin", null, new Class[]{Context.class}, new Object[]{context});
        Object invokeFieldValue = PlatformUtil.invokeFieldValue("com.taobao.weex.devtools.inspector.elements.android.WXComponentDescriptor", "sClassName", null);
        if (invokeFieldValue == null || !(invokeFieldValue instanceof HashMap)) {
            return;
        }
        HashMap hashMap = (HashMap) invokeFieldValue;
        hashMap.put(FrescoImageComponent.class, "image");
        hashMap.put(FrescoImageComponentU.class, "image");
        hashMap.put(WXDCWeb.class, "web-view");
        hashMap.put(DCWXView.class, WXBasicComponentType.VIEW);
        hashMap.put(DCCoverViewComponent.class, "cover-view");
        hashMap.put(DCWXSlider.class, WXBasicComponentType.SLIDER);
    }

    public void addComponentByName(String name, Class component) {
        try {
            Object invokeFieldValue = PlatformUtil.invokeFieldValue("com.taobao.weex.devtools.inspector.elements.android.WXComponentDescriptor", "sClassName", null);
            if (invokeFieldValue == null || !(invokeFieldValue instanceof HashMap)) {
                return;
            }
            ((HashMap) invokeFieldValue).put(component, name);
        } catch (Exception unused) {
        }
    }

    private String getConfigParam() {
        JSONObject jSONObject = new JSONObject();
        jSONObject.put("__HtMl_Id__", (Object) "__uniapp_webview");
        jSONObject.put(RenderTypes.RENDER_TYPE_NATIVE, (Object) 1);
        jSONObject.put("debug", (Object) true);
        JSONObject jSONObject2 = new JSONObject();
        jSONObject2.put(IApp.ConfigProperty.CONFIG_LANGUAGE, (Object) LanguageUtil.getDeviceDefLocalLanguage());
        jSONObject2.put("version", (Object) Build.VERSION.RELEASE);
        jSONObject2.put("name", (Object) TimeCalculator.PLATFORM_ANDROID);
        jSONObject2.put("vendor", (Object) "Google");
        jSONObject.put(WXConfig.os, (Object) jSONObject2);
        JSONObject jSONObject3 = new JSONObject();
        jSONObject3.put("CONNECTION_TYPE", (Object) 0);
        jSONObject.put("networkinfo", (Object) jSONObject3);
        return jSONObject.toJSONString();
    }

    public WXViewWrapper createWeexView(final IWebview webview, final ViewGroup parentView, final org.json.JSONObject itme, final String weexId, int zIndex) {
        WXViewWrapper makeWXViewWrapper = makeWXViewWrapper(webview, parentView, itme, weexId, zIndex);
        makeWXViewWrapper.loadTemplate(itme);
        return makeWXViewWrapper;
    }

    private WXViewWrapper makeWXViewWrapper(IWebview webview, ViewGroup parentView, org.json.JSONObject itme, String weexId, int zIndex) {
        WXViewWrapper wXViewWrapper = new WXViewWrapper(webview, parentView, itme, weexId, zIndex, (!weexId.equals("__uniapp__service") || this.mPreUniAppid == null || WXSDKManager.getInstance().getSDKInstance(this.mPreInstanceId) == null) ? false : true);
        if (this.instanceHashMap.containsKey(weexId)) {
            this.instanceHashMap.remove(weexId).mWXSDKInstance.destroy();
        }
        this.instanceHashMap.put(weexId, wXViewWrapper);
        return wXViewWrapper;
    }

    public WXServiceWrapper createWeexService(IApp app, ViewGroup parentView, String weexId, org.json.JSONObject data) {
        WXServiceWrapper wXServiceWrapper = new WXServiceWrapper(app, parentView, weexId, data);
        this.serviceWrapperMapsCache.put(weexId, wXServiceWrapper);
        return wXServiceWrapper;
    }

    WXViewWrapper findWXViewWrapper(String weexId) {
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId);
        }
        return null;
    }

    public WXServiceWrapper findWXServiceWrapper(WXSDKInstance instance2) {
        if (this.serviceWrapperMapsCache.size() > 0) {
            for (String str : this.serviceWrapperMapsCache.keySet()) {
                WXServiceWrapper wXServiceWrapper = this.serviceWrapperMapsCache.get(str);
                if (wXServiceWrapper != null && wXServiceWrapper.mWXSDKInstance == instance2) {
                    return wXServiceWrapper;
                }
            }
            return null;
        }
        return null;
    }

    public void reloadWXServiceWrapper() {
        if (this.serviceWrapperMapsCache.size() > 0) {
            for (String str : this.serviceWrapperMapsCache.keySet()) {
                WXServiceWrapper wXServiceWrapper = this.serviceWrapperMapsCache.get(str);
                if (wXServiceWrapper != null) {
                    wXServiceWrapper.reload();
                }
            }
        }
    }

    public WXSDKInstance findWXSDKInstance(String weexId) {
        if (this.serviceWrapperMapsCache.containsKey(weexId)) {
            return this.serviceWrapperMapsCache.get(weexId).mWXSDKInstance;
        }
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId).mWXSDKInstance;
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public WXBaseWrapper findWXBaseWrapper(String weexId) {
        if (this.serviceWrapperMapsCache.containsKey(weexId)) {
            return this.serviceWrapperMapsCache.get(weexId);
        }
        if (this.instanceHashMap.containsKey(weexId)) {
            return this.instanceHashMap.get(weexId);
        }
        return null;
    }

    /* JADX WARN: Multi-variable type inference failed */
    public IWebview findWebview(IWebview webview, IApp app, String appid, String webviewid) {
        AbsMgr absMgr = this.featureMgr;
        IMgr.MgrType mgrType = IMgr.MgrType.FeatureMgr;
        Object[] objArr = new Object[4];
        if (webview == null) {
            webview = app;
        }
        objArr[0] = webview;
        objArr[1] = AbsoluteConst.F_UI;
        objArr[2] = "findWebview";
        String[] strArr = new String[2];
        strArr[0] = appid;
        strArr[1] = webviewid;
        objArr[3] = strArr;
        Object processEvent = absMgr.processEvent(mgrType, 10, objArr);
        if (processEvent instanceof IWebview) {
            return (IWebview) processEvent;
        }
        return null;
    }

    public Object doForFeature(IMgr.MgrType type, int event, Object[] args) {
        AbsMgr absMgr = this.featureMgr;
        if (absMgr != null) {
            return absMgr.processEvent(type, event, args);
        }
        return null;
    }

    public WXBaseWrapper findWXBaseWrapper(WXSDKInstance instance2) {
        WXViewWrapper wXViewWrapper = null;
        for (String str : this.instanceHashMap.keySet()) {
            WXViewWrapper wXViewWrapper2 = this.instanceHashMap.get(str);
            if (wXViewWrapper2 != null && wXViewWrapper2.mWXSDKInstance == instance2) {
                wXViewWrapper = wXViewWrapper2;
            }
        }
        return wXViewWrapper;
    }

    public IWebview findWebview(WXSDKInstance instance2) {
        for (String str : this.instanceHashMap.keySet()) {
            WXViewWrapper wXViewWrapper = this.instanceHashMap.get(str);
            if (wXViewWrapper != null && wXViewWrapper.mWXSDKInstance == instance2) {
                return wXViewWrapper.mWebview;
            }
        }
        return null;
    }

    public IWebview findWebviewByInstanceId(String instanceId) {
        for (String str : this.instanceHashMap.keySet()) {
            WXViewWrapper wXViewWrapper = this.instanceHashMap.get(str);
            if (wXViewWrapper != null && wXViewWrapper.mWXSDKInstance.getInstanceId().equals(instanceId)) {
                return wXViewWrapper.mWebview;
            }
        }
        return null;
    }

    public WXViewWrapper findPathByWrapper(String byPath) {
        if (TextUtils.isEmpty(byPath)) {
            return null;
        }
        for (String str : this.instanceHashMap.keySet()) {
            WXViewWrapper wXViewWrapper = this.instanceHashMap.get(str);
            String initSrcPath = wXViewWrapper.initSrcPath(byPath);
            String srcPath = wXViewWrapper.getSrcPath();
            if (wXViewWrapper != null && !TextUtils.isEmpty(srcPath) && srcPath.equals(initSrcPath)) {
                return wXViewWrapper;
            }
        }
        return null;
    }

    public void removeWeexView(String weexId) {
        if (this.instanceHashMap.containsKey(weexId)) {
            this.instanceHashMap.remove(weexId).onDestroy();
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityResume() {
        forEach(new EachListener<WXBaseWrapper>() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.2
            @Override // io.dcloud.feature.weex.WeexInstanceMgr.EachListener
            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityResume();
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityPause() {
        forEach(new EachListener<WXBaseWrapper>() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.3
            @Override // io.dcloud.feature.weex.WeexInstanceMgr.EachListener
            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityPause();
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityResult(final int requestCode, final int resultCode, final Intent data) {
        forEach(new EachListener<WXBaseWrapper>() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.4
            @Override // io.dcloud.feature.weex.WeexInstanceMgr.EachListener
            public void onEach(WXBaseWrapper wrapper) {
                wrapper.onActivityResult(requestCode, resultCode, data);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityDestroy() {
        onActivityDestroy(true);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void onActivityDestroy(final boolean isDelay) {
        this.mPreUniAppid = null;
        this.mPreInstanceId = null;
        if (this.instanceHashMap.size() > 0 || this.serviceWrapperMapsCache.size() > 0) {
            if (isDelay) {
                getHandler().postDelayed(new Runnable() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.5
                    @Override // java.lang.Runnable
                    public void run() {
                        WeexInstanceMgr.this.wrapperDestroy();
                    }
                }, 200L);
            } else {
                getHandler().post(new Runnable() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.6
                    @Override // java.lang.Runnable
                    public void run() {
                        WeexInstanceMgr.this.wrapperDestroy();
                    }
                });
            }
        }
        this.mPreUniMPCallBackMap.clear();
        this.mApplication = null;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void wrapperDestroy() {
        forEach(new EachListener<WXBaseWrapper>() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.7
            @Override // io.dcloud.feature.weex.WeexInstanceMgr.EachListener
            public void onEach(final WXBaseWrapper wrapper) {
                if (wrapper != null) {
                    wrapper.onDestroy();
                }
            }
        });
        this.instanceHashMap.clear();
        this.serviceWrapperMapsCache.clear();
        if (SDK.isUniMPSDK()) {
            reloadWeexEngine();
        }
    }

    private void reloadWeexEngine() {
        unRegisterUniappService();
        WXSDKEngine.reload();
    }

    private void forEach(EachListener listener) {
        try {
            Collection<WXViewWrapper> values = this.instanceHashMap.values();
            if (values != null) {
                for (WXViewWrapper wXViewWrapper : values) {
                    if (wXViewWrapper != null) {
                        listener.onEach(wXViewWrapper);
                    }
                }
            }
            Collection<WXServiceWrapper> values2 = this.serviceWrapperMapsCache.values();
            if (values2 != null) {
                for (WXServiceWrapper wXServiceWrapper : values2) {
                    if (wXServiceWrapper != null) {
                        listener.onEach(wXServiceWrapper);
                    }
                }
            }
        } catch (Exception e) {
            Logger.e("forEach---" + e.getMessage());
        }
    }

    public void weexDebugReload() {
        LinkedHashMap<String, WXViewWrapper> linkedHashMap = this.instanceHashMap;
        if (linkedHashMap == null || linkedHashMap.size() <= 0) {
            return;
        }
        Iterator<String> it = this.instanceHashMap.keySet().iterator();
        if (it.hasNext()) {
            this.instanceHashMap.get(it.next()).mWebview.obtainFrameView().obtainWindowMgr().processEvent(IMgr.MgrType.AppMgr, 3, "snc:CID");
        }
    }

    public void onRequestPermissionsResult(final int requestCode, final String[] permissions, final int[] grantResults) {
        forEach(new EachListener<WXBaseWrapper>() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.8
            @Override // io.dcloud.feature.weex.WeexInstanceMgr.EachListener
            public void onEach(WXBaseWrapper wrapper) {
                if (wrapper != null) {
                    wrapper.onRequestPermissionsResult(requestCode, permissions, grantResults);
                }
            }
        });
    }

    public String getComplier() {
        return this.complier;
    }

    public String getControl() {
        return this.control;
    }

    public int getVueVersion() {
        return this.mVueVersion;
    }

    public boolean isWeexInitEnd() {
        return this.isWeexInitEnd;
    }

    public void setWeexInitEnd(boolean isEnd) {
        this.isWeexInitEnd = isEnd;
    }

    public void setJsFrameworkReady(boolean isReady) {
        this.isJsFrameworkReady = isReady;
    }

    public boolean isJsFrameworkReady() {
        return this.isJsFrameworkReady;
    }

    @Override // com.taobao.weex.IWXStatisticsListener
    public void onJsFrameworkReady() {
        this.isJsFrameworkReady = true;
        if (this.mRestartReadyCall != null) {
            MessageHandler.sendMessage(new MessageHandler.IMessages() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.9
                @Override // io.dcloud.common.adapter.util.MessageHandler.IMessages
                public void execute(Object pArgs) {
                    WeexInstanceMgr.this.mRestartReadyCall.onCallBack(1, null);
                    WeexInstanceMgr.this.mRestartReadyCall = null;
                }
            }, null);
        }
        ArrayList<IWXStatisticsCallBack> arrayList = this.callBacks;
        if (arrayList != null) {
            Iterator<IWXStatisticsCallBack> it = arrayList.iterator();
            while (it.hasNext()) {
                it.next().onJsFrameworkReady();
            }
        }
    }

    public void setWXStatisticsCallBack(IWXStatisticsCallBack callBack) {
        if (this.callBacks.contains(callBack)) {
            return;
        }
        this.callBacks.add(callBack);
    }

    public void unWXStatisticsCallBack(IWXStatisticsCallBack callBack) {
        if (this.callBacks.contains(callBack)) {
            this.callBacks.remove(callBack);
        }
    }

    public boolean isUniServiceCreated(IApp app) {
        String obtainConfigProperty = app.obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
        if (!TextUtils.isEmpty(obtainConfigProperty) && !obtainConfigProperty.equals("fast") && getControl().equals(AbsoluteConst.UNI_V3)) {
            return this.isUniServiceCreated;
        }
        if (getControl().equals(Constants.CodeCache.SAVE_PATH)) {
            return this.isUniServiceCreated;
        }
        return true;
    }

    public String getPreInstanceId() {
        return this.mPreInstanceId;
    }

    public String getPreUniAppid() {
        return this.mPreUniAppid;
    }

    /* JADX WARN: Code restructure failed: missing block: B:5:0x0010, code lost:
        if (android.text.TextUtils.isEmpty(r4) == false) goto L5;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void setUniServiceCreated(boolean is, IApp app) {
        String str;
        this.isUniServiceCreated = is;
        if (app != null) {
            str = app.obtainConfigProperty(AbsoluteConst.NVUE_LAUNCH_MODE);
        }
        str = "fast";
        if ((getControl().equals(Constants.CodeCache.SAVE_PATH) || (!str.equals("fast") && getControl().equals(AbsoluteConst.UNI_V3))) && this.isUniServiceCreated) {
            for (String str2 : this.instanceHashMap.keySet()) {
                WXViewWrapper wXViewWrapper = this.instanceHashMap.get(str2);
                if (wXViewWrapper != null && !wXViewWrapper.isService) {
                    wXViewWrapper.runDelayedRenderCaches(wXViewWrapper.getWaitServiceRenderList());
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void preUniControlService(Application context, String appid) {
        this.isUniServiceCreated = true;
        this.mPreUniAppid = appid;
        UniSDKInstance uniSDKInstance = new UniSDKInstance(context);
        this.mPreInstanceId = uniSDKInstance.getInstanceId();
        String uniFileStr = getUniFileStr(context, appid, "app-service.js");
        String uniFileStr2 = getUniFileStr(context, appid, "app-config.js");
        HashMap hashMap = new HashMap();
        hashMap.put("plus_appid", appid);
        hashMap.put("preload", true);
        hashMap.put("bundleUrl", "app-service.js");
        org.json.JSONObject jSONObject = new org.json.JSONObject();
        uniSDKInstance.render("__uniapp__service", (uniFileStr2 + uniFileStr + " plus.weexBridge.preloadReady('" + appid + "');").replaceFirst(Pattern.quote("\"use weex:vue\""), Matcher.quoteReplacement("")), hashMap, jSONObject.toString(), WXRenderStrategy.APPEND_ASYNC);
        String str = this.TAG;
        StringBuilder sb = new StringBuilder();
        sb.append("preUniControlService------");
        sb.append(appid);
        Logger.e(str, sb.toString());
    }

    private String getUniFileStr(Context context, String appid, String fileName) {
        try {
            return IOUtil.toString(getAppFileStream(context, appid, fileName));
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        }
    }

    public ICallBack getPreUniMPCallBack(String appid) {
        if (this.mPreUniMPCallBackMap.containsKey(appid)) {
            return this.mPreUniMPCallBackMap.remove(appid);
        }
        return null;
    }

    public void preUniMP(final Application context, final String appid, ICallBack iCallBack) {
        if (!TextUtils.isEmpty(this.mPreUniAppid) && iCallBack != null) {
            iCallBack.onCallBack(-101, "");
            return;
        }
        if (iCallBack != null) {
            this.mPreUniMPCallBackMap.put(appid, iCallBack);
        }
        if (isWeexInitEnd()) {
            restartWeex(context, new ICallBack() { // from class: io.dcloud.feature.weex.WeexInstanceMgr.10
                @Override // io.dcloud.common.DHInterface.ICallBack
                public Object onCallBack(int pType, Object pArgs) {
                    if (pType == 1) {
                        WeexInstanceMgr.this.preUniControlService(context, appid);
                        return null;
                    }
                    return null;
                }
            }, appid);
            return;
        }
        initWeexEnv(context);
        preUniControlService(context, appid);
    }

    private Handler getHandler() {
        if (this.mHandler == null) {
            this.mHandler = new Handler(Looper.getMainLooper());
        }
        return this.mHandler;
    }

    private void clearHandler() {
        if (this.mHandler != null) {
            this.mHandler = null;
        }
    }

    @Override // io.dcloud.common.DHInterface.IUniInstanceMgr
    public void initUniappPlugin(Application application) {
        UniMoudlesLoader.getInstance().onCreate(application);
    }

    public boolean isJSFKFileNotFound() {
        return this.isJSFKFileNotFound;
    }

    public void setJSFKFileNotFound(boolean JSFKFileNotFound) {
        this.isJSFKFileNotFound = JSFKFileNotFound;
    }
}
