package com.alibaba.fastjson.parser.deserializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.parser.DefaultJSONParser;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.parser.JSONLexer;
import com.alibaba.fastjson.parser.JSONLexerBase;
import com.alibaba.fastjson.parser.JSONToken;
import com.alibaba.fastjson.parser.ParseContext;
import com.alibaba.fastjson.parser.ParserConfig;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.JavaBeanInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.util.PdrUtil;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Proxy;
import java.lang.reflect.Type;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
/* loaded from: classes.dex */
public class JavaBeanDeserializer implements ObjectDeserializer {
    private final Map<String, FieldDeserializer> alterNameFieldDeserializers;
    private final ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler;
    public final JavaBeanInfo beanInfo;
    protected final Class<?> clazz;
    private ConcurrentMap<String, Object> extraFieldDeserializers;
    private Map<String, FieldDeserializer> fieldDeserializerMap;
    private final FieldDeserializer[] fieldDeserializers;
    private transient long[] hashArray;
    private transient short[] hashArrayMapping;
    private transient long[] smartMatchHashArray;
    private transient short[] smartMatchHashArrayMapping;
    protected final FieldDeserializer[] sortedFieldDeserializers;

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public int getFastMatchToken() {
        return 12;
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls) {
        this(parserConfig, cls, cls);
    }

    public JavaBeanDeserializer(ParserConfig parserConfig, Class<?> cls, Type type) {
        this(parserConfig, JavaBeanInfo.build(cls, type, parserConfig.propertyNamingStrategy, parserConfig.fieldBased, parserConfig.compatibleWithJavaBean, parserConfig.isJacksonCompatible()));
    }

    /* JADX WARN: Removed duplicated region for block: B:11:0x0036  */
    /* JADX WARN: Removed duplicated region for block: B:26:0x007e A[LOOP:2: B:25:0x007c->B:26:0x007e, LOOP_END] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public JavaBeanDeserializer(ParserConfig parserConfig, JavaBeanInfo javaBeanInfo) {
        ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler;
        int length;
        int i;
        int i2;
        int length2;
        String[] strArr;
        this.clazz = javaBeanInfo.clazz;
        this.beanInfo = javaBeanInfo;
        HashMap hashMap = null;
        if (javaBeanInfo.jsonType != null && javaBeanInfo.jsonType.autoTypeCheckHandler() != ParserConfig.AutoTypeCheckHandler.class) {
            try {
                autoTypeCheckHandler = javaBeanInfo.jsonType.autoTypeCheckHandler().newInstance();
            } catch (Exception unused) {
            }
            this.autoTypeCheckHandler = autoTypeCheckHandler;
            this.sortedFieldDeserializers = new FieldDeserializer[javaBeanInfo.sortedFields.length];
            length = javaBeanInfo.sortedFields.length;
            for (i2 = 0; i2 < length; i2++) {
                FieldInfo fieldInfo = javaBeanInfo.sortedFields[i2];
                FieldDeserializer createFieldDeserializer = parserConfig.createFieldDeserializer(parserConfig, javaBeanInfo, fieldInfo);
                this.sortedFieldDeserializers[i2] = createFieldDeserializer;
                if (length > 128) {
                    if (this.fieldDeserializerMap == null) {
                        this.fieldDeserializerMap = new HashMap();
                    }
                    this.fieldDeserializerMap.put(fieldInfo.name, createFieldDeserializer);
                }
                for (String str : fieldInfo.alternateNames) {
                    if (hashMap == null) {
                        hashMap = new HashMap();
                    }
                    hashMap.put(str, createFieldDeserializer);
                }
            }
            this.alterNameFieldDeserializers = hashMap;
            this.fieldDeserializers = new FieldDeserializer[javaBeanInfo.fields.length];
            length2 = javaBeanInfo.fields.length;
            for (i = 0; i < length2; i++) {
                this.fieldDeserializers[i] = getFieldDeserializer(javaBeanInfo.fields[i].name);
            }
        }
        autoTypeCheckHandler = null;
        this.autoTypeCheckHandler = autoTypeCheckHandler;
        this.sortedFieldDeserializers = new FieldDeserializer[javaBeanInfo.sortedFields.length];
        length = javaBeanInfo.sortedFields.length;
        while (i2 < length) {
        }
        this.alterNameFieldDeserializers = hashMap;
        this.fieldDeserializers = new FieldDeserializer[javaBeanInfo.fields.length];
        length2 = javaBeanInfo.fields.length;
        while (i < length2) {
        }
    }

    public FieldDeserializer getFieldDeserializer(String str) {
        return getFieldDeserializer(str, null);
    }

    public FieldDeserializer getFieldDeserializer(String str, int[] iArr) {
        FieldDeserializer fieldDeserializer;
        if (str == null) {
            return null;
        }
        Map<String, FieldDeserializer> map = this.fieldDeserializerMap;
        if (map == null || (fieldDeserializer = map.get(str)) == null) {
            int i = 0;
            int length = this.sortedFieldDeserializers.length - 1;
            while (i <= length) {
                int i2 = (i + length) >>> 1;
                int compareTo = this.sortedFieldDeserializers[i2].fieldInfo.name.compareTo(str);
                if (compareTo < 0) {
                    i = i2 + 1;
                } else if (compareTo <= 0) {
                    if (isSetFlag(i2, iArr)) {
                        return null;
                    }
                    return this.sortedFieldDeserializers[i2];
                } else {
                    length = i2 - 1;
                }
            }
            Map<String, FieldDeserializer> map2 = this.alterNameFieldDeserializers;
            if (map2 != null) {
                return map2.get(str);
            }
            return null;
        }
        return fieldDeserializer;
    }

    public FieldDeserializer getFieldDeserializer(long j) {
        int i = 0;
        if (this.hashArray == null) {
            long[] jArr = new long[this.sortedFieldDeserializers.length];
            int i2 = 0;
            while (true) {
                FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                if (i2 >= fieldDeserializerArr.length) {
                    break;
                }
                jArr[i2] = TypeUtils.fnv1a_64(fieldDeserializerArr[i2].fieldInfo.name);
                i2++;
            }
            Arrays.sort(jArr);
            this.hashArray = jArr;
        }
        int binarySearch = Arrays.binarySearch(this.hashArray, j);
        if (binarySearch < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            short[] sArr = new short[this.hashArray.length];
            Arrays.fill(sArr, (short) -1);
            while (true) {
                FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                if (i >= fieldDeserializerArr2.length) {
                    break;
                }
                int binarySearch2 = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(fieldDeserializerArr2[i].fieldInfo.name));
                if (binarySearch2 >= 0) {
                    sArr[binarySearch2] = (short) i;
                }
                i++;
            }
            this.hashArrayMapping = sArr;
        }
        short s = this.hashArrayMapping[binarySearch];
        if (s != -1) {
            return this.sortedFieldDeserializers[s];
        }
        return null;
    }

    static boolean isSetFlag(int i, int[] iArr) {
        int i2;
        if (iArr != null && (i2 = i / 32) < iArr.length) {
            return ((1 << (i % 32)) & iArr[i2]) != 0;
        }
        return false;
    }

    public Object createInstance(DefaultJSONParser defaultJSONParser, Type type) {
        Object newInstance;
        FieldInfo[] fieldInfoArr;
        if ((type instanceof Class) && this.clazz.isInterface()) {
            return Proxy.newProxyInstance(Thread.currentThread().getContextClassLoader(), new Class[]{(Class) type}, new JSONObject());
        }
        Object obj = null;
        if (this.beanInfo.defaultConstructor == null && this.beanInfo.factoryMethod == null) {
            return null;
        }
        if (this.beanInfo.factoryMethod == null || this.beanInfo.defaultConstructorParameterSize <= 0) {
            try {
                Constructor<?> constructor = this.beanInfo.defaultConstructor;
                if (this.beanInfo.defaultConstructorParameterSize != 0) {
                    ParseContext context = defaultJSONParser.getContext();
                    if (context == null || context.object == null) {
                        throw new JSONException("can't create non-static inner class instance.");
                    }
                    if (type instanceof Class) {
                        String name = ((Class) type).getName();
                        String substring = name.substring(0, name.lastIndexOf(36));
                        Object obj2 = context.object;
                        String name2 = obj2.getClass().getName();
                        if (!name2.equals(substring)) {
                            ParseContext parseContext = context.parent;
                            if (parseContext == null || parseContext.object == null || !("java.util.ArrayList".equals(name2) || "java.util.List".equals(name2) || "java.util.Collection".equals(name2) || "java.util.Map".equals(name2) || "java.util.HashMap".equals(name2))) {
                                obj = obj2;
                            } else if (parseContext.object.getClass().getName().equals(substring)) {
                                obj = parseContext.object;
                            }
                            obj2 = obj;
                        }
                        if (obj2 == null || ((obj2 instanceof Collection) && ((Collection) obj2).isEmpty())) {
                            throw new JSONException("can't create non-static inner class instance.");
                        }
                        newInstance = constructor.newInstance(obj2);
                    } else {
                        throw new JSONException("can't create non-static inner class instance.");
                    }
                } else if (constructor != null) {
                    newInstance = constructor.newInstance(new Object[0]);
                } else {
                    newInstance = this.beanInfo.factoryMethod.invoke(null, new Object[0]);
                }
                if (defaultJSONParser != null && defaultJSONParser.lexer.isEnabled(Feature.InitStringFieldAsEmpty)) {
                    for (FieldInfo fieldInfo : this.beanInfo.fields) {
                        if (fieldInfo.fieldClass == String.class) {
                            try {
                                fieldInfo.set(newInstance, "");
                            } catch (Exception e) {
                                throw new JSONException("create instance error, class " + this.clazz.getName(), e);
                            }
                        }
                    }
                }
                return newInstance;
            } catch (JSONException e2) {
                throw e2;
            } catch (Exception e3) {
                throw new JSONException("create instance error, class " + this.clazz.getName(), e3);
            }
        }
        return null;
    }

    @Override // com.alibaba.fastjson.parser.deserializer.ObjectDeserializer
    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        return (T) deserialze(defaultJSONParser, type, obj, 0);
    }

    public <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj, int i) {
        return (T) deserialze(defaultJSONParser, type, obj, null, i, null);
    }

    public <T> T deserialzeArrayMapping(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2) {
        Enum<?> scanEnum;
        JSONLexer jSONLexer = defaultJSONParser.lexer;
        if (jSONLexer.token() != 14) {
            throw new JSONException("error");
        }
        String scanTypeName = jSONLexer.scanTypeName(defaultJSONParser.symbolTable);
        if (scanTypeName != null) {
            ObjectDeserializer seeAlso = getSeeAlso(defaultJSONParser.getConfig(), this.beanInfo, scanTypeName);
            if (seeAlso == null) {
                seeAlso = defaultJSONParser.getConfig().getDeserializer(defaultJSONParser.getConfig().checkAutoType(scanTypeName, TypeUtils.getClass(type), jSONLexer.getFeatures()));
            }
            if (seeAlso instanceof JavaBeanDeserializer) {
                return (T) ((JavaBeanDeserializer) seeAlso).deserialzeArrayMapping(defaultJSONParser, type, obj, obj2);
            }
        }
        T t = (T) createInstance(defaultJSONParser, type);
        int i = 0;
        int length = this.sortedFieldDeserializers.length;
        while (true) {
            if (i >= length) {
                break;
            }
            char c = i == length + (-1) ? Operators.ARRAY_END : Operators.ARRAY_SEPRATOR;
            FieldDeserializer fieldDeserializer = this.sortedFieldDeserializers[i];
            Class<?> cls = fieldDeserializer.fieldInfo.fieldClass;
            if (cls == Integer.TYPE) {
                fieldDeserializer.setValue((Object) t, jSONLexer.scanInt(c));
            } else if (cls == String.class) {
                fieldDeserializer.setValue((Object) t, jSONLexer.scanString(c));
            } else if (cls == Long.TYPE) {
                fieldDeserializer.setValue(t, jSONLexer.scanLong(c));
            } else if (cls.isEnum()) {
                char current = jSONLexer.getCurrent();
                if (current == '\"' || current == 'n') {
                    scanEnum = jSONLexer.scanEnum(cls, defaultJSONParser.getSymbolTable(), c);
                } else if (current >= '0' && current <= '9') {
                    scanEnum = ((EnumDeserializer) ((DefaultFieldDeserializer) fieldDeserializer).getFieldValueDeserilizer(defaultJSONParser.getConfig())).valueOf(jSONLexer.scanInt(c));
                } else {
                    scanEnum = scanEnum(jSONLexer, c);
                }
                fieldDeserializer.setValue(t, scanEnum);
            } else if (cls == Boolean.TYPE) {
                fieldDeserializer.setValue(t, jSONLexer.scanBoolean(c));
            } else if (cls == Float.TYPE) {
                fieldDeserializer.setValue(t, Float.valueOf(jSONLexer.scanFloat(c)));
            } else if (cls == Double.TYPE) {
                fieldDeserializer.setValue(t, Double.valueOf(jSONLexer.scanDouble(c)));
            } else if (cls == Date.class && jSONLexer.getCurrent() == '1') {
                fieldDeserializer.setValue(t, new Date(jSONLexer.scanLong(c)));
            } else if (cls == BigDecimal.class) {
                fieldDeserializer.setValue(t, jSONLexer.scanDecimal(c));
            } else {
                jSONLexer.nextToken(14);
                fieldDeserializer.setValue(t, defaultJSONParser.parseObject(fieldDeserializer.fieldInfo.fieldType, fieldDeserializer.fieldInfo.name));
                if (jSONLexer.token() == 15) {
                    break;
                }
                check(jSONLexer, c == ']' ? 15 : 16);
            }
            i++;
        }
        jSONLexer.nextToken(16);
        return t;
    }

    protected void check(JSONLexer jSONLexer, int i) {
        if (jSONLexer.token() != i) {
            throw new JSONException("syntax error");
        }
    }

    protected Enum<?> scanEnum(JSONLexer jSONLexer, char c) {
        throw new JSONException("illegal enum. " + jSONLexer.info());
    }

    /* JADX WARN: Code restructure failed: missing block: B:299:0x038f, code lost:
        if (r12.matchStat == (-2)) goto L635;
     */
    /* JADX WARN: Code restructure failed: missing block: B:315:0x03cc, code lost:
        r14 = r27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:319:0x03da, code lost:
        if (r12.isEnabled(com.alibaba.fastjson.parser.Feature.AllowArbitraryCommas) != false) goto L486;
     */
    /* JADX WARN: Code restructure failed: missing block: B:402:0x0532, code lost:
        if (r3 != null) goto L582;
     */
    /* JADX WARN: Code restructure failed: missing block: B:403:0x0534, code lost:
        r15 = r13.checkAutoType(r1, r2, r12.getFeatures());
     */
    /* JADX WARN: Code restructure failed: missing block: B:404:0x053e, code lost:
        r15 = r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:405:0x053f, code lost:
        r2 = r32.getConfig().getDeserializer(r15);
     */
    /* JADX WARN: Code restructure failed: missing block: B:408:0x0549, code lost:
        r3 = (T) r2.deserialze(r32, r15, r34);
     */
    /* JADX WARN: Code restructure failed: missing block: B:409:0x054f, code lost:
        if ((r2 instanceof com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) == false) goto L577;
     */
    /* JADX WARN: Code restructure failed: missing block: B:410:0x0551, code lost:
        r2 = (com.alibaba.fastjson.parser.deserializer.JavaBeanDeserializer) r2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:411:0x0553, code lost:
        if (r6 == null) goto L577;
     */
    /* JADX WARN: Code restructure failed: missing block: B:412:0x0555, code lost:
        r2 = r2.getFieldDeserializer(r6);
     */
    /* JADX WARN: Code restructure failed: missing block: B:413:0x0559, code lost:
        if (r2 == null) goto L577;
     */
    /* JADX WARN: Code restructure failed: missing block: B:414:0x055b, code lost:
        r2.setValue((java.lang.Object) r3, r1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:415:0x055e, code lost:
        if (r5 == null) goto L579;
     */
    /* JADX WARN: Code restructure failed: missing block: B:416:0x0560, code lost:
        r5.object = r27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:417:0x0564, code lost:
        r32.setContext(r7);
     */
    /* JADX WARN: Code restructure failed: missing block: B:418:0x0567, code lost:
        return r3;
     */
    /* JADX WARN: Code restructure failed: missing block: B:423:0x0575, code lost:
        r30 = r7;
        r1 = r17;
        r35 = 0;
        r14 = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:479:0x0658, code lost:
        if ((r1.parserFeatures & com.alibaba.fastjson.parser.Feature.TrimStringFieldValue.mask) != 0) goto L442;
     */
    /* JADX WARN: Code restructure failed: missing block: B:500:0x06c2, code lost:
        r12.nextToken();
     */
    /* JADX WARN: Code restructure failed: missing block: B:513:0x06f1, code lost:
        r12.nextToken(16);
     */
    /* JADX WARN: Code restructure failed: missing block: B:514:0x06f4, code lost:
        r1 = r19;
        r5 = r27;
        r14 = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:515:0x06f8, code lost:
        if (r14 != null) goto L408;
     */
    /* JADX WARN: Code restructure failed: missing block: B:516:0x06fa, code lost:
        if (r1 != null) goto L186;
     */
    /* JADX WARN: Code restructure failed: missing block: B:517:0x06fc, code lost:
        r1 = (T) createInstance(r32, r33);
     */
    /* JADX WARN: Code restructure failed: missing block: B:518:0x0700, code lost:
        if (r5 != null) goto L404;
     */
    /* JADX WARN: Code restructure failed: missing block: B:519:0x0702, code lost:
        r3 = r30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:520:0x0704, code lost:
        r5 = r32.setContext(r3, r1, r34);
     */
    /* JADX WARN: Code restructure failed: missing block: B:522:0x0709, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:523:0x070a, code lost:
        r14 = r1;
        r15 = r5;
     */
    /* JADX WARN: Code restructure failed: missing block: B:524:0x070e, code lost:
        r3 = r30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:525:0x0710, code lost:
        if (r5 == null) goto L398;
     */
    /* JADX WARN: Code restructure failed: missing block: B:526:0x0712, code lost:
        r5.object = r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:527:0x0714, code lost:
        r32.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:528:0x0717, code lost:
        return r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:529:0x0718, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:530:0x0719, code lost:
        r3 = r30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:531:0x071d, code lost:
        r3 = r30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:532:0x071f, code lost:
        r2 = r31.beanInfo.creatorConstructorParameters;
     */
    /* JADX WARN: Code restructure failed: missing block: B:533:0x0723, code lost:
        r4 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:534:0x0725, code lost:
        if (r2 == null) goto L343;
     */
    /* JADX WARN: Code restructure failed: missing block: B:535:0x0727, code lost:
        r6 = new java.lang.Object[r2.length];
        r7 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:537:0x072c, code lost:
        if (r7 >= r2.length) goto L242;
     */
    /* JADX WARN: Code restructure failed: missing block: B:538:0x072e, code lost:
        r10 = r1.remove(r2[r7]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:539:0x0734, code lost:
        if (r10 != null) goto L225;
     */
    /* JADX WARN: Code restructure failed: missing block: B:540:0x0736, code lost:
        r11 = r31.beanInfo.creatorConstructorParameterTypes[r7];
        r12 = r31.beanInfo.fields[r7];
     */
    /* JADX WARN: Code restructure failed: missing block: B:541:0x0744, code lost:
        if (r11 != java.lang.Byte.TYPE) goto L202;
     */
    /* JADX WARN: Code restructure failed: missing block: B:542:0x0746, code lost:
        r10 = java.lang.Byte.valueOf(r35);
     */
    /* JADX WARN: Code restructure failed: missing block: B:544:0x074d, code lost:
        if (r11 != java.lang.Short.TYPE) goto L205;
     */
    /* JADX WARN: Code restructure failed: missing block: B:545:0x074f, code lost:
        r10 = java.lang.Short.valueOf(r35);
     */
    /* JADX WARN: Code restructure failed: missing block: B:547:0x0756, code lost:
        if (r11 != java.lang.Integer.TYPE) goto L208;
     */
    /* JADX WARN: Code restructure failed: missing block: B:548:0x0758, code lost:
        r10 = java.lang.Integer.valueOf(r35);
     */
    /* JADX WARN: Code restructure failed: missing block: B:550:0x075f, code lost:
        if (r11 != java.lang.Long.TYPE) goto L211;
     */
    /* JADX WARN: Code restructure failed: missing block: B:551:0x0761, code lost:
        r10 = 0L;
     */
    /* JADX WARN: Code restructure failed: missing block: B:553:0x0768, code lost:
        if (r11 != java.lang.Float.TYPE) goto L214;
     */
    /* JADX WARN: Code restructure failed: missing block: B:554:0x076a, code lost:
        r10 = java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARN: Code restructure failed: missing block: B:556:0x0771, code lost:
        if (r11 != java.lang.Double.TYPE) goto L217;
     */
    /* JADX WARN: Code restructure failed: missing block: B:557:0x0773, code lost:
        r10 = java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:559:0x077a, code lost:
        if (r11 != java.lang.Boolean.TYPE) goto L220;
     */
    /* JADX WARN: Code restructure failed: missing block: B:560:0x077c, code lost:
        r10 = java.lang.Boolean.FALSE;
     */
    /* JADX WARN: Code restructure failed: missing block: B:562:0x0781, code lost:
        if (r11 != java.lang.String.class) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:564:0x078a, code lost:
        if ((r12.parserFeatures & com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask) == 0) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:565:0x078c, code lost:
        r10 = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:568:0x0793, code lost:
        if (r31.beanInfo.creatorConstructorParameterTypes == null) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:570:0x079a, code lost:
        if (r7 >= r31.beanInfo.creatorConstructorParameterTypes.length) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:571:0x079c, code lost:
        r11 = r31.beanInfo.creatorConstructorParameterTypes[r7];
     */
    /* JADX WARN: Code restructure failed: missing block: B:572:0x07a4, code lost:
        if ((r11 instanceof java.lang.Class) == false) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:573:0x07a6, code lost:
        r11 = (java.lang.Class) r11;
     */
    /* JADX WARN: Code restructure failed: missing block: B:574:0x07ac, code lost:
        if (r11.isInstance(r10) != false) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:576:0x07b0, code lost:
        if ((r10 instanceof java.util.List) == false) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:577:0x07b2, code lost:
        r12 = (java.util.List) r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:578:0x07ba, code lost:
        if (r12.size() != 1) goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:580:0x07c5, code lost:
        if (r11.isInstance(r12.get(0)) == false) goto L241;
     */
    /* JADX WARN: Code restructure failed: missing block: B:581:0x07c7, code lost:
        r10 = r12.get(0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:582:0x07cb, code lost:
        r6[r7] = r10;
        r7 = r7 + 1;
        r35 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:583:0x07d3, code lost:
        r6 = r31.beanInfo.fields;
        r7 = r6.length;
        r10 = new java.lang.Object[r7];
        r11 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:584:0x07dc, code lost:
        if (r11 >= r7) goto L386;
     */
    /* JADX WARN: Code restructure failed: missing block: B:585:0x07de, code lost:
        r12 = r6[r11];
        r15 = r1.get(r12.name);
     */
    /* JADX WARN: Code restructure failed: missing block: B:586:0x07e6, code lost:
        if (r15 != null) goto L384;
     */
    /* JADX WARN: Code restructure failed: missing block: B:587:0x07e8, code lost:
        r13 = r12.fieldType;
        r33 = r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:588:0x07ee, code lost:
        if (r13 != java.lang.Byte.TYPE) goto L352;
     */
    /* JADX WARN: Code restructure failed: missing block: B:589:0x07f0, code lost:
        r15 = (byte) 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:591:0x07f8, code lost:
        if (r13 != java.lang.Short.TYPE) goto L356;
     */
    /* JADX WARN: Code restructure failed: missing block: B:592:0x07fa, code lost:
        r15 = (short) 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:594:0x0802, code lost:
        if (r13 != java.lang.Integer.TYPE) goto L360;
     */
    /* JADX WARN: Code restructure failed: missing block: B:595:0x0804, code lost:
        r15 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:597:0x080c, code lost:
        if (r13 != java.lang.Long.TYPE) goto L364;
     */
    /* JADX WARN: Code restructure failed: missing block: B:598:0x080e, code lost:
        r15 = 0L;
     */
    /* JADX WARN: Code restructure failed: missing block: B:600:0x0815, code lost:
        if (r13 != java.lang.Float.TYPE) goto L368;
     */
    /* JADX WARN: Code restructure failed: missing block: B:601:0x0817, code lost:
        r15 = java.lang.Float.valueOf(0.0f);
     */
    /* JADX WARN: Code restructure failed: missing block: B:603:0x081e, code lost:
        if (r13 != java.lang.Double.TYPE) goto L372;
     */
    /* JADX WARN: Code restructure failed: missing block: B:604:0x0820, code lost:
        r15 = java.lang.Double.valueOf(0.0d);
     */
    /* JADX WARN: Code restructure failed: missing block: B:606:0x0827, code lost:
        if (r13 != java.lang.Boolean.TYPE) goto L376;
     */
    /* JADX WARN: Code restructure failed: missing block: B:607:0x0829, code lost:
        r15 = java.lang.Boolean.FALSE;
     */
    /* JADX WARN: Code restructure failed: missing block: B:609:0x082e, code lost:
        if (r13 != java.lang.String.class) goto L383;
     */
    /* JADX WARN: Code restructure failed: missing block: B:611:0x0837, code lost:
        if ((r12.parserFeatures & com.alibaba.fastjson.parser.Feature.InitStringFieldAsEmpty.mask) == 0) goto L382;
     */
    /* JADX WARN: Code restructure failed: missing block: B:612:0x0839, code lost:
        r15 = r33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:613:0x083c, code lost:
        r33 = r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:614:0x083e, code lost:
        r10[r11] = r15;
        r11 = r11 + 1;
        r4 = r33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:615:0x0846, code lost:
        r6 = r10;
     */
    /* JADX WARN: Code restructure failed: missing block: B:617:0x084b, code lost:
        if (r31.beanInfo.creatorConstructor == null) goto L333;
     */
    /* JADX WARN: Code restructure failed: missing block: B:619:0x0851, code lost:
        if (r31.beanInfo.f0kotlin == false) goto L332;
     */
    /* JADX WARN: Code restructure failed: missing block: B:620:0x0853, code lost:
        r4 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:622:0x0855, code lost:
        if (r4 >= r6.length) goto L331;
     */
    /* JADX WARN: Code restructure failed: missing block: B:624:0x0859, code lost:
        if (r6[r4] != null) goto L330;
     */
    /* JADX WARN: Code restructure failed: missing block: B:626:0x085f, code lost:
        if (r31.beanInfo.fields == null) goto L329;
     */
    /* JADX WARN: Code restructure failed: missing block: B:628:0x0866, code lost:
        if (r4 >= r31.beanInfo.fields.length) goto L327;
     */
    /* JADX WARN: Code restructure failed: missing block: B:630:0x0872, code lost:
        if (r31.beanInfo.fields[r4].fieldClass != java.lang.String.class) goto L332;
     */
    /* JADX WARN: Code restructure failed: missing block: B:631:0x0874, code lost:
        r28 = true;
     */
    /* JADX WARN: Code restructure failed: missing block: B:632:0x0877, code lost:
        r4 = r4 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:633:0x087a, code lost:
        r28 = false;
     */
    /* JADX WARN: Code restructure failed: missing block: B:634:0x087c, code lost:
        if (r28 == false) goto L261;
     */
    /* JADX WARN: Code restructure failed: missing block: B:636:0x0882, code lost:
        if (r31.beanInfo.kotlinDefaultConstructor == null) goto L261;
     */
    /* JADX WARN: Code restructure failed: missing block: B:637:0x0884, code lost:
        r4 = r31.beanInfo.kotlinDefaultConstructor.newInstance(new java.lang.Object[0]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:638:0x088f, code lost:
        r7 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:640:0x0891, code lost:
        if (r7 >= r6.length) goto L320;
     */
    /* JADX WARN: Code restructure failed: missing block: B:641:0x0893, code lost:
        r10 = r6[r7];
     */
    /* JADX WARN: Code restructure failed: missing block: B:642:0x0895, code lost:
        if (r10 == null) goto L319;
     */
    /* JADX WARN: Code restructure failed: missing block: B:644:0x089b, code lost:
        if (r31.beanInfo.fields == null) goto L318;
     */
    /* JADX WARN: Code restructure failed: missing block: B:646:0x08a2, code lost:
        if (r7 >= r31.beanInfo.fields.length) goto L317;
     */
    /* JADX WARN: Code restructure failed: missing block: B:647:0x08a4, code lost:
        r31.beanInfo.fields[r7].set(r4, r10);
     */
    /* JADX WARN: Code restructure failed: missing block: B:648:0x08ad, code lost:
        r7 = r7 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:649:0x08b0, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:650:0x08b1, code lost:
        r1 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:651:0x08b3, code lost:
        r4 = r31.beanInfo.creatorConstructor.newInstance(r6);
     */
    /* JADX WARN: Code restructure failed: missing block: B:652:0x08bb, code lost:
        if (r2 == null) goto L274;
     */
    /* JADX WARN: Code restructure failed: missing block: B:653:0x08bd, code lost:
        r1 = r1.entrySet().iterator();
     */
    /* JADX WARN: Code restructure failed: missing block: B:655:0x08c9, code lost:
        if (r1.hasNext() == false) goto L273;
     */
    /* JADX WARN: Code restructure failed: missing block: B:656:0x08cb, code lost:
        r2 = r1.next();
        r6 = getFieldDeserializer(r2.getKey());
     */
    /* JADX WARN: Code restructure failed: missing block: B:657:0x08db, code lost:
        if (r6 == null) goto L272;
     */
    /* JADX WARN: Code restructure failed: missing block: B:658:0x08dd, code lost:
        r6.setValue(r4, r2.getValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:659:0x08e5, code lost:
        r14 = (T) r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:660:0x08e7, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:661:0x08e8, code lost:
        r1 = r0;
        r14 = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:663:0x0910, code lost:
        throw new com.alibaba.fastjson.JSONException("create instance error, " + r2 + ", " + r31.beanInfo.creatorConstructor.toGenericString(), r1);
     */
    /* JADX WARN: Code restructure failed: missing block: B:664:0x0911, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:665:0x0912, code lost:
        r1 = r0;
        r14 = r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:667:0x0919, code lost:
        if (r31.beanInfo.factoryMethod == null) goto L275;
     */
    /* JADX WARN: Code restructure failed: missing block: B:669:0x0924, code lost:
        r14 = (T) r31.beanInfo.factoryMethod.invoke(null, r6);
     */
    /* JADX WARN: Code restructure failed: missing block: B:670:0x0926, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:673:0x0946, code lost:
        throw new com.alibaba.fastjson.JSONException("create factory method error, " + r31.beanInfo.factoryMethod.toString(), r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:674:0x0947, code lost:
        if (r5 == null) goto L277;
     */
    /* JADX WARN: Code restructure failed: missing block: B:675:0x0949, code lost:
        r5.object = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:676:0x094c, code lost:
        r3 = r30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:677:0x094e, code lost:
        r1 = r31.beanInfo.buildMethod;
     */
    /* JADX WARN: Code restructure failed: missing block: B:678:0x0952, code lost:
        if (r1 != null) goto L283;
     */
    /* JADX WARN: Code restructure failed: missing block: B:679:0x0954, code lost:
        if (r5 == null) goto L281;
     */
    /* JADX WARN: Code restructure failed: missing block: B:680:0x0956, code lost:
        r5.object = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:681:0x0958, code lost:
        r32.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:682:0x095b, code lost:
        return (T) r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:684:0x095d, code lost:
        r1 = (T) r1.invoke(r14, new java.lang.Object[0]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:685:0x0963, code lost:
        if (r5 == null) goto L288;
     */
    /* JADX WARN: Code restructure failed: missing block: B:686:0x0965, code lost:
        r5.object = r14;
     */
    /* JADX WARN: Code restructure failed: missing block: B:687:0x0967, code lost:
        r32.setContext(r3);
     */
    /* JADX WARN: Code restructure failed: missing block: B:688:0x096a, code lost:
        return r1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:689:0x096b, code lost:
        r0 = move-exception;
     */
    /* JADX WARN: Code restructure failed: missing block: B:692:0x0974, code lost:
        throw new com.alibaba.fastjson.JSONException("build object error", r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:693:0x0975, code lost:
        r0 = th;
     */
    /* JADX WARN: Code restructure failed: missing block: B:694:0x0976, code lost:
        r1 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:695:0x0977, code lost:
        r15 = r5;
     */
    /* JADX WARN: Code restructure failed: missing block: B:704:0x09c3, code lost:
        throw new com.alibaba.fastjson.JSONException("syntax error, unexpect token " + com.alibaba.fastjson.parser.JSONToken.name(r12.token()));
     */
    /* JADX WARN: Removed duplicated region for block: B:251:0x030b A[Catch: all -> 0x03e2, TryCatch #1 {all -> 0x03e2, blocks: (B:312:0x03bd, B:314:0x03c7, B:318:0x03d4, B:328:0x03ef, B:330:0x03f8, B:332:0x0404, B:333:0x0408, B:335:0x0410, B:337:0x0416, B:338:0x041a, B:339:0x0426, B:342:0x042f, B:344:0x0433, B:345:0x0436, B:347:0x043a, B:348:0x043d, B:349:0x0449, B:351:0x0451, B:352:0x0457, B:354:0x045d, B:356:0x0463, B:357:0x0469, B:358:0x046f, B:359:0x0473, B:362:0x047b, B:374:0x04ab, B:375:0x04c5, B:377:0x04c8, B:390:0x0501, B:392:0x0509, B:395:0x0515, B:397:0x051d, B:399:0x0525, B:401:0x052d, B:403:0x0534, B:405:0x053f, B:410:0x0551, B:412:0x0555, B:414:0x055b, B:139:0x01e3, B:146:0x01f1, B:150:0x01ff, B:157:0x020e, B:159:0x0212, B:162:0x021b, B:167:0x0225, B:170:0x022e, B:175:0x0238, B:178:0x0241, B:181:0x0247, B:186:0x0251, B:191:0x025b, B:196:0x0265, B:198:0x026b, B:201:0x0279, B:203:0x0281, B:205:0x0285, B:208:0x0295, B:215:0x02a6, B:218:0x02b0, B:223:0x02bb, B:226:0x02c5, B:231:0x02d0, B:234:0x02da, B:237:0x02e1, B:241:0x02ed, B:243:0x02f5, B:248:0x0305, B:251:0x030b, B:247:0x0300, B:254:0x0312, B:256:0x031c, B:260:0x0328, B:263:0x032d, B:259:0x0323, B:266:0x0334, B:270:0x0346, B:273:0x034b, B:269:0x0341, B:276:0x0351, B:278:0x035b, B:282:0x0367, B:285:0x036c, B:281:0x0362, B:288:0x0372, B:290:0x037a, B:294:0x0386, B:297:0x038c, B:293:0x0381), top: B:727:0x03bd }] */
    /* JADX WARN: Removed duplicated region for block: B:39:0x0071 A[Catch: all -> 0x0049, TRY_LEAVE, TryCatch #6 {all -> 0x0049, blocks: (B:17:0x0039, B:19:0x003e, B:29:0x0054, B:31:0x005f, B:33:0x0067, B:39:0x0071, B:45:0x0080, B:50:0x008c, B:52:0x0096, B:55:0x009d, B:57:0x00a3, B:59:0x00af, B:61:0x00b9, B:66:0x00c6, B:68:0x00ce, B:71:0x00d8, B:73:0x00de, B:76:0x00e6, B:80:0x00f6, B:83:0x0109, B:87:0x0112, B:92:0x0123, B:93:0x012c, B:94:0x012d, B:96:0x014e, B:97:0x0156, B:98:0x0169, B:103:0x0170), top: B:735:0x0037, inners: #22 }] */
    /* JADX WARN: Removed duplicated region for block: B:432:0x05ab  */
    /* JADX WARN: Removed duplicated region for block: B:434:0x05b6 A[ADDED_TO_REGION] */
    /* JADX WARN: Removed duplicated region for block: B:437:0x05be A[Catch: all -> 0x05ea, TRY_LEAVE, TryCatch #7 {all -> 0x05ea, blocks: (B:435:0x05b8, B:437:0x05be), top: B:736:0x05b8 }] */
    /* JADX WARN: Removed duplicated region for block: B:440:0x05cb  */
    /* JADX WARN: Removed duplicated region for block: B:443:0x05d3 A[Catch: all -> 0x05e5, TRY_ENTER, TRY_LEAVE, TryCatch #3 {all -> 0x05e5, blocks: (B:420:0x056a, B:422:0x0572, B:426:0x0595, B:427:0x059e, B:443:0x05d3), top: B:730:0x056a }] */
    /* JADX WARN: Removed duplicated region for block: B:453:0x05f7  */
    /* JADX WARN: Removed duplicated region for block: B:488:0x0680  */
    /* JADX WARN: Removed duplicated region for block: B:510:0x06e7  */
    /* JADX WARN: Removed duplicated region for block: B:511:0x06eb A[Catch: all -> 0x09d0, TryCatch #11 {all -> 0x09d0, blocks: (B:508:0x06df, B:511:0x06eb, B:513:0x06f1, B:496:0x06b6, B:506:0x06d7), top: B:742:0x06df }] */
    /* JADX WARN: Removed duplicated region for block: B:719:0x09e5  */
    /* JADX WARN: Removed duplicated region for block: B:728:0x03b3 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    protected <T> T deserialze(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i, int[] iArr) {
        Object obj3;
        Throwable th;
        ParseContext parseContext;
        ParseContext parseContext2;
        ParseContext parseContext3;
        int i2;
        boolean z;
        FieldInfo fieldInfo;
        Class<?> cls;
        FieldDeserializer fieldDeserializer;
        JSONField jSONField;
        Object obj4;
        int[] iArr2;
        FieldInfo fieldInfo2;
        boolean z2;
        Throwable th2;
        Object obj5;
        String str;
        HashMap hashMap;
        int i3;
        Object obj6;
        int i4;
        int[] iArr3;
        int i5;
        Object obj7;
        boolean z3;
        Object obj8;
        String scanSymbol;
        Class<?> cls2;
        ParseContext parseContext4;
        byte b;
        int i6;
        Object obj9;
        HashMap hashMap2;
        int i7;
        ParseContext parseContext5;
        Class<?> cls3;
        Class<?>[] seeAlso;
        boolean z4;
        if (type == JSON.class || type == JSONObject.class) {
            return (T) defaultJSONParser.parse();
        }
        JSONLexerBase jSONLexerBase = (JSONLexerBase) defaultJSONParser.lexer;
        ParserConfig config = defaultJSONParser.getConfig();
        int i8 = jSONLexerBase.token();
        ParseContext parseContext6 = null;
        if (i8 == 8) {
            jSONLexerBase.nextToken(16);
            return null;
        }
        ParseContext context = defaultJSONParser.getContext();
        if (obj2 != null && context != null) {
            context = context.parent;
        }
        ParseContext parseContext7 = context;
        try {
            if (i8 == 13) {
                jSONLexerBase.nextToken(16);
                T t = obj2 == null ? (T) createInstance(defaultJSONParser, type) : (T) obj2;
                defaultJSONParser.setContext(parseContext7);
                return t;
            }
            if (i8 == 14) {
                int i9 = Feature.SupportArrayToBean.mask;
                if ((this.beanInfo.parserFeatures & i9) == 0 && !jSONLexerBase.isEnabled(Feature.SupportArrayToBean) && (i & i9) == 0) {
                    z4 = false;
                    if (z4) {
                        T t2 = (T) deserialzeArrayMapping(defaultJSONParser, type, obj, obj2);
                        defaultJSONParser.setContext(parseContext7);
                        return t2;
                    }
                }
                z4 = true;
                if (z4) {
                }
            }
            if (i8 != 12 && i8 != 16) {
                if (jSONLexerBase.isBlankInput()) {
                    defaultJSONParser.setContext(parseContext7);
                    return null;
                }
                if (i8 == 4) {
                    String stringVal = jSONLexerBase.stringVal();
                    if (stringVal.length() == 0) {
                        jSONLexerBase.nextToken();
                        defaultJSONParser.setContext(parseContext7);
                        return null;
                    } else if (this.beanInfo.jsonType != null) {
                        for (Class<?> cls4 : this.beanInfo.jsonType.seeAlso()) {
                            if (Enum.class.isAssignableFrom(cls4)) {
                                try {
                                    T t3 = (T) Enum.valueOf(cls4, stringVal);
                                    defaultJSONParser.setContext(parseContext7);
                                    return t3;
                                } catch (IllegalArgumentException unused) {
                                    continue;
                                }
                            }
                        }
                    }
                }
                if (i8 == 14 && jSONLexerBase.getCurrent() == ']') {
                    jSONLexerBase.next();
                    jSONLexerBase.nextToken();
                    defaultJSONParser.setContext(parseContext7);
                    return null;
                }
                if (this.beanInfo.factoryMethod != null && this.beanInfo.fields.length == 1) {
                    try {
                        FieldInfo fieldInfo3 = this.beanInfo.fields[0];
                        if (fieldInfo3.fieldClass == Integer.class) {
                            if (i8 == 2) {
                                int intValue = jSONLexerBase.intValue();
                                jSONLexerBase.nextToken();
                                T t4 = (T) createFactoryInstance(config, Integer.valueOf(intValue));
                                defaultJSONParser.setContext(parseContext7);
                                return t4;
                            }
                        } else if (fieldInfo3.fieldClass == String.class && i8 == 4) {
                            String stringVal2 = jSONLexerBase.stringVal();
                            jSONLexerBase.nextToken();
                            T t5 = (T) createFactoryInstance(config, stringVal2);
                            defaultJSONParser.setContext(parseContext7);
                            return t5;
                        }
                    } catch (Exception e) {
                        throw new JSONException(e.getMessage(), e);
                    }
                }
                StringBuilder sb = new StringBuilder();
                sb.append("syntax error, expect {, actual ");
                sb.append(jSONLexerBase.tokenName());
                sb.append(", pos ");
                sb.append(jSONLexerBase.pos());
                if (obj instanceof String) {
                    sb.append(", fieldName ");
                    sb.append(obj);
                }
                sb.append(", fastjson-version ");
                sb.append(JSON.VERSION);
                throw new JSONException(sb.toString());
            }
            try {
                if (defaultJSONParser.resolveStatus == 2) {
                    defaultJSONParser.resolveStatus = 0;
                }
                String str2 = this.beanInfo.typeKey;
                Object obj10 = obj2;
                int[] iArr4 = iArr;
                ParseContext parseContext8 = null;
                HashMap hashMap3 = null;
                int i10 = 0;
                int i11 = 0;
                while (true) {
                    try {
                        FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                        if (i11 >= fieldDeserializerArr.length || i10 >= 16) {
                            i2 = i11;
                            z = false;
                            fieldInfo = null;
                            cls = null;
                            fieldDeserializer = null;
                            jSONField = null;
                        } else {
                            try {
                                FieldDeserializer fieldDeserializer2 = fieldDeserializerArr[i11];
                                FieldInfo fieldInfo4 = fieldDeserializer2.fieldInfo;
                                i2 = i11;
                                Class<?> cls5 = fieldInfo4.fieldClass;
                                jSONField = fieldInfo4.getAnnotation();
                                if (jSONField != null) {
                                    cls3 = cls5;
                                    if (fieldDeserializer2 instanceof DefaultFieldDeserializer) {
                                        z = ((DefaultFieldDeserializer) fieldDeserializer2).customDeserilizer;
                                        fieldInfo = fieldInfo4;
                                        fieldDeserializer = fieldDeserializer2;
                                        cls = cls3;
                                    }
                                } else {
                                    cls3 = cls5;
                                }
                                fieldInfo = fieldInfo4;
                                z = false;
                                fieldDeserializer = fieldDeserializer2;
                                cls = cls3;
                            } catch (Throwable th3) {
                                th = th3;
                                obj3 = obj10;
                                parseContext6 = parseContext8;
                                parseContext = parseContext7;
                                th = th;
                                if (parseContext6 != null) {
                                }
                                defaultJSONParser.setContext(parseContext);
                                throw th;
                            }
                        }
                        try {
                            if (fieldDeserializer != null) {
                                iArr2 = iArr4;
                                try {
                                    char[] cArr = fieldInfo.name_chars;
                                    if (z && jSONLexerBase.matchField(cArr)) {
                                        obj4 = obj10;
                                    } else {
                                        obj4 = obj10;
                                        if (cls != Integer.TYPE && cls != Integer.class) {
                                            if (cls != Long.TYPE && cls != Long.class) {
                                                if (cls == String.class) {
                                                    obj8 = jSONLexerBase.scanFieldString(cArr);
                                                    if (jSONLexerBase.matchStat <= 0) {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i10 + 1;
                                                            str = str2;
                                                            parseContext = parseContext7;
                                                            hashMap = hashMap3;
                                                            obj6 = cls;
                                                            obj5 = obj4;
                                                        }
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                            i5 = i10;
                                                            cls2 = cls;
                                                            obj3 = obj4;
                                                            scanSymbol = null;
                                                        } else {
                                                            try {
                                                                scanSymbol = jSONLexerBase.scanSymbol(defaultJSONParser.symbolTable);
                                                                if (scanSymbol == null) {
                                                                    i5 = i10;
                                                                    try {
                                                                        int i12 = jSONLexerBase.token();
                                                                        cls2 = cls;
                                                                        if (i12 == 13) {
                                                                            jSONLexerBase.nextToken(16);
                                                                            break;
                                                                        } else if (i12 == 16) {
                                                                        }
                                                                    } catch (Throwable th4) {
                                                                        th2 = th4;
                                                                        th = th2;
                                                                        parseContext6 = parseContext8;
                                                                        parseContext = parseContext7;
                                                                        obj3 = obj4;
                                                                        if (parseContext6 != null) {
                                                                            parseContext6.object = obj3;
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext);
                                                                        throw th;
                                                                    }
                                                                } else {
                                                                    i5 = i10;
                                                                    cls2 = cls;
                                                                }
                                                                if ("$ref" == scanSymbol && parseContext7 != null) {
                                                                    jSONLexerBase.nextTokenWithColon(4);
                                                                    if (jSONLexerBase.token() != 4) {
                                                                        throw new JSONException("illegal ref, " + JSONToken.name(i6));
                                                                    }
                                                                    String stringVal3 = jSONLexerBase.stringVal();
                                                                    if ("@".equals(stringVal3)) {
                                                                        obj9 = (T) parseContext7.object;
                                                                    } else if (PdrUtil.FILE_PATH_ENTRY_BACK.equals(stringVal3)) {
                                                                        ParseContext parseContext9 = parseContext7.parent;
                                                                        if (parseContext9.object != null) {
                                                                            obj9 = (T) parseContext9.object;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext9, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            obj9 = (T) obj4;
                                                                        }
                                                                    } else if (Operators.DOLLAR_STR.equals(stringVal3)) {
                                                                        ParseContext parseContext10 = parseContext7;
                                                                        while (parseContext10.parent != null) {
                                                                            parseContext10 = parseContext10.parent;
                                                                        }
                                                                        if (parseContext10.object != null) {
                                                                            obj9 = (T) parseContext10.object;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext10, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            obj9 = (T) obj4;
                                                                        }
                                                                    } else {
                                                                        if (stringVal3.indexOf(92) > 0) {
                                                                            StringBuilder sb2 = new StringBuilder();
                                                                            int i13 = 0;
                                                                            while (i13 < stringVal3.length()) {
                                                                                char charAt = stringVal3.charAt(i13);
                                                                                if (charAt == '\\') {
                                                                                    i13++;
                                                                                    charAt = stringVal3.charAt(i13);
                                                                                }
                                                                                sb2.append(charAt);
                                                                                i13++;
                                                                            }
                                                                            stringVal3 = sb2.toString();
                                                                        }
                                                                        Object resolveReference = defaultJSONParser.resolveReference(stringVal3);
                                                                        if (resolveReference != null) {
                                                                            obj9 = (T) resolveReference;
                                                                        } else {
                                                                            defaultJSONParser.addResolveTask(new DefaultJSONParser.ResolveTask(parseContext7, stringVal3));
                                                                            defaultJSONParser.resolveStatus = 1;
                                                                            obj9 = (T) obj4;
                                                                        }
                                                                    }
                                                                    jSONLexerBase.nextToken(13);
                                                                    if (jSONLexerBase.token() == 13) {
                                                                        jSONLexerBase.nextToken(16);
                                                                        defaultJSONParser.setContext(parseContext7, obj9, obj);
                                                                        if (parseContext8 != null) {
                                                                            parseContext8.object = obj9;
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext7);
                                                                        return (T) obj9;
                                                                    }
                                                                    throw new JSONException("illegal ref");
                                                                } else if ((str2 == null || !str2.equals(scanSymbol)) && JSON.DEFAULT_TYPE_KEY != scanSymbol) {
                                                                    obj3 = obj4;
                                                                } else {
                                                                    jSONLexerBase.nextTokenWithColon(4);
                                                                    if (jSONLexerBase.token() != 4) {
                                                                        throw new JSONException("syntax error");
                                                                    }
                                                                    String stringVal4 = jSONLexerBase.stringVal();
                                                                    jSONLexerBase.nextToken(16);
                                                                    try {
                                                                        if (!stringVal4.equals(this.beanInfo.typeName) && !defaultJSONParser.isEnabled(Feature.IgnoreAutoType)) {
                                                                            ObjectDeserializer seeAlso2 = getSeeAlso(config, this.beanInfo, stringVal4);
                                                                            if (seeAlso2 != null) {
                                                                                Class<?> cls6 = null;
                                                                                break;
                                                                            }
                                                                            Class<?> cls7 = TypeUtils.getClass(type);
                                                                            ParserConfig.AutoTypeCheckHandler autoTypeCheckHandler = this.autoTypeCheckHandler;
                                                                            Class<?> handler = autoTypeCheckHandler != null ? autoTypeCheckHandler.handler(stringVal4, cls7, jSONLexerBase.getFeatures()) : null;
                                                                            if (handler != null || (!stringVal4.equals("java.util.HashMap") && !stringVal4.equals("java.util.LinkedHashMap"))) {
                                                                                break;
                                                                            }
                                                                            if (jSONLexerBase.token() == 13) {
                                                                                jSONLexerBase.nextToken();
                                                                                break;
                                                                            }
                                                                            obj7 = obj4;
                                                                            i4 = i2;
                                                                            str = str2;
                                                                            parseContext = parseContext7;
                                                                            obj5 = obj7;
                                                                            hashMap = hashMap3;
                                                                            i3 = i5;
                                                                            obj6 = obj7;
                                                                        }
                                                                        obj7 = obj3;
                                                                        if (jSONLexerBase.token() == 13) {
                                                                            jSONLexerBase.nextToken();
                                                                            Object obj11 = obj3;
                                                                            break;
                                                                        }
                                                                        i4 = i2;
                                                                        str = str2;
                                                                        parseContext = parseContext7;
                                                                        obj5 = obj7;
                                                                        hashMap = hashMap3;
                                                                        i3 = i5;
                                                                        obj6 = obj7;
                                                                    } catch (Throwable th5) {
                                                                        th = th5;
                                                                        th = th;
                                                                        parseContext6 = parseContext8;
                                                                        parseContext = parseContext7;
                                                                        if (parseContext6 != null) {
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext);
                                                                        throw th;
                                                                    }
                                                                    obj3 = obj4;
                                                                }
                                                            } catch (Throwable th6) {
                                                                th = th6;
                                                                obj3 = obj4;
                                                            }
                                                        }
                                                        if (obj3 == null && hashMap3 == null) {
                                                            try {
                                                                obj3 = (T) createInstance(defaultJSONParser, type);
                                                                if (obj3 != null) {
                                                                    parseContext5 = parseContext8;
                                                                    try {
                                                                        hashMap3 = new HashMap(this.fieldDeserializers.length);
                                                                    } catch (Throwable th7) {
                                                                        th = th7;
                                                                        th = th;
                                                                        parseContext = parseContext7;
                                                                        parseContext3 = parseContext5;
                                                                        parseContext6 = parseContext3;
                                                                        if (parseContext6 != null) {
                                                                        }
                                                                        defaultJSONParser.setContext(parseContext);
                                                                        throw th;
                                                                    }
                                                                } else {
                                                                    parseContext5 = parseContext8;
                                                                }
                                                                parseContext8 = defaultJSONParser.setContext(parseContext7, obj3, obj);
                                                                if (iArr2 == null) {
                                                                    parseContext2 = parseContext8;
                                                                    hashMap2 = hashMap3;
                                                                    iArr3 = new int[(this.fieldDeserializers.length / 32) + 1];
                                                                    if (z2) {
                                                                        i3 = i5;
                                                                        String str3 = scanSymbol;
                                                                        i4 = i2;
                                                                        hashMap = hashMap2;
                                                                        b = 0;
                                                                        str = str2;
                                                                        i7 = 13;
                                                                        parseContext4 = parseContext7;
                                                                        if (parseField(defaultJSONParser, str3, obj3, type, hashMap2 == null ? new HashMap(this.fieldDeserializers.length) : hashMap2, iArr3)) {
                                                                            if (jSONLexerBase.token() == 17) {
                                                                                throw new JSONException("syntax error, unexpect token ':'");
                                                                            }
                                                                            if (jSONLexerBase.token() != 16) {
                                                                            }
                                                                        } else {
                                                                            try {
                                                                                if (jSONLexerBase.token() == 13) {
                                                                                    break;
                                                                                }
                                                                                parseContext = parseContext4;
                                                                                parseContext8 = parseContext2;
                                                                                parseContext2 = obj3;
                                                                                obj3 = obj3;
                                                                            } catch (Throwable th8) {
                                                                                th = th8;
                                                                                parseContext6 = parseContext2;
                                                                                parseContext = parseContext4;
                                                                                if (parseContext6 != null) {
                                                                                }
                                                                                defaultJSONParser.setContext(parseContext);
                                                                                throw th;
                                                                            }
                                                                        }
                                                                    } else {
                                                                        if (z3) {
                                                                            FieldInfo fieldInfo5 = fieldInfo2;
                                                                            if (obj3 == null) {
                                                                                hashMap2.put(fieldInfo5.name, obj8);
                                                                            } else if (obj8 == null) {
                                                                                Class<?> cls8 = cls2;
                                                                                if (cls8 != Integer.TYPE && cls8 != Long.TYPE && cls8 != Float.TYPE && cls8 != Double.TYPE && cls8 != Boolean.TYPE) {
                                                                                    fieldDeserializer.setValue(obj3, obj8);
                                                                                }
                                                                            } else {
                                                                                String str4 = obj8;
                                                                                if (cls2 == String.class) {
                                                                                    if ((i & Feature.TrimStringFieldValue.mask) == 0 && (this.beanInfo.parserFeatures & Feature.TrimStringFieldValue.mask) == 0) {
                                                                                        str4 = obj8;
                                                                                    }
                                                                                    str4 = ((String) obj8).trim();
                                                                                }
                                                                                fieldDeserializer.setValue(obj3, str4);
                                                                            }
                                                                            if (iArr3 != null) {
                                                                                int i14 = i2 / 32;
                                                                                iArr3[i14] = (1 << (i2 % 32)) | iArr3[i14];
                                                                            }
                                                                            if (jSONLexerBase.matchStat == 4) {
                                                                                hashMap = hashMap2;
                                                                                parseContext4 = parseContext7;
                                                                                b = 0;
                                                                                break;
                                                                            }
                                                                        } else {
                                                                            fieldDeserializer.parseField(defaultJSONParser, obj3, type, hashMap2);
                                                                        }
                                                                        i4 = i2;
                                                                        hashMap = hashMap2;
                                                                        str = str2;
                                                                        parseContext4 = parseContext7;
                                                                        i3 = i5;
                                                                        b = 0;
                                                                        i7 = 13;
                                                                        try {
                                                                            if (jSONLexerBase.token() != 16) {
                                                                                parseContext = parseContext4;
                                                                                parseContext8 = parseContext2;
                                                                                parseContext2 = obj3;
                                                                                obj3 = obj3;
                                                                            } else if (jSONLexerBase.token() == i7) {
                                                                                break;
                                                                            } else {
                                                                                parseContext = parseContext4;
                                                                                if (jSONLexerBase.token() == 18 || jSONLexerBase.token() == 1) {
                                                                                    break;
                                                                                }
                                                                                parseContext8 = parseContext2;
                                                                                parseContext2 = obj3;
                                                                                obj3 = obj3;
                                                                            }
                                                                        } catch (Throwable th9) {
                                                                            th = th9;
                                                                            parseContext = parseContext4;
                                                                            th = th;
                                                                            parseContext3 = parseContext2;
                                                                            parseContext6 = parseContext3;
                                                                            if (parseContext6 != null) {
                                                                            }
                                                                            defaultJSONParser.setContext(parseContext);
                                                                            throw th;
                                                                        }
                                                                    }
                                                                    i11 = i4 + 1;
                                                                    iArr4 = iArr3;
                                                                    hashMap3 = hashMap;
                                                                    str2 = str;
                                                                    obj10 = parseContext2;
                                                                    parseContext7 = parseContext;
                                                                    i10 = i3;
                                                                }
                                                            } catch (Throwable th10) {
                                                                th = th10;
                                                                parseContext5 = parseContext8;
                                                            }
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    }
                                                    fieldInfo2 = fieldInfo;
                                                    z2 = true;
                                                    z3 = true;
                                                    if (z2) {
                                                    }
                                                    if (obj3 == null) {
                                                        obj3 = (T) createInstance(defaultJSONParser, type);
                                                        if (obj3 != null) {
                                                        }
                                                        parseContext8 = defaultJSONParser.setContext(parseContext7, obj3, obj);
                                                        if (iArr2 == null) {
                                                        }
                                                    }
                                                    parseContext2 = parseContext8;
                                                    hashMap2 = hashMap3;
                                                    iArr3 = iArr2;
                                                    if (z2) {
                                                    }
                                                    i11 = i4 + 1;
                                                    iArr4 = iArr3;
                                                    hashMap3 = hashMap;
                                                    str2 = str;
                                                    obj10 = parseContext2;
                                                    parseContext7 = parseContext;
                                                    i10 = i3;
                                                } else if (cls == Date.class && fieldInfo.format == null) {
                                                    obj8 = jSONLexerBase.scanFieldDate(cArr);
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i10 + 1;
                                                            str = str2;
                                                            parseContext = parseContext7;
                                                            hashMap = hashMap3;
                                                            obj6 = cls;
                                                            obj5 = obj4;
                                                        }
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    }
                                                } else if (cls == BigDecimal.class) {
                                                    obj8 = jSONLexerBase.scanFieldDecimal(cArr);
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i10 + 1;
                                                            str = str2;
                                                            parseContext = parseContext7;
                                                            hashMap = hashMap3;
                                                            obj6 = cls;
                                                            obj5 = obj4;
                                                        }
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    }
                                                } else if (cls == BigInteger.class) {
                                                    obj8 = jSONLexerBase.scanFieldBigInteger(cArr);
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i10 + 1;
                                                            str = str2;
                                                            parseContext = parseContext7;
                                                            hashMap = hashMap3;
                                                            obj6 = cls;
                                                            obj5 = obj4;
                                                        }
                                                        fieldInfo2 = fieldInfo;
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    }
                                                } else {
                                                    if (cls != Boolean.TYPE && cls != Boolean.class) {
                                                        if (cls != Float.TYPE && cls != Float.class) {
                                                            if (cls != Double.TYPE && cls != Double.class) {
                                                                if (cls.isEnum() && (defaultJSONParser.getConfig().getDeserializer(cls) instanceof EnumDeserializer) && (jSONField == null || jSONField.deserializeUsing() == Void.class)) {
                                                                    if (fieldDeserializer instanceof DefaultFieldDeserializer) {
                                                                        obj8 = scanEnum(jSONLexerBase, cArr, ((DefaultFieldDeserializer) fieldDeserializer).fieldValueDeserilizer);
                                                                        if (jSONLexerBase.matchStat > 0) {
                                                                            z2 = true;
                                                                            z3 = true;
                                                                        } else if (jSONLexerBase.matchStat != -2) {
                                                                            z2 = false;
                                                                            z3 = false;
                                                                        }
                                                                        fieldInfo2 = fieldInfo;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    }
                                                                } else if (cls == int[].class) {
                                                                    obj8 = jSONLexerBase.scanFieldIntArray(cArr);
                                                                    if (jSONLexerBase.matchStat > 0) {
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = true;
                                                                        z3 = true;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    } else {
                                                                        if (jSONLexerBase.matchStat == -2) {
                                                                        }
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = false;
                                                                        z3 = false;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    }
                                                                } else if (cls == float[].class) {
                                                                    obj8 = jSONLexerBase.scanFieldFloatArray(cArr);
                                                                    if (jSONLexerBase.matchStat > 0) {
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = true;
                                                                        z3 = true;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    } else {
                                                                        if (jSONLexerBase.matchStat == -2) {
                                                                        }
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = false;
                                                                        z3 = false;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    }
                                                                } else if (cls == float[][].class) {
                                                                    obj8 = jSONLexerBase.scanFieldFloatArray2(cArr);
                                                                    if (jSONLexerBase.matchStat > 0) {
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = true;
                                                                        z3 = true;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    } else {
                                                                        if (jSONLexerBase.matchStat == -2) {
                                                                        }
                                                                        fieldInfo2 = fieldInfo;
                                                                        z2 = false;
                                                                        z3 = false;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    }
                                                                } else if (!jSONLexerBase.matchField(cArr)) {
                                                                    i5 = i10;
                                                                    obj7 = obj4;
                                                                    i4 = i2;
                                                                    str = str2;
                                                                    parseContext = parseContext7;
                                                                    obj5 = obj7;
                                                                    hashMap = hashMap3;
                                                                    i3 = i5;
                                                                    obj6 = obj7;
                                                                }
                                                                i4 = i2;
                                                                i3 = i10 + 1;
                                                                str = str2;
                                                                parseContext = parseContext7;
                                                                hashMap = hashMap3;
                                                                obj6 = cls;
                                                                obj5 = obj4;
                                                            }
                                                            double scanFieldDouble = jSONLexerBase.scanFieldDouble(cArr);
                                                            if (scanFieldDouble == 0.0d) {
                                                                fieldInfo2 = fieldInfo;
                                                                if (jSONLexerBase.matchStat == 5) {
                                                                    obj8 = null;
                                                                    if (jSONLexerBase.matchStat <= 0) {
                                                                        if (jSONLexerBase.matchStat == -2) {
                                                                            i4 = i2;
                                                                            i3 = i10 + 1;
                                                                            str = str2;
                                                                            parseContext = parseContext7;
                                                                            hashMap = hashMap3;
                                                                            obj6 = cls;
                                                                            obj5 = obj4;
                                                                        }
                                                                        z2 = false;
                                                                        z3 = false;
                                                                        if (z2) {
                                                                        }
                                                                        if (obj3 == null) {
                                                                        }
                                                                        parseContext2 = parseContext8;
                                                                        hashMap2 = hashMap3;
                                                                        iArr3 = iArr2;
                                                                        if (z2) {
                                                                        }
                                                                        i11 = i4 + 1;
                                                                        iArr4 = iArr3;
                                                                        hashMap3 = hashMap;
                                                                        str2 = str;
                                                                        obj10 = parseContext2;
                                                                        parseContext7 = parseContext;
                                                                        i10 = i3;
                                                                    }
                                                                    z2 = true;
                                                                    z3 = true;
                                                                    if (z2) {
                                                                    }
                                                                    if (obj3 == null) {
                                                                    }
                                                                    parseContext2 = parseContext8;
                                                                    hashMap2 = hashMap3;
                                                                    iArr3 = iArr2;
                                                                    if (z2) {
                                                                    }
                                                                    i11 = i4 + 1;
                                                                    iArr4 = iArr3;
                                                                    hashMap3 = hashMap;
                                                                    str2 = str;
                                                                    obj10 = parseContext2;
                                                                    parseContext7 = parseContext;
                                                                    i10 = i3;
                                                                }
                                                            } else {
                                                                fieldInfo2 = fieldInfo;
                                                            }
                                                            obj8 = Double.valueOf(scanFieldDouble);
                                                            if (jSONLexerBase.matchStat <= 0) {
                                                            }
                                                            z2 = true;
                                                            z3 = true;
                                                            if (z2) {
                                                            }
                                                            if (obj3 == null) {
                                                            }
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap3;
                                                            iArr3 = iArr2;
                                                            if (z2) {
                                                            }
                                                            i11 = i4 + 1;
                                                            iArr4 = iArr3;
                                                            hashMap3 = hashMap;
                                                            str2 = str;
                                                            obj10 = parseContext2;
                                                            parseContext7 = parseContext;
                                                            i10 = i3;
                                                        }
                                                        fieldInfo2 = fieldInfo;
                                                        float scanFieldFloat = jSONLexerBase.scanFieldFloat(cArr);
                                                        obj8 = (scanFieldFloat == 0.0f && jSONLexerBase.matchStat == 5) ? null : Float.valueOf(scanFieldFloat);
                                                        if (jSONLexerBase.matchStat > 0) {
                                                            z2 = true;
                                                            z3 = true;
                                                            if (z2) {
                                                            }
                                                            if (obj3 == null) {
                                                            }
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap3;
                                                            iArr3 = iArr2;
                                                            if (z2) {
                                                            }
                                                            i11 = i4 + 1;
                                                            iArr4 = iArr3;
                                                            hashMap3 = hashMap;
                                                            str2 = str;
                                                            obj10 = parseContext2;
                                                            parseContext7 = parseContext;
                                                            i10 = i3;
                                                        } else {
                                                            if (jSONLexerBase.matchStat == -2) {
                                                                i4 = i2;
                                                                i3 = i10 + 1;
                                                                str = str2;
                                                                parseContext = parseContext7;
                                                                hashMap = hashMap3;
                                                                obj6 = cls;
                                                                obj5 = obj4;
                                                            }
                                                            z2 = false;
                                                            z3 = false;
                                                            if (z2) {
                                                            }
                                                            if (obj3 == null) {
                                                            }
                                                            parseContext2 = parseContext8;
                                                            hashMap2 = hashMap3;
                                                            iArr3 = iArr2;
                                                            if (z2) {
                                                            }
                                                            i11 = i4 + 1;
                                                            iArr4 = iArr3;
                                                            hashMap3 = hashMap;
                                                            str2 = str;
                                                            obj10 = parseContext2;
                                                            parseContext7 = parseContext;
                                                            i10 = i3;
                                                        }
                                                    }
                                                    fieldInfo2 = fieldInfo;
                                                    obj8 = jSONLexerBase.matchStat == 5 ? null : Boolean.valueOf(jSONLexerBase.scanFieldBoolean(cArr));
                                                    if (jSONLexerBase.matchStat > 0) {
                                                        z2 = true;
                                                        z3 = true;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    } else {
                                                        if (jSONLexerBase.matchStat == -2) {
                                                            i4 = i2;
                                                            i3 = i10 + 1;
                                                            str = str2;
                                                            parseContext = parseContext7;
                                                            hashMap = hashMap3;
                                                            obj6 = cls;
                                                            obj5 = obj4;
                                                        }
                                                        z2 = false;
                                                        z3 = false;
                                                        if (z2) {
                                                        }
                                                        if (obj3 == null) {
                                                        }
                                                        parseContext2 = parseContext8;
                                                        hashMap2 = hashMap3;
                                                        iArr3 = iArr2;
                                                        if (z2) {
                                                        }
                                                        i11 = i4 + 1;
                                                        iArr4 = iArr3;
                                                        hashMap3 = hashMap;
                                                        str2 = str;
                                                        obj10 = parseContext2;
                                                        parseContext7 = parseContext;
                                                        i10 = i3;
                                                    }
                                                }
                                                iArr3 = iArr2;
                                                obj3 = obj6;
                                                parseContext2 = obj5;
                                                i11 = i4 + 1;
                                                iArr4 = iArr3;
                                                hashMap3 = hashMap;
                                                str2 = str;
                                                obj10 = parseContext2;
                                                parseContext7 = parseContext;
                                                i10 = i3;
                                            }
                                            fieldInfo2 = fieldInfo;
                                            long scanFieldLong = jSONLexerBase.scanFieldLong(cArr);
                                            obj8 = (scanFieldLong == 0 && jSONLexerBase.matchStat == 5) ? null : Long.valueOf(scanFieldLong);
                                            if (jSONLexerBase.matchStat > 0) {
                                                z2 = true;
                                                z3 = true;
                                                if (z2) {
                                                }
                                                if (obj3 == null) {
                                                }
                                                parseContext2 = parseContext8;
                                                hashMap2 = hashMap3;
                                                iArr3 = iArr2;
                                                if (z2) {
                                                }
                                                i11 = i4 + 1;
                                                iArr4 = iArr3;
                                                hashMap3 = hashMap;
                                                str2 = str;
                                                obj10 = parseContext2;
                                                parseContext7 = parseContext;
                                                i10 = i3;
                                            } else {
                                                if (jSONLexerBase.matchStat == -2) {
                                                    i4 = i2;
                                                    i3 = i10 + 1;
                                                    str = str2;
                                                    parseContext = parseContext7;
                                                    hashMap = hashMap3;
                                                    obj6 = cls;
                                                    obj5 = obj4;
                                                    iArr3 = iArr2;
                                                    obj3 = obj6;
                                                    parseContext2 = obj5;
                                                    i11 = i4 + 1;
                                                    iArr4 = iArr3;
                                                    hashMap3 = hashMap;
                                                    str2 = str;
                                                    obj10 = parseContext2;
                                                    parseContext7 = parseContext;
                                                    i10 = i3;
                                                }
                                                z2 = false;
                                                z3 = false;
                                                if (z2) {
                                                }
                                                if (obj3 == null) {
                                                }
                                                parseContext2 = parseContext8;
                                                hashMap2 = hashMap3;
                                                iArr3 = iArr2;
                                                if (z2) {
                                                }
                                                i11 = i4 + 1;
                                                iArr4 = iArr3;
                                                hashMap3 = hashMap;
                                                str2 = str;
                                                obj10 = parseContext2;
                                                parseContext7 = parseContext;
                                                i10 = i3;
                                            }
                                        }
                                        fieldInfo2 = fieldInfo;
                                        int scanFieldInt = jSONLexerBase.scanFieldInt(cArr);
                                        obj8 = (scanFieldInt == 0 && jSONLexerBase.matchStat == 5) ? null : Integer.valueOf(scanFieldInt);
                                        if (jSONLexerBase.matchStat > 0) {
                                            z2 = true;
                                            z3 = true;
                                            if (z2) {
                                            }
                                            if (obj3 == null) {
                                            }
                                            parseContext2 = parseContext8;
                                            hashMap2 = hashMap3;
                                            iArr3 = iArr2;
                                            if (z2) {
                                            }
                                            i11 = i4 + 1;
                                            iArr4 = iArr3;
                                            hashMap3 = hashMap;
                                            str2 = str;
                                            obj10 = parseContext2;
                                            parseContext7 = parseContext;
                                            i10 = i3;
                                        }
                                    }
                                    fieldInfo2 = fieldInfo;
                                    z2 = true;
                                    obj8 = null;
                                    z3 = false;
                                    if (z2) {
                                    }
                                    if (obj3 == null) {
                                    }
                                    parseContext2 = parseContext8;
                                    hashMap2 = hashMap3;
                                    iArr3 = iArr2;
                                    if (z2) {
                                    }
                                    i11 = i4 + 1;
                                    iArr4 = iArr3;
                                    hashMap3 = hashMap;
                                    str2 = str;
                                    obj10 = parseContext2;
                                    parseContext7 = parseContext;
                                    i10 = i3;
                                } catch (Throwable th11) {
                                    th2 = th11;
                                    obj4 = obj10;
                                    th = th2;
                                    parseContext6 = parseContext8;
                                    parseContext = parseContext7;
                                    obj3 = obj4;
                                    if (parseContext6 != null) {
                                    }
                                    defaultJSONParser.setContext(parseContext);
                                    throw th;
                                }
                            } else {
                                obj4 = obj10;
                                iArr2 = iArr4;
                            }
                            i11 = i4 + 1;
                            iArr4 = iArr3;
                            hashMap3 = hashMap;
                            str2 = str;
                            obj10 = parseContext2;
                            parseContext7 = parseContext;
                            i10 = i3;
                        } catch (Throwable th12) {
                            th = th12;
                            th = th;
                            parseContext3 = parseContext2;
                            parseContext6 = parseContext3;
                            if (parseContext6 != null) {
                            }
                            defaultJSONParser.setContext(parseContext);
                            throw th;
                        }
                        fieldInfo2 = fieldInfo;
                        z2 = false;
                        obj8 = null;
                        z3 = false;
                        if (z2) {
                        }
                        if (obj3 == null) {
                        }
                        parseContext2 = parseContext8;
                        hashMap2 = hashMap3;
                        iArr3 = iArr2;
                        if (z2) {
                        }
                    } catch (Throwable th13) {
                        th = th13;
                        obj3 = obj10;
                        parseContext2 = parseContext8;
                        parseContext = parseContext7;
                    }
                }
            } catch (Throwable th14) {
                th = th14;
                parseContext = parseContext7;
                obj3 = obj2;
            }
        } catch (Throwable th15) {
            obj3 = obj2;
            th = th15;
        }
    }

    protected Enum scanEnum(JSONLexerBase jSONLexerBase, char[] cArr, ObjectDeserializer objectDeserializer) {
        EnumDeserializer enumDeserializer = objectDeserializer instanceof EnumDeserializer ? (EnumDeserializer) objectDeserializer : null;
        if (enumDeserializer == null) {
            jSONLexerBase.matchStat = -1;
            return null;
        }
        long scanEnumSymbol = jSONLexerBase.scanEnumSymbol(cArr);
        if (jSONLexerBase.matchStat > 0) {
            Enum enumByHashCode = enumDeserializer.getEnumByHashCode(scanEnumSymbol);
            if (enumByHashCode == null) {
                if (scanEnumSymbol == TypeUtils.fnv1a_64_magic_hashcode) {
                    return null;
                }
                if (jSONLexerBase.isEnabled(Feature.ErrorOnEnumNotMatch)) {
                    throw new JSONException("not match enum value, " + enumDeserializer.enumClass);
                }
            }
            return enumByHashCode;
        }
        return null;
    }

    public boolean parseField(DefaultJSONParser defaultJSONParser, String str, Object obj, Type type, Map<String, Object> map) {
        return parseField(defaultJSONParser, str, obj, type, map, null);
    }

    /* JADX WARN: Removed duplicated region for block: B:111:0x0212  */
    /* JADX WARN: Removed duplicated region for block: B:59:0x0125  */
    /* JADX WARN: Type inference failed for: r17v0 */
    /* JADX WARN: Type inference failed for: r17v1, types: [boolean, int] */
    /* JADX WARN: Type inference failed for: r17v3 */
    /* JADX WARN: Type inference failed for: r17v4 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean parseField(DefaultJSONParser defaultJSONParser, String str, Object obj, Type type, Map<String, Object> map, int[] iArr) {
        FieldDeserializer fieldDeserializer;
        FieldDeserializer fieldDeserializer2;
        JSONLexer jSONLexer;
        ?? r17;
        FieldDeserializer fieldDeserializer3;
        FieldDeserializer fieldDeserializer4;
        Field[] fieldArr;
        JSONLexer jSONLexer2 = defaultJSONParser.lexer;
        int i = Feature.DisableFieldSmartMatch.mask;
        int i2 = Feature.InitStringFieldAsEmpty.mask;
        if (jSONLexer2.isEnabled(i) || (i & this.beanInfo.parserFeatures) != 0) {
            fieldDeserializer = getFieldDeserializer(str);
        } else if (jSONLexer2.isEnabled(i2) || (this.beanInfo.parserFeatures & i2) != 0) {
            fieldDeserializer = smartMatch(str);
        } else {
            fieldDeserializer = smartMatch(str, iArr);
        }
        int i3 = Feature.SupportNonPublicField.mask;
        if (fieldDeserializer != null || (!jSONLexer2.isEnabled(i3) && (i3 & this.beanInfo.parserFeatures) == 0)) {
            fieldDeserializer2 = fieldDeserializer;
        } else {
            if (this.extraFieldDeserializers == null) {
                ConcurrentHashMap concurrentHashMap = new ConcurrentHashMap(1, 0.75f, 1);
                for (Class<?> cls = this.clazz; cls != null && cls != Object.class; cls = cls.getSuperclass()) {
                    Field[] declaredFields = cls.getDeclaredFields();
                    int length = declaredFields.length;
                    int i4 = 0;
                    while (i4 < length) {
                        Field field = declaredFields[i4];
                        String name = field.getName();
                        if (getFieldDeserializer(name) == null) {
                            int modifiers = field.getModifiers();
                            if ((modifiers & 16) == 0 && (modifiers & 8) == 0) {
                                fieldDeserializer4 = fieldDeserializer;
                                JSONField jSONField = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                                if (jSONField != null) {
                                    String name2 = jSONField.name();
                                    fieldArr = declaredFields;
                                    if (!"".equals(name2)) {
                                        name = name2;
                                    }
                                } else {
                                    fieldArr = declaredFields;
                                }
                                concurrentHashMap.put(name, field);
                                i4++;
                                fieldDeserializer = fieldDeserializer4;
                                declaredFields = fieldArr;
                            }
                        }
                        fieldDeserializer4 = fieldDeserializer;
                        fieldArr = declaredFields;
                        i4++;
                        fieldDeserializer = fieldDeserializer4;
                        declaredFields = fieldArr;
                    }
                }
                fieldDeserializer2 = fieldDeserializer;
                this.extraFieldDeserializers = concurrentHashMap;
            } else {
                fieldDeserializer2 = fieldDeserializer;
            }
            Object obj2 = this.extraFieldDeserializers.get(str);
            if (obj2 != null) {
                if (obj2 instanceof FieldDeserializer) {
                    fieldDeserializer3 = (FieldDeserializer) obj2;
                    jSONLexer = jSONLexer2;
                    r17 = 1;
                } else {
                    Field field2 = (Field) obj2;
                    field2.setAccessible(true);
                    r17 = 1;
                    jSONLexer = jSONLexer2;
                    fieldDeserializer3 = new DefaultFieldDeserializer(defaultJSONParser.getConfig(), this.clazz, new FieldInfo(str, field2.getDeclaringClass(), field2.getType(), field2.getGenericType(), field2, 0, 0, 0));
                    this.extraFieldDeserializers.put(str, fieldDeserializer3);
                }
                if (fieldDeserializer3 != null) {
                    if (!jSONLexer.isEnabled(Feature.IgnoreNotMatch)) {
                        throw new JSONException("setter not found, class " + this.clazz.getName() + ", property " + str);
                    }
                    int i5 = 0;
                    int i6 = -1;
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                        if (i5 >= fieldDeserializerArr.length) {
                            break;
                        }
                        FieldDeserializer fieldDeserializer5 = fieldDeserializerArr[i5];
                        FieldInfo fieldInfo = fieldDeserializer5.fieldInfo;
                        if (fieldInfo.unwrapped && (fieldDeserializer5 instanceof DefaultFieldDeserializer)) {
                            if (fieldInfo.field != null) {
                                DefaultFieldDeserializer defaultFieldDeserializer = (DefaultFieldDeserializer) fieldDeserializer5;
                                ObjectDeserializer fieldValueDeserilizer = defaultFieldDeserializer.getFieldValueDeserilizer(defaultJSONParser.getConfig());
                                if (fieldValueDeserilizer instanceof JavaBeanDeserializer) {
                                    FieldDeserializer fieldDeserializer6 = ((JavaBeanDeserializer) fieldValueDeserilizer).getFieldDeserializer(str);
                                    if (fieldDeserializer6 != null) {
                                        try {
                                            Object obj3 = fieldInfo.field.get(obj);
                                            if (obj3 == null) {
                                                obj3 = ((JavaBeanDeserializer) fieldValueDeserilizer).createInstance(defaultJSONParser, fieldInfo.fieldType);
                                                fieldDeserializer5.setValue(obj, obj3);
                                            }
                                            jSONLexer.nextTokenWithColon(defaultFieldDeserializer.getFastMatchToken());
                                            fieldDeserializer6.parseField(defaultJSONParser, obj3, type, map);
                                            i6 = i5;
                                        } catch (Exception e) {
                                            throw new JSONException("parse unwrapped field error.", e);
                                        }
                                    } else {
                                        continue;
                                    }
                                } else if (fieldValueDeserilizer instanceof MapDeserializer) {
                                    MapDeserializer mapDeserializer = (MapDeserializer) fieldValueDeserilizer;
                                    try {
                                        Map<Object, Object> map2 = (Map) fieldInfo.field.get(obj);
                                        if (map2 == null) {
                                            map2 = mapDeserializer.createMap(fieldInfo.fieldType);
                                            fieldDeserializer5.setValue(obj, map2);
                                        }
                                        jSONLexer.nextTokenWithColon();
                                        map2.put(str, defaultJSONParser.parse(str));
                                        i6 = i5;
                                    } catch (Exception e2) {
                                        throw new JSONException("parse unwrapped field error.", e2);
                                    }
                                } else {
                                    continue;
                                }
                            } else if (fieldInfo.method.getParameterTypes().length == 2) {
                                jSONLexer.nextTokenWithColon();
                                Object parse = defaultJSONParser.parse(str);
                                try {
                                    Method method = fieldInfo.method;
                                    Object[] objArr = new Object[2];
                                    objArr[0] = str;
                                    objArr[r17] = parse;
                                    method.invoke(obj, objArr);
                                    i6 = i5;
                                } catch (Exception e3) {
                                    throw new JSONException("parse unwrapped field error.", e3);
                                }
                            } else {
                                continue;
                            }
                        }
                        i5++;
                    }
                    if (i6 == -1) {
                        defaultJSONParser.parseExtra(obj, str);
                        return false;
                    }
                    if (iArr != null) {
                        int i7 = i6 / 32;
                        iArr[i7] = iArr[i7] | (r17 << (i6 % 32));
                    }
                    return r17;
                }
                JSONLexer jSONLexer3 = jSONLexer;
                int i8 = 0;
                while (true) {
                    FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                    if (i8 >= fieldDeserializerArr2.length) {
                        i8 = -1;
                        break;
                    } else if (fieldDeserializerArr2[i8] == fieldDeserializer3) {
                        break;
                    } else {
                        i8++;
                    }
                }
                if (i8 != -1 && iArr != null && str.startsWith("_") && isSetFlag(i8, iArr)) {
                    defaultJSONParser.parseExtra(obj, str);
                    return false;
                }
                jSONLexer3.nextTokenWithColon(fieldDeserializer3.getFastMatchToken());
                fieldDeserializer3.parseField(defaultJSONParser, obj, type, map);
                if (iArr != null) {
                    int i9 = i8 / 32;
                    iArr[i9] = iArr[i9] | (r17 << (i8 % 32));
                }
                return r17;
            }
        }
        jSONLexer = jSONLexer2;
        r17 = 1;
        fieldDeserializer3 = fieldDeserializer2;
        if (fieldDeserializer3 != null) {
        }
    }

    public FieldDeserializer smartMatch(String str) {
        return smartMatch(str, null);
    }

    public FieldDeserializer smartMatch(String str, int[] iArr) {
        boolean z;
        if (str == null) {
            return null;
        }
        FieldDeserializer fieldDeserializer = getFieldDeserializer(str, iArr);
        if (fieldDeserializer == null) {
            int i = 0;
            if (this.smartMatchHashArray == null) {
                long[] jArr = new long[this.sortedFieldDeserializers.length];
                int i2 = 0;
                while (true) {
                    FieldDeserializer[] fieldDeserializerArr = this.sortedFieldDeserializers;
                    if (i2 >= fieldDeserializerArr.length) {
                        break;
                    }
                    jArr[i2] = fieldDeserializerArr[i2].fieldInfo.nameHashCode;
                    i2++;
                }
                Arrays.sort(jArr);
                this.smartMatchHashArray = jArr;
            }
            int binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_lower(str));
            if (binarySearch < 0) {
                binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(str));
            }
            if (binarySearch < 0) {
                z = str.startsWith("is");
                if (z) {
                    binarySearch = Arrays.binarySearch(this.smartMatchHashArray, TypeUtils.fnv1a_64_extract(str.substring(2)));
                }
            } else {
                z = false;
            }
            if (binarySearch >= 0) {
                if (this.smartMatchHashArrayMapping == null) {
                    short[] sArr = new short[this.smartMatchHashArray.length];
                    Arrays.fill(sArr, (short) -1);
                    while (true) {
                        FieldDeserializer[] fieldDeserializerArr2 = this.sortedFieldDeserializers;
                        if (i >= fieldDeserializerArr2.length) {
                            break;
                        }
                        int binarySearch2 = Arrays.binarySearch(this.smartMatchHashArray, fieldDeserializerArr2[i].fieldInfo.nameHashCode);
                        if (binarySearch2 >= 0) {
                            sArr[binarySearch2] = (short) i;
                        }
                        i++;
                    }
                    this.smartMatchHashArrayMapping = sArr;
                }
                short s = this.smartMatchHashArrayMapping[binarySearch];
                if (s != -1 && !isSetFlag(s, iArr)) {
                    fieldDeserializer = this.sortedFieldDeserializers[s];
                }
            }
            if (fieldDeserializer != null) {
                FieldInfo fieldInfo = fieldDeserializer.fieldInfo;
                if ((fieldInfo.parserFeatures & Feature.DisableFieldSmartMatch.mask) != 0) {
                    return null;
                }
                Class<?> cls = fieldInfo.fieldClass;
                if (z && cls != Boolean.TYPE && cls != Boolean.class) {
                    return null;
                }
            }
        }
        return fieldDeserializer;
    }

    private Object createFactoryInstance(ParserConfig parserConfig, Object obj) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        return this.beanInfo.factoryMethod.invoke(null, obj);
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x006b, code lost:
        if (com.alibaba.fastjson.JSONValidator.from(r6).validate() != false) goto L131;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x007f, code lost:
        if (r6.method != null) goto L124;
     */
    /* JADX WARN: Code restructure failed: missing block: B:29:0x0081, code lost:
        r9 = r7.getType();
     */
    /* JADX WARN: Code restructure failed: missing block: B:30:0x0087, code lost:
        if (r9 != java.lang.Boolean.TYPE) goto L24;
     */
    /* JADX WARN: Code restructure failed: missing block: B:32:0x008b, code lost:
        if (r4 != java.lang.Boolean.FALSE) goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:33:0x008d, code lost:
        r7.setBoolean(r0, false);
     */
    /* JADX WARN: Code restructure failed: missing block: B:35:0x0093, code lost:
        if (r4 != java.lang.Boolean.TRUE) goto L117;
     */
    /* JADX WARN: Code restructure failed: missing block: B:36:0x0095, code lost:
        r7.setBoolean(r0, true);
     */
    /* JADX WARN: Code restructure failed: missing block: B:38:0x009b, code lost:
        if (r9 != java.lang.Integer.TYPE) goto L27;
     */
    /* JADX WARN: Code restructure failed: missing block: B:40:0x009f, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L110;
     */
    /* JADX WARN: Code restructure failed: missing block: B:41:0x00a1, code lost:
        r7.setInt(r0, ((java.lang.Number) r4).intValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:43:0x00ae, code lost:
        if (r9 != java.lang.Long.TYPE) goto L30;
     */
    /* JADX WARN: Code restructure failed: missing block: B:45:0x00b2, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L103;
     */
    /* JADX WARN: Code restructure failed: missing block: B:46:0x00b4, code lost:
        r7.setLong(r0, ((java.lang.Number) r4).longValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:48:0x00c3, code lost:
        if (r9 != java.lang.Float.TYPE) goto L33;
     */
    /* JADX WARN: Code restructure failed: missing block: B:50:0x00c7, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L86;
     */
    /* JADX WARN: Code restructure failed: missing block: B:51:0x00c9, code lost:
        r7.setFloat(r0, ((java.lang.Number) r4).floatValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:53:0x00d6, code lost:
        if ((r4 instanceof java.lang.String) == false) goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:54:0x00d8, code lost:
        r4 = (java.lang.String) r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:55:0x00de, code lost:
        if (r4.length() > 10) goto L95;
     */
    /* JADX WARN: Code restructure failed: missing block: B:56:0x00e0, code lost:
        r4 = com.alibaba.fastjson.util.TypeUtils.parseFloat(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:57:0x00e5, code lost:
        r4 = java.lang.Float.parseFloat(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:58:0x00e9, code lost:
        r7.setFloat(r0, r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:60:0x00f0, code lost:
        if (r9 != java.lang.Double.TYPE) goto L36;
     */
    /* JADX WARN: Code restructure failed: missing block: B:62:0x00f4, code lost:
        if ((r4 instanceof java.lang.Number) == false) goto L69;
     */
    /* JADX WARN: Code restructure failed: missing block: B:63:0x00f6, code lost:
        r7.setDouble(r0, ((java.lang.Number) r4).doubleValue());
     */
    /* JADX WARN: Code restructure failed: missing block: B:65:0x0103, code lost:
        if ((r4 instanceof java.lang.String) == false) goto L79;
     */
    /* JADX WARN: Code restructure failed: missing block: B:66:0x0105, code lost:
        r4 = (java.lang.String) r4;
     */
    /* JADX WARN: Code restructure failed: missing block: B:67:0x010b, code lost:
        if (r4.length() > 10) goto L78;
     */
    /* JADX WARN: Code restructure failed: missing block: B:68:0x010d, code lost:
        r4 = com.alibaba.fastjson.util.TypeUtils.parseDouble(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:69:0x0112, code lost:
        r4 = java.lang.Double.parseDouble(r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x0116, code lost:
        r7.setDouble(r0, r4);
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x011b, code lost:
        if (r4 == null) goto L62;
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x0121, code lost:
        if (r8 != r4.getClass()) goto L44;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x0123, code lost:
        r7.set(r0, r4);
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public Object createInstance(Map<String, Object> map, ParserConfig parserConfig) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException {
        boolean z;
        Integer num;
        Object cast;
        String jSONString;
        if (this.beanInfo.creatorConstructor == null && this.beanInfo.factoryMethod == null) {
            Object createInstance = createInstance((DefaultJSONParser) null, this.clazz);
            for (Map.Entry<String, Object> entry : map.entrySet()) {
                Object value = entry.getValue();
                FieldDeserializer smartMatch = smartMatch(entry.getKey());
                if (smartMatch != null) {
                    FieldInfo fieldInfo = smartMatch.fieldInfo;
                    Field field = smartMatch.fieldInfo.field;
                    Type type = fieldInfo.fieldType;
                    Class<?> cls = fieldInfo.fieldClass;
                    JSONField annotation = fieldInfo.getAnnotation();
                    if (fieldInfo.declaringClass != null && (!cls.isInstance(value) || (annotation != null && annotation.deserializeUsing() != Void.class))) {
                        if (value instanceof String) {
                            jSONString = (String) value;
                        }
                        jSONString = JSON.toJSONString(value);
                        smartMatch.parseField(new DefaultJSONParser(jSONString), createInstance, type, null);
                    } else {
                        String str = fieldInfo.format;
                        if (str != null && type == Date.class) {
                            cast = TypeUtils.castToDate(value, str);
                        } else if (str != null && (type instanceof Class) && ((Class) type).getName().equals("java.time.LocalDateTime")) {
                            cast = Jdk8DateCodec.castToLocalDateTime(value, str);
                        } else if (type instanceof ParameterizedType) {
                            cast = TypeUtils.cast(value, (ParameterizedType) type, parserConfig);
                        } else {
                            cast = TypeUtils.cast(value, type, parserConfig);
                        }
                        smartMatch.setValue(createInstance, cast);
                    }
                }
            }
            if (this.beanInfo.buildMethod != null) {
                try {
                    return this.beanInfo.buildMethod.invoke(createInstance, new Object[0]);
                } catch (Exception e) {
                    throw new JSONException("build object error", e);
                }
            }
            return createInstance;
        }
        FieldInfo[] fieldInfoArr = this.beanInfo.fields;
        int length = fieldInfoArr.length;
        Object[] objArr = new Object[length];
        HashMap hashMap = null;
        for (int i = 0; i < length; i++) {
            FieldInfo fieldInfo2 = fieldInfoArr[i];
            boolean z2 = map.get(fieldInfo2.name);
            if (z2 == null) {
                Class<?> cls2 = fieldInfo2.fieldClass;
                if (cls2 == Integer.TYPE) {
                    z2 = 0;
                } else if (cls2 == Long.TYPE) {
                    z2 = 0L;
                } else if (cls2 == Short.TYPE) {
                    z2 = (short) 0;
                } else if (cls2 == Byte.TYPE) {
                    z2 = (byte) 0;
                } else if (cls2 == Float.TYPE) {
                    z2 = Float.valueOf(0.0f);
                } else if (cls2 == Double.TYPE) {
                    z2 = Double.valueOf(0.0d);
                } else if (cls2 == Character.TYPE) {
                    z2 = '0';
                } else if (cls2 == Boolean.TYPE) {
                    z2 = false;
                }
                if (hashMap == null) {
                    hashMap = new HashMap();
                }
                hashMap.put(fieldInfo2.name, Integer.valueOf(i));
            }
            objArr[i] = z2;
        }
        if (hashMap != null) {
            for (Map.Entry<String, Object> entry2 : map.entrySet()) {
                Object value2 = entry2.getValue();
                FieldDeserializer smartMatch2 = smartMatch(entry2.getKey());
                if (smartMatch2 != null && (num = (Integer) hashMap.get(smartMatch2.fieldInfo.name)) != null) {
                    objArr[num.intValue()] = value2;
                }
            }
        }
        if (this.beanInfo.creatorConstructor != null) {
            if (this.beanInfo.f0kotlin) {
                z = false;
                for (int i2 = 0; i2 < length; i2++) {
                    Object obj = objArr[i2];
                    if (obj == null) {
                        if (this.beanInfo.fields != null && i2 < this.beanInfo.fields.length && this.beanInfo.fields[i2].fieldClass == String.class) {
                            z = true;
                        }
                    } else if (obj.getClass() != this.beanInfo.fields[i2].fieldClass) {
                        objArr[i2] = TypeUtils.cast(obj, (Class<Object>) this.beanInfo.fields[i2].fieldClass, parserConfig);
                    }
                }
            } else {
                z = false;
            }
            if (z && this.beanInfo.kotlinDefaultConstructor != null) {
                try {
                    Object newInstance = this.beanInfo.kotlinDefaultConstructor.newInstance(new Object[0]);
                    for (int i3 = 0; i3 < length; i3++) {
                        Object obj2 = objArr[i3];
                        if (obj2 != null && this.beanInfo.fields != null && i3 < this.beanInfo.fields.length) {
                            this.beanInfo.fields[i3].set(newInstance, obj2);
                        }
                    }
                    return newInstance;
                } catch (Exception e2) {
                    throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e2);
                }
            }
            try {
                return this.beanInfo.creatorConstructor.newInstance(objArr);
            } catch (Exception e3) {
                throw new JSONException("create instance error, " + this.beanInfo.creatorConstructor.toGenericString(), e3);
            }
        } else if (this.beanInfo.factoryMethod != null) {
            try {
                return this.beanInfo.factoryMethod.invoke(null, objArr);
            } catch (Exception e4) {
                throw new JSONException("create factory method error, " + this.beanInfo.factoryMethod.toString(), e4);
            }
        } else {
            return null;
        }
    }

    public Type getFieldType(int i) {
        return this.sortedFieldDeserializers[i].fieldInfo.fieldType;
    }

    protected Object parseRest(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i) {
        return parseRest(defaultJSONParser, type, obj, obj2, i, new int[0]);
    }

    protected Object parseRest(DefaultJSONParser defaultJSONParser, Type type, Object obj, Object obj2, int i, int[] iArr) {
        return deserialze(defaultJSONParser, type, obj, obj2, i, iArr);
    }

    protected static JavaBeanDeserializer getSeeAlso(ParserConfig parserConfig, JavaBeanInfo javaBeanInfo, String str) {
        if (javaBeanInfo.jsonType == null) {
            return null;
        }
        for (Class<?> cls : javaBeanInfo.jsonType.seeAlso()) {
            ObjectDeserializer deserializer = parserConfig.getDeserializer(cls);
            if (deserializer instanceof JavaBeanDeserializer) {
                JavaBeanDeserializer javaBeanDeserializer = (JavaBeanDeserializer) deserializer;
                JavaBeanInfo javaBeanInfo2 = javaBeanDeserializer.beanInfo;
                if (javaBeanInfo2.typeName.equals(str)) {
                    return javaBeanDeserializer;
                }
                JavaBeanDeserializer seeAlso = getSeeAlso(parserConfig, javaBeanInfo2, str);
                if (seeAlso != null) {
                    return seeAlso;
                }
            }
        }
        return null;
    }

    protected static void parseArray(Collection collection, ObjectDeserializer objectDeserializer, DefaultJSONParser defaultJSONParser, Type type, Object obj) {
        JSONLexerBase jSONLexerBase = (JSONLexerBase) defaultJSONParser.lexer;
        int i = jSONLexerBase.token();
        if (i == 8) {
            jSONLexerBase.nextToken(16);
            jSONLexerBase.token();
            return;
        }
        if (i != 14) {
            defaultJSONParser.throwException(i);
        }
        if (jSONLexerBase.getCurrent() == '[') {
            jSONLexerBase.next();
            jSONLexerBase.setToken(14);
        } else {
            jSONLexerBase.nextToken(14);
        }
        if (jSONLexerBase.token() == 15) {
            jSONLexerBase.nextToken();
            return;
        }
        int i2 = 0;
        while (true) {
            collection.add(objectDeserializer.deserialze(defaultJSONParser, type, Integer.valueOf(i2)));
            i2++;
            if (jSONLexerBase.token() != 16) {
                break;
            } else if (jSONLexerBase.getCurrent() == '[') {
                jSONLexerBase.next();
                jSONLexerBase.setToken(14);
            } else {
                jSONLexerBase.nextToken(14);
            }
        }
        int i3 = jSONLexerBase.token();
        if (i3 != 15) {
            defaultJSONParser.throwException(i3);
        }
        if (jSONLexerBase.getCurrent() == ',') {
            jSONLexerBase.next();
            jSONLexerBase.setToken(16);
            return;
        }
        jSONLexerBase.nextToken(16);
    }
}
