package com.alibaba.fastjson.serializer;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.util.FieldInfo;
import com.alibaba.fastjson.util.TypeUtils;
import com.taobao.weex.el.parse.Operators;
import io.dcloud.common.constant.AbsoluteConst;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.lang.reflect.WildcardType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
/* loaded from: classes.dex */
public class JavaBeanSerializer extends SerializeFilterable implements ObjectSerializer {
    protected final SerializeBeanInfo beanInfo;
    protected final FieldSerializer[] getters;
    private volatile transient long[] hashArray;
    private volatile transient short[] hashArrayMapping;
    protected final FieldSerializer[] sortedGetters;

    public JavaBeanSerializer(Class<?> cls) {
        this(cls, (Map<String, String>) null);
    }

    public JavaBeanSerializer(Class<?> cls, String... strArr) {
        this(cls, createAliasMap(strArr));
    }

    static Map<String, String> createAliasMap(String... strArr) {
        HashMap hashMap = new HashMap();
        for (String str : strArr) {
            hashMap.put(str, str);
        }
        return hashMap;
    }

    public JSONType getJSONType() {
        return this.beanInfo.jsonType;
    }

    public Class<?> getType() {
        return this.beanInfo.beanType;
    }

    public JavaBeanSerializer(Class<?> cls, Map<String, String> map) {
        this(TypeUtils.buildBeanInfo(cls, map, null));
    }

    public JavaBeanSerializer(SerializeBeanInfo serializeBeanInfo) {
        boolean z;
        this.beanInfo = serializeBeanInfo;
        this.sortedGetters = new FieldSerializer[serializeBeanInfo.sortedFields.length];
        int i = 0;
        while (true) {
            FieldSerializer[] fieldSerializerArr = this.sortedGetters;
            if (i >= fieldSerializerArr.length) {
                break;
            }
            fieldSerializerArr[i] = new FieldSerializer(serializeBeanInfo.beanType, serializeBeanInfo.sortedFields[i]);
            i++;
        }
        if (serializeBeanInfo.fields == serializeBeanInfo.sortedFields) {
            this.getters = this.sortedGetters;
        } else {
            this.getters = new FieldSerializer[serializeBeanInfo.fields.length];
            int i2 = 0;
            while (true) {
                if (i2 >= this.getters.length) {
                    z = false;
                    break;
                }
                FieldSerializer fieldSerializer = getFieldSerializer(serializeBeanInfo.fields[i2].name);
                if (fieldSerializer == null) {
                    z = true;
                    break;
                } else {
                    this.getters[i2] = fieldSerializer;
                    i2++;
                }
            }
            if (z) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                System.arraycopy(fieldSerializerArr2, 0, this.getters, 0, fieldSerializerArr2.length);
            }
        }
        if (serializeBeanInfo.jsonType != null) {
            for (Class<? extends SerializeFilter> cls : serializeBeanInfo.jsonType.serialzeFilters()) {
                try {
                    addFilter(cls.getConstructor(new Class[0]).newInstance(new Object[0]));
                } catch (Exception unused) {
                }
            }
        }
    }

    public void writeDirectNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    public void writeAsArray(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    public void writeAsArrayNonContext(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i);
    }

    @Override // com.alibaba.fastjson.serializer.ObjectSerializer
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i, false);
    }

    public void writeNoneASM(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i) throws IOException {
        write(jSONSerializer, obj, obj2, type, i, false);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Code restructure failed: missing block: B:346:0x048c, code lost:
        if (r5 == false) goto L251;
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x0105, code lost:
        if (r13.fieldTransient != false) goto L58;
     */
    /* JADX WARN: Removed duplicated region for block: B:105:0x015e  */
    /* JADX WARN: Removed duplicated region for block: B:106:0x015f  */
    /* JADX WARN: Removed duplicated region for block: B:299:0x03e4 A[Catch: Exception -> 0x0497, all -> 0x04f6, TryCatch #1 {Exception -> 0x0497, blocks: (B:115:0x0198, B:118:0x01a0, B:120:0x01ac, B:122:0x01bb, B:124:0x01c5, B:127:0x01cf, B:129:0x01da, B:131:0x01de, B:134:0x01e5, B:136:0x01e9, B:137:0x01ef, B:139:0x01f4, B:141:0x01fb, B:144:0x0205, B:146:0x0210, B:148:0x0214, B:151:0x021b, B:154:0x0222, B:156:0x0227, B:159:0x022f, B:161:0x0237, B:163:0x0242, B:165:0x0246, B:168:0x024d, B:170:0x0251, B:171:0x0256, B:173:0x025b, B:175:0x0262, B:176:0x0267, B:178:0x026f, B:180:0x027a, B:182:0x027e, B:185:0x0285, B:187:0x0289, B:188:0x028e, B:190:0x0293, B:192:0x029a, B:194:0x02a1, B:196:0x02a5, B:198:0x02af, B:202:0x02ba, B:204:0x02be, B:206:0x02c7, B:208:0x02d2, B:210:0x02d8, B:212:0x02dc, B:215:0x02e7, B:217:0x02eb, B:219:0x02ef, B:222:0x02fa, B:224:0x02fe, B:226:0x0302, B:229:0x030d, B:231:0x0311, B:233:0x0315, B:236:0x0323, B:238:0x0327, B:240:0x032b, B:243:0x0338, B:245:0x033c, B:247:0x0340, B:250:0x034e, B:252:0x0352, B:254:0x0356, B:258:0x0362, B:260:0x0366, B:262:0x036a, B:265:0x0377, B:267:0x0382, B:271:0x038b, B:273:0x0391, B:330:0x045b, B:332:0x045f, B:334:0x0463, B:337:0x046d, B:339:0x0475, B:340:0x047d, B:342:0x0483, B:278:0x039e, B:279:0x03a1, B:281:0x03a7, B:283:0x03b3, B:290:0x03c8, B:295:0x03d2, B:299:0x03e4, B:302:0x03ee, B:305:0x03f8, B:307:0x0400, B:308:0x040d, B:310:0x0416, B:312:0x041d, B:313:0x0421, B:315:0x0428, B:316:0x042c, B:317:0x0430, B:319:0x0435, B:320:0x0439, B:321:0x043d, B:323:0x0441, B:325:0x0445, B:328:0x0454, B:329:0x0458, B:296:0x03dc), top: B:429:0x0198 }] */
    /* JADX WARN: Removed duplicated region for block: B:329:0x0458 A[Catch: Exception -> 0x0497, all -> 0x04f6, TryCatch #1 {Exception -> 0x0497, blocks: (B:115:0x0198, B:118:0x01a0, B:120:0x01ac, B:122:0x01bb, B:124:0x01c5, B:127:0x01cf, B:129:0x01da, B:131:0x01de, B:134:0x01e5, B:136:0x01e9, B:137:0x01ef, B:139:0x01f4, B:141:0x01fb, B:144:0x0205, B:146:0x0210, B:148:0x0214, B:151:0x021b, B:154:0x0222, B:156:0x0227, B:159:0x022f, B:161:0x0237, B:163:0x0242, B:165:0x0246, B:168:0x024d, B:170:0x0251, B:171:0x0256, B:173:0x025b, B:175:0x0262, B:176:0x0267, B:178:0x026f, B:180:0x027a, B:182:0x027e, B:185:0x0285, B:187:0x0289, B:188:0x028e, B:190:0x0293, B:192:0x029a, B:194:0x02a1, B:196:0x02a5, B:198:0x02af, B:202:0x02ba, B:204:0x02be, B:206:0x02c7, B:208:0x02d2, B:210:0x02d8, B:212:0x02dc, B:215:0x02e7, B:217:0x02eb, B:219:0x02ef, B:222:0x02fa, B:224:0x02fe, B:226:0x0302, B:229:0x030d, B:231:0x0311, B:233:0x0315, B:236:0x0323, B:238:0x0327, B:240:0x032b, B:243:0x0338, B:245:0x033c, B:247:0x0340, B:250:0x034e, B:252:0x0352, B:254:0x0356, B:258:0x0362, B:260:0x0366, B:262:0x036a, B:265:0x0377, B:267:0x0382, B:271:0x038b, B:273:0x0391, B:330:0x045b, B:332:0x045f, B:334:0x0463, B:337:0x046d, B:339:0x0475, B:340:0x047d, B:342:0x0483, B:278:0x039e, B:279:0x03a1, B:281:0x03a7, B:283:0x03b3, B:290:0x03c8, B:295:0x03d2, B:299:0x03e4, B:302:0x03ee, B:305:0x03f8, B:307:0x0400, B:308:0x040d, B:310:0x0416, B:312:0x041d, B:313:0x0421, B:315:0x0428, B:316:0x042c, B:317:0x0430, B:319:0x0435, B:320:0x0439, B:321:0x043d, B:323:0x0441, B:325:0x0445, B:328:0x0454, B:329:0x0458, B:296:0x03dc), top: B:429:0x0198 }] */
    /* JADX WARN: Removed duplicated region for block: B:332:0x045f A[Catch: Exception -> 0x0497, all -> 0x04f6, TryCatch #1 {Exception -> 0x0497, blocks: (B:115:0x0198, B:118:0x01a0, B:120:0x01ac, B:122:0x01bb, B:124:0x01c5, B:127:0x01cf, B:129:0x01da, B:131:0x01de, B:134:0x01e5, B:136:0x01e9, B:137:0x01ef, B:139:0x01f4, B:141:0x01fb, B:144:0x0205, B:146:0x0210, B:148:0x0214, B:151:0x021b, B:154:0x0222, B:156:0x0227, B:159:0x022f, B:161:0x0237, B:163:0x0242, B:165:0x0246, B:168:0x024d, B:170:0x0251, B:171:0x0256, B:173:0x025b, B:175:0x0262, B:176:0x0267, B:178:0x026f, B:180:0x027a, B:182:0x027e, B:185:0x0285, B:187:0x0289, B:188:0x028e, B:190:0x0293, B:192:0x029a, B:194:0x02a1, B:196:0x02a5, B:198:0x02af, B:202:0x02ba, B:204:0x02be, B:206:0x02c7, B:208:0x02d2, B:210:0x02d8, B:212:0x02dc, B:215:0x02e7, B:217:0x02eb, B:219:0x02ef, B:222:0x02fa, B:224:0x02fe, B:226:0x0302, B:229:0x030d, B:231:0x0311, B:233:0x0315, B:236:0x0323, B:238:0x0327, B:240:0x032b, B:243:0x0338, B:245:0x033c, B:247:0x0340, B:250:0x034e, B:252:0x0352, B:254:0x0356, B:258:0x0362, B:260:0x0366, B:262:0x036a, B:265:0x0377, B:267:0x0382, B:271:0x038b, B:273:0x0391, B:330:0x045b, B:332:0x045f, B:334:0x0463, B:337:0x046d, B:339:0x0475, B:340:0x047d, B:342:0x0483, B:278:0x039e, B:279:0x03a1, B:281:0x03a7, B:283:0x03b3, B:290:0x03c8, B:295:0x03d2, B:299:0x03e4, B:302:0x03ee, B:305:0x03f8, B:307:0x0400, B:308:0x040d, B:310:0x0416, B:312:0x041d, B:313:0x0421, B:315:0x0428, B:316:0x042c, B:317:0x0430, B:319:0x0435, B:320:0x0439, B:321:0x043d, B:323:0x0441, B:325:0x0445, B:328:0x0454, B:329:0x0458, B:296:0x03dc), top: B:429:0x0198 }] */
    /* JADX WARN: Removed duplicated region for block: B:337:0x046d A[Catch: Exception -> 0x0497, all -> 0x04f6, TryCatch #1 {Exception -> 0x0497, blocks: (B:115:0x0198, B:118:0x01a0, B:120:0x01ac, B:122:0x01bb, B:124:0x01c5, B:127:0x01cf, B:129:0x01da, B:131:0x01de, B:134:0x01e5, B:136:0x01e9, B:137:0x01ef, B:139:0x01f4, B:141:0x01fb, B:144:0x0205, B:146:0x0210, B:148:0x0214, B:151:0x021b, B:154:0x0222, B:156:0x0227, B:159:0x022f, B:161:0x0237, B:163:0x0242, B:165:0x0246, B:168:0x024d, B:170:0x0251, B:171:0x0256, B:173:0x025b, B:175:0x0262, B:176:0x0267, B:178:0x026f, B:180:0x027a, B:182:0x027e, B:185:0x0285, B:187:0x0289, B:188:0x028e, B:190:0x0293, B:192:0x029a, B:194:0x02a1, B:196:0x02a5, B:198:0x02af, B:202:0x02ba, B:204:0x02be, B:206:0x02c7, B:208:0x02d2, B:210:0x02d8, B:212:0x02dc, B:215:0x02e7, B:217:0x02eb, B:219:0x02ef, B:222:0x02fa, B:224:0x02fe, B:226:0x0302, B:229:0x030d, B:231:0x0311, B:233:0x0315, B:236:0x0323, B:238:0x0327, B:240:0x032b, B:243:0x0338, B:245:0x033c, B:247:0x0340, B:250:0x034e, B:252:0x0352, B:254:0x0356, B:258:0x0362, B:260:0x0366, B:262:0x036a, B:265:0x0377, B:267:0x0382, B:271:0x038b, B:273:0x0391, B:330:0x045b, B:332:0x045f, B:334:0x0463, B:337:0x046d, B:339:0x0475, B:340:0x047d, B:342:0x0483, B:278:0x039e, B:279:0x03a1, B:281:0x03a7, B:283:0x03b3, B:290:0x03c8, B:295:0x03d2, B:299:0x03e4, B:302:0x03ee, B:305:0x03f8, B:307:0x0400, B:308:0x040d, B:310:0x0416, B:312:0x041d, B:313:0x0421, B:315:0x0428, B:316:0x042c, B:317:0x0430, B:319:0x0435, B:320:0x0439, B:321:0x043d, B:323:0x0441, B:325:0x0445, B:328:0x0454, B:329:0x0458, B:296:0x03dc), top: B:429:0x0198 }] */
    /* JADX WARN: Removed duplicated region for block: B:350:0x0492  */
    /* JADX WARN: Removed duplicated region for block: B:368:0x04db  */
    /* JADX WARN: Removed duplicated region for block: B:369:0x04de  */
    /* JADX WARN: Removed duplicated region for block: B:381:0x0505 A[Catch: all -> 0x04f6, Exception -> 0x04fc, TRY_LEAVE, TryCatch #7 {Exception -> 0x04fc, blocks: (B:372:0x04e7, B:374:0x04ef, B:381:0x0505), top: B:436:0x04e7 }] */
    /* JADX WARN: Removed duplicated region for block: B:403:0x0552 A[Catch: all -> 0x05d3, TRY_ENTER, TryCatch #6 {all -> 0x05d3, blocks: (B:400:0x0530, B:403:0x0552, B:411:0x05a2, B:413:0x05a8, B:414:0x05c0, B:416:0x05c4, B:420:0x05cd, B:421:0x05d2, B:405:0x0567, B:407:0x056b, B:409:0x0571, B:410:0x058c), top: B:434:0x0530 }] */
    /* JADX WARN: Removed duplicated region for block: B:404:0x0565  */
    /* JADX WARN: Removed duplicated region for block: B:413:0x05a8 A[Catch: all -> 0x05d3, TryCatch #6 {all -> 0x05d3, blocks: (B:400:0x0530, B:403:0x0552, B:411:0x05a2, B:413:0x05a8, B:414:0x05c0, B:416:0x05c4, B:420:0x05cd, B:421:0x05d2, B:405:0x0567, B:407:0x056b, B:409:0x0571, B:410:0x058c), top: B:434:0x0530 }] */
    /* JADX WARN: Removed duplicated region for block: B:416:0x05c4 A[Catch: all -> 0x05d3, TryCatch #6 {all -> 0x05d3, blocks: (B:400:0x0530, B:403:0x0552, B:411:0x05a2, B:413:0x05a8, B:414:0x05c0, B:416:0x05c4, B:420:0x05cd, B:421:0x05d2, B:405:0x0567, B:407:0x056b, B:409:0x0571, B:410:0x058c), top: B:434:0x0530 }] */
    /* JADX WARN: Removed duplicated region for block: B:418:0x05ca  */
    /* JADX WARN: Removed duplicated region for block: B:419:0x05cb  */
    /* JADX WARN: Removed duplicated region for block: B:434:0x0530 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:436:0x04e7 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:445:0x00da A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x00b3  */
    /* JADX WARN: Removed duplicated region for block: B:56:0x00b6  */
    /* JADX WARN: Removed duplicated region for block: B:59:0x00c3  */
    /* JADX WARN: Removed duplicated region for block: B:60:0x00c5  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void write(JSONSerializer jSONSerializer, Object obj, Object obj2, Type type, int i, boolean z) throws IOException {
        FieldSerializer[] fieldSerializerArr;
        Exception exc;
        SerialContext serialContext;
        Object obj3;
        FieldSerializer fieldSerializer;
        Throwable th;
        Throwable th2;
        FieldInfo fieldInfo;
        boolean z2;
        int i2;
        FieldSerializer fieldSerializer2;
        SerialContext serialContext2;
        FieldSerializer[] fieldSerializerArr2;
        FieldSerializer fieldSerializer3;
        Field field;
        FieldInfo fieldInfo2;
        String str;
        FieldSerializer[] fieldSerializerArr3;
        Class<?> cls;
        char c;
        boolean z3;
        Object propertyValueDirect;
        char c2;
        boolean z4;
        Map map;
        boolean z5;
        Class<?> cls2;
        Object obj4 = obj;
        Type type2 = type;
        SerializeWriter serializeWriter = jSONSerializer.out;
        if (obj4 == null) {
            serializeWriter.writeNull();
        } else if (writeReference(jSONSerializer, obj4, i)) {
        } else {
            if (serializeWriter.sortField) {
                fieldSerializerArr = this.sortedGetters;
            } else {
                fieldSerializerArr = this.getters;
            }
            FieldSerializer[] fieldSerializerArr4 = fieldSerializerArr;
            SerialContext serialContext3 = jSONSerializer.context;
            if (!this.beanInfo.beanType.isEnum()) {
                jSONSerializer.setContext(serialContext3, obj, obj2, this.beanInfo.features, i);
            }
            boolean isWriteAsArray = isWriteAsArray(jSONSerializer, i);
            char c3 = isWriteAsArray ? Operators.ARRAY_START : Operators.BLOCK_START;
            char c4 = isWriteAsArray ? Operators.ARRAY_END : Operators.BLOCK_END;
            if (!z) {
                try {
                    try {
                        serializeWriter.append(c3);
                    } catch (Exception e) {
                        exc = e;
                        serialContext = serialContext3;
                        obj3 = obj4;
                        fieldSerializer = null;
                        String str2 = "write javaBean error, fastjson version 1.2.83";
                        if (obj3 != null) {
                        }
                        if (obj2 != null) {
                        }
                        if (exc.getMessage() != null) {
                        }
                        if (exc instanceof InvocationTargetException) {
                        }
                        throw new JSONException(str2, r17 == null ? exc : r17);
                    }
                } catch (Throwable th3) {
                    th = th3;
                    serialContext = serialContext3;
                    jSONSerializer.context = serialContext;
                    throw th;
                }
            }
            try {
                try {
                    if (fieldSerializerArr4.length > 0 && serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                        jSONSerializer.incrementIndent();
                        jSONSerializer.println();
                    }
                } catch (Throwable th4) {
                    th2 = th4;
                    serialContext = serialContext3;
                }
            } catch (Exception e2) {
                serialContext = serialContext3;
                obj3 = obj4;
                exc = e2;
                fieldSerializer = null;
                String str22 = "write javaBean error, fastjson version 1.2.83";
                if (obj3 != null) {
                }
                if (obj2 != null) {
                }
                if (exc.getMessage() != null) {
                }
                if (exc instanceof InvocationTargetException) {
                }
                throw new JSONException(str22, r17 == null ? exc : r17);
            }
            try {
                if ((this.beanInfo.features & SerializerFeature.WriteClassName.mask) != 0 || (SerializerFeature.WriteClassName.mask & i) != 0 || jSONSerializer.isWriteClassName(type2, obj4)) {
                    Class<?> cls3 = obj.getClass();
                    if (cls3 != ((cls3 == type2 || !(type2 instanceof WildcardType)) ? type2 : TypeUtils.getClass(type))) {
                        writeClassName(jSONSerializer, this.beanInfo.typeKey, obj4);
                        z2 = true;
                        char c5 = !z2 ? Operators.ARRAY_SEPRATOR : (char) 0;
                        boolean isEnabled = serializeWriter.isEnabled(SerializerFeature.WriteClassName);
                        boolean z6 = writeBefore(jSONSerializer, obj4, c5) != ',';
                        boolean isEnabled2 = serializeWriter.isEnabled(SerializerFeature.SkipTransientField);
                        boolean isEnabled3 = serializeWriter.isEnabled(SerializerFeature.IgnoreNonFieldGetter);
                        boolean z7 = z6;
                        FieldSerializer fieldSerializer4 = null;
                        i2 = 0;
                        while (i2 < fieldSerializerArr4.length) {
                            try {
                                try {
                                    fieldSerializer3 = fieldSerializerArr4[i2];
                                    field = fieldSerializer3.fieldInfo.field;
                                    fieldInfo2 = fieldSerializer3.fieldInfo;
                                    str = fieldInfo2.name;
                                    fieldSerializerArr3 = fieldSerializerArr4;
                                    cls = fieldInfo2.fieldClass;
                                    fieldSerializer2 = fieldSerializer4;
                                } catch (Exception e3) {
                                    e = e3;
                                    fieldSerializer2 = fieldSerializer4;
                                }
                            } catch (Exception e4) {
                                e = e4;
                                fieldSerializer2 = fieldSerializer4;
                                serialContext = serialContext3;
                                obj3 = obj4;
                            }
                            try {
                                int i3 = i2;
                                boolean isEnabled4 = SerializerFeature.isEnabled(serializeWriter.features, fieldInfo2.serialzeFeatures, SerializerFeature.UseSingleQuotes);
                                boolean z8 = serializeWriter.quoteFieldNames && !isEnabled4;
                                if (isEnabled2) {
                                    try {
                                    } catch (Exception e5) {
                                        exc = e5;
                                        serialContext = serialContext3;
                                        obj3 = obj4;
                                        fieldSerializer = fieldSerializer2;
                                        String str222 = "write javaBean error, fastjson version 1.2.83";
                                        if (obj3 != null) {
                                        }
                                        if (obj2 != null) {
                                        }
                                        if (exc.getMessage() != null) {
                                        }
                                        if (exc instanceof InvocationTargetException) {
                                        }
                                        throw new JSONException(str222, r17 == null ? exc : r17);
                                    }
                                }
                                if (!isEnabled3 || field != null) {
                                    if (applyName(jSONSerializer, obj4, str) && applyLabel(jSONSerializer, fieldInfo2.label)) {
                                        z3 = false;
                                    } else {
                                        z3 = isWriteAsArray ? true : true;
                                    }
                                    if (!str.equals(this.beanInfo.typeKey) || !jSONSerializer.isWriteClassName(type2, obj4)) {
                                        if (!z3) {
                                            try {
                                                propertyValueDirect = fieldSerializer3.getPropertyValueDirect(obj4);
                                            } catch (InvocationTargetException e6) {
                                                try {
                                                    if (!serializeWriter.isEnabled(SerializerFeature.IgnoreErrorGetter)) {
                                                        fieldSerializer = fieldSerializer3;
                                                        serialContext2 = serialContext3;
                                                        try {
                                                            throw e6;
                                                        } catch (Exception e7) {
                                                            obj3 = obj;
                                                            exc = e7;
                                                            serialContext = serialContext2;
                                                            String str2222 = "write javaBean error, fastjson version 1.2.83";
                                                            if (obj3 != null) {
                                                            }
                                                            if (obj2 != null) {
                                                            }
                                                            if (exc.getMessage() != null) {
                                                            }
                                                            if (exc instanceof InvocationTargetException) {
                                                            }
                                                            throw new JSONException(str2222, r17 == null ? exc : r17);
                                                        }
                                                    }
                                                    fieldSerializer2 = fieldSerializer3;
                                                } catch (Exception e8) {
                                                    fieldSerializer = fieldSerializer3;
                                                    obj3 = obj;
                                                    exc = e8;
                                                    serialContext = serialContext3;
                                                    String str22222 = "write javaBean error, fastjson version 1.2.83";
                                                    if (obj3 != null) {
                                                    }
                                                    if (obj2 != null) {
                                                    }
                                                    if (exc.getMessage() != null) {
                                                    }
                                                    if (exc instanceof InvocationTargetException) {
                                                    }
                                                    throw new JSONException(str22222, r17 == null ? exc : r17);
                                                }
                                            }
                                            if (!apply(jSONSerializer, obj4, str, propertyValueDirect)) {
                                                String str3 = propertyValueDirect;
                                                if (cls == String.class) {
                                                    str3 = propertyValueDirect;
                                                    str3 = propertyValueDirect;
                                                    if (AbsoluteConst.XML_TRIM.equals(fieldInfo2.format) && propertyValueDirect != null) {
                                                        str3 = ((String) propertyValueDirect).trim();
                                                    }
                                                }
                                                Object obj5 = str3;
                                                String processKey = processKey(jSONSerializer, obj4, str, obj5);
                                                c = c4;
                                                serialContext2 = serialContext3;
                                                try {
                                                    try {
                                                        Object processValue = processValue(jSONSerializer, fieldSerializer3.fieldContext, obj, str, obj5, i);
                                                        if (processValue == null) {
                                                            int i4 = fieldInfo2.serialzeFeatures;
                                                            JSONField annotation = fieldInfo2.getAnnotation();
                                                            if (this.beanInfo.jsonType != null) {
                                                                i4 |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                            }
                                                            if (annotation != null && !"".equals(annotation.defaultValue())) {
                                                                processValue = annotation.defaultValue();
                                                            } else {
                                                                if (cls == Boolean.class) {
                                                                    int i5 = SerializerFeature.WriteNullBooleanAsFalse.mask;
                                                                    int i6 = SerializerFeature.WriteMapNullValue.mask | i5;
                                                                    if (isWriteAsArray || (i4 & i6) != 0 || (i6 & serializeWriter.features) != 0) {
                                                                        if ((i4 & i5) != 0) {
                                                                            processValue = false;
                                                                        } else if ((i5 & serializeWriter.features) != 0 && (i4 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                            processValue = false;
                                                                        }
                                                                    }
                                                                } else if (cls == String.class) {
                                                                    int i7 = SerializerFeature.WriteNullStringAsEmpty.mask;
                                                                    int i8 = SerializerFeature.WriteMapNullValue.mask | i7;
                                                                    if (isWriteAsArray || (i4 & i8) != 0 || (i8 & serializeWriter.features) != 0) {
                                                                        if ((i4 & i7) == 0) {
                                                                            if ((i7 & serializeWriter.features) != 0 && (i4 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                            }
                                                                        }
                                                                        processValue = "";
                                                                    }
                                                                } else if (Number.class.isAssignableFrom(cls)) {
                                                                    int i9 = SerializerFeature.WriteNullNumberAsZero.mask;
                                                                    int i10 = SerializerFeature.WriteMapNullValue.mask | i9;
                                                                    if (isWriteAsArray || (i4 & i10) != 0 || (i10 & serializeWriter.features) != 0) {
                                                                        if ((i4 & i9) != 0) {
                                                                            processValue = 0;
                                                                        } else if ((i9 & serializeWriter.features) != 0 && (i4 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                            processValue = 0;
                                                                        }
                                                                    }
                                                                } else if (Collection.class.isAssignableFrom(cls)) {
                                                                    int i11 = SerializerFeature.WriteNullListAsEmpty.mask;
                                                                    int i12 = SerializerFeature.WriteMapNullValue.mask | i11;
                                                                    if (isWriteAsArray || (i4 & i12) != 0 || (i12 & serializeWriter.features) != 0) {
                                                                        if ((i4 & i11) != 0) {
                                                                            processValue = Collections.emptyList();
                                                                        } else if ((i11 & serializeWriter.features) != 0 && (i4 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                            processValue = Collections.emptyList();
                                                                        }
                                                                    }
                                                                } else if (!isWriteAsArray && !fieldSerializer3.writeNull && !serializeWriter.isEnabled(SerializerFeature.WriteMapNullValue.mask) && (i4 & SerializerFeature.WriteMapNullValue.mask) == 0) {
                                                                }
                                                                fieldSerializer4 = fieldSerializer2;
                                                                i2 = i3 + 1;
                                                                obj4 = obj;
                                                                type2 = type;
                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                c4 = c;
                                                                serialContext3 = serialContext2;
                                                            }
                                                        }
                                                        if (processValue == null || ((!serializeWriter.notWriteDefaultValue && (fieldInfo2.serialzeFeatures & SerializerFeature.NotWriteDefaultValue.mask) == 0 && (this.beanInfo.features & SerializerFeature.NotWriteDefaultValue.mask) == 0) || (((cls2 = fieldInfo2.fieldClass) != Byte.TYPE || !(processValue instanceof Byte) || ((Byte) processValue).byteValue() != 0) && ((cls2 != Short.TYPE || !(processValue instanceof Short) || ((Short) processValue).shortValue() != 0) && ((cls2 != Integer.TYPE || !(processValue instanceof Integer) || ((Integer) processValue).intValue() != 0) && ((cls2 != Long.TYPE || !(processValue instanceof Long) || ((Long) processValue).longValue() != 0) && ((cls2 != Float.TYPE || !(processValue instanceof Float) || ((Float) processValue).floatValue() != 0.0f) && ((cls2 != Double.TYPE || !(processValue instanceof Double) || ((Double) processValue).doubleValue() != 0.0d) && (cls2 != Boolean.TYPE || !(processValue instanceof Boolean) || ((Boolean) processValue).booleanValue()))))))))) {
                                                            if (z7) {
                                                                if (!fieldInfo2.unwrapped || !(processValue instanceof Map) || ((Map) processValue).size() != 0) {
                                                                    serializeWriter.write(44);
                                                                    if (serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                                                                        jSONSerializer.println();
                                                                    }
                                                                }
                                                            }
                                                            if (processKey != str) {
                                                                if (!isWriteAsArray) {
                                                                    serializeWriter.writeFieldName(processKey, true);
                                                                }
                                                                jSONSerializer.write(processValue);
                                                            } else if (obj5 != processValue) {
                                                                if (!isWriteAsArray) {
                                                                    fieldSerializer3.writePrefix(jSONSerializer);
                                                                }
                                                                jSONSerializer.write(processValue);
                                                            } else {
                                                                if (!isWriteAsArray) {
                                                                    boolean isAssignableFrom = Map.class.isAssignableFrom(cls);
                                                                    boolean z9 = !(cls.isPrimitive() || cls.getName().startsWith("java.")) || cls == Object.class;
                                                                    if (isEnabled || !fieldInfo2.unwrapped || (!isAssignableFrom && !z9)) {
                                                                        if (z8) {
                                                                            c2 = 0;
                                                                            serializeWriter.write(fieldInfo2.name_chars, 0, fieldInfo2.name_chars.length);
                                                                        } else {
                                                                            c2 = 0;
                                                                            fieldSerializer3.writePrefix(jSONSerializer);
                                                                        }
                                                                        if (isWriteAsArray) {
                                                                            JSONField annotation2 = fieldInfo2.getAnnotation();
                                                                            if (cls == String.class && (annotation2 == null || annotation2.serializeUsing() == Void.class)) {
                                                                                if (processValue == null) {
                                                                                    int i13 = fieldSerializer3.features;
                                                                                    if (this.beanInfo.jsonType != null) {
                                                                                        i13 |= SerializerFeature.of(this.beanInfo.jsonType.serialzeFeatures());
                                                                                    }
                                                                                    if ((serializeWriter.features & SerializerFeature.WriteNullStringAsEmpty.mask) != 0 && (SerializerFeature.WriteMapNullValue.mask & i13) == 0) {
                                                                                        serializeWriter.writeString("");
                                                                                    } else if ((i13 & SerializerFeature.WriteNullStringAsEmpty.mask) != 0) {
                                                                                        serializeWriter.writeString("");
                                                                                    } else {
                                                                                        serializeWriter.writeNull();
                                                                                    }
                                                                                } else {
                                                                                    String str4 = (String) processValue;
                                                                                    if (isEnabled4) {
                                                                                        serializeWriter.writeStringWithSingleQuote(str4);
                                                                                    } else {
                                                                                        serializeWriter.writeStringWithDoubleQuote(str4, c2);
                                                                                    }
                                                                                }
                                                                            } else if (fieldInfo2.unwrapped && (processValue instanceof Map) && ((Map) processValue).size() == 0) {
                                                                                fieldSerializer4 = fieldSerializer2;
                                                                                z7 = false;
                                                                                i2 = i3 + 1;
                                                                                obj4 = obj;
                                                                                type2 = type;
                                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                                c4 = c;
                                                                                serialContext3 = serialContext2;
                                                                            } else {
                                                                                fieldSerializer3.writeValue(jSONSerializer, processValue);
                                                                            }
                                                                        } else {
                                                                            fieldSerializer3.writeValue(jSONSerializer, processValue);
                                                                        }
                                                                        if (fieldInfo2.unwrapped && (processValue instanceof Map)) {
                                                                            map = (Map) processValue;
                                                                            if (map.size() != 0) {
                                                                                if (!jSONSerializer.isEnabled(SerializerFeature.WriteMapNullValue)) {
                                                                                    Iterator it = map.values().iterator();
                                                                                    while (true) {
                                                                                        if (!it.hasNext()) {
                                                                                            z5 = false;
                                                                                            break;
                                                                                        } else if (it.next() != null) {
                                                                                            z5 = true;
                                                                                            break;
                                                                                        }
                                                                                    }
                                                                                }
                                                                            }
                                                                            z4 = true;
                                                                            if (!z4) {
                                                                                fieldSerializer4 = fieldSerializer2;
                                                                                z7 = true;
                                                                                i2 = i3 + 1;
                                                                                obj4 = obj;
                                                                                type2 = type;
                                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                                c4 = c;
                                                                                serialContext3 = serialContext2;
                                                                            }
                                                                            fieldSerializer4 = fieldSerializer2;
                                                                            i2 = i3 + 1;
                                                                            obj4 = obj;
                                                                            type2 = type;
                                                                            fieldSerializerArr4 = fieldSerializerArr3;
                                                                            c4 = c;
                                                                            serialContext3 = serialContext2;
                                                                        }
                                                                        z4 = false;
                                                                        if (!z4) {
                                                                        }
                                                                        fieldSerializer4 = fieldSerializer2;
                                                                        i2 = i3 + 1;
                                                                        obj4 = obj;
                                                                        type2 = type;
                                                                        fieldSerializerArr4 = fieldSerializerArr3;
                                                                        c4 = c;
                                                                        serialContext3 = serialContext2;
                                                                    }
                                                                }
                                                                c2 = 0;
                                                                if (isWriteAsArray) {
                                                                }
                                                                if (fieldInfo2.unwrapped) {
                                                                    map = (Map) processValue;
                                                                    if (map.size() != 0) {
                                                                    }
                                                                    z4 = true;
                                                                    if (!z4) {
                                                                    }
                                                                    fieldSerializer4 = fieldSerializer2;
                                                                    i2 = i3 + 1;
                                                                    obj4 = obj;
                                                                    type2 = type;
                                                                    fieldSerializerArr4 = fieldSerializerArr3;
                                                                    c4 = c;
                                                                    serialContext3 = serialContext2;
                                                                }
                                                                z4 = false;
                                                                if (!z4) {
                                                                }
                                                                fieldSerializer4 = fieldSerializer2;
                                                                i2 = i3 + 1;
                                                                obj4 = obj;
                                                                type2 = type;
                                                                fieldSerializerArr4 = fieldSerializerArr3;
                                                                c4 = c;
                                                                serialContext3 = serialContext2;
                                                            }
                                                            if (fieldInfo2.unwrapped) {
                                                            }
                                                            z4 = false;
                                                            if (!z4) {
                                                            }
                                                            fieldSerializer4 = fieldSerializer2;
                                                            i2 = i3 + 1;
                                                            obj4 = obj;
                                                            type2 = type;
                                                            fieldSerializerArr4 = fieldSerializerArr3;
                                                            c4 = c;
                                                            serialContext3 = serialContext2;
                                                        }
                                                        fieldSerializer4 = fieldSerializer2;
                                                        i2 = i3 + 1;
                                                        obj4 = obj;
                                                        type2 = type;
                                                        fieldSerializerArr4 = fieldSerializerArr3;
                                                        c4 = c;
                                                        serialContext3 = serialContext2;
                                                    } catch (Exception e9) {
                                                        e = e9;
                                                        obj3 = obj;
                                                        exc = e;
                                                        fieldSerializer = fieldSerializer2;
                                                        serialContext = serialContext2;
                                                        String str222222 = "write javaBean error, fastjson version 1.2.83";
                                                        if (obj3 != null) {
                                                            try {
                                                                str222222 = "write javaBean error, fastjson version 1.2.83, class " + obj.getClass().getName();
                                                            } catch (Throwable th5) {
                                                                th2 = th5;
                                                                th = th2;
                                                                jSONSerializer.context = serialContext;
                                                                throw th;
                                                            }
                                                        }
                                                        if (obj2 != null) {
                                                            str222222 = str222222 + ", fieldName : " + obj2;
                                                        } else if (fieldSerializer != null && fieldSerializer.fieldInfo != null) {
                                                            if (fieldSerializer.fieldInfo.method != null) {
                                                                str222222 = str222222 + ", method : " + fieldInfo.method.getName();
                                                            } else {
                                                                str222222 = str222222 + ", fieldName : " + fieldSerializer.fieldInfo.name;
                                                            }
                                                        }
                                                        if (exc.getMessage() != null) {
                                                            str222222 = str222222 + ", " + exc.getMessage();
                                                        }
                                                        Throwable cause = exc instanceof InvocationTargetException ? exc.getCause() : null;
                                                        throw new JSONException(str222222, cause == null ? exc : cause);
                                                    }
                                                } catch (Throwable th6) {
                                                    th = th6;
                                                    serialContext = serialContext2;
                                                    jSONSerializer.context = serialContext;
                                                    throw th;
                                                }
                                            }
                                        }
                                        propertyValueDirect = null;
                                        if (!apply(jSONSerializer, obj4, str, propertyValueDirect)) {
                                        }
                                    }
                                }
                                c = c4;
                                serialContext2 = serialContext3;
                                fieldSerializer4 = fieldSerializer2;
                                i2 = i3 + 1;
                                obj4 = obj;
                                type2 = type;
                                fieldSerializerArr4 = fieldSerializerArr3;
                                c4 = c;
                                serialContext3 = serialContext2;
                            } catch (Exception e10) {
                                e = e10;
                                obj3 = obj;
                                exc = e;
                                serialContext = serialContext3;
                                fieldSerializer = fieldSerializer2;
                                String str2222222 = "write javaBean error, fastjson version 1.2.83";
                                if (obj3 != null) {
                                }
                                if (obj2 != null) {
                                }
                                if (exc.getMessage() != null) {
                                }
                                if (exc instanceof InvocationTargetException) {
                                }
                                throw new JSONException(str2222222, cause == null ? exc : cause);
                            }
                        }
                        fieldSerializer2 = fieldSerializer4;
                        char c6 = c4;
                        serialContext2 = serialContext3;
                        fieldSerializerArr2 = fieldSerializerArr4;
                        obj3 = obj;
                        writeAfter(jSONSerializer, obj3, !z7 ? Operators.ARRAY_SEPRATOR : (char) 0);
                        if (fieldSerializerArr2.length > 0) {
                            try {
                                if (serializeWriter.isEnabled(SerializerFeature.PrettyFormat)) {
                                    jSONSerializer.decrementIdent();
                                    jSONSerializer.println();
                                }
                            } catch (Exception e11) {
                                e = e11;
                                exc = e;
                                fieldSerializer = fieldSerializer2;
                                serialContext = serialContext2;
                                String str22222222 = "write javaBean error, fastjson version 1.2.83";
                                if (obj3 != null) {
                                }
                                if (obj2 != null) {
                                }
                                if (exc.getMessage() != null) {
                                }
                                if (exc instanceof InvocationTargetException) {
                                }
                                throw new JSONException(str22222222, cause == null ? exc : cause);
                            }
                        }
                        if (!z) {
                            serializeWriter.append(c6);
                        }
                        jSONSerializer.context = serialContext2;
                        return;
                    }
                }
                writeAfter(jSONSerializer, obj3, !z7 ? Operators.ARRAY_SEPRATOR : (char) 0);
                if (fieldSerializerArr2.length > 0) {
                }
                if (!z) {
                }
                jSONSerializer.context = serialContext2;
                return;
            } catch (Exception e12) {
                e = e12;
                serialContext = serialContext2;
                exc = e;
                fieldSerializer = fieldSerializer2;
                String str222222222 = "write javaBean error, fastjson version 1.2.83";
                if (obj3 != null) {
                }
                if (obj2 != null) {
                }
                if (exc.getMessage() != null) {
                }
                if (exc instanceof InvocationTargetException) {
                }
                throw new JSONException(str222222222, cause == null ? exc : cause);
            } catch (Throwable th7) {
                th2 = th7;
                serialContext = serialContext2;
                th = th2;
                jSONSerializer.context = serialContext;
                throw th;
            }
            z2 = false;
            if (!z2) {
            }
            boolean isEnabled5 = serializeWriter.isEnabled(SerializerFeature.WriteClassName);
            if (writeBefore(jSONSerializer, obj4, c5) != ',') {
            }
            boolean isEnabled22 = serializeWriter.isEnabled(SerializerFeature.SkipTransientField);
            boolean isEnabled32 = serializeWriter.isEnabled(SerializerFeature.IgnoreNonFieldGetter);
            boolean z72 = z6;
            FieldSerializer fieldSerializer42 = null;
            i2 = 0;
            while (i2 < fieldSerializerArr4.length) {
            }
            fieldSerializer2 = fieldSerializer42;
            char c62 = c4;
            serialContext2 = serialContext3;
            fieldSerializerArr2 = fieldSerializerArr4;
            obj3 = obj;
        }
    }

    protected void writeClassName(JSONSerializer jSONSerializer, String str, Object obj) {
        if (str == null) {
            str = jSONSerializer.config.typeKey;
        }
        jSONSerializer.out.writeFieldName(str, false);
        String str2 = this.beanInfo.typeName;
        if (str2 == null) {
            Class<?> cls = obj.getClass();
            if (TypeUtils.isProxy(cls)) {
                cls = cls.getSuperclass();
            }
            str2 = cls.getName();
        }
        jSONSerializer.write(str2);
    }

    public boolean writeReference(JSONSerializer jSONSerializer, Object obj, int i) {
        SerialContext serialContext = jSONSerializer.context;
        int i2 = SerializerFeature.DisableCircularReferenceDetect.mask;
        if (serialContext != null && (serialContext.features & i2) == 0 && (i & i2) == 0 && jSONSerializer.references != null && jSONSerializer.references.containsKey(obj)) {
            jSONSerializer.writeReference(obj);
            return true;
        }
        return false;
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer) {
        return isWriteAsArray(jSONSerializer, 0);
    }

    protected boolean isWriteAsArray(JSONSerializer jSONSerializer, int i) {
        int i2 = SerializerFeature.BeanToArray.mask;
        return ((this.beanInfo.features & i2) == 0 && !jSONSerializer.out.beanToArray && (i & i2) == 0) ? false : true;
    }

    public Object getFieldValue(Object obj, String str) {
        FieldSerializer fieldSerializer = getFieldSerializer(str);
        if (fieldSerializer == null) {
            throw new JSONException("field not found. " + str);
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e) {
            throw new JSONException("getFieldValue error." + str, e);
        } catch (InvocationTargetException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        }
    }

    public Object getFieldValue(Object obj, String str, long j, boolean z) {
        FieldSerializer fieldSerializer = getFieldSerializer(j);
        if (fieldSerializer == null) {
            if (z) {
                throw new JSONException("field not found. " + str);
            }
            return null;
        }
        try {
            return fieldSerializer.getPropertyValue(obj);
        } catch (IllegalAccessException e) {
            throw new JSONException("getFieldValue error." + str, e);
        } catch (InvocationTargetException e2) {
            throw new JSONException("getFieldValue error." + str, e2);
        }
    }

    public FieldSerializer getFieldSerializer(String str) {
        if (str == null) {
            return null;
        }
        int i = 0;
        int length = this.sortedGetters.length - 1;
        while (i <= length) {
            int i2 = (i + length) >>> 1;
            int compareTo = this.sortedGetters[i2].fieldInfo.name.compareTo(str);
            if (compareTo < 0) {
                i = i2 + 1;
            } else if (compareTo <= 0) {
                return this.sortedGetters[i2];
            } else {
                length = i2 - 1;
            }
        }
        return null;
    }

    public FieldSerializer getFieldSerializer(long j) {
        PropertyNamingStrategy[] propertyNamingStrategyArr;
        int binarySearch;
        if (this.hashArray == null) {
            propertyNamingStrategyArr = PropertyNamingStrategy.values();
            long[] jArr = new long[this.sortedGetters.length * propertyNamingStrategyArr.length];
            int i = 0;
            int i2 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr = this.sortedGetters;
                if (i >= fieldSerializerArr.length) {
                    break;
                }
                String str = fieldSerializerArr[i].fieldInfo.name;
                jArr[i2] = TypeUtils.fnv1a_64(str);
                i2++;
                for (PropertyNamingStrategy propertyNamingStrategy : propertyNamingStrategyArr) {
                    String translate = propertyNamingStrategy.translate(str);
                    if (!str.equals(translate)) {
                        jArr[i2] = TypeUtils.fnv1a_64(translate);
                        i2++;
                    }
                }
                i++;
            }
            Arrays.sort(jArr, 0, i2);
            this.hashArray = new long[i2];
            System.arraycopy(jArr, 0, this.hashArray, 0, i2);
        } else {
            propertyNamingStrategyArr = null;
        }
        int binarySearch2 = Arrays.binarySearch(this.hashArray, j);
        if (binarySearch2 < 0) {
            return null;
        }
        if (this.hashArrayMapping == null) {
            if (propertyNamingStrategyArr == null) {
                propertyNamingStrategyArr = PropertyNamingStrategy.values();
            }
            short[] sArr = new short[this.hashArray.length];
            Arrays.fill(sArr, (short) -1);
            int i3 = 0;
            while (true) {
                FieldSerializer[] fieldSerializerArr2 = this.sortedGetters;
                if (i3 >= fieldSerializerArr2.length) {
                    break;
                }
                String str2 = fieldSerializerArr2[i3].fieldInfo.name;
                int binarySearch3 = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(str2));
                if (binarySearch3 >= 0) {
                    sArr[binarySearch3] = (short) i3;
                }
                for (PropertyNamingStrategy propertyNamingStrategy2 : propertyNamingStrategyArr) {
                    String translate2 = propertyNamingStrategy2.translate(str2);
                    if (!str2.equals(translate2) && (binarySearch = Arrays.binarySearch(this.hashArray, TypeUtils.fnv1a_64(translate2))) >= 0) {
                        sArr[binarySearch] = (short) i3;
                    }
                }
                i3++;
            }
            this.hashArrayMapping = sArr;
        }
        short s = this.hashArrayMapping[binarySearch2];
        if (s != -1) {
            return this.sortedGetters[s];
        }
        return null;
    }

    public List<Object> getFieldValues(Object obj) throws Exception {
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            arrayList.add(fieldSerializer.getPropertyValue(obj));
        }
        return arrayList;
    }

    public List<Object> getObjectFieldValues(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        ArrayList arrayList = new ArrayList(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            Class<?> cls = fieldSerializer.fieldInfo.fieldClass;
            if (!cls.isPrimitive() && !cls.getName().startsWith("java.lang.")) {
                arrayList.add(fieldSerializer.getPropertyValue(obj));
            }
        }
        return arrayList;
    }

    public int getSize(Object obj) throws Exception {
        int i = 0;
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                i++;
            }
        }
        return i;
    }

    public Set<String> getFieldNames(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        HashSet hashSet = new HashSet();
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            if (fieldSerializer.getPropertyValueDirect(obj) != null) {
                hashSet.add(fieldSerializer.fieldInfo.name);
            }
        }
        return hashSet;
    }

    public Map<String, Object> getFieldValuesMap(Object obj) throws Exception {
        FieldSerializer[] fieldSerializerArr;
        LinkedHashMap linkedHashMap = new LinkedHashMap(this.sortedGetters.length);
        for (FieldSerializer fieldSerializer : this.sortedGetters) {
            boolean isEnabled = SerializerFeature.isEnabled(fieldSerializer.features, SerializerFeature.SkipTransientField);
            FieldInfo fieldInfo = fieldSerializer.fieldInfo;
            if (!isEnabled || fieldInfo == null || !fieldInfo.fieldTransient) {
                if (fieldSerializer.fieldInfo.unwrapped) {
                    Object json = JSON.toJSON(fieldSerializer.getPropertyValue(obj));
                    if (json instanceof Map) {
                        linkedHashMap.putAll((Map) json);
                    } else {
                        linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                    }
                } else {
                    linkedHashMap.put(fieldSerializer.fieldInfo.name, fieldSerializer.getPropertyValue(obj));
                }
            }
        }
        return linkedHashMap;
    }

    protected BeanContext getBeanContext(int i) {
        return this.sortedGetters[i].fieldContext;
    }

    protected Type getFieldType(int i) {
        return this.sortedGetters[i].fieldInfo.fieldType;
    }

    protected char writeBefore(JSONSerializer jSONSerializer, Object obj, char c) {
        if (jSONSerializer.beforeFilters != null) {
            for (BeforeFilter beforeFilter : jSONSerializer.beforeFilters) {
                c = beforeFilter.writeBefore(jSONSerializer, obj, c);
            }
        }
        if (this.beforeFilters != null) {
            for (BeforeFilter beforeFilter2 : this.beforeFilters) {
                c = beforeFilter2.writeBefore(jSONSerializer, obj, c);
            }
        }
        return c;
    }

    protected char writeAfter(JSONSerializer jSONSerializer, Object obj, char c) {
        if (jSONSerializer.afterFilters != null) {
            for (AfterFilter afterFilter : jSONSerializer.afterFilters) {
                c = afterFilter.writeAfter(jSONSerializer, obj, c);
            }
        }
        if (this.afterFilters != null) {
            for (AfterFilter afterFilter2 : this.afterFilters) {
                c = afterFilter2.writeAfter(jSONSerializer, obj, c);
            }
        }
        return c;
    }

    protected boolean applyLabel(JSONSerializer jSONSerializer, String str) {
        if (jSONSerializer.labelFilters != null) {
            for (LabelFilter labelFilter : jSONSerializer.labelFilters) {
                if (!labelFilter.apply(str)) {
                    return false;
                }
            }
        }
        if (this.labelFilters != null) {
            for (LabelFilter labelFilter2 : this.labelFilters) {
                if (!labelFilter2.apply(str)) {
                    return false;
                }
            }
            return true;
        }
        return true;
    }
}
