package com.alibaba.fastjson.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONException;
import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONCreator;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONPOJOBuilder;
import com.alibaba.fastjson.annotation.JSONType;
import com.alibaba.fastjson.parser.Feature;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.taobao.weex.common.Constants;
import io.dcloud.common.DHInterface.IApp;
import java.lang.annotation.Annotation;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.ParameterizedType;
import java.lang.reflect.Type;
import java.lang.reflect.TypeVariable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
/* loaded from: classes.dex */
public class JavaBeanInfo {
    public final Method buildMethod;
    public final Class<?> builderClass;
    public final Class<?> clazz;
    public final Constructor<?> creatorConstructor;
    public Type[] creatorConstructorParameterTypes;
    public String[] creatorConstructorParameters;
    public final Constructor<?> defaultConstructor;
    public final int defaultConstructorParameterSize;
    public final Method factoryMethod;
    public final FieldInfo[] fields;
    public final JSONType jsonType;

    /* renamed from: kotlin  reason: collision with root package name */
    public boolean f0kotlin;
    public Constructor<?> kotlinDefaultConstructor;
    public String[] orders;
    public final int parserFeatures;
    public final FieldInfo[] sortedFields;
    public final String typeKey;
    public final String typeName;

    public JavaBeanInfo(Class<?> cls, Class<?> cls2, Constructor<?> constructor, Constructor<?> constructor2, Method method, Method method2, JSONType jSONType, List<FieldInfo> list) {
        JSONField jSONField;
        String[] strArr;
        this.clazz = cls;
        this.builderClass = cls2;
        this.defaultConstructor = constructor;
        this.creatorConstructor = constructor2;
        this.factoryMethod = method;
        this.parserFeatures = TypeUtils.getParserFeatures(cls);
        this.buildMethod = method2;
        this.jsonType = jSONType;
        if (jSONType != null) {
            String typeName = jSONType.typeName();
            String typeKey = jSONType.typeKey();
            this.typeKey = typeKey.length() <= 0 ? null : typeKey;
            if (typeName.length() != 0) {
                this.typeName = typeName;
            } else {
                this.typeName = cls.getName();
            }
            String[] orders = jSONType.orders();
            this.orders = orders.length == 0 ? null : orders;
        } else {
            this.typeName = cls.getName();
            this.typeKey = null;
            this.orders = null;
        }
        FieldInfo[] fieldInfoArr = new FieldInfo[list.size()];
        this.fields = fieldInfoArr;
        list.toArray(fieldInfoArr);
        FieldInfo[] fieldInfoArr2 = new FieldInfo[fieldInfoArr.length];
        boolean z = false;
        if (this.orders != null) {
            LinkedHashMap linkedHashMap = new LinkedHashMap(list.size());
            for (FieldInfo fieldInfo : fieldInfoArr) {
                linkedHashMap.put(fieldInfo.name, fieldInfo);
            }
            int i = 0;
            for (String str : this.orders) {
                FieldInfo fieldInfo2 = (FieldInfo) linkedHashMap.get(str);
                if (fieldInfo2 != null) {
                    fieldInfoArr2[i] = fieldInfo2;
                    linkedHashMap.remove(str);
                    i++;
                }
            }
            for (FieldInfo fieldInfo3 : linkedHashMap.values()) {
                fieldInfoArr2[i] = fieldInfo3;
                i++;
            }
        } else {
            System.arraycopy(fieldInfoArr, 0, fieldInfoArr2, 0, fieldInfoArr.length);
            Arrays.sort(fieldInfoArr2);
        }
        this.sortedFields = Arrays.equals(this.fields, fieldInfoArr2) ? this.fields : fieldInfoArr2;
        if (constructor != null) {
            this.defaultConstructorParameterSize = constructor.getParameterTypes().length;
        } else if (method != null) {
            this.defaultConstructorParameterSize = method.getParameterTypes().length;
        } else {
            this.defaultConstructorParameterSize = 0;
        }
        if (constructor2 != null) {
            this.creatorConstructorParameterTypes = constructor2.getParameterTypes();
            boolean isKotlin = TypeUtils.isKotlin(cls);
            this.f0kotlin = isKotlin;
            if (isKotlin) {
                this.creatorConstructorParameters = TypeUtils.getKoltinConstructorParameters(cls);
                try {
                    this.kotlinDefaultConstructor = cls.getConstructor(new Class[0]);
                } catch (Throwable unused) {
                }
                Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor2);
                for (int i2 = 0; i2 < this.creatorConstructorParameters.length && i2 < parameterAnnotations.length; i2++) {
                    Annotation[] annotationArr = parameterAnnotations[i2];
                    int length = annotationArr.length;
                    int i3 = 0;
                    while (true) {
                        if (i3 >= length) {
                            jSONField = null;
                            break;
                        }
                        Annotation annotation = annotationArr[i3];
                        if (annotation instanceof JSONField) {
                            jSONField = (JSONField) annotation;
                            break;
                        }
                        i3++;
                    }
                    if (jSONField != null) {
                        String name = jSONField.name();
                        if (name.length() > 0) {
                            this.creatorConstructorParameters[i2] = name;
                        }
                    }
                }
                return;
            }
            if (this.creatorConstructorParameterTypes.length == this.fields.length) {
                int i4 = 0;
                while (true) {
                    Type[] typeArr = this.creatorConstructorParameterTypes;
                    if (i4 >= typeArr.length) {
                        z = true;
                        break;
                    } else if (typeArr[i4] != this.fields[i4].fieldClass) {
                        break;
                    } else {
                        i4++;
                    }
                }
            }
            if (z) {
                return;
            }
            this.creatorConstructorParameters = ASMUtils.lookupParameterNames(constructor2);
        }
    }

    private static FieldInfo getField(List<FieldInfo> list, String str) {
        for (FieldInfo fieldInfo : list) {
            if (fieldInfo.name.equals(str)) {
                return fieldInfo;
            }
            Field field = fieldInfo.field;
            if (field != null && fieldInfo.getAnnotation() != null && field.getName().equals(str)) {
                return fieldInfo;
            }
        }
        return null;
    }

    static boolean add(List<FieldInfo> list, FieldInfo fieldInfo) {
        for (int size = list.size() - 1; size >= 0; size--) {
            FieldInfo fieldInfo2 = list.get(size);
            if (fieldInfo2.name.equals(fieldInfo.name) && (!fieldInfo2.getOnly || fieldInfo.getOnly)) {
                if (fieldInfo2.fieldClass.isAssignableFrom(fieldInfo.fieldClass)) {
                    list.set(size, fieldInfo);
                    return true;
                } else if (fieldInfo2.compareTo(fieldInfo) < 0) {
                    list.set(size, fieldInfo);
                    return true;
                } else {
                    return false;
                }
            }
        }
        list.add(fieldInfo);
        return true;
    }

    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy) {
        return build(cls, type, propertyNamingStrategy, false, TypeUtils.compatibleWithJavaBean, false);
    }

    private static Map<TypeVariable, Type> buildGenericInfo(Class<?> cls) {
        Class<? super Object> superclass = cls.getSuperclass();
        HashMap hashMap = null;
        if (superclass == null) {
            return null;
        }
        while (true) {
            Class<? super Object> cls2 = superclass;
            Class<?> cls3 = cls;
            cls = cls2;
            if (cls == null || cls == Object.class) {
                break;
            }
            if (cls3.getGenericSuperclass() instanceof ParameterizedType) {
                Type[] actualTypeArguments = ((ParameterizedType) cls3.getGenericSuperclass()).getActualTypeArguments();
                TypeVariable<Class<?>>[] typeParameters = cls.getTypeParameters();
                for (int i = 0; i < actualTypeArguments.length; i++) {
                    if (hashMap == null) {
                        hashMap = new HashMap();
                    }
                    if (hashMap.containsKey(actualTypeArguments[i])) {
                        hashMap.put(typeParameters[i], hashMap.get(actualTypeArguments[i]));
                    } else {
                        hashMap.put(typeParameters[i], actualTypeArguments[i]);
                    }
                }
            }
            superclass = cls.getSuperclass();
        }
        return hashMap;
    }

    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean z, boolean z2) {
        return build(cls, type, propertyNamingStrategy, z, z2, false);
    }

    /* JADX WARN: Code restructure failed: missing block: B:141:0x02a8, code lost:
        r7 = r1;
        r22 = r3;
     */
    /* JADX WARN: Removed duplicated region for block: B:123:0x025d  */
    /* JADX WARN: Removed duplicated region for block: B:181:0x032e  */
    /* JADX WARN: Removed duplicated region for block: B:182:0x0334  */
    /* JADX WARN: Removed duplicated region for block: B:272:0x0588  */
    /* JADX WARN: Removed duplicated region for block: B:304:0x062e  */
    /* JADX WARN: Removed duplicated region for block: B:410:0x0866  */
    /* JADX WARN: Removed duplicated region for block: B:418:0x089e  */
    /* JADX WARN: Removed duplicated region for block: B:429:0x091c  */
    /* JADX WARN: Removed duplicated region for block: B:432:0x092f  */
    /* JADX WARN: Removed duplicated region for block: B:437:0x097b  */
    /* JADX WARN: Removed duplicated region for block: B:47:0x00c1  */
    /* JADX WARN: Removed duplicated region for block: B:493:0x0ac1  */
    /* JADX WARN: Removed duplicated region for block: B:522:0x095e A[EDGE_INSN: B:522:0x095e->B:435:0x095e ?: BREAK  , SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:90:0x01ab  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public static JavaBeanInfo build(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, boolean z, boolean z2, boolean z3) {
        Constructor<?> defaultConstructor;
        Constructor<?> constructor;
        ArrayList arrayList;
        PropertyNamingStrategy propertyNamingStrategy2;
        Method[] methodArr;
        Constructor<?> constructor2;
        String str;
        Field[] fieldArr;
        Class<?> cls2;
        JSONType jSONType;
        PropertyNamingStrategy propertyNamingStrategy3;
        Method[] methodArr2;
        char c;
        int length;
        int i;
        String str2;
        int i2;
        int length2;
        int i3;
        JSONField jSONField;
        String propertyNameByMethodName;
        Field[] fieldArr2;
        Field field;
        Field[] fieldArr3;
        int i4;
        String str3;
        int i5;
        Method[] methodArr3;
        PropertyNamingStrategy propertyNamingStrategy4;
        Type type2;
        int i6;
        int i7;
        ArrayList arrayList2;
        Class<?> cls3;
        Field[] fieldArr4;
        String propertyNameByMethodName2;
        Field field2;
        Field[] fieldArr5;
        String str4;
        Class<?> cls4;
        Method[] methodArr4;
        JSONField jSONField2;
        int i8;
        PropertyNamingStrategy propertyNamingStrategy5;
        PropertyNamingStrategy propertyNamingStrategy6;
        Field[] fieldArr6;
        int i9;
        int i10;
        Method[] methodArr5;
        String str5;
        String str6;
        Field[] fieldArr7;
        Class<?> cls5;
        JSONType jSONType2;
        PropertyNamingStrategy propertyNamingStrategy7;
        Method[] methodArr6;
        int i11;
        int i12;
        int i13;
        String str7;
        StringBuilder sb;
        String str8;
        String str9;
        char charAt;
        Constructor<?> constructor3;
        String[] strArr;
        String[] lookupParameterNames;
        String[] strArr2;
        JSONField jSONField3;
        int of;
        int i14;
        int i15;
        JSONField jSONField4;
        String str10;
        int i16;
        int i17;
        int i18;
        JSONField jSONField5;
        Field field3;
        String str11;
        int i19;
        int i20;
        int i21;
        Field field4;
        Field field5;
        String[] strArr3;
        Constructor<?> creatorConstructor;
        PropertyNamingStrategy naming;
        Class<?> cls6 = cls;
        boolean z4 = z3;
        JSONType jSONType3 = (JSONType) TypeUtils.getAnnotation(cls6, JSONType.class);
        PropertyNamingStrategy propertyNamingStrategy8 = (jSONType3 == null || (naming = jSONType3.naming()) == null || naming == PropertyNamingStrategy.CamelCase) ? propertyNamingStrategy : naming;
        Class<?> builderClass = getBuilderClass(cls6, jSONType3);
        Field[] declaredFields = cls.getDeclaredFields();
        Method[] methods = cls.getMethods();
        Map<TypeVariable, Type> buildGenericInfo = buildGenericInfo(cls);
        boolean isKotlin = TypeUtils.isKotlin(cls);
        Constructor<?>[] declaredConstructors = cls.getDeclaredConstructors();
        if (!isKotlin || declaredConstructors.length == 1) {
            if (builderClass == null) {
                defaultConstructor = getDefaultConstructor(cls6, declaredConstructors);
            } else {
                defaultConstructor = getDefaultConstructor(builderClass, builderClass.getDeclaredConstructors());
            }
            constructor = defaultConstructor;
        } else {
            constructor = null;
        }
        Method method = null;
        Method method2 = null;
        ArrayList arrayList3 = new ArrayList();
        if (z) {
            for (Class<?> cls7 = cls6; cls7 != null; cls7 = cls7.getSuperclass()) {
                computeFields(cls6, type, propertyNamingStrategy8, arrayList3, cls7.getDeclaredFields());
            }
            if (constructor != null) {
                TypeUtils.setAccessible(constructor);
            }
            return new JavaBeanInfo(cls, builderClass, constructor, null, null, null, jSONType3, arrayList3);
        }
        boolean z5 = cls.isInterface() || Modifier.isAbstract(cls.getModifiers());
        if ((constructor == null && builderClass == null) || z5) {
            Type mixInAnnotations = JSON.getMixInAnnotations(cls);
            if ((mixInAnnotations instanceof Class) && (creatorConstructor = getCreatorConstructor(((Class) mixInAnnotations).getConstructors())) != null) {
                try {
                    constructor3 = cls6.getConstructor(creatorConstructor.getParameterTypes());
                } catch (NoSuchMethodException unused) {
                }
                if (constructor3 == null) {
                    constructor3 = getCreatorConstructor(declaredConstructors);
                }
                constructor2 = constructor3;
                if (constructor2 == null && !z5) {
                    TypeUtils.setAccessible(constructor2);
                    Class<?>[] parameterTypes = constructor2.getParameterTypes();
                    if (parameterTypes.length > 0) {
                        String[] strArr4 = null;
                        int i22 = 0;
                        for (Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor2); i22 < parameterTypes.length && i22 < parameterAnnotations.length; parameterAnnotations = parameterAnnotations) {
                            Annotation[] annotationArr = parameterAnnotations[i22];
                            int length3 = annotationArr.length;
                            int i23 = 0;
                            while (true) {
                                if (i23 >= length3) {
                                    jSONField5 = null;
                                    break;
                                }
                                Annotation annotation = annotationArr[i23];
                                Annotation[] annotationArr2 = annotationArr;
                                if (annotation instanceof JSONField) {
                                    jSONField5 = (JSONField) annotation;
                                    break;
                                }
                                i23++;
                                annotationArr = annotationArr2;
                            }
                            Class<?> cls8 = parameterTypes[i22];
                            Type type3 = constructor2.getGenericParameterTypes()[i22];
                            if (jSONField5 != null) {
                                field3 = TypeUtils.getField(cls6, jSONField5.name(), declaredFields);
                                i19 = jSONField5.ordinal();
                                i20 = SerializerFeature.of(jSONField5.serialzeFeatures());
                                i21 = Feature.of(jSONField5.parseFeatures());
                                str11 = jSONField5.name();
                            } else {
                                field3 = null;
                                str11 = null;
                                i19 = 0;
                                i20 = 0;
                                i21 = 0;
                            }
                            if (str11 == null || str11.length() == 0) {
                                if (strArr4 == null) {
                                    strArr4 = ASMUtils.lookupParameterNames(constructor2);
                                }
                                str11 = strArr4[i22];
                            }
                            if (field3 == null) {
                                if (strArr4 == null) {
                                    if (isKotlin) {
                                        strArr4 = TypeUtils.getKoltinConstructorParameters(cls);
                                    } else {
                                        strArr4 = ASMUtils.lookupParameterNames(constructor2);
                                    }
                                }
                                field4 = field3;
                                if (strArr4.length > i22) {
                                    strArr3 = strArr4;
                                    field5 = TypeUtils.getField(cls6, strArr4[i22], declaredFields);
                                    ArrayList arrayList4 = arrayList3;
                                    add(arrayList4, new FieldInfo(str11, cls, cls8, type3, field5, i19, i20, i21));
                                    i22++;
                                    parameterTypes = parameterTypes;
                                    methods = methods;
                                    arrayList3 = arrayList4;
                                    propertyNamingStrategy8 = propertyNamingStrategy8;
                                    strArr4 = strArr3;
                                }
                            } else {
                                field4 = field3;
                            }
                            field5 = field4;
                            strArr3 = strArr4;
                            ArrayList arrayList42 = arrayList3;
                            add(arrayList42, new FieldInfo(str11, cls, cls8, type3, field5, i19, i20, i21));
                            i22++;
                            parameterTypes = parameterTypes;
                            methods = methods;
                            arrayList3 = arrayList42;
                            propertyNamingStrategy8 = propertyNamingStrategy8;
                            strArr4 = strArr3;
                        }
                    }
                    arrayList = arrayList3;
                    propertyNamingStrategy2 = propertyNamingStrategy8;
                    methodArr = methods;
                } else {
                    arrayList = arrayList3;
                    propertyNamingStrategy2 = propertyNamingStrategy8;
                    methodArr = methods;
                    method2 = getFactoryMethod(cls6, methodArr, z4);
                    if (method2 == null) {
                        TypeUtils.setAccessible(method2);
                        Class<?>[] parameterTypes2 = method2.getParameterTypes();
                        if (parameterTypes2.length > 0) {
                            Annotation[][] parameterAnnotations2 = TypeUtils.getParameterAnnotations(method2);
                            String[] strArr5 = null;
                            int i24 = 0;
                            while (i24 < parameterTypes2.length) {
                                Annotation[] annotationArr3 = parameterAnnotations2[i24];
                                int length4 = annotationArr3.length;
                                int i25 = 0;
                                while (true) {
                                    if (i25 >= length4) {
                                        jSONField4 = null;
                                        break;
                                    }
                                    Annotation annotation2 = annotationArr3[i25];
                                    if (annotation2 instanceof JSONField) {
                                        jSONField4 = (JSONField) annotation2;
                                        break;
                                    }
                                    i25++;
                                }
                                if (jSONField4 == null && (!z4 || !TypeUtils.isJacksonCreator(method2))) {
                                    throw new JSONException("illegal json creator");
                                }
                                if (jSONField4 != null) {
                                    str10 = jSONField4.name();
                                    int ordinal = jSONField4.ordinal();
                                    int of2 = SerializerFeature.of(jSONField4.serialzeFeatures());
                                    i16 = ordinal;
                                    i18 = Feature.of(jSONField4.parseFeatures());
                                    i17 = of2;
                                } else {
                                    str10 = null;
                                    i16 = 0;
                                    i17 = 0;
                                    i18 = 0;
                                }
                                if (str10 == null || str10.length() == 0) {
                                    if (strArr5 == null) {
                                        strArr5 = ASMUtils.lookupParameterNames(method2);
                                    }
                                    str10 = strArr5[i24];
                                }
                                String[] strArr6 = strArr5;
                                add(arrayList, new FieldInfo(str10, cls, parameterTypes2[i24], method2.getGenericParameterTypes()[i24], TypeUtils.getField(cls6, str10, declaredFields), i16, i17, i18));
                                i24++;
                                z4 = z3;
                                parameterTypes2 = parameterTypes2;
                                strArr5 = strArr6;
                            }
                            return new JavaBeanInfo(cls, builderClass, null, null, method2, null, jSONType3, arrayList);
                        }
                    } else if (!z5) {
                        String name = cls.getName();
                        if (isKotlin && declaredConstructors.length > 0) {
                            String[] koltinConstructorParameters = TypeUtils.getKoltinConstructorParameters(cls);
                            Constructor<?> kotlinConstructor = TypeUtils.getKotlinConstructor(declaredConstructors, koltinConstructorParameters);
                            TypeUtils.setAccessible(kotlinConstructor);
                            constructor2 = kotlinConstructor;
                            strArr = koltinConstructorParameters;
                        } else {
                            int length5 = declaredConstructors.length;
                            String[] strArr7 = null;
                            int i26 = 0;
                            while (true) {
                                if (i26 >= length5) {
                                    strArr = strArr7;
                                    break;
                                }
                                Constructor<?> constructor4 = declaredConstructors[i26];
                                Class<?>[] parameterTypes3 = constructor4.getParameterTypes();
                                if (name.equals("org.springframework.security.web.authentication.WebAuthenticationDetails")) {
                                    if (parameterTypes3.length == 2 && parameterTypes3[0] == String.class && parameterTypes3[1] == String.class) {
                                        constructor4.setAccessible(true);
                                        strArr2 = ASMUtils.lookupParameterNames(constructor4);
                                        break;
                                    }
                                    i26++;
                                } else if (name.equals("org.springframework.security.web.authentication.preauth.PreAuthenticatedAuthenticationToken")) {
                                    if (parameterTypes3.length == 3 && parameterTypes3[0] == Object.class && parameterTypes3[1] == Object.class && parameterTypes3[2] == Collection.class) {
                                        constructor4.setAccessible(true);
                                        strArr2 = new String[]{"principal", "credentials", "authorities"};
                                        break;
                                    }
                                    i26++;
                                } else {
                                    if (name.equals("org.springframework.security.core.authority.SimpleGrantedAuthority")) {
                                        if (parameterTypes3.length == 1 && parameterTypes3[0] == String.class) {
                                            strArr = new String[]{IApp.ConfigProperty.CONFIG_AUTHORITY};
                                            constructor2 = constructor4;
                                            break;
                                        }
                                    } else if (((constructor4.getModifiers() & 1) != 0) && (lookupParameterNames = ASMUtils.lookupParameterNames(constructor4)) != null && lookupParameterNames.length != 0 && (constructor2 == null || strArr7 == null || lookupParameterNames.length > strArr7.length)) {
                                        constructor2 = constructor4;
                                        strArr7 = lookupParameterNames;
                                    }
                                    i26++;
                                }
                            }
                            Class<?>[] parameterTypes4 = strArr == null ? constructor2.getParameterTypes() : null;
                            if (strArr == null && parameterTypes4.length == strArr.length) {
                                Annotation[][] parameterAnnotations3 = TypeUtils.getParameterAnnotations(constructor2);
                                int i27 = 0;
                                while (i27 < parameterTypes4.length) {
                                    Annotation[] annotationArr4 = parameterAnnotations3[i27];
                                    String str12 = strArr[i27];
                                    int length6 = annotationArr4.length;
                                    int i28 = 0;
                                    while (true) {
                                        if (i28 >= length6) {
                                            jSONField3 = null;
                                            break;
                                        }
                                        Annotation annotation3 = annotationArr4[i28];
                                        if (annotation3 instanceof JSONField) {
                                            jSONField3 = (JSONField) annotation3;
                                            break;
                                        }
                                        i28++;
                                    }
                                    Class<?> cls9 = parameterTypes4[i27];
                                    Type type4 = constructor2.getGenericParameterTypes()[i27];
                                    Field field6 = TypeUtils.getField(cls6, str12, declaredFields);
                                    if (field6 != null && jSONField3 == null) {
                                        jSONField3 = (JSONField) TypeUtils.getAnnotation(field6, JSONField.class);
                                    }
                                    if (jSONField3 == null) {
                                        if ("org.springframework.security.core.userdetails.User".equals(name) && Constants.Value.PASSWORD.equals(str12)) {
                                            of = Feature.InitStringFieldAsEmpty.mask;
                                            i15 = 0;
                                            i14 = 0;
                                        } else {
                                            i15 = 0;
                                            i14 = 0;
                                            of = 0;
                                        }
                                    } else {
                                        String name2 = jSONField3.name();
                                        if (name2.length() != 0) {
                                            str12 = name2;
                                        }
                                        int ordinal2 = jSONField3.ordinal();
                                        int of3 = SerializerFeature.of(jSONField3.serialzeFeatures());
                                        of = Feature.of(jSONField3.parseFeatures());
                                        i14 = of3;
                                        i15 = ordinal2;
                                    }
                                    add(arrayList, new FieldInfo(str12, cls, cls9, type4, field6, i15, i14, of));
                                    i27++;
                                    name = name;
                                    strArr = strArr;
                                    parameterTypes4 = parameterTypes4;
                                }
                                if (!isKotlin && !cls.getName().equals("javax.servlet.http.Cookie")) {
                                    return new JavaBeanInfo(cls, builderClass, null, constructor2, null, null, jSONType3, arrayList);
                                }
                            } else {
                                throw new JSONException("default constructor not found. " + cls6);
                            }
                        }
                        if (strArr == null) {
                        }
                        if (strArr == null) {
                        }
                        throw new JSONException("default constructor not found. " + cls6);
                    }
                }
            }
            constructor3 = null;
            if (constructor3 == null) {
            }
            constructor2 = constructor3;
            if (constructor2 == null) {
            }
            arrayList = arrayList3;
            propertyNamingStrategy2 = propertyNamingStrategy8;
            methodArr = methods;
            method2 = getFactoryMethod(cls6, methodArr, z4);
            if (method2 == null) {
            }
        } else {
            arrayList = arrayList3;
            propertyNamingStrategy2 = propertyNamingStrategy8;
            methodArr = methods;
            constructor2 = null;
        }
        if (constructor != null) {
            TypeUtils.setAccessible(constructor);
        }
        String str13 = "set";
        if (builderClass != null) {
            JSONPOJOBuilder jSONPOJOBuilder = (JSONPOJOBuilder) TypeUtils.getAnnotation(builderClass, JSONPOJOBuilder.class);
            String withPrefix = jSONPOJOBuilder != null ? jSONPOJOBuilder.withPrefix() : null;
            if (withPrefix == null) {
                withPrefix = "with";
            }
            String str14 = withPrefix;
            Method[] methods2 = builderClass.getMethods();
            int length7 = methods2.length;
            int i29 = 0;
            while (i29 < length7) {
                Method method3 = methods2[i29];
                if (!Modifier.isStatic(method3.getModifiers()) && method3.getReturnType().equals(builderClass)) {
                    JSONField jSONField6 = (JSONField) TypeUtils.getAnnotation(method3, JSONField.class);
                    if (jSONField6 == null) {
                        jSONField6 = TypeUtils.getSuperMethodAnnotation(cls6, method3);
                    }
                    JSONField jSONField7 = jSONField6;
                    if (jSONField7 == null) {
                        i9 = i29;
                        i10 = length7;
                        methodArr5 = methods2;
                        str5 = str14;
                        str6 = str13;
                        fieldArr7 = declaredFields;
                        cls5 = builderClass;
                        jSONType2 = jSONType3;
                        propertyNamingStrategy7 = propertyNamingStrategy2;
                        methodArr6 = methodArr;
                        i11 = 0;
                        i12 = 0;
                        i13 = 0;
                    } else if (jSONField7.deserialize()) {
                        int ordinal3 = jSONField7.ordinal();
                        int of4 = SerializerFeature.of(jSONField7.serialzeFeatures());
                        int of5 = Feature.of(jSONField7.parseFeatures());
                        if (jSONField7.name().length() != 0) {
                            i9 = i29;
                            i10 = length7;
                            methodArr5 = methods2;
                            fieldArr7 = declaredFields;
                            cls5 = builderClass;
                            jSONType2 = jSONType3;
                            propertyNamingStrategy7 = propertyNamingStrategy2;
                            methodArr6 = methodArr;
                            add(arrayList, new FieldInfo(jSONField7.name(), method3, null, cls, type, ordinal3, of4, of5, jSONField7, null, null, buildGenericInfo));
                            str8 = str14;
                            str9 = str13;
                            i29 = i9 + 1;
                            cls6 = cls;
                            methodArr = methodArr6;
                            str14 = str8;
                            jSONType3 = jSONType2;
                            length7 = i10;
                            methods2 = methodArr5;
                            declaredFields = fieldArr7;
                            builderClass = cls5;
                            propertyNamingStrategy2 = propertyNamingStrategy7;
                            str13 = str9;
                        } else {
                            i9 = i29;
                            i10 = length7;
                            methodArr5 = methods2;
                            str5 = str14;
                            str6 = str13;
                            fieldArr7 = declaredFields;
                            cls5 = builderClass;
                            jSONType2 = jSONType3;
                            propertyNamingStrategy7 = propertyNamingStrategy2;
                            methodArr6 = methodArr;
                            i11 = ordinal3;
                            i12 = of4;
                            i13 = of5;
                        }
                    }
                    String name3 = method3.getName();
                    String str15 = str6;
                    if (name3.startsWith(str15) && name3.length() > 3) {
                        sb = new StringBuilder(name3.substring(3));
                        str7 = str5;
                        charAt = sb.charAt(0);
                        if (str7.length() != 0 || Character.isUpperCase(charAt)) {
                            sb.setCharAt(0, Character.toLowerCase(charAt));
                            str8 = str7;
                            str9 = str15;
                            add(arrayList, new FieldInfo(sb.toString(), method3, null, cls, type, i11, i12, i13, jSONField7, null, null, buildGenericInfo));
                            i29 = i9 + 1;
                            cls6 = cls;
                            methodArr = methodArr6;
                            str14 = str8;
                            jSONType3 = jSONType2;
                            length7 = i10;
                            methods2 = methodArr5;
                            declaredFields = fieldArr7;
                            builderClass = cls5;
                            propertyNamingStrategy2 = propertyNamingStrategy7;
                            str13 = str9;
                        }
                        str8 = str7;
                        str9 = str15;
                        i29 = i9 + 1;
                        cls6 = cls;
                        methodArr = methodArr6;
                        str14 = str8;
                        jSONType3 = jSONType2;
                        length7 = i10;
                        methods2 = methodArr5;
                        declaredFields = fieldArr7;
                        builderClass = cls5;
                        propertyNamingStrategy2 = propertyNamingStrategy7;
                        str13 = str9;
                    }
                    if (str5.length() == 0) {
                        sb = new StringBuilder(name3);
                        str7 = str5;
                        charAt = sb.charAt(0);
                        if (str7.length() != 0) {
                        }
                        sb.setCharAt(0, Character.toLowerCase(charAt));
                        str8 = str7;
                        str9 = str15;
                        add(arrayList, new FieldInfo(sb.toString(), method3, null, cls, type, i11, i12, i13, jSONField7, null, null, buildGenericInfo));
                        i29 = i9 + 1;
                        cls6 = cls;
                        methodArr = methodArr6;
                        str14 = str8;
                        jSONType3 = jSONType2;
                        length7 = i10;
                        methods2 = methodArr5;
                        declaredFields = fieldArr7;
                        builderClass = cls5;
                        propertyNamingStrategy2 = propertyNamingStrategy7;
                        str13 = str9;
                    } else {
                        str7 = str5;
                        if (name3.startsWith(str7) && name3.length() > str7.length()) {
                            sb = new StringBuilder(name3.substring(str7.length()));
                            charAt = sb.charAt(0);
                            if (str7.length() != 0) {
                            }
                            sb.setCharAt(0, Character.toLowerCase(charAt));
                            str8 = str7;
                            str9 = str15;
                            add(arrayList, new FieldInfo(sb.toString(), method3, null, cls, type, i11, i12, i13, jSONField7, null, null, buildGenericInfo));
                            i29 = i9 + 1;
                            cls6 = cls;
                            methodArr = methodArr6;
                            str14 = str8;
                            jSONType3 = jSONType2;
                            length7 = i10;
                            methods2 = methodArr5;
                            declaredFields = fieldArr7;
                            builderClass = cls5;
                            propertyNamingStrategy2 = propertyNamingStrategy7;
                            str13 = str9;
                        }
                        str8 = str7;
                        str9 = str15;
                        i29 = i9 + 1;
                        cls6 = cls;
                        methodArr = methodArr6;
                        str14 = str8;
                        jSONType3 = jSONType2;
                        length7 = i10;
                        methods2 = methodArr5;
                        declaredFields = fieldArr7;
                        builderClass = cls5;
                        propertyNamingStrategy2 = propertyNamingStrategy7;
                        str13 = str9;
                    }
                }
                i9 = i29;
                i10 = length7;
                methodArr5 = methods2;
                str8 = str14;
                str9 = str13;
                fieldArr7 = declaredFields;
                cls5 = builderClass;
                jSONType2 = jSONType3;
                propertyNamingStrategy7 = propertyNamingStrategy2;
                methodArr6 = methodArr;
                i29 = i9 + 1;
                cls6 = cls;
                methodArr = methodArr6;
                str14 = str8;
                jSONType3 = jSONType2;
                length7 = i10;
                methods2 = methodArr5;
                declaredFields = fieldArr7;
                builderClass = cls5;
                propertyNamingStrategy2 = propertyNamingStrategy7;
                str13 = str9;
            }
            str = str13;
            fieldArr = declaredFields;
            cls2 = builderClass;
            jSONType = jSONType3;
            propertyNamingStrategy3 = propertyNamingStrategy2;
            methodArr2 = methodArr;
            if (cls2 != null) {
                JSONPOJOBuilder jSONPOJOBuilder2 = (JSONPOJOBuilder) TypeUtils.getAnnotation(cls2, JSONPOJOBuilder.class);
                String buildMethod = jSONPOJOBuilder2 != null ? jSONPOJOBuilder2.buildMethod() : null;
                c = 0;
                try {
                    method = cls2.getMethod((buildMethod == null || buildMethod.length() == 0) ? "build" : "build", new Class[0]);
                } catch (NoSuchMethodException | SecurityException unused2) {
                }
                if (method == null) {
                    try {
                        method = cls2.getMethod("create", new Class[0]);
                    } catch (NoSuchMethodException | SecurityException unused3) {
                    }
                }
                if (method == null) {
                    throw new JSONException("buildMethod not found.");
                }
                TypeUtils.setAccessible(method);
                length = methodArr2.length;
                i = 0;
                while (true) {
                    str2 = "get";
                    i2 = 4;
                    if (i < length) {
                        break;
                    }
                    Method method4 = methodArr2[i];
                    int i30 = 0;
                    int i31 = 0;
                    int i32 = 0;
                    String name4 = method4.getName();
                    if (!Modifier.isStatic(method4.getModifiers())) {
                        Class<?> returnType = method4.getReturnType();
                        if ((returnType.equals(Void.TYPE) || returnType.equals(method4.getDeclaringClass())) && method4.getDeclaringClass() != Object.class) {
                            Class<?>[] parameterTypes5 = method4.getParameterTypes();
                            if (parameterTypes5.length != 0 && parameterTypes5.length <= 2) {
                                JSONField jSONField8 = (JSONField) TypeUtils.getAnnotation(method4, JSONField.class);
                                if (jSONField8 != null && parameterTypes5.length == 2 && parameterTypes5[c] == String.class && parameterTypes5[1] == Object.class) {
                                    i6 = i;
                                    i7 = length;
                                    add(arrayList, new FieldInfo("", method4, null, cls, type, 0, 0, 0, jSONField8, null, null, buildGenericInfo));
                                } else {
                                    i6 = i;
                                    i7 = length;
                                    if (parameterTypes5.length == 1) {
                                        if (jSONField8 == null) {
                                            jSONField8 = TypeUtils.getSuperMethodAnnotation(cls, method4);
                                        }
                                        if (jSONField8 != null || name4.length() >= 4) {
                                            if (jSONField8 != null) {
                                                if (jSONField8.deserialize()) {
                                                    i30 = jSONField8.ordinal();
                                                    i31 = SerializerFeature.of(jSONField8.serialzeFeatures());
                                                    int of6 = Feature.of(jSONField8.parseFeatures());
                                                    if (jSONField8.name().length() != 0) {
                                                        add(arrayList, new FieldInfo(jSONField8.name(), method4, null, cls, type, i30, i31, of6, jSONField8, null, null, buildGenericInfo));
                                                    } else {
                                                        i32 = of6;
                                                    }
                                                }
                                            }
                                            String str16 = str;
                                            if ((jSONField8 != null || name4.startsWith(str16)) && cls2 == null) {
                                                char charAt2 = name4.charAt(3);
                                                if (isKotlin) {
                                                    arrayList2 = new ArrayList();
                                                    for (int i33 = 0; i33 < methodArr2.length; i33++) {
                                                        if (methodArr2[i33].getName().startsWith("get")) {
                                                            arrayList2.add(methodArr2[i33].getName());
                                                        }
                                                    }
                                                } else {
                                                    arrayList2 = null;
                                                }
                                                if (Character.isUpperCase(charAt2) || charAt2 > 512) {
                                                    cls3 = cls;
                                                    fieldArr4 = fieldArr;
                                                    if (isKotlin) {
                                                        propertyNameByMethodName2 = TypeUtils.getPropertyNameByMethodName("g" + name4.substring(1));
                                                    } else if (TypeUtils.compatibleWithJavaBean) {
                                                        propertyNameByMethodName2 = TypeUtils.decapitalize(name4.substring(3));
                                                    } else {
                                                        propertyNameByMethodName2 = TypeUtils.getPropertyNameByMethodName(name4);
                                                    }
                                                } else {
                                                    if (charAt2 != '_') {
                                                        cls3 = cls;
                                                        fieldArr6 = fieldArr;
                                                        if (charAt2 == 'f') {
                                                            propertyNameByMethodName2 = name4.substring(3);
                                                        } else if (name4.length() >= 5 && Character.isUpperCase(name4.charAt(4))) {
                                                            propertyNameByMethodName2 = TypeUtils.decapitalize(name4.substring(3));
                                                        } else {
                                                            propertyNameByMethodName2 = name4.substring(3);
                                                            field2 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr6);
                                                            if (field2 == null) {
                                                                fieldArr5 = fieldArr6;
                                                                str4 = str16;
                                                                cls4 = cls2;
                                                                methodArr4 = methodArr2;
                                                            }
                                                        }
                                                        fieldArr4 = fieldArr6;
                                                    } else if (isKotlin) {
                                                        propertyNameByMethodName2 = arrayList2.contains("g" + name4.substring(1)) ? name4.substring(3) : "is" + name4.substring(3);
                                                        cls3 = cls;
                                                        fieldArr6 = fieldArr;
                                                        field2 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr6);
                                                    } else {
                                                        cls3 = cls;
                                                        fieldArr6 = fieldArr;
                                                        String substring = name4.substring(4);
                                                        Field field7 = TypeUtils.getField(cls3, substring, fieldArr6);
                                                        if (field7 != null || (field7 = TypeUtils.getField(cls3, (propertyNameByMethodName2 = name4.substring(3)), fieldArr6)) == null) {
                                                            propertyNameByMethodName2 = substring;
                                                        }
                                                        field2 = field7;
                                                    }
                                                    fieldArr4 = fieldArr6;
                                                    if (field2 == null) {
                                                        field2 = TypeUtils.getField(cls3, propertyNameByMethodName2, fieldArr4);
                                                    }
                                                    if (field2 == null && parameterTypes5[0] == Boolean.TYPE) {
                                                        field2 = TypeUtils.getField(cls3, "is" + Character.toUpperCase(propertyNameByMethodName2.charAt(0)) + propertyNameByMethodName2.substring(1), fieldArr4);
                                                    }
                                                    if (field2 == null) {
                                                        JSONField jSONField9 = (JSONField) TypeUtils.getAnnotation(field2, JSONField.class);
                                                        if (jSONField9 == null) {
                                                            fieldArr5 = fieldArr4;
                                                            str4 = str16;
                                                            methodArr4 = methodArr2;
                                                            i8 = i32;
                                                        } else if (jSONField9.deserialize()) {
                                                            i30 = jSONField9.ordinal();
                                                            i31 = SerializerFeature.of(jSONField9.serialzeFeatures());
                                                            int of7 = Feature.of(jSONField9.parseFeatures());
                                                            if (jSONField9.name().length() != 0) {
                                                                fieldArr5 = fieldArr4;
                                                                methodArr4 = methodArr2;
                                                                str4 = str16;
                                                                add(arrayList, new FieldInfo(jSONField9.name(), method4, field2, cls, type, i30, i31, of7, jSONField8, jSONField9, null, buildGenericInfo));
                                                                cls4 = cls2;
                                                                propertyNamingStrategy6 = propertyNamingStrategy3;
                                                                i = i6 + 1;
                                                                propertyNamingStrategy3 = propertyNamingStrategy6;
                                                                length = i7;
                                                                methodArr2 = methodArr4;
                                                                str = str4;
                                                                cls2 = cls4;
                                                                fieldArr = fieldArr5;
                                                                c = 0;
                                                            } else {
                                                                fieldArr5 = fieldArr4;
                                                                str4 = str16;
                                                                methodArr4 = methodArr2;
                                                                i8 = of7;
                                                            }
                                                        } else {
                                                            fieldArr5 = fieldArr4;
                                                            str4 = str16;
                                                            cls4 = cls2;
                                                            methodArr4 = methodArr2;
                                                        }
                                                        jSONField2 = jSONField9;
                                                    } else {
                                                        fieldArr5 = fieldArr4;
                                                        str4 = str16;
                                                        methodArr4 = methodArr2;
                                                        jSONField2 = null;
                                                        i8 = i32;
                                                    }
                                                    propertyNamingStrategy5 = propertyNamingStrategy3;
                                                    if (propertyNamingStrategy5 != null) {
                                                        propertyNameByMethodName2 = propertyNamingStrategy5.translate(propertyNameByMethodName2);
                                                    }
                                                    cls4 = cls2;
                                                    propertyNamingStrategy6 = propertyNamingStrategy5;
                                                    add(arrayList, new FieldInfo(propertyNameByMethodName2, method4, field2, cls, type, i30, i31, i8, jSONField8, jSONField2, null, buildGenericInfo));
                                                    i = i6 + 1;
                                                    propertyNamingStrategy3 = propertyNamingStrategy6;
                                                    length = i7;
                                                    methodArr2 = methodArr4;
                                                    str = str4;
                                                    cls2 = cls4;
                                                    fieldArr = fieldArr5;
                                                    c = 0;
                                                }
                                                field2 = null;
                                                if (field2 == null) {
                                                }
                                                if (field2 == null) {
                                                    field2 = TypeUtils.getField(cls3, "is" + Character.toUpperCase(propertyNameByMethodName2.charAt(0)) + propertyNameByMethodName2.substring(1), fieldArr4);
                                                }
                                                if (field2 == null) {
                                                }
                                                propertyNamingStrategy5 = propertyNamingStrategy3;
                                                if (propertyNamingStrategy5 != null) {
                                                }
                                                cls4 = cls2;
                                                propertyNamingStrategy6 = propertyNamingStrategy5;
                                                add(arrayList, new FieldInfo(propertyNameByMethodName2, method4, field2, cls, type, i30, i31, i8, jSONField8, jSONField2, null, buildGenericInfo));
                                                i = i6 + 1;
                                                propertyNamingStrategy3 = propertyNamingStrategy6;
                                                length = i7;
                                                methodArr2 = methodArr4;
                                                str = str4;
                                                cls2 = cls4;
                                                fieldArr = fieldArr5;
                                                c = 0;
                                            } else {
                                                str4 = str16;
                                                cls4 = cls2;
                                                methodArr4 = methodArr2;
                                                fieldArr5 = fieldArr;
                                            }
                                            propertyNamingStrategy6 = propertyNamingStrategy3;
                                            i = i6 + 1;
                                            propertyNamingStrategy3 = propertyNamingStrategy6;
                                            length = i7;
                                            methodArr2 = methodArr4;
                                            str = str4;
                                            cls2 = cls4;
                                            fieldArr = fieldArr5;
                                            c = 0;
                                        }
                                    }
                                }
                                cls4 = cls2;
                                methodArr4 = methodArr2;
                                fieldArr5 = fieldArr;
                                propertyNamingStrategy6 = propertyNamingStrategy3;
                                str4 = str;
                                i = i6 + 1;
                                propertyNamingStrategy3 = propertyNamingStrategy6;
                                length = i7;
                                methodArr2 = methodArr4;
                                str = str4;
                                cls2 = cls4;
                                fieldArr = fieldArr5;
                                c = 0;
                            }
                        }
                    }
                    i6 = i;
                    i7 = length;
                    cls4 = cls2;
                    methodArr4 = methodArr2;
                    fieldArr5 = fieldArr;
                    propertyNamingStrategy6 = propertyNamingStrategy3;
                    str4 = str;
                    i = i6 + 1;
                    propertyNamingStrategy3 = propertyNamingStrategy6;
                    length = i7;
                    methodArr2 = methodArr4;
                    str = str4;
                    cls2 = cls4;
                    fieldArr = fieldArr5;
                    c = 0;
                }
                Class<?> cls10 = cls2;
                Field[] fieldArr8 = fieldArr;
                PropertyNamingStrategy propertyNamingStrategy9 = propertyNamingStrategy3;
                Type type5 = type;
                computeFields(cls, type5, propertyNamingStrategy9, arrayList, cls.getFields());
                Method[] methods3 = cls.getMethods();
                length2 = methods3.length;
                i3 = 0;
                while (i3 < length2) {
                    Method method5 = methods3[i3];
                    String name5 = method5.getName();
                    if (name5.length() >= i2 && !Modifier.isStatic(method5.getModifiers()) && cls10 == null && name5.startsWith(str2) && Character.isUpperCase(name5.charAt(3)) && method5.getParameterTypes().length == 0 && ((Collection.class.isAssignableFrom(method5.getReturnType()) || Map.class.isAssignableFrom(method5.getReturnType()) || AtomicBoolean.class == method5.getReturnType() || AtomicInteger.class == method5.getReturnType() || AtomicLong.class == method5.getReturnType()) && ((jSONField = (JSONField) TypeUtils.getAnnotation(method5, JSONField.class)) == null || !jSONField.deserialize()))) {
                        if (jSONField != null && jSONField.name().length() > 0) {
                            propertyNameByMethodName = jSONField.name();
                            field = null;
                            fieldArr2 = fieldArr8;
                        } else {
                            propertyNameByMethodName = TypeUtils.getPropertyNameByMethodName(name5);
                            fieldArr2 = fieldArr8;
                            Field field8 = TypeUtils.getField(cls, propertyNameByMethodName, fieldArr2);
                            if (field8 != null) {
                                JSONField jSONField10 = (JSONField) TypeUtils.getAnnotation(field8, JSONField.class);
                                if (jSONField10 == null || jSONField10.deserialize()) {
                                    if (Collection.class.isAssignableFrom(method5.getReturnType()) || Map.class.isAssignableFrom(method5.getReturnType())) {
                                        field = field8;
                                    }
                                }
                                fieldArr3 = fieldArr2;
                                i4 = i3;
                                str3 = str2;
                                i5 = length2;
                                methodArr3 = methods3;
                                propertyNamingStrategy4 = propertyNamingStrategy9;
                            }
                            field = null;
                        }
                        if (propertyNamingStrategy9 != null) {
                            propertyNameByMethodName = propertyNamingStrategy9.translate(propertyNameByMethodName);
                        }
                        String str17 = propertyNameByMethodName;
                        if (getField(arrayList, str17) == null) {
                            fieldArr3 = fieldArr2;
                            i4 = i3;
                            str3 = str2;
                            i5 = length2;
                            methodArr3 = methods3;
                            propertyNamingStrategy4 = propertyNamingStrategy9;
                            type2 = type5;
                            add(arrayList, new FieldInfo(str17, method5, field, cls, type, 0, 0, 0, jSONField, null, null, buildGenericInfo));
                            i3 = i4 + 1;
                            type5 = type2;
                            length2 = i5;
                            str2 = str3;
                            methods3 = methodArr3;
                            propertyNamingStrategy9 = propertyNamingStrategy4;
                            fieldArr8 = fieldArr3;
                            i2 = 4;
                        }
                        fieldArr3 = fieldArr2;
                        i4 = i3;
                        str3 = str2;
                        i5 = length2;
                        methodArr3 = methods3;
                        propertyNamingStrategy4 = propertyNamingStrategy9;
                    } else {
                        i4 = i3;
                        str3 = str2;
                        i5 = length2;
                        methodArr3 = methods3;
                        propertyNamingStrategy4 = propertyNamingStrategy9;
                        fieldArr3 = fieldArr8;
                    }
                    type2 = type5;
                    i3 = i4 + 1;
                    type5 = type2;
                    length2 = i5;
                    str2 = str3;
                    methods3 = methodArr3;
                    propertyNamingStrategy9 = propertyNamingStrategy4;
                    fieldArr8 = fieldArr3;
                    i2 = 4;
                }
                PropertyNamingStrategy propertyNamingStrategy10 = propertyNamingStrategy9;
                Field[] fieldArr9 = fieldArr8;
                Type type6 = type5;
                if (arrayList.size() == 0) {
                    if (TypeUtils.isXmlField(cls) ? true : z) {
                        for (Class<?> cls11 = cls; cls11 != null; cls11 = cls11.getSuperclass()) {
                            computeFields(cls, type6, propertyNamingStrategy10, arrayList, fieldArr9);
                        }
                    }
                }
                return new JavaBeanInfo(cls, cls10, constructor, constructor2, method2, method, jSONType, arrayList);
            }
        } else {
            str = "set";
            fieldArr = declaredFields;
            cls2 = builderClass;
            jSONType = jSONType3;
            propertyNamingStrategy3 = propertyNamingStrategy2;
            methodArr2 = methodArr;
        }
        c = 0;
        length = methodArr2.length;
        i = 0;
        while (true) {
            str2 = "get";
            i2 = 4;
            if (i < length) {
            }
            i = i6 + 1;
            propertyNamingStrategy3 = propertyNamingStrategy6;
            length = i7;
            methodArr2 = methodArr4;
            str = str4;
            cls2 = cls4;
            fieldArr = fieldArr5;
            c = 0;
        }
        Class<?> cls102 = cls2;
        Field[] fieldArr82 = fieldArr;
        PropertyNamingStrategy propertyNamingStrategy92 = propertyNamingStrategy3;
        Type type52 = type;
        computeFields(cls, type52, propertyNamingStrategy92, arrayList, cls.getFields());
        Method[] methods32 = cls.getMethods();
        length2 = methods32.length;
        i3 = 0;
        while (i3 < length2) {
        }
        PropertyNamingStrategy propertyNamingStrategy102 = propertyNamingStrategy92;
        Field[] fieldArr92 = fieldArr82;
        Type type62 = type52;
        if (arrayList.size() == 0) {
        }
        return new JavaBeanInfo(cls, cls102, constructor, constructor2, method2, method, jSONType, arrayList);
    }

    /* JADX WARN: Code restructure failed: missing block: B:22:0x0055, code lost:
        if ((java.util.Map.class.isAssignableFrom(r2) || java.util.Collection.class.isAssignableFrom(r2) || java.util.concurrent.atomic.AtomicLong.class.equals(r2) || java.util.concurrent.atomic.AtomicInteger.class.equals(r2) || java.util.concurrent.atomic.AtomicBoolean.class.equals(r2)) == false) goto L5;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static void computeFields(Class<?> cls, Type type, PropertyNamingStrategy propertyNamingStrategy, List<FieldInfo> list, Field[] fieldArr) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        Map<TypeVariable, Type> buildGenericInfo = buildGenericInfo(cls);
        int length = fieldArr.length;
        int i6 = 0;
        while (i6 < length) {
            Field field = fieldArr[i6];
            int modifiers = field.getModifiers();
            if ((modifiers & 8) == 0) {
                boolean z = true;
                if ((modifiers & 16) != 0) {
                    Class<?> type2 = field.getType();
                }
                Iterator<FieldInfo> it = list.iterator();
                while (true) {
                    if (!it.hasNext()) {
                        z = false;
                        break;
                    } else if (it.next().name.equals(field.getName())) {
                        break;
                    }
                }
                if (!z) {
                    String name = field.getName();
                    JSONField jSONField = (JSONField) TypeUtils.getAnnotation(field, JSONField.class);
                    if (jSONField == null) {
                        i = 0;
                        i2 = 0;
                        i3 = 0;
                    } else if (jSONField.deserialize()) {
                        int ordinal = jSONField.ordinal();
                        int of = SerializerFeature.of(jSONField.serialzeFeatures());
                        int of2 = Feature.of(jSONField.parseFeatures());
                        if (jSONField.name().length() != 0) {
                            name = jSONField.name();
                        }
                        i = ordinal;
                        i2 = of;
                        i3 = of2;
                    }
                    if (propertyNamingStrategy != null) {
                        name = propertyNamingStrategy.translate(name);
                    }
                    i4 = i6;
                    i5 = length;
                    add(list, new FieldInfo(name, null, field, cls, type, i, i2, i3, null, jSONField, null, buildGenericInfo));
                    i6 = i4 + 1;
                    length = i5;
                }
            }
            i4 = i6;
            i5 = length;
            i6 = i4 + 1;
            length = i5;
        }
    }

    static Constructor<?> getDefaultConstructor(Class<?> cls, Constructor<?>[] constructorArr) {
        Constructor<?> constructor = null;
        if (Modifier.isAbstract(cls.getModifiers())) {
            return null;
        }
        int length = constructorArr.length;
        int i = 0;
        while (true) {
            if (i >= length) {
                break;
            }
            Constructor<?> constructor2 = constructorArr[i];
            if (constructor2.getParameterTypes().length == 0) {
                constructor = constructor2;
                break;
            }
            i++;
        }
        if (constructor == null && cls.isMemberClass() && !Modifier.isStatic(cls.getModifiers())) {
            for (Constructor<?> constructor3 : constructorArr) {
                Class<?>[] parameterTypes = constructor3.getParameterTypes();
                if (parameterTypes.length == 1 && parameterTypes[0].equals(cls.getDeclaringClass())) {
                    return constructor3;
                }
            }
            return constructor;
        }
        return constructor;
    }

    public static Constructor<?> getCreatorConstructor(Constructor[] constructorArr) {
        boolean z;
        Constructor constructor = null;
        for (Constructor constructor2 : constructorArr) {
            if (((JSONCreator) constructor2.getAnnotation(JSONCreator.class)) != null) {
                if (constructor != null) {
                    throw new JSONException("multi-JSONCreator");
                }
                constructor = constructor2;
            }
        }
        if (constructor != null) {
            return constructor;
        }
        for (Constructor constructor3 : constructorArr) {
            Annotation[][] parameterAnnotations = TypeUtils.getParameterAnnotations(constructor3);
            if (parameterAnnotations.length != 0) {
                int length = parameterAnnotations.length;
                int i = 0;
                while (true) {
                    z = true;
                    if (i >= length) {
                        break;
                    }
                    Annotation[] annotationArr = parameterAnnotations[i];
                    int length2 = annotationArr.length;
                    int i2 = 0;
                    while (true) {
                        if (i2 >= length2) {
                            z = false;
                            break;
                        } else if (annotationArr[i2] instanceof JSONField) {
                            break;
                        } else {
                            i2++;
                        }
                    }
                    if (!z) {
                        z = false;
                        break;
                    }
                    i++;
                }
                if (!z) {
                    continue;
                } else if (constructor != null) {
                    throw new JSONException("multi-JSONCreator");
                } else {
                    constructor = constructor3;
                }
            }
        }
        return constructor;
    }

    private static Method getFactoryMethod(Class<?> cls, Method[] methodArr, boolean z) {
        Method method = null;
        for (Method method2 : methodArr) {
            if (Modifier.isStatic(method2.getModifiers()) && cls.isAssignableFrom(method2.getReturnType()) && ((JSONCreator) TypeUtils.getAnnotation(method2, JSONCreator.class)) != null) {
                if (method != null) {
                    throw new JSONException("multi-JSONCreator");
                }
                method = method2;
            }
        }
        if (method == null && z) {
            for (Method method3 : methodArr) {
                if (TypeUtils.isJacksonCreator(method3)) {
                    return method3;
                }
            }
            return method;
        }
        return method;
    }

    public static Class<?> getBuilderClass(JSONType jSONType) {
        return getBuilderClass(null, jSONType);
    }

    public static Class<?> getBuilderClass(Class<?> cls, JSONType jSONType) {
        Class<?> builder;
        if (cls != null && cls.getName().equals("org.springframework.security.web.savedrequest.DefaultSavedRequest")) {
            return TypeUtils.loadClass("org.springframework.security.web.savedrequest.DefaultSavedRequest$Builder");
        }
        if (jSONType == null || (builder = jSONType.builder()) == Void.class) {
            return null;
        }
        return builder;
    }
}
