package com.dcloud.android.widget;

import android.content.Context;
import android.text.TextUtils;
import android.view.MotionEvent;
import android.view.VelocityTracker;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.widget.Scroller;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.JSONUtil;
import io.dcloud.common.util.PdrUtil;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class SlideLayout extends android.widget.AbsoluteLayout {
    private static String AFTER_SLIDE = "afterSlide";
    private static String BEFORE_SLIDE = "beforeSlide";
    private static String LEFT = "left";
    private static String RIGHT = "right";
    private static final int SCROLL_DURATION = 150;
    private static final int SNAP_VELOCITY = 1000;
    boolean isLeftSlide;
    boolean isRightSlide;
    boolean isSlideOpen;
    private boolean mCanDoSlideTransverseEvent;
    private OnStateChangeListener mChangeListener;
    private float mFirstX;
    private boolean mInterceptEventEnable;
    private boolean mIsHandledTouchEvent;
    private float mLastMotionX;
    private Scroller mScroller;
    private int mSlideLeftPosition;
    private int mSlideRightPosition;
    private int mSlideTransverseLeftMaxWitch;
    private int mSlideTransverseRightMaxWitch;
    private int mTouchSlop;
    private VelocityTracker mVelocityTracker;

    /* loaded from: classes.dex */
    public interface OnStateChangeListener {
        void onStateChanged(String str, String str2);
    }

    public SlideLayout(Context context) {
        super(context);
        this.mInterceptEventEnable = true;
        this.mIsHandledTouchEvent = false;
        this.mLastMotionX = -1.0f;
        this.mCanDoSlideTransverseEvent = false;
        this.mSlideTransverseLeftMaxWitch = 0;
        this.mSlideTransverseRightMaxWitch = 0;
        this.mSlideLeftPosition = -1;
        this.mSlideRightPosition = -1;
        this.isRightSlide = false;
        this.isLeftSlide = false;
        this.isSlideOpen = false;
        this.mFirstX = 0.0f;
        this.mScroller = new Scroller(getContext());
        this.mTouchSlop = ViewConfiguration.get(context).getScaledTouchSlop();
    }

    private void setState(final String str, final String str2) {
        if (this.mChangeListener != null) {
            postDelayed(new Runnable() { // from class: com.dcloud.android.widget.SlideLayout.1
                @Override // java.lang.Runnable
                public void run() {
                    SlideLayout.this.mChangeListener.onStateChanged(str2, str);
                }
            }, 150L);
        }
    }

    private void smoothScrollTo(int i, int i2) {
        enableChildrenCache();
        this.mScroller.startScroll(getScrollX(), 0, i, 0, Math.abs(i) * 2);
        invalidate();
    }

    void clearChildrenCache() {
        int childCount = getChildCount();
        for (int i = 0; i < childCount; i++) {
            getChildAt(i).setDrawingCacheEnabled(false);
        }
    }

    @Override // android.view.View
    public void computeScroll() {
        if (this.mScroller.computeScrollOffset()) {
            scrollTo(this.mScroller.getCurrX(), this.mScroller.getCurrY());
            postInvalidate();
        } else {
            clearChildrenCache();
        }
        super.computeScroll();
    }

    void enableChildrenCache() {
        int childCount = getChildCount();
        for (int i = 0; i < childCount; i++) {
            getChildAt(i).setDrawingCacheEnabled(true);
        }
    }

    public void initSlideInfo(JSONObject jSONObject, float f, int i) {
        JSONObject jSONObject2 = JSONUtil.getJSONObject(jSONObject, AbsoluteConst.BOUNCE_SLIDEO_OFFSET);
        if (jSONObject2 != null) {
            JSONObject jSONObject3 = JSONUtil.getJSONObject(jSONObject, "position");
            if (jSONObject3 != null) {
                String optString = jSONObject3.optString(LEFT);
                String optString2 = jSONObject3.optString(RIGHT);
                if (!TextUtils.isEmpty(optString)) {
                    this.mSlideLeftPosition = PdrUtil.convertToScreenInt(optString, i, i / 2, f);
                }
                if (!TextUtils.isEmpty(optString2)) {
                    this.mSlideRightPosition = PdrUtil.convertToScreenInt(optString2, i, i / 2, f);
                }
            }
            this.mInterceptEventEnable = jSONObject.optBoolean("preventTouchEvent", true);
            String string = JSONUtil.getString(jSONObject2, LEFT);
            if (!TextUtils.isEmpty(string)) {
                this.isLeftSlide = this.mSlideLeftPosition > 0;
                this.mSlideTransverseLeftMaxWitch = PdrUtil.convertToScreenInt(string, i, i / 2, f);
            }
            String string2 = JSONUtil.getString(jSONObject2, RIGHT);
            if (TextUtils.isEmpty(string2)) {
                return;
            }
            this.isRightSlide = this.mSlideRightPosition > 0;
            this.mSlideTransverseRightMaxWitch = PdrUtil.convertToScreenInt(string2, i, i / 2, f);
        }
    }

    @Override // android.view.ViewGroup
    public boolean onInterceptTouchEvent(MotionEvent motionEvent) {
        int action = motionEvent.getAction();
        if (this.mInterceptEventEnable) {
            if (this.isLeftSlide || this.isRightSlide) {
                if (action != 3 && action != 1) {
                    if (action == 0 || !this.mIsHandledTouchEvent) {
                        if (action != 0) {
                            if (action == 2 && ((int) Math.abs(motionEvent.getX() - this.mFirstX)) > this.mTouchSlop) {
                                enableChildrenCache();
                                this.mIsHandledTouchEvent = true;
                                this.mCanDoSlideTransverseEvent = true;
                                requestDisallowInterceptTouchEvent(true);
                            }
                        } else {
                            this.mLastMotionX = motionEvent.getX();
                            this.mFirstX = motionEvent.getX();
                            this.mIsHandledTouchEvent = false;
                            this.mCanDoSlideTransverseEvent = false;
                        }
                        return this.mIsHandledTouchEvent;
                    }
                    return true;
                }
                this.mIsHandledTouchEvent = false;
                clearChildrenCache();
                return this.mIsHandledTouchEvent;
            }
            return false;
        }
        return false;
    }

    /* JADX WARN: Code restructure failed: missing block: B:14:0x001c, code lost:
        if (r0 != 3) goto L14;
     */
    @Override // android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean onTouchEvent(MotionEvent motionEvent) {
        if (this.mCanDoSlideTransverseEvent && this.mVelocityTracker == null) {
            this.mVelocityTracker = VelocityTracker.obtain();
        }
        int action = motionEvent.getAction();
        if (action != 0) {
            if (action != 1) {
                if (action == 2) {
                    VelocityTracker velocityTracker = this.mVelocityTracker;
                    if (velocityTracker != null) {
                        velocityTracker.addMovement(motionEvent);
                    }
                    float x = motionEvent.getX();
                    if (this.mCanDoSlideTransverseEvent) {
                        int i = (int) (this.mLastMotionX - x);
                        this.mLastMotionX = x;
                        int scrollX = getScrollX();
                        int right = (getChildAt(getChildCount() - 1).getRight() - scrollX) - getWidth();
                        if (scrollX == 0) {
                            if (this.isRightSlide && i > 0) {
                                scrollBy(i, 0);
                            } else if (this.isLeftSlide && i < 0) {
                                scrollBy(i, 0);
                            }
                        } else if (scrollX > 0 && right < 0 && this.isRightSlide) {
                            int i2 = scrollX + i;
                            if (Math.abs(i2) <= this.mSlideRightPosition) {
                                if (i2 < 0) {
                                    scrollBy(0, 0);
                                } else if (Math.abs(i2) >= this.mSlideTransverseRightMaxWitch) {
                                    double d = i;
                                    Double.isNaN(d);
                                    scrollBy((int) (d / 1.5d), 0);
                                } else {
                                    scrollBy(i, 0);
                                }
                            }
                        } else if (scrollX < 0 && right > 0 && this.isLeftSlide) {
                            int i3 = scrollX + i;
                            if (Math.abs(i3) <= this.mSlideLeftPosition) {
                                if (i3 > 0) {
                                    scrollBy(0, 0);
                                } else if (Math.abs(i3) >= this.mSlideTransverseLeftMaxWitch) {
                                    double d2 = i;
                                    Double.isNaN(d2);
                                    scrollBy((int) (d2 / 1.5d), 0);
                                } else {
                                    scrollBy(i, 0);
                                }
                            }
                        }
                    }
                }
            }
            if (this.mIsHandledTouchEvent) {
                this.mIsHandledTouchEvent = false;
                if (this.mCanDoSlideTransverseEvent) {
                    requestDisallowInterceptTouchEvent(false);
                    VelocityTracker velocityTracker2 = this.mVelocityTracker;
                    velocityTracker2.computeCurrentVelocity(1000);
                    int xVelocity = (int) velocityTracker2.getXVelocity();
                    int scrollX2 = getScrollX();
                    if (xVelocity > 1000) {
                        if (scrollX2 < 0 && this.isLeftSlide) {
                            int i4 = this.mSlideLeftPosition;
                            int i5 = this.mSlideTransverseLeftMaxWitch;
                            if (i4 >= i5) {
                                smoothScrollTo(-(i5 - Math.abs(scrollX2)), 0);
                                this.isSlideOpen = true;
                                setState(LEFT, AFTER_SLIDE);
                            }
                        }
                        if (scrollX2 > 0 && this.isRightSlide) {
                            smoothScrollTo(-scrollX2, 0);
                            this.isSlideOpen = false;
                            setState(RIGHT, BEFORE_SLIDE);
                        } else {
                            upSlideTo(scrollX2);
                        }
                    } else if (xVelocity < -1000) {
                        if (scrollX2 < 0 && this.isLeftSlide) {
                            smoothScrollTo(-scrollX2, 0);
                            this.isSlideOpen = false;
                            setState(LEFT, BEFORE_SLIDE);
                        } else {
                            if (scrollX2 > 0 && this.isRightSlide) {
                                int i6 = this.mSlideRightPosition;
                                int i7 = this.mSlideTransverseRightMaxWitch;
                                if (i6 >= i7) {
                                    smoothScrollTo(i7 - Math.abs(scrollX2), 0);
                                    this.isSlideOpen = true;
                                    setState(RIGHT, AFTER_SLIDE);
                                }
                            }
                            upSlideTo(scrollX2);
                        }
                    } else {
                        upSlideTo(scrollX2);
                    }
                    VelocityTracker velocityTracker3 = this.mVelocityTracker;
                    if (velocityTracker3 != null) {
                        velocityTracker3.recycle();
                        this.mVelocityTracker = null;
                    }
                }
            }
            VelocityTracker velocityTracker4 = this.mVelocityTracker;
            if (velocityTracker4 != null) {
                velocityTracker4.recycle();
                this.mVelocityTracker = null;
            }
        } else {
            this.mIsHandledTouchEvent = false;
            if (!this.mScroller.isFinished()) {
                this.mScroller.abortAnimation();
            }
        }
        return super.onTouchEvent(motionEvent);
    }

    public void reset() {
        int scrollX = getScrollX();
        if (scrollX == 0) {
            return;
        }
        smoothScrollTo(-scrollX, 0);
        if (scrollX < 0) {
            setState(LEFT, BEFORE_SLIDE);
        } else {
            setState(RIGHT, BEFORE_SLIDE);
        }
    }

    public void setHeight(int i) {
        ViewGroup.LayoutParams layoutParams = getLayoutParams();
        if (layoutParams != null) {
            layoutParams.height = i;
            requestLayout();
        }
    }

    public void setInterceptTouchEventEnabled(boolean z) {
        this.mIsHandledTouchEvent = z;
    }

    public void setOffset(String str, String str2, float f) {
        int convertToScreenInt = PdrUtil.convertToScreenInt(str2, getWidth(), 0, f);
        int scrollX = getScrollX();
        if (str.equals(LEFT)) {
            if (convertToScreenInt == 0) {
                if (scrollX != 0) {
                    smoothScrollTo(-scrollX, 0);
                    setState(LEFT, BEFORE_SLIDE);
                    return;
                }
                return;
            }
            int i = this.mSlideLeftPosition;
            if (convertToScreenInt > i) {
                convertToScreenInt = i;
            }
            int abs = convertToScreenInt - Math.abs(scrollX);
            smoothScrollTo(-abs, 0);
            postDelayed(new Runnable() { // from class: com.dcloud.android.widget.SlideLayout.2
                @Override // java.lang.Runnable
                public void run() {
                    SlideLayout slideLayout = SlideLayout.this;
                    slideLayout.upSlideTo(slideLayout.getScrollX());
                }
            }, (abs * 2) + 200);
        } else if (convertToScreenInt == 0) {
            if (scrollX != 0) {
                smoothScrollTo(-scrollX, 0);
                setState(RIGHT, BEFORE_SLIDE);
            }
        } else {
            int i2 = this.mSlideRightPosition;
            if (convertToScreenInt > i2) {
                convertToScreenInt = i2;
            }
            int abs2 = convertToScreenInt - Math.abs(scrollX);
            smoothScrollTo(abs2, 0);
            postDelayed(new Runnable() { // from class: com.dcloud.android.widget.SlideLayout.3
                @Override // java.lang.Runnable
                public void run() {
                    SlideLayout slideLayout = SlideLayout.this;
                    slideLayout.upSlideTo(slideLayout.getScrollX());
                }
            }, (abs2 * 2) + 200);
        }
    }

    public void setOnStateChangeListener(OnStateChangeListener onStateChangeListener) {
        this.mChangeListener = onStateChangeListener;
    }

    public void setWidth(int i) {
        ViewGroup.LayoutParams layoutParams = getLayoutParams();
        if (layoutParams != null) {
            layoutParams.width = i;
            requestLayout();
        }
    }

    public void upSlideTo(int i) {
        if (i < 0) {
            int abs = Math.abs(i);
            int i2 = this.mSlideTransverseLeftMaxWitch;
            if (abs >= i2 / 2 && this.mSlideLeftPosition >= i2) {
                smoothScrollTo(-(i2 - Math.abs(i)), 0);
                this.isSlideOpen = true;
                setState(LEFT, AFTER_SLIDE);
                return;
            }
        }
        if (i > 0) {
            int abs2 = Math.abs(i);
            int i3 = this.mSlideTransverseRightMaxWitch;
            if (abs2 >= i3 / 2 && this.mSlideRightPosition >= i3) {
                smoothScrollTo(i3 - Math.abs(i), 0);
                this.isSlideOpen = true;
                setState(RIGHT, AFTER_SLIDE);
                return;
            }
        }
        if (i > 0) {
            smoothScrollTo(-i, 0);
            setState(RIGHT, BEFORE_SLIDE);
        } else {
            smoothScrollTo(-i, 0);
            setState(LEFT, BEFORE_SLIDE);
        }
        this.isSlideOpen = false;
    }
}
