package com.dcloud.zxing2.qrcode;

import android.os.Handler;
import android.os.Message;
import com.dcloud.zxing2.BarcodeFormat;
import com.dcloud.zxing2.BinaryBitmap;
import com.dcloud.zxing2.ChecksumException;
import com.dcloud.zxing2.DecodeHintType;
import com.dcloud.zxing2.FormatException;
import com.dcloud.zxing2.NotFoundException;
import com.dcloud.zxing2.Reader;
import com.dcloud.zxing2.Result;
import com.dcloud.zxing2.ResultMetadataType;
import com.dcloud.zxing2.ResultPoint;
import com.dcloud.zxing2.common.BitMatrix;
import com.dcloud.zxing2.common.DecoderResult;
import com.dcloud.zxing2.common.DetectorResult;
import com.dcloud.zxing2.qrcode.decoder.Decoder;
import com.dcloud.zxing2.qrcode.decoder.QRCodeDecoderMetaData;
import com.dcloud.zxing2.qrcode.detector.Detector;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class QRCodeReader implements Reader {
    private static final ResultPoint[] NO_POINTS = new ResultPoint[0];
    private final Decoder decoder = new Decoder();
    private Handler hostHandler;

    private static BitMatrix extractPureBits(BitMatrix bitMatrix) throws NotFoundException {
        int[] topLeftOnBit = bitMatrix.getTopLeftOnBit();
        int[] bottomRightOnBit = bitMatrix.getBottomRightOnBit();
        if (topLeftOnBit != null && bottomRightOnBit != null) {
            float moduleSize = moduleSize(topLeftOnBit, bitMatrix);
            int i = topLeftOnBit[1];
            int i2 = bottomRightOnBit[1];
            int i3 = topLeftOnBit[0];
            int i4 = bottomRightOnBit[0];
            if (i3 < i4 && i < i2) {
                int i5 = i2 - i;
                if (i5 != i4 - i3) {
                    i4 = i3 + i5;
                }
                int round = Math.round(((i4 - i3) + 1) / moduleSize);
                int round2 = Math.round((i5 + 1) / moduleSize);
                if (round <= 0 || round2 <= 0) {
                    throw NotFoundException.getNotFoundInstance();
                }
                if (round2 == round) {
                    int i6 = (int) (moduleSize / 2.0f);
                    int i7 = i + i6;
                    int i8 = i3 + i6;
                    int i9 = (((int) ((round - 1) * moduleSize)) + i8) - i4;
                    if (i9 > 0) {
                        if (i9 > i6) {
                            throw NotFoundException.getNotFoundInstance();
                        }
                        i8 -= i9;
                    }
                    int i10 = (((int) ((round2 - 1) * moduleSize)) + i7) - i2;
                    if (i10 > 0) {
                        if (i10 > i6) {
                            throw NotFoundException.getNotFoundInstance();
                        }
                        i7 -= i10;
                    }
                    BitMatrix bitMatrix2 = new BitMatrix(round, round2);
                    for (int i11 = 0; i11 < round2; i11++) {
                        int i12 = ((int) (i11 * moduleSize)) + i7;
                        for (int i13 = 0; i13 < round; i13++) {
                            if (bitMatrix.get(((int) (i13 * moduleSize)) + i8, i12)) {
                                bitMatrix2.set(i13, i11);
                            }
                        }
                    }
                    return bitMatrix2;
                }
                throw NotFoundException.getNotFoundInstance();
            }
            throw NotFoundException.getNotFoundInstance();
        }
        throw NotFoundException.getNotFoundInstance();
    }

    private static float moduleSize(int[] iArr, BitMatrix bitMatrix) throws NotFoundException {
        int height = bitMatrix.getHeight();
        int width = bitMatrix.getWidth();
        int i = iArr[0];
        boolean z = true;
        int i2 = iArr[1];
        int i3 = 0;
        while (i < width && i2 < height) {
            if (z != bitMatrix.get(i, i2)) {
                i3++;
                if (i3 == 5) {
                    break;
                }
                z = !z;
            }
            i++;
            i2++;
        }
        if (i != width && i2 != height) {
            return (i - iArr[0]) / 7.0f;
        }
        throw NotFoundException.getNotFoundInstance();
    }

    @Override // com.dcloud.zxing2.Reader
    public Result decode(BinaryBitmap binaryBitmap) throws NotFoundException, ChecksumException, FormatException {
        return decode(binaryBitmap, null);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public final Decoder getDecoder() {
        return this.decoder;
    }

    @Override // com.dcloud.zxing2.Reader
    public void reset() {
    }

    public void updateHandler(Handler handler) {
        this.hostHandler = handler;
    }

    @Override // com.dcloud.zxing2.Reader
    public final Result decode(BinaryBitmap binaryBitmap, Map<DecodeHintType, ?> map) throws NotFoundException, ChecksumException, FormatException {
        DecoderResult decoderResult;
        ResultPoint[] points;
        DecoderResult decoderResult2;
        if (map != null && map.containsKey(DecodeHintType.PURE_BARCODE)) {
            decoderResult2 = this.decoder.decode(extractPureBits(binaryBitmap.getBlackMatrix()), map);
            points = NO_POINTS;
        } else {
            DetectorResult detect = new Detector(binaryBitmap.getBlackMatrix()).detect(map);
            try {
                decoderResult = this.decoder.decode(detect.getBits(), map);
            } catch (Exception unused) {
                if (this.hostHandler != null && detect != null) {
                    Message message = new Message();
                    message.what = 1010;
                    message.obj = Float.valueOf(detect.moduleSize);
                    this.hostHandler.sendMessage(message);
                }
                decoderResult = null;
            }
            if (decoderResult != null) {
                DecoderResult decoderResult3 = decoderResult;
                points = detect.getPoints();
                decoderResult2 = decoderResult3;
            } else {
                throw NotFoundException.getNotFoundInstance();
            }
        }
        if (decoderResult2.getOther() instanceof QRCodeDecoderMetaData) {
            ((QRCodeDecoderMetaData) decoderResult2.getOther()).applyMirroredCorrection(points);
        }
        Result result = new Result(decoderResult2.getText(), decoderResult2.getRawBytes(), points, BarcodeFormat.QR_CODE);
        result.textCharset = decoderResult2.textCharset;
        List<byte[]> byteSegments = decoderResult2.getByteSegments();
        if (byteSegments != null) {
            result.putMetadata(ResultMetadataType.BYTE_SEGMENTS, byteSegments);
        }
        String eCLevel = decoderResult2.getECLevel();
        if (eCLevel != null) {
            result.putMetadata(ResultMetadataType.ERROR_CORRECTION_LEVEL, eCLevel);
        }
        if (decoderResult2.hasStructuredAppend()) {
            result.putMetadata(ResultMetadataType.STRUCTURED_APPEND_SEQUENCE, Integer.valueOf(decoderResult2.getStructuredAppendSequenceNumber()));
            result.putMetadata(ResultMetadataType.STRUCTURED_APPEND_PARITY, Integer.valueOf(decoderResult2.getStructuredAppendParity()));
        }
        return result;
    }
}
