package com.taobao.weex.appfram.pickers;

import android.app.AlertDialog;
import android.app.DatePickerDialog;
import android.app.TimePickerDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.TimePicker;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.module.WXModalUIModule;
import com.taobao.weex.utils.WXLogUtils;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;
import java.util.Map;
/* loaded from: classes.dex */
public class DatePickerImpl {
    private static final int DEFAULT_END_YEAR = 2100;
    private static final int DEFAULT_START_YEAR = 1900;
    private static SimpleDateFormat dateFormatter;
    private static SimpleDateFormat timeFormatter;

    /* loaded from: classes.dex */
    public interface OnPickListener {
        void onPick(boolean set, String result);
    }

    public static void pickDate(Context context, String value, String max, String min, final OnPickListener listener, Map<String, Object> extras) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(parseDate(value));
        DatePickerDialog datePickerDialog = new DatePickerDialog(context, new DatePickerDialog.OnDateSetListener() { // from class: com.taobao.weex.appfram.pickers.DatePickerImpl.1
            @Override // android.app.DatePickerDialog.OnDateSetListener
            public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth) {
                String valueOf;
                String valueOf2;
                int i = monthOfYear + 1;
                if (i < 10) {
                    valueOf = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT + i;
                } else {
                    valueOf = String.valueOf(i);
                }
                if (dayOfMonth < 10) {
                    valueOf2 = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT + dayOfMonth;
                } else {
                    valueOf2 = String.valueOf(dayOfMonth);
                }
                OnPickListener.this.onPick(true, year + Operators.SUB + valueOf + Operators.SUB + valueOf2);
            }
        }, calendar.get(1), calendar.get(2), calendar.get(5));
        DatePicker datePicker = datePickerDialog.getDatePicker();
        Calendar calendar2 = Calendar.getInstance(Locale.getDefault());
        Calendar calendar3 = Calendar.getInstance(Locale.getDefault());
        calendar2.set(DEFAULT_START_YEAR, 0, 1);
        calendar3.set(DEFAULT_END_YEAR, 11, 31);
        if (!TextUtils.isEmpty(min)) {
            if (datePicker.getMaxDate() >= parseDate(min).getTime()) {
                datePicker.setMinDate(parseDate(min).getTime());
            } else {
                datePicker.setMinDate(calendar2.getTimeInMillis());
                datePicker.setMaxDate(calendar3.getTimeInMillis());
            }
        }
        if (!TextUtils.isEmpty(max)) {
            if (datePicker.getMinDate() <= parseDate(max).getTime()) {
                datePicker.setMaxDate(parseDate(max).getTime());
            } else {
                datePicker.setMinDate(calendar2.getTimeInMillis());
                datePicker.setMaxDate(calendar3.getTimeInMillis());
            }
        }
        datePickerDialog.setOnCancelListener(new DialogInterface.OnCancelListener() { // from class: com.taobao.weex.appfram.pickers.DatePickerImpl.2
            @Override // android.content.DialogInterface.OnCancelListener
            public void onCancel(DialogInterface dialog) {
                OnPickListener.this.onPick(false, null);
            }
        });
        setButtonText(datePickerDialog, -2, String.valueOf(extras != null ? extras.get(WXModalUIModule.CANCEL_TITLE) : null));
        setButtonText(datePickerDialog, -1, String.valueOf(extras != null ? extras.get("confirmTitle") : null));
        datePickerDialog.show();
    }

    public static void pickTime(Context context, String value, final OnPickListener listener, Map<String, Object> extras) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(parseTime(value));
        TimePickerDialog timePickerDialog = new TimePickerDialog(context, new TimePickerDialog.OnTimeSetListener() { // from class: com.taobao.weex.appfram.pickers.DatePickerImpl.3
            @Override // android.app.TimePickerDialog.OnTimeSetListener
            public void onTimeSet(TimePicker view, int hourOfDay, int minute) {
                String valueOf;
                String valueOf2;
                if (hourOfDay < 10) {
                    valueOf = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT + hourOfDay;
                } else {
                    valueOf = String.valueOf(hourOfDay);
                }
                if (minute < 10) {
                    valueOf2 = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT + minute;
                } else {
                    valueOf2 = String.valueOf(minute);
                }
                OnPickListener.this.onPick(true, valueOf + ":" + valueOf2);
            }
        }, calendar.get(11), calendar.get(12), false);
        timePickerDialog.setOnCancelListener(new DialogInterface.OnCancelListener() { // from class: com.taobao.weex.appfram.pickers.DatePickerImpl.4
            @Override // android.content.DialogInterface.OnCancelListener
            public void onCancel(DialogInterface dialog) {
                OnPickListener.this.onPick(false, null);
            }
        });
        setButtonText(timePickerDialog, -2, String.valueOf(extras != null ? extras.get(WXModalUIModule.CANCEL_TITLE) : null));
        setButtonText(timePickerDialog, -1, String.valueOf(extras != null ? extras.get("confirmTitle") : null));
        timePickerDialog.show();
    }

    private static Date parseDate(String s) {
        if (dateFormatter == null) {
            dateFormatter = new SimpleDateFormat("yyyy-MM-dd", Locale.getDefault());
        }
        try {
            return dateFormatter.parse(s);
        } catch (ParseException e) {
            WXLogUtils.w("[DatePickerImpl] " + e.toString());
            return new Date();
        }
    }

    private static Date parseTime(String s) {
        if (timeFormatter == null) {
            timeFormatter = new SimpleDateFormat("HH:mm", Locale.getDefault());
        }
        try {
            return timeFormatter.parse(s);
        } catch (ParseException e) {
            WXLogUtils.w("[DatePickerImpl] " + e.toString());
            return new Date();
        }
    }

    private static void setButtonText(final AlertDialog dialog, final int which, final CharSequence text) {
        if (TextUtils.isEmpty(text) || "null".equals(text)) {
            return;
        }
        try {
            dialog.getWindow().getDecorView().post(WXThread.secure(new Runnable() { // from class: com.taobao.weex.appfram.pickers.DatePickerImpl.5
                @Override // java.lang.Runnable
                public void run() {
                    Button button = dialog.getButton(which);
                    if (button != null) {
                        button.setAllCaps(false);
                        button.setText(text);
                    }
                }
            }));
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }
}
