package com.taobao.weex.appfram.websocket;

import android.os.Looper;
import com.alibaba.fastjson.JSON;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.appfram.websocket.IWebSocketAdapter;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.utils.WXLogUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.HashMap;
/* loaded from: classes.dex */
public class WebSocketModule extends WXSDKEngine.DestroyableModule {
    private static final String KEY_CODE = "code";
    private static final String KEY_DATA = "data";
    private static final String KEY_REASON = "reason";
    private static final String KEY_WAS_CLEAN = "wasClean";
    private static final String TAG = "WebSocketModule";
    private WebSocketEventListener eventListener;
    private IWebSocketAdapter webSocketAdapter;

    public WebSocketModule() {
        WXLogUtils.e(TAG, "create new instance");
    }

    @JSMethod(uiThread = false)
    public void WebSocket(String url, String protocol) {
        if (this.webSocketAdapter != null) {
            WXLogUtils.w(TAG, AbsoluteConst.EVENTS_CLOSE);
            this.webSocketAdapter.close(WebSocketCloseCodes.CLOSE_GOING_AWAY.getCode(), WebSocketCloseCodes.CLOSE_GOING_AWAY.name());
        }
        this.webSocketAdapter = this.mWXSDKInstance.getWXWebSocketAdapter();
        if (reportErrorIfNoAdapter()) {
            return;
        }
        WebSocketEventListener webSocketEventListener = new WebSocketEventListener();
        this.eventListener = webSocketEventListener;
        this.webSocketAdapter.connect(url, protocol, webSocketEventListener);
    }

    @JSMethod(uiThread = false)
    public void WebSocket(String url, String protocol, String headerJson) {
        if (this.webSocketAdapter != null) {
            WXLogUtils.w(TAG, AbsoluteConst.EVENTS_CLOSE);
            this.webSocketAdapter.close(WebSocketCloseCodes.CLOSE_GOING_AWAY.getCode(), WebSocketCloseCodes.CLOSE_GOING_AWAY.name());
        }
        this.webSocketAdapter = this.mWXSDKInstance.getWXWebSocketAdapter();
        if (reportErrorIfNoAdapter()) {
            return;
        }
        WebSocketEventListener webSocketEventListener = new WebSocketEventListener();
        this.eventListener = webSocketEventListener;
        this.webSocketAdapter.connect(url, protocol, headerJson, webSocketEventListener);
    }

    @JSMethod(uiThread = false)
    public void send(String data) {
        if (reportErrorIfNoAdapter()) {
            return;
        }
        this.webSocketAdapter.send(data);
    }

    @JSMethod(uiThread = false)
    public void close(String code, String reason) {
        if (reportErrorIfNoAdapter()) {
            return;
        }
        int code2 = WebSocketCloseCodes.CLOSE_NORMAL.getCode();
        if (code != null) {
            try {
                code2 = Integer.parseInt(code);
            } catch (NumberFormatException unused) {
            }
        }
        this.webSocketAdapter.close(code2, reason);
    }

    @JSMethod(uiThread = false)
    public void onopen(JSCallback callback) {
        WebSocketEventListener webSocketEventListener = this.eventListener;
        if (webSocketEventListener != null) {
            webSocketEventListener.onOpen = callback;
        }
    }

    @JSMethod(uiThread = false)
    public void onmessage(JSCallback callback) {
        WebSocketEventListener webSocketEventListener = this.eventListener;
        if (webSocketEventListener != null) {
            webSocketEventListener.onMessage = callback;
        }
    }

    @JSMethod(uiThread = false)
    public void onclose(JSCallback callback) {
        WebSocketEventListener webSocketEventListener = this.eventListener;
        if (webSocketEventListener != null) {
            webSocketEventListener.onClose = callback;
        }
    }

    @JSMethod(uiThread = false)
    public void onerror(JSCallback callback) {
        WebSocketEventListener webSocketEventListener = this.eventListener;
        if (webSocketEventListener != null) {
            webSocketEventListener.onError = callback;
        }
    }

    @Override // com.taobao.weex.common.Destroyable
    public void destroy() {
        Runnable runnable = new Runnable() { // from class: com.taobao.weex.appfram.websocket.WebSocketModule.1
            @Override // java.lang.Runnable
            public void run() {
                WXLogUtils.w(WebSocketModule.TAG, "close session with instance id " + WebSocketModule.this.mWXSDKInstance.getInstanceId());
                if (WebSocketModule.this.webSocketAdapter != null) {
                    WebSocketModule.this.webSocketAdapter.destroy();
                }
                WebSocketModule.this.webSocketAdapter = null;
                WebSocketModule.this.eventListener = null;
            }
        };
        if (Looper.myLooper() == Looper.getMainLooper()) {
            WXBridgeManager.getInstance().post(runnable);
        } else {
            runnable.run();
        }
    }

    private boolean reportErrorIfNoAdapter() {
        if (this.webSocketAdapter == null) {
            WebSocketEventListener webSocketEventListener = this.eventListener;
            if (webSocketEventListener != null) {
                webSocketEventListener.onError("No implementation found for IWebSocketAdapter");
            }
            WXLogUtils.e(TAG, "No implementation found for IWebSocketAdapter");
            return true;
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public class WebSocketEventListener implements IWebSocketAdapter.EventListener {
        private JSCallback onClose;
        private JSCallback onError;
        private JSCallback onMessage;
        private JSCallback onOpen;

        private WebSocketEventListener() {
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onOpen() {
            JSCallback jSCallback = this.onOpen;
            if (jSCallback != null) {
                jSCallback.invoke(new HashMap(0));
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onMessage(String data) {
            if (this.onMessage != null) {
                HashMap hashMap = new HashMap(1);
                try {
                    hashMap.put("data", JSON.parseObject(data));
                } catch (Exception unused) {
                    hashMap.put("data", data);
                }
                this.onMessage.invokeAndKeepAlive(hashMap);
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onClose(int code, String reason, boolean wasClean) {
            if (this.onClose != null) {
                HashMap hashMap = new HashMap(3);
                hashMap.put("code", Integer.valueOf(code));
                hashMap.put(WebSocketModule.KEY_REASON, reason);
                hashMap.put(WebSocketModule.KEY_WAS_CLEAN, Boolean.valueOf(wasClean));
                this.onClose.invoke(hashMap);
            }
        }

        @Override // com.taobao.weex.appfram.websocket.IWebSocketAdapter.EventListener
        public void onError(String msg) {
            if (this.onError != null) {
                HashMap hashMap = new HashMap(1);
                hashMap.put("data", msg);
                this.onError.invokeAndKeepAlive(hashMap);
            }
        }
    }
}
