package com.taobao.weex.bridge;

import android.text.TextUtils;
import android.util.Log;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.IWXBridge;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.common.WXRenderStrategy;
import com.taobao.weex.dom.CSSShorthand;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.performance.WXStateRecord;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXJsonUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXWsonJSONSwitch;
import com.taobao.weex.utils.tools.TimeCalculator;
import io.dcloud.feature.internal.sdk.SDK;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
/* loaded from: classes.dex */
public class WXBridge implements IWXBridge {
    public static final boolean MULTIPROCESS = true;
    public static final String TAG = "WXBridge";

    private native void nativeBindMeasurementToRenderObject(long ptr);

    private native String nativeDecrypt(String appId, String data, String appKey, String clientKeyData);

    private native String nativeEncrypt(String appId, String data, String appKey, String clientKeyData);

    private native int nativeExecJS(String instanceId, String name, String function, WXJSObject[] args);

    private native int nativeExecJSService(String javascript);

    private native void nativeForceLayout(String instanceId);

    private native int nativeInitFramework(String framework, WXParams params);

    private native int nativeInitFrameworkEnv(String framework, WXParams params, String cacheDir, boolean pieSupport);

    private native void nativeMarkDirty(String instanceId, String ref, boolean dirty);

    private native boolean nativeNotifyLayout(String instanceId);

    private native void nativeOnInstanceClose(String instanceId);

    private native String nativePreGetClientKey(String appId, String data, String appKey);

    private native void nativeRefreshInstance(String instanceId, String namespace, String function, WXJSObject[] args);

    private native void nativeRegisterCoreEnv(String key, String value);

    private native void nativeReloadPageLayout(String instanceId);

    private native void nativeRemoveInstanceRenderType(String instanceId);

    private native void nativeResetWXBridge(Object bridge, String className);

    private native void nativeSetDefaultHeightAndWidthIntoRootDom(String instanceId, float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent);

    private native void nativeSetDeviceDisplay(String instanceId, float width, float height, float scale);

    private native void nativeSetDeviceDisplayOfPage(String instanceId, float width, float height);

    private native void nativeSetFlexDirectionDef(String def);

    private native void nativeSetInstanceRenderType(String instanceId, String renderType);

    private native void nativeSetLogType(float type, float isPerf);

    private native void nativeSetMargin(String instanceId, String ref, int edge, float value);

    private native void nativeSetPadding(String instanceId, String ref, int edge, float value);

    private native void nativeSetPageArgument(String instanceId, String key, String value);

    private native void nativeSetPosition(String instanceId, String ref, int edge, float value);

    private native void nativeSetRenderContainerWrapContent(boolean wrap, String instanceId);

    private native void nativeSetStyleHeight(String instanceId, String ref, float value, boolean update);

    private native void nativeSetStyleWidth(String instanceId, String ref, float value, boolean update);

    private native void nativeSetViewPortWidth(String instanceId, float viewPortWidth);

    private native void nativeTakeHeapSnapshot(String filename);

    private native void nativeUpdateInitFrameworkParams(String key, String value, String desc);

    private native boolean nativeVerifyClientKeyPayload(String appId, String appKey, String clientKeyData);

    public native int nativeCreateInstanceContext(String instanceId, String name, String function, WXJSObject[] args);

    public native int nativeDestoryInstance(String instanceId, String name, String function, WXJSObject[] args);

    public native String nativeDumpIpcPageQueueInfo();

    public native String nativeExecJSOnInstance(String instanceId, String script, int type);

    public native void nativeExecJSWithCallback(String instanceId, String _namespace, String _function, WXJSObject[] args, long callbackId);

    public native byte[] nativeExecJSWithResult(String instanceId, String _namespace, String _function, WXJSObject[] args);

    public native void nativeFireEventOnDataRenderNode(String instanceId, String ref, String type, String data, String domChanges);

    public native long[] nativeGetFirstScreenRenderTime(String instanceId);

    public native long[] nativeGetRenderFinishTime(String instanceId);

    public native void nativeInvokeCallbackOnDataRender(String instanceId, String callbackId, String data, boolean keepAlive);

    public native void nativeOnInteractionTimeUpdate(String instanceId);

    public native void nativeRegisterComponentOnDataRenderNode(String data);

    public native void nativeRegisterModuleOnDataRenderNode(String data);

    public native void nativeUpdateGlobalConfig(String config);

    @Override // com.taobao.weex.common.IWXBridge
    public void updateInitFrameworkParams(String key, String value, String desc) {
        WXStateRecord.getInstance().recordAction("", "updateInitFrameworkParams:");
        nativeUpdateInitFrameworkParams(key, value, desc);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setLogType(float type, boolean isPerf) {
        Log.e("WeexCore", "setLog" + WXEnvironment.sLogLevel.getValue() + "isPerf : " + isPerf);
        nativeSetLogType(type, isPerf ? 1.0f : 0.0f);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int initFramework(String framework, WXParams params) {
        return nativeInitFramework(framework, params);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int initFrameworkEnv(String framework, WXParams params, String cacheDir, boolean pieSupport) {
        WXStateRecord.getInstance().recordAction("", "nativeInitFrameworkEnv:");
        return nativeInitFrameworkEnv(framework, params, cacheDir, pieSupport);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void refreshInstance(String instanceId, String namespace, String function, WXJSObject[] args) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "refreshInstance:" + namespace + "," + function);
        nativeRefreshInstance(instanceId, namespace, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int execJS(String instanceId, String namespace, String function, WXJSObject[] args) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "execJS:" + namespace + "," + function);
        return nativeExecJS(instanceId, namespace, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void execJSWithCallback(String instanceId, String namespace, String function, WXJSObject[] args, ResultCallback callback) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "execJSWithCallback:" + namespace + "," + function);
        if (callback == null) {
            execJS(instanceId, namespace, function, args);
        }
        nativeExecJSWithCallback(instanceId, namespace, function, args, ResultCallbackManager.generateCallbackId(callback));
    }

    public void onNativePerformanceDataUpdate(String instanceId, Map<String, String> map) {
        WXSDKInstance wXSDKInstance;
        if (TextUtils.isEmpty(instanceId) || map == null || map.size() < 1 || (wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(instanceId)) == null || wXSDKInstance.getApmForInstance() == null) {
            return;
        }
        wXSDKInstance.getApmForInstance().updateNativePerformanceData(map);
    }

    public void onReceivedResult(long callbackId, byte[] result) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction("onReceivedResult", SDK.UNIMP_EVENT_CALLBACKID + callbackId);
        ResultCallback removeCallbackById = ResultCallbackManager.removeCallbackById(callbackId);
        if (removeCallbackById != null) {
            removeCallbackById.onReceiveResult(result);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int execJSService(String javascript) {
        WXStateRecord.getInstance().recordAction("execJSService", "execJSService:");
        return nativeExecJSService(javascript);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void takeHeapSnapshot(String filename) {
        nativeTakeHeapSnapshot(filename);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int createInstanceContext(String instanceId, String name, String function, WXJSObject[] args) {
        Log.e(TimeCalculator.TIMELINE_TAG, "createInstance :" + System.currentTimeMillis());
        WXStateRecord.getInstance().recordAction(instanceId, "createInstanceContext:");
        return nativeCreateInstanceContext(instanceId, name, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int destoryInstance(String instanceId, String name, String function, WXJSObject[] args) {
        WXStateRecord.getInstance().recordAction(instanceId, "destoryInstance:");
        return nativeDestoryInstance(instanceId, name, function, args);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public String execJSOnInstance(String instanceId, String script, int type) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "execJSOnInstance:" + type);
        return nativeExecJSOnInstance(instanceId, script, type);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callNative(String instanceId, byte[] tasks, String callback) {
        if ("HeartBeat".equals(callback)) {
            Log.e("HeartBeat instanceId", instanceId);
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (sDKInstance != null) {
                sDKInstance.createInstanceFuncHeartBeat();
                return 1;
            }
            return 1;
        }
        return callNative(instanceId, JSON.parseArray(new String(tasks)), callback);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callNative(String instanceId, String tasks, String callback) {
        try {
            return callNative(instanceId, JSONArray.parseArray(tasks), callback);
        } catch (Exception e) {
            WXLogUtils.e(TAG, "callNative throw exception: " + WXLogUtils.getStackTrace(e));
            return 1;
        }
    }

    private int callNative(String instanceId, JSONArray tasks, String callback) {
        long currentTimeMillis = System.currentTimeMillis();
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            sDKInstance.firstScreenCreateInstanceTime(currentTimeMillis);
        }
        int i = 1;
        try {
            i = WXBridgeManager.getInstance().callNative(instanceId, tasks, callback);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "callNative throw exception:" + WXLogUtils.getStackTrace(th));
        }
        if (WXEnvironment.isApkDebugable() && i == -1) {
            WXLogUtils.w("destroyInstance :" + instanceId + " JSF must stop callNative");
        }
        return i;
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportJSException(String instanceId, String func, String exception) {
        WXBridgeManager.getInstance().reportJSException(instanceId, func, exception);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public Object callVueExecSync(String instanceId, String name, String value) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            if (sDKInstance != null && sDKInstance.isDestroy()) {
                return new WXJSObject(null);
            }
            String execSync = WXSDKManager.getInstance().getVueBridgeAdapter().execSync(sDKInstance, name, value);
            if (execSync == null) {
                return new WXJSObject(null);
            }
            return new WXJSObject(3, WXJsonUtils.fromObjectToJSONString(execSync));
        }
        return new WXJSObject(null);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callVueExec(String instanceId, final String name, final String value) {
        final WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        if (sDKInstance != null) {
            if (sDKInstance == null || !sDKInstance.isDestroy()) {
                WXSDKManager.getInstance().postOnUiThread(new Runnable() { // from class: com.taobao.weex.bridge.WXBridge.1
                    @Override // java.lang.Runnable
                    public void run() {
                        WXSDKManager.getInstance().getVueBridgeAdapter().exec(sDKInstance, name, value);
                    }
                }, 0L);
            }
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public Object callNativeModule(String instanceId, String module, String method, byte[] arguments, byte[] options) {
        JSONArray jSONArray;
        JSONObject jSONObject;
        WXSDKInstance sDKInstance;
        JSONArray jSONArray2;
        try {
            WXStateRecord.getInstance().recordAction(instanceId, "callNativeModule:" + module + Operators.DOT_STR + method);
            long fixUnixTime = WXUtils.getFixUnixTime();
            WXSDKInstance sDKInstance2 = WXSDKManager.getInstance().getSDKInstance(instanceId);
            if (arguments != null) {
                if (sDKInstance2 != null && (sDKInstance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || sDKInstance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
                    try {
                        jSONArray = (JSONArray) JSON.parse(new String(arguments, "UTF-8"));
                    } catch (Exception unused) {
                        jSONArray2 = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                    }
                } else {
                    jSONArray2 = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                }
                jSONArray = jSONArray2;
            } else {
                jSONArray = null;
            }
            if (options != null) {
                jSONObject = (JSONObject) WXWsonJSONSwitch.parseWsonOrJSON(options);
            } else {
                if (jSONArray != null && (sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId)) != null && WXBridgeManager.BundType.Rax.equals(sDKInstance.bundleType)) {
                    Iterator<Object> it = jSONArray.iterator();
                    Object obj = null;
                    while (it.hasNext()) {
                        Object next = it.next();
                        if ((next instanceof JSONObject) && ((JSONObject) next).containsKey("__weex_options__")) {
                            obj = ((JSONObject) next).get("__weex_options__");
                        }
                    }
                    if (obj instanceof JSONObject) {
                        jSONObject = (JSONObject) obj;
                    }
                }
                jSONObject = null;
            }
            Object callNativeModule = WXBridgeManager.getInstance().callNativeModule(instanceId, module, method, jSONArray, jSONObject);
            if (sDKInstance2 != null) {
                sDKInstance2.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_NATIVE_NUM, 1.0d);
                sDKInstance2.getApmForInstance().updateFSDiffStats(WXInstanceApm.KEY_PAGE_STATS_FS_CALL_NATIVE_TIME, WXUtils.getFixUnixTime() - fixUnixTime);
            }
            if (sDKInstance2 != null && (sDKInstance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || sDKInstance2.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
                try {
                    if (callNativeModule == null) {
                        return new WXJSObject(null);
                    }
                    if (callNativeModule.getClass() == WXJSObject.class) {
                        return (WXJSObject) callNativeModule;
                    }
                    return new WXJSObject(3, WXJsonUtils.fromObjectToJSONString(callNativeModule));
                } catch (Exception unused2) {
                    return WXWsonJSONSwitch.toWsonOrJsonWXJSObject(callNativeModule);
                }
            }
            return WXWsonJSONSwitch.toWsonOrJsonWXJSObject(callNativeModule);
        } catch (Exception e) {
            WXLogUtils.e(TAG, e);
            return new WXJSObject(null);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callNativeComponent(String instanceId, String ref, String method, byte[] arguments, byte[] optionsData) {
        WXStateRecord wXStateRecord = WXStateRecord.getInstance();
        wXStateRecord.recordAction(instanceId, "callNativeComponent:" + method);
        try {
            WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
            JSONArray jSONArray = null;
            if (arguments != null) {
                if (sDKInstance != null && (sDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER || sDKInstance.getRenderStrategy() == WXRenderStrategy.DATA_RENDER_BINARY)) {
                    try {
                        jSONArray = (JSONArray) JSON.parse(new String(arguments, "UTF-8"));
                    } catch (Exception unused) {
                        jSONArray = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                    }
                } else {
                    jSONArray = (JSONArray) WXWsonJSONSwitch.parseWsonOrJSON(arguments);
                }
            }
            Object parseWsonOrJSON = WXWsonJSONSwitch.parseWsonOrJSON(optionsData);
            WXBridgeManager.getInstance().callNativeComponent(instanceId, ref, method, jSONArray, parseWsonOrJSON);
        } catch (Exception e) {
            WXLogUtils.e(TAG, e);
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setTimeoutNative(String callbackId, String time) {
        WXBridgeManager.getInstance().setTimeout(callbackId, time);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setJSFrmVersion(String version) {
        if (version != null) {
            WXEnvironment.JS_LIB_SDK_VERSION = version;
        }
        WXStateRecord.getInstance().onJSFMInit();
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void resetWXBridge(boolean remoteDebug) {
        nativeResetWXBridge(this, getClass().getName().replace(Operators.DOT, '/'));
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateFinish(String instanceId, byte[] tasks, String callback) {
        try {
            return WXBridgeManager.getInstance().callUpdateFinish(instanceId, callback);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callCreateBody throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRefreshFinish(String instanceId, byte[] tasks, String callback) {
        try {
            return WXBridgeManager.getInstance().callRefreshFinish(instanceId, callback);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportServerCrash(String instanceId, String crashFile) {
        WXLogUtils.e(TAG, "reportServerCrash instanceId:" + instanceId + " crashFile: " + crashFile);
        try {
            WXBridgeManager.getInstance().callReportCrashReloadPage(instanceId, crashFile);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "reloadPageNative throw exception:" + WXLogUtils.getStackTrace(th));
            }
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callCreateBody(String instanceId, String componentType, String ref, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders) {
        try {
            return WXBridgeManager.getInstance().callCreateBody(instanceId, componentType, ref, styles, attributes, events, margins, paddings, borders);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callCreateBody throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddElement(String instanceId, String componentType, String ref, int index, String parentRef, HashMap<String, String> styles, HashMap<String, String> attributes, HashSet<String> events, float[] margins, float[] paddings, float[] borders, boolean willLayout) {
        try {
            return WXBridgeManager.getInstance().callAddElement(instanceId, componentType, ref, index, parentRef, styles, attributes, events, margins, paddings, borders, willLayout);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                th.printStackTrace();
                WXLogUtils.e(TAG, "callAddElement throw error:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveElement(String instanceId, String ref) {
        try {
            return WXBridgeManager.getInstance().callRemoveElement(instanceId, ref);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callRemoveElement throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callMoveElement(String instanceId, String ref, String parentref, int index) {
        try {
            return WXBridgeManager.getInstance().callMoveElement(instanceId, ref, parentref, index);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callMoveElement throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddEvent(String instanceId, String ref, String event) {
        try {
            return WXBridgeManager.getInstance().callAddEvent(instanceId, ref, event);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "callAddEvent throw exception:" + WXLogUtils.getStackTrace(th));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callBacthStart(String instanceId) {
        try {
            WXBridgeManager.getInstance().callBacthStart(instanceId);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "cal\n    return errorCode;\n  }lAddEvent throw exception:" + WXLogUtils.getStackTrace(th));
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void callBacthEnd(String instanceId) {
        try {
            WXBridgeManager.getInstance().callBacthEnd(instanceId);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "cal\n    return errorCode;\n  }lAddEvent throw exception:" + WXLogUtils.getStackTrace(th));
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveEvent(String instanceId, String ref, String event) {
        try {
            return WXBridgeManager.getInstance().callRemoveEvent(instanceId, ref, event);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callRemoveEvent throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateStyle(String instanceId, String ref, HashMap<String, Object> styles, HashMap<String, String> paddings, HashMap<String, String> margins, HashMap<String, String> borders) {
        if (styles != null) {
            try {
                if (styles.isEmpty() && paddings != null && paddings.isEmpty() && margins != null && margins.isEmpty() && borders != null && borders.isEmpty()) {
                    return 1;
                }
            } catch (Throwable th) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.e(TAG, "callUpdateStyle throw exception:" + WXLogUtils.getStackTrace(th));
                    return 1;
                }
                return 1;
            }
        }
        return WXBridgeManager.getInstance().callUpdateStyle(instanceId, ref, styles, paddings, margins, borders);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateAttrs(String instanceId, String ref, HashMap<String, String> attrs) {
        try {
            return WXBridgeManager.getInstance().callUpdateAttrs(instanceId, ref, attrs);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callUpdateAttr throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAddChildToRichtext(String instanceId, String nodeType, String ref, String parentRef, String richTextRef, HashMap<String, String> styles, HashMap<String, String> attrs) {
        try {
            return WXBridgeManager.getInstance().callAddChildToRichtext(instanceId, nodeType, ref, parentRef, richTextRef, styles, attrs);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callAddChildToRichtext throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRemoveChildFromRichtext(String instanceId, String ref, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callRemoveChildFromRichtext(instanceId, ref, parentRef, richTextRef);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callRemoveChildFromRichtext throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateRichtextStyle(String instanceId, String ref, HashMap<String, String> styles, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callUpdateRichtextStyle(instanceId, ref, styles, parentRef, richTextRef);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callUpdateRichtextStyle throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callUpdateRichtextChildAttr(String instanceId, String ref, HashMap<String, String> attrs, String parentRef, String richTextRef) {
        try {
            return WXBridgeManager.getInstance().callUpdateRichtextChildAttr(instanceId, ref, attrs, parentRef, richTextRef);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callUpdateRichtextChildAttr throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callLayout(String instanceId, String ref, int top, int bottom, int left, int right, int height, int width, boolean isRTL, int index) {
        try {
            return WXBridgeManager.getInstance().callLayout(instanceId, ref, top, bottom, left, right, height, width, isRTL, index);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callLayout throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callCreateFinish(String instanceId) {
        try {
            return WXBridgeManager.getInstance().callCreateFinish(instanceId);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(th));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callRenderSuccess(String instanceId) {
        try {
            return WXBridgeManager.getInstance().callRenderSuccess(instanceId);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "callCreateFinish throw exception:" + WXLogUtils.getStackTrace(th));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callAppendTreeCreateFinish(String instanceId, String ref) {
        try {
            return WXBridgeManager.getInstance().callAppendTreeCreateFinish(instanceId, ref);
        } catch (Throwable th) {
            WXLogUtils.e(TAG, "callAppendTreeCreateFinish throw exception:" + WXLogUtils.getStackTrace(th));
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public int callHasTransitionPros(String instanceId, String ref, HashMap<String, String> styles) {
        try {
            return WXBridgeManager.getInstance().callHasTransitionPros(instanceId, ref, styles);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "callHasTransitionPros throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return 1;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public ContentBoxMeasurement getMeasurementFunc(String instanceId, long renderObjectPtr) {
        try {
            return WXBridgeManager.getInstance().getMeasurementFunc(instanceId, renderObjectPtr);
        } catch (Throwable th) {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e(TAG, "getMeasurementFunc throw exception:" + WXLogUtils.getStackTrace(th));
            }
            return null;
        }
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void bindMeasurementToRenderObject(long ptr) {
        nativeBindMeasurementToRenderObject(ptr);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setRenderContainerWrapContent(boolean wrap, String instanceId) {
        nativeSetRenderContainerWrapContent(wrap, instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public long[] getFirstScreenRenderTime(String instanceId) {
        return nativeGetFirstScreenRenderTime(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public long[] getRenderFinishTime(String instanceId) {
        return nativeGetRenderFinishTime(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDefaultHeightAndWidthIntoRootDom(String instanceId, float defaultWidth, float defaultHeight, boolean isWidthWrapContent, boolean isHeightWrapContent) {
        nativeSetDefaultHeightAndWidthIntoRootDom(instanceId, defaultWidth, defaultHeight, isWidthWrapContent, isHeightWrapContent);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void onInstanceClose(String instanceId) {
        nativeOnInstanceClose(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void forceLayout(String instanceId) {
        nativeForceLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public boolean notifyLayout(String instanceId) {
        return nativeNotifyLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleWidth(String instanceId, String ref, float value, boolean update) {
        nativeSetStyleWidth(instanceId, ref, value, update);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setMargin(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetMargin(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPadding(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetPadding(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPosition(String instanceId, String ref, CSSShorthand.EDGE edge, float value) {
        nativeSetPosition(instanceId, ref, edge.ordinal(), value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void markDirty(String instanceId, String ref, boolean dirty) {
        nativeMarkDirty(instanceId, ref, dirty);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDeviceDisplay(String instanceId, float width, float height, float scale) {
        nativeSetDeviceDisplay(instanceId, width, height, scale);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleHeight(String instanceId, String ref, float value, boolean update) {
        nativeSetStyleHeight(instanceId, ref, value, update);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleWidth(String instanceId, String ref, float value) {
        nativeSetStyleWidth(instanceId, ref, value, false);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setStyleHeight(String instanceId, String ref, float value) {
        nativeSetStyleHeight(instanceId, ref, value, false);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setInstanceRenderType(String instanceId, String renderType) {
        if (TextUtils.isEmpty(renderType)) {
            return;
        }
        nativeSetInstanceRenderType(instanceId, renderType);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setViewPortWidth(String instanceId, float viewPortWidth) {
        nativeSetViewPortWidth(instanceId, viewPortWidth);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setFlexDirectionDef(String def) {
        nativeSetFlexDirectionDef(def);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void removeInstanceRenderType(String instanceId) {
        nativeRemoveInstanceRenderType(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setPageArgument(String instanceId, String key, String value) {
        nativeSetPageArgument(instanceId, key, value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void registerCoreEnv(String key, String value) {
        nativeRegisterCoreEnv(key, value);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reportNativeInitStatus(String statusCode, String errorMsg) {
        WXErrorCode[] values;
        if (WXErrorCode.WX_JS_FRAMEWORK_INIT_SINGLE_PROCESS_SUCCESS.getErrorCode().equals(statusCode) || WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED.getErrorCode().equals(statusCode)) {
            IWXUserTrackAdapter iWXUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
            if (iWXUserTrackAdapter != null) {
                HashMap hashMap = new HashMap(3);
                hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, statusCode);
                hashMap.put(IWXUserTrackAdapter.MONITOR_ARG, "InitFrameworkNativeError");
                hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, errorMsg);
                WXLogUtils.e("reportNativeInitStatus is running and errorCode is " + statusCode + " And errorMsg is " + errorMsg);
                iWXUserTrackAdapter.commit(null, null, IWXUserTrackAdapter.INIT_FRAMEWORK, null, hashMap);
            }
        } else if (WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL.getErrorCode().equals(statusCode)) {
            WXExceptionUtils.commitCriticalExceptionRT(null, WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL, "WeexProxy::initFromParam()", WXErrorCode.WX_JS_FRAMEWORK_INIT_FAILED_PARAMS_NULL.getErrorMsg() + ": " + errorMsg, null);
        } else {
            for (WXErrorCode wXErrorCode : WXErrorCode.values()) {
                if (wXErrorCode.getErrorType().equals(WXErrorCode.ErrorType.NATIVE_ERROR) && wXErrorCode.getErrorCode().equals(statusCode)) {
                    WXExceptionUtils.commitCriticalExceptionRT(null, wXErrorCode, IWXUserTrackAdapter.INIT_FRAMEWORK, errorMsg, null);
                    return;
                }
            }
        }
    }

    public void fireEventOnDataRenderNode(String instanceId, String ref, String type, String data, String domChanges) {
        nativeFireEventOnDataRenderNode(instanceId, ref, type, data, domChanges);
    }

    public void invokeCallbackOnDataRender(String instanceId, String callbackId, String data, boolean keepAlive) {
        nativeInvokeCallbackOnDataRender(instanceId, callbackId, data, keepAlive);
    }

    public void registerModuleOnDataRenderNode(String data) {
        nativeRegisterModuleOnDataRenderNode(data);
    }

    public void registerComponentOnDataRenderNode(String data) {
        nativeRegisterComponentOnDataRenderNode(data);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void reloadPageLayout(String instanceId) {
        nativeReloadPageLayout(instanceId);
    }

    @Override // com.taobao.weex.common.IWXBridge
    public void setDeviceDisplayOfPage(String instanceId, float width, float height) {
        nativeSetDeviceDisplayOfPage(instanceId, width, height);
    }

    public String encryptGetClientKeyPayload(String appId, String data, String appKey) {
        return nativePreGetClientKey(appId, data, appKey);
    }

    public String encrypt(String appId, String data, String appKey, String clientKeyData) {
        return nativeEncrypt(appId, data, appKey, clientKeyData);
    }

    public String decrypt(String appId, String data, String appKey, String clientKeyData) {
        return nativeDecrypt(appId, data, appKey, clientKeyData);
    }

    public boolean verifyClientKeyPayload(String appId, String appKey, String clientKeyData) {
        return nativeVerifyClientKeyPayload(appId, appKey, clientKeyData);
    }
}
