package com.taobao.weex.bridge;

import android.content.Intent;
import android.text.TextUtils;
import android.view.Menu;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXUserTrackAdapter;
import com.taobao.weex.common.Destroyable;
import com.taobao.weex.common.WXException;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.ui.config.ConfigModuleFactory;
import com.taobao.weex.ui.module.WXDomModule;
import com.taobao.weex.ui.module.WXTimerModule;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.cache.RegisterCache;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;
/* loaded from: classes.dex */
public class WXModuleManager {
    private static ArrayList<String> mBlackModuleList;
    private static volatile ConcurrentMap<String, ModuleFactoryImpl> sModuleFactoryMap = new ConcurrentHashMap();
    private static Map<String, WXModule> sGlobalModuleMap = new HashMap();
    private static Map<String, WXDomModule> sDomModuleMap = new HashMap();
    private static Map<String, Map<String, WXModule>> sInstanceModuleMap = new ConcurrentHashMap();

    public static boolean registerModule(Map<String, RegisterCache.ModuleCache> moduleCacheMap) {
        if (moduleCacheMap.isEmpty()) {
            return true;
        }
        final Iterator<Map.Entry<String, RegisterCache.ModuleCache>> it = moduleCacheMap.entrySet().iterator();
        WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.bridge.WXModuleManager.1
            @Override // java.lang.Runnable
            public void run() {
                HashMap hashMap = new HashMap();
                while (it.hasNext()) {
                    RegisterCache.ModuleCache moduleCache = (RegisterCache.ModuleCache) ((Map.Entry) it.next()).getValue();
                    String str = moduleCache.name;
                    if (!TextUtils.equals(str, WXDomModule.WXDOM)) {
                        if (WXModuleManager.sModuleFactoryMap != null && WXModuleManager.sModuleFactoryMap.containsKey(str)) {
                            WXLogUtils.w("WXComponentRegistry Duplicate the Module name: " + str);
                        }
                        ModuleFactory moduleFactory = moduleCache.factory;
                        try {
                            WXModuleManager.registerNativeModule(str, moduleFactory);
                        } catch (WXException e) {
                            WXLogUtils.e("registerNativeModule" + e);
                        }
                        if (moduleCache.global) {
                            try {
                                WXModule buildInstance = moduleFactory.buildInstance();
                                buildInstance.setModuleName(str);
                                WXModuleManager.sGlobalModuleMap.put(str, buildInstance);
                            } catch (Exception e2) {
                                WXLogUtils.e(str + " class must have a default constructor without params. ", e2);
                            }
                        }
                        try {
                            WXModuleManager.sModuleFactoryMap.put(str, new ModuleFactoryImpl(moduleFactory));
                        } catch (Throwable unused) {
                        }
                        hashMap.put(str, moduleFactory.getMethods());
                    } else {
                        WXLogUtils.e("Cannot registered module with name 'dom'.");
                    }
                }
                WXSDKManager.getInstance().registerModules(hashMap);
            }
        });
        return true;
    }

    public static boolean registerModule(final String moduleName, final ModuleFactory factory, final boolean global) throws WXException {
        if (moduleName == null || factory == null) {
            return false;
        }
        if (TextUtils.equals(moduleName, WXDomModule.WXDOM)) {
            WXLogUtils.e("Cannot registered module with name 'dom'.");
            return false;
        } else if (RegisterCache.getInstance().cacheModule(moduleName, factory, global)) {
            return true;
        } else {
            WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.bridge.WXModuleManager.2
                @Override // java.lang.Runnable
                public void run() {
                    if (WXModuleManager.sModuleFactoryMap != null && WXModuleManager.sModuleFactoryMap.containsKey(moduleName)) {
                        WXLogUtils.w("WXComponentRegistry Duplicate the Module name: " + moduleName);
                    }
                    try {
                        WXModuleManager.registerNativeModule(moduleName, factory);
                    } catch (WXException e) {
                        WXLogUtils.e("registerNativeModule" + e);
                    }
                    if (global) {
                        try {
                            WXModule buildInstance = factory.buildInstance();
                            buildInstance.setModuleName(moduleName);
                            WXModuleManager.sGlobalModuleMap.put(moduleName, buildInstance);
                        } catch (Exception e2) {
                            WXLogUtils.e(moduleName + " class must have a default constructor without params. ", e2);
                        }
                    }
                    WXModuleManager.registerJSModule(moduleName, factory);
                    try {
                        WXModuleManager.sModuleFactoryMap.put(moduleName, new ModuleFactoryImpl(factory));
                    } catch (Throwable unused) {
                    }
                }
            });
            return true;
        }
    }

    static boolean registerNativeModule(String moduleName, ModuleFactory factory) throws WXException {
        if (factory == null) {
            return false;
        }
        try {
            if (sModuleFactoryMap.containsKey(moduleName)) {
                return true;
            }
            sModuleFactoryMap.put(moduleName, new ModuleFactoryImpl(factory));
            return true;
        } catch (ArrayStoreException e) {
            e.printStackTrace();
            WXLogUtils.e("[WXModuleManager] registerNativeModule Error moduleName:" + moduleName + " Error:" + e.toString());
            return true;
        }
    }

    static boolean registerJSModule(String moduleName, ModuleFactory factory) {
        HashMap hashMap = new HashMap();
        hashMap.put(moduleName, factory.getMethods());
        WXSDKManager.getInstance().registerModules(hashMap);
        return true;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static Object callModuleMethod(final String instanceId, String moduleStr, String methodStr, JSONArray args) {
        ModuleFactory moduleFactory = sModuleFactoryMap.get(moduleStr).mFactory;
        if (moduleFactory == null) {
            WXLogUtils.e("[WXModuleManager] module factory not found.");
            return null;
        }
        WXModule findModule = findModule(instanceId, moduleStr, moduleFactory);
        if (findModule == null) {
            return null;
        }
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(instanceId);
        findModule.mWXSDKInstance = sDKInstance;
        findModule.mUniSDKInstance = sDKInstance;
        Invoker methodInvoker = moduleFactory.getMethodInvoker(methodStr);
        try {
            try {
                if (sDKInstance == null) {
                    WXLogUtils.e("callModuleMethod >>> instance is null");
                    if ((findModule instanceof WXDomModule) || (findModule instanceof WXTimerModule)) {
                        findModule.mWXSDKInstance = null;
                        findModule.mUniSDKInstance = null;
                    }
                    return null;
                }
                IWXUserTrackAdapter iWXUserTrackAdapter = WXSDKManager.getInstance().getIWXUserTrackAdapter();
                if (iWXUserTrackAdapter != null) {
                    HashMap hashMap = new HashMap();
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_CODE, "101");
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ARG, moduleStr + Operators.DOT_STR + methodStr);
                    hashMap.put(IWXUserTrackAdapter.MONITOR_ERROR_MSG, sDKInstance.getBundleUrl());
                    iWXUserTrackAdapter.commit(sDKInstance.getContext(), null, IWXUserTrackAdapter.INVOKE_MODULE, null, hashMap);
                }
                Object dispatchCallModuleMethod = dispatchCallModuleMethod(sDKInstance, findModule, args, methodInvoker);
                if ((findModule instanceof WXDomModule) || (findModule instanceof WXTimerModule)) {
                    findModule.mWXSDKInstance = null;
                    findModule.mUniSDKInstance = null;
                }
                return dispatchCallModuleMethod;
            } catch (Exception e) {
                WXLogUtils.e("callModuleMethod >>> invoke module:" + moduleStr + ", method:" + methodStr + " failed. ", e);
                if ((findModule instanceof WXDomModule) || (findModule instanceof WXTimerModule)) {
                    findModule.mWXSDKInstance = null;
                    findModule.mUniSDKInstance = null;
                }
                return null;
            }
        } catch (Throwable th) {
            if ((findModule instanceof WXDomModule) || (findModule instanceof WXTimerModule)) {
                findModule.mWXSDKInstance = null;
                findModule.mUniSDKInstance = null;
            }
            throw th;
        }
    }

    private static Object dispatchCallModuleMethod(WXSDKInstance instance, WXModule wxModule, JSONArray args, Invoker invoker) throws Exception {
        if (!instance.isPreRenderMode()) {
            return instance.getNativeInvokeHelper().invoke(wxModule, invoker, args);
        }
        if (invoker.isRunOnUIThread()) {
            return null;
        }
        return instance.getNativeInvokeHelper().invoke(wxModule, invoker, args);
    }

    public static boolean hasModule(String module) {
        return sGlobalModuleMap.containsKey(module) || sModuleFactoryMap.containsKey(module);
    }

    private static WXModule findModule(String instanceId, String moduleStr, ModuleFactory factory) {
        WXModule buildInstance;
        WXModule wXModule = sGlobalModuleMap.get(moduleStr);
        if (wXModule == null) {
            Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
            if (map == null) {
                map = new ConcurrentHashMap<>();
                sInstanceModuleMap.put(instanceId, map);
            }
            WXModule wXModule2 = map.get(moduleStr);
            if (wXModule2 == null) {
                try {
                    if (factory instanceof ConfigModuleFactory) {
                        buildInstance = ((ConfigModuleFactory) factory).buildInstance(WXSDKManager.getInstance().getSDKInstance(instanceId));
                    } else {
                        buildInstance = factory.buildInstance();
                    }
                    buildInstance.setModuleName(moduleStr);
                    map.put(moduleStr, buildInstance);
                    return buildInstance;
                } catch (Exception e) {
                    WXLogUtils.e(moduleStr + " module build instace failed.", e);
                    return null;
                }
            }
            return wXModule2;
        }
        return wXModule;
    }

    public static void onActivityCreate(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityCreate();
                } else {
                    WXLogUtils.w("onActivityCreate can not find the " + str + " module");
                }
            }
        }
    }

    public static void onActivityStart(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityStart();
                } else {
                    WXLogUtils.w("onActivityStart can not find the " + str + " module");
                }
            }
        }
    }

    public static void onActivityPause(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityPause();
                } else {
                    WXLogUtils.w("onActivityPause can not find the " + str + " module");
                }
            }
        }
    }

    public static void onActivityResume(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityResume();
                } else {
                    WXLogUtils.w("onActivityResume can not find the " + str + " module");
                }
            }
        }
    }

    public static void onActivityStop(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityStop();
                } else {
                    WXLogUtils.w("onActivityStop can not find the " + str + " module");
                }
            }
        }
    }

    public static void onActivityDestroy(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityDestroy();
                } else {
                    WXLogUtils.w("onActivityDestroy can not find the " + str + " module");
                }
            }
        }
    }

    public static boolean onActivityBack(String instanceId) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    return wXModule.onActivityBack();
                }
                WXLogUtils.w("onActivityCreate can not find the " + str + " module");
            }
            return false;
        }
        return false;
    }

    public static void onActivityResult(String instanceId, int requestCode, int resultCode, Intent data) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onActivityResult(requestCode, resultCode, data);
                } else {
                    WXLogUtils.w("onActivityResult can not find the " + str + " module");
                }
            }
        }
    }

    public static boolean onCreateOptionsMenu(String instanceId, Menu menu) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onCreateOptionsMenu(menu);
                } else {
                    WXLogUtils.w("onActivityResult can not find the " + str + " module");
                }
            }
            return false;
        }
        return false;
    }

    public static void onRequestPermissionsResult(String instanceId, int requestCode, String[] permissions, int[] grantResults) {
        Map<String, WXModule> map = sInstanceModuleMap.get(instanceId);
        if (map != null) {
            for (String str : map.keySet()) {
                WXModule wXModule = map.get(str);
                if (wXModule != null) {
                    wXModule.onRequestPermissionsResult(requestCode, permissions, grantResults);
                } else {
                    WXLogUtils.w("onActivityResult can not find the " + str + " module");
                }
            }
        }
    }

    public static void destroyInstanceModules(String instanceId) {
        sDomModuleMap.remove(instanceId);
        Map<String, WXModule> remove = sInstanceModuleMap.remove(instanceId);
        if (remove == null || remove.size() < 1) {
            return;
        }
        for (Map.Entry<String, WXModule> entry : remove.entrySet()) {
            WXModule value = entry.getValue();
            if (value instanceof Destroyable) {
                ((Destroyable) value).destroy();
            }
        }
    }

    public static void createDomModule(WXSDKInstance instance) {
        if (instance != null) {
            sDomModuleMap.put(instance.getInstanceId(), new WXDomModule(instance));
        }
    }

    public static void destoryDomModule(String instanceID) {
        sDomModuleMap.remove(instanceID);
    }

    public static WXDomModule getDomModule(String instanceId) {
        return sDomModuleMap.get(instanceId);
    }

    public static void reload() {
        if (sModuleFactoryMap == null || sModuleFactoryMap.size() <= 0) {
            return;
        }
        for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
            try {
                registerJSModule(entry.getKey(), entry.getValue().mFactory);
            } catch (Throwable unused) {
            }
        }
    }

    public static void registerWhenCreateInstance() {
        if (sModuleFactoryMap == null || sModuleFactoryMap.size() <= 0) {
            return;
        }
        for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
            try {
                if (!entry.getValue().hasRigster) {
                    registerJSModule(entry.getKey(), entry.getValue().mFactory);
                }
            } catch (Throwable unused) {
            }
        }
    }

    public static void resetAllModuleState() {
        if (sModuleFactoryMap == null || sModuleFactoryMap.size() <= 0) {
            return;
        }
        for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
            entry.getValue().hasRigster = false;
        }
    }

    public static void resetModuleState(String module, boolean state) {
        if (sModuleFactoryMap == null || sModuleFactoryMap.size() <= 0) {
            return;
        }
        for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
            try {
                if (entry.getKey() != null && entry.getKey().equals(module)) {
                    entry.getValue().hasRigster = state;
                }
            } catch (Throwable unused) {
            }
        }
    }

    public static JSONObject getRegisterJsModules() {
        if (sModuleFactoryMap == null || sModuleFactoryMap.size() <= 0) {
            return null;
        }
        JSONObject jSONObject = new JSONObject();
        for (Map.Entry<String, ModuleFactoryImpl> entry : sModuleFactoryMap.entrySet()) {
            try {
                if (!getBlackList().contains(entry.getKey()) && entry.getValue().mFactory != null) {
                    jSONObject.put(entry.getKey(), (Object) modulesToJSONArray(entry.getValue().mFactory.getMethods(), entry.getValue().mFactory));
                }
            } catch (Throwable unused) {
            }
        }
        return jSONObject;
    }

    private static ArrayList<String> getBlackList() {
        if (mBlackModuleList == null) {
            ArrayList<String> arrayList = new ArrayList<>();
            mBlackModuleList = arrayList;
            arrayList.add("webview");
            mBlackModuleList.add("animation");
            mBlackModuleList.add("binding");
            mBlackModuleList.add("bindingx");
            mBlackModuleList.add("instanceWrap");
            mBlackModuleList.add("meta");
            mBlackModuleList.add("navigator");
            mBlackModuleList.add("expressionBinding");
        }
        return mBlackModuleList;
    }

    public static JSONArray modulesToJSONArray(String[] json, ModuleFactory factory) {
        JSONArray jSONArray = null;
        if (json != null && json.length > 0) {
            for (int i = 0; i < json.length; i++) {
                if (jSONArray == null) {
                    jSONArray = new JSONArray();
                }
                if (!json[i].equals("addEventListener") && !json[i].equals("removeAllEventListeners")) {
                    boolean z = !factory.getMethodInvoker(json[i]).isRunOnUIThread();
                    StringBuilder sb = new StringBuilder();
                    sb.append(json[i]);
                    sb.append(z ? ":sync" : ":async");
                    jSONArray.add(sb.toString());
                }
            }
        }
        return jSONArray;
    }
}
