package com.taobao.weex.common;

import android.os.Handler;
import android.os.HandlerThread;
import android.os.Message;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.tools.LogDetail;
import com.taobao.weex.utils.tools.TimeCalculator;
import java.lang.ref.WeakReference;
/* loaded from: classes.dex */
public class WXThread extends HandlerThread {
    private Handler mHandler;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class SafeRunnable implements Runnable {
        static final String TAG = "SafeRunnable";
        private WeakReference<WXSDKInstance> mInstance;
        final Runnable mTask;
        private LogDetail mTimelineLog;

        SafeRunnable(Runnable task) {
            this(task, null);
        }

        SafeRunnable(Runnable task, String taskName) {
            this(task, null, taskName);
        }

        SafeRunnable(Runnable runnable, WXSDKInstance instance, String taskName) {
            this.mTimelineLog = null;
            this.mTask = runnable;
            if (taskName != null) {
                LogDetail logDetail = new LogDetail();
                this.mTimelineLog = logDetail;
                logDetail.info.platform = TimeCalculator.PLATFORM_ANDROID;
                this.mTimelineLog.name(taskName);
                this.mInstance = new WeakReference<>(instance);
            }
        }

        @Override // java.lang.Runnable
        public void run() {
            WeakReference<WXSDKInstance> weakReference;
            WXSDKInstance wXSDKInstance;
            try {
                if (this.mTask != null) {
                    LogDetail logDetail = this.mTimelineLog;
                    if (logDetail != null) {
                        logDetail.taskStart();
                    }
                    this.mTask.run();
                    LogDetail logDetail2 = this.mTimelineLog;
                    if (logDetail2 != null) {
                        logDetail2.taskEnd();
                    }
                }
            } catch (Throwable th) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.e(TAG, "SafeRunnable run throw expection:" + th.getMessage());
                    throw th;
                }
                WXLogUtils.w(TAG, th);
            }
            if (this.mTimelineLog == null || (weakReference = this.mInstance) == null || (wXSDKInstance = weakReference.get()) == null || wXSDKInstance.mTimeCalculator == null) {
                return;
            }
            wXSDKInstance.mTimeCalculator.addLog(this.mTimelineLog);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class SafeCallback implements Handler.Callback {
        static final String TAG = "SafeCallback";
        final Handler.Callback mCallback;

        SafeCallback(Handler.Callback cb) {
            this.mCallback = cb;
        }

        @Override // android.os.Handler.Callback
        public boolean handleMessage(Message msg) {
            boolean isApkDebugable;
            try {
                Handler.Callback callback = this.mCallback;
                if (callback != null) {
                    return callback.handleMessage(msg);
                }
                return false;
            } finally {
                if (!isApkDebugable) {
                }
            }
        }
    }

    public static Runnable secure(Runnable runnable) {
        return secure(runnable, null, null);
    }

    public static Runnable secure(Runnable runnable, WXSDKInstance instance, String runnableName) {
        return (runnable == null || (runnable instanceof SafeRunnable)) ? runnable : new SafeRunnable(runnable, instance, runnableName);
    }

    public static Handler.Callback secure(Handler.Callback callback) {
        return (callback == null || (callback instanceof SafeCallback)) ? callback : new SafeCallback(callback);
    }

    public WXThread(String name) {
        super(name);
        start();
        this.mHandler = new Handler(getLooper());
    }

    public WXThread(String name, Handler.Callback callback) {
        super(name);
        start();
        this.mHandler = new Handler(getLooper(), secure(callback));
    }

    public WXThread(String name, int priority, Handler.Callback callback) {
        super(name, priority);
        start();
        this.mHandler = new Handler(getLooper(), secure(callback));
    }

    public WXThread(String name, int priority) {
        super(name, priority);
        start();
        this.mHandler = new Handler(getLooper());
    }

    public Handler getHandler() {
        return this.mHandler;
    }

    public boolean isWXThreadAlive() {
        return (this.mHandler == null || getLooper() == null || !isAlive()) ? false : true;
    }

    @Override // android.os.HandlerThread
    public boolean quit() {
        Handler handler = this.mHandler;
        if (handler != null) {
            handler.removeCallbacksAndMessages(null);
        }
        return super.quit();
    }
}
