package com.taobao.weex.dom.binding;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.el.parse.Parser;
import com.taobao.weex.el.parse.Token;
import com.taobao.weex.utils.WXLogUtils;
/* loaded from: classes.dex */
public class ELUtils {
    public static final String BINDING = "@binding";
    public static final String COMPONENT_PROPS = "@componentProps";
    public static final String[] EXCLUDES_BINDING = {"clickEventParams"};
    public static final String IS_COMPONENT_ROOT = "@isComponentRoot";

    public static boolean isBinding(Object value) {
        if (value instanceof JSONObject) {
            return ((JSONObject) value).containsKey(BINDING);
        } else if (!(value instanceof JSONArray)) {
            return (value instanceof String) && ((String) value).indexOf(BINDING) >= 0;
        } else {
            JSONArray jSONArray = (JSONArray) value;
            for (int i = 0; i < jSONArray.size(); i++) {
                if (isBinding(jSONArray.get(i))) {
                    return true;
                }
            }
            return false;
        }
    }

    public static Object bindingBlock(Object value) {
        if (value instanceof JSONObject) {
            JSONObject jSONObject = (JSONObject) value;
            if (jSONObject.containsKey(BINDING)) {
                Object obj = jSONObject.get(BINDING);
                if (!(obj instanceof Token)) {
                    jSONObject.put(BINDING, (Object) Parser.parse(obj.toString()));
                }
            }
            for (String str : jSONObject.keySet()) {
                if ((jSONObject.get(str) instanceof JSONObject) && ((JSONObject) jSONObject.get(str)).containsKey(BINDING)) {
                    JSONObject jSONObject2 = (JSONObject) jSONObject.get(str);
                    Object obj2 = jSONObject2.get(BINDING);
                    if (!(obj2 instanceof Token)) {
                        jSONObject2.put(BINDING, (Object) Parser.parse(obj2.toString()));
                    }
                }
            }
            return value;
        } else if (value instanceof JSONArray) {
            JSONArray jSONArray = (JSONArray) value;
            for (int i = 0; i < jSONArray.size(); i++) {
                bindingBlock(jSONArray.get(i));
            }
            return value;
        } else if (value instanceof String) {
            String obj3 = value.toString();
            if (obj3.startsWith(Operators.BLOCK_START_STR)) {
                return bindingBlock(JSON.parseObject(obj3));
            }
            return obj3.startsWith(Operators.ARRAY_START_STR) ? bindingBlock(JSON.parseArray(obj3)) : value;
        } else {
            return value;
        }
    }

    public static Object vforBlock(Object vfor) {
        if (vfor instanceof JSONObject) {
            JSONObject jSONObject = (JSONObject) vfor;
            if (jSONObject.containsKey(WXStatement.WX_FOR_LIST)) {
                Object obj = jSONObject.get(WXStatement.WX_FOR_LIST);
                if (!(obj instanceof Token)) {
                    jSONObject.put(WXStatement.WX_FOR_LIST, (Object) Parser.parse(obj.toString()));
                }
            }
        } else if (vfor instanceof String) {
            return vforBlock(JSONObject.parseObject(vfor.toString()));
        } else {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.e("weex", "weex vfor is illegal " + vfor);
            }
        }
        return vfor;
    }
}
