package com.taobao.weex.http;

import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.common.WXRequest;
import java.util.HashMap;
import java.util.Map;
/* loaded from: classes.dex */
class Options {
    private String body;
    private Map<String, String> headers;
    private String inputType;
    private boolean isFirstIpv4;
    private String method;
    private boolean sslVerify;
    private int timeout;
    private JSONObject tlsConfig;
    private Type type;
    private String url;

    /* loaded from: classes.dex */
    public enum Type {
        json,
        text,
        jsonp,
        base64
    }

    private Options(String method, String url, Map<String, String> headers, String body, Type type, int timeout) {
        this.type = Type.text;
        this.timeout = WXRequest.DEFAULT_TIMEOUT_MS;
        this.sslVerify = false;
        this.isFirstIpv4 = false;
        this.method = method;
        this.url = url;
        this.headers = headers;
        this.body = body;
        this.type = type;
        this.timeout = timeout == 0 ? WXRequest.DEFAULT_TIMEOUT_MS : timeout;
    }

    private Options(String method, String url, Map<String, String> headers, String body, Type type, int timeout, boolean sslVerify, boolean sFirstIpv4) {
        this.type = Type.text;
        this.timeout = WXRequest.DEFAULT_TIMEOUT_MS;
        this.sslVerify = false;
        this.isFirstIpv4 = false;
        this.method = method;
        this.url = url;
        this.headers = headers;
        this.body = body;
        this.type = type;
        this.timeout = timeout == 0 ? WXRequest.DEFAULT_TIMEOUT_MS : timeout;
        this.sslVerify = sslVerify;
        this.isFirstIpv4 = sFirstIpv4;
    }

    public String getMethod() {
        return this.method;
    }

    public String getUrl() {
        return this.url;
    }

    public Map<String, String> getHeaders() {
        return this.headers;
    }

    public String getBody() {
        return this.body;
    }

    public Type getType() {
        return this.type;
    }

    public int getTimeout() {
        return this.timeout;
    }

    public boolean getSslVerify() {
        return this.sslVerify;
    }

    public boolean isFirstIpv4() {
        return this.isFirstIpv4;
    }

    public JSONObject getTlsConfig() {
        return this.tlsConfig;
    }

    public void setTlsConfig(JSONObject tlsConfig) {
        this.tlsConfig = tlsConfig;
    }

    public String getInputType() {
        return this.inputType;
    }

    public void setInputType(String inputType) {
        this.inputType = inputType;
    }

    /* loaded from: classes.dex */
    public static class Builder {
        private JSONObject androidTLSConfig;
        private String body;
        private Map<String, String> headers = new HashMap();
        private String inputType;
        private boolean isFirstIpv4;
        private String method;
        private boolean sslVerify;
        private int timeout;
        private Type type;
        private String url;

        public Builder setAndroidTlsConfig(JSONObject config) {
            this.androidTLSConfig = config;
            return this;
        }

        public Builder setMethod(String method) {
            this.method = method;
            return this;
        }

        public Builder setUrl(String url) {
            this.url = url;
            return this;
        }

        public Builder putHeader(String key, String value) {
            this.headers.put(key, value);
            return this;
        }

        public Builder setBody(String body) {
            this.body = body;
            return this;
        }

        public Builder setSslVerify(boolean sslVerify) {
            this.sslVerify = sslVerify;
            return this;
        }

        public Builder setFirstIpv4(boolean firstIpv4) {
            this.isFirstIpv4 = firstIpv4;
            return this;
        }

        public Builder setType(String type) {
            if (Type.json.name().equals(type)) {
                this.type = Type.json;
            } else if (Type.jsonp.name().equals(type)) {
                this.type = Type.jsonp;
            } else if (Type.base64.name().equals(type)) {
                this.type = Type.base64;
            } else {
                this.type = Type.text;
            }
            return this;
        }

        public Builder setType(Type type) {
            this.type = type;
            return this;
        }

        public Builder setInputTypes(String type) {
            this.inputType = type;
            return this;
        }

        public Builder setTimeout(int timeout) {
            this.timeout = timeout;
            return this;
        }

        public Options createOptions() {
            Options options = new Options(this.method, this.url, this.headers, this.body, this.type, this.timeout, this.sslVerify, this.isFirstIpv4);
            options.setInputType(this.inputType);
            options.setTlsConfig(this.androidTLSConfig);
            return options;
        }
    }
}
