package com.taobao.weex.layout.measurefunc;

import android.graphics.Canvas;
import android.os.Build;
import android.os.Looper;
import android.text.Editable;
import android.text.Layout;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.text.SpannedString;
import android.text.StaticLayout;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.style.AlignmentSpan;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.TextDecorationSpan;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXCustomStyleSpan;
import com.taobao.weex.dom.WXLineHeightSpan;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.layout.MeasureMode;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXTextDecoration;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;
/* loaded from: classes.dex */
public class TextContentBoxMeasurement extends ContentBoxMeasurement {
    private static final Canvas DUMMY_CANVAS = new Canvas();
    private static final String ELLIPSIS = "…";
    private AtomicReference<Layout> atomicReference;
    private boolean hasBeenMeasured;
    private Layout layout;
    protected Layout.Alignment mAlignment;
    protected int mColor;
    protected String mFontFamily;
    protected int mFontSize;
    protected int mFontStyle;
    protected int mFontWeight;
    protected boolean mIsColorSet;
    protected int mLineHeight;
    private int mNumberOfLines;
    private String mText;
    protected WXTextDecoration mTextDecoration;
    protected TextPaint mTextPaint;
    private float previousWidth;
    private Spanned spanned;
    private TextUtils.TruncateAt textOverflow;

    public TextContentBoxMeasurement(WXComponent component) {
        super(component);
        this.mIsColorSet = false;
        this.hasBeenMeasured = false;
        this.mFontStyle = -1;
        this.mFontWeight = -1;
        this.mNumberOfLines = -1;
        this.mFontSize = -1;
        this.mLineHeight = -1;
        this.previousWidth = Float.NaN;
        this.mFontFamily = null;
        this.mText = null;
        this.mTextDecoration = WXTextDecoration.NONE;
        this.atomicReference = new AtomicReference<>();
    }

    /* loaded from: classes.dex */
    class SetSpanOperation {
        protected final int end;
        protected final int flag;
        protected final int start;
        protected final Object what;

        SetSpanOperation(final TextContentBoxMeasurement this$0, int start, int end, Object what) {
            this(start, end, what, 17);
        }

        SetSpanOperation(int start, int end, Object what, int flag) {
            this.start = start;
            this.end = end;
            this.what = what;
            this.flag = flag;
        }

        public void execute(Spannable sb) {
            sb.setSpan(this.what, this.start, this.end, this.flag);
        }
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void layoutBefore() {
        this.mTextPaint = new TextPaint(1);
        this.hasBeenMeasured = false;
        updateStyleAndText();
        this.spanned = createSpanned(this.mText);
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
        Layout createLayout;
        this.hasBeenMeasured = true;
        float textWidth = getTextWidth(this.mTextPaint, width, widthMeasureMode == MeasureMode.EXACTLY);
        if (textWidth > 0.0f && this.spanned != null) {
            this.layout = createLayout(textWidth, null);
            this.previousWidth = createLayout.getWidth();
            if (Float.isNaN(width)) {
                width = this.layout.getWidth();
            } else {
                width = Math.min(this.layout.getWidth(), width);
            }
            if (Float.isNaN(height)) {
                height = this.layout.getHeight();
            }
        } else {
            if (widthMeasureMode == MeasureMode.UNSPECIFIED) {
                width = 0.0f;
            }
            if (heightMeasureMode == MeasureMode.UNSPECIFIED) {
                height = 0.0f;
            }
        }
        this.mMeasureWidth = width;
        this.mMeasureHeight = height;
    }

    @Override // com.taobao.weex.layout.ContentBoxMeasurement
    public void layoutAfter(float computedWidth, float computedHeight) {
        if (this.mComponent != null) {
            if (this.hasBeenMeasured) {
                if (this.layout != null && WXDomUtils.getContentWidth(this.mComponent.getPadding(), this.mComponent.getBorder(), computedWidth) != this.previousWidth) {
                    recalculateLayout(computedWidth);
                }
            } else {
                updateStyleAndText();
                recalculateLayout(computedWidth);
            }
            this.hasBeenMeasured = false;
            Layout layout = this.layout;
            if (layout != null && !layout.equals(this.atomicReference.get()) && Build.VERSION.SDK_INT >= 19 && Thread.currentThread() != Looper.getMainLooper().getThread()) {
                warmUpTextLayoutCache(this.layout);
            }
            swap();
            WXSDKManager.getInstance().getWXRenderManager().postOnUiThread(new Runnable() { // from class: com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement.1
                @Override // java.lang.Runnable
                public void run() {
                    if (TextContentBoxMeasurement.this.mComponent != null) {
                        TextContentBoxMeasurement.this.mComponent.updateExtra(TextContentBoxMeasurement.this.atomicReference.get());
                    }
                }
            }, this.mComponent.getInstanceId());
        }
    }

    private void updateStyleAndText() {
        updateStyleImp(this.mComponent.getStyles());
        this.mText = WXAttr.getValue(this.mComponent.getAttrs());
    }

    public void forceRelayout() {
        layoutBefore();
        measure(this.previousWidth, Float.NaN, MeasureMode.EXACTLY, MeasureMode.UNSPECIFIED);
        layoutAfter(this.previousWidth, Float.NaN);
    }

    private void updateStyleImp(Map<String, Object> style) {
        if (style != null) {
            if (style.containsKey(Constants.Name.LINES)) {
                int lines = WXStyle.getLines(style);
                if (lines <= 0) {
                    lines = -1;
                }
                this.mNumberOfLines = lines;
            }
            if (style.containsKey(Constants.Name.FONT_SIZE)) {
                this.mFontSize = WXStyle.getFontSize(style, this.mComponent.getInstance().getDefaultFontSize(), this.mComponent.getViewPortWidthForFloat());
            }
            if (style.containsKey(Constants.Name.FONT_WEIGHT)) {
                this.mFontWeight = WXStyle.getFontWeight(style);
            }
            if (style.containsKey(Constants.Name.FONT_STYLE)) {
                this.mFontStyle = WXStyle.getFontStyle(style);
            }
            if (style.containsKey("color")) {
                int color = WXResourceUtils.getColor(WXStyle.getTextColor(style));
                this.mColor = color;
                this.mIsColorSet = color != Integer.MIN_VALUE;
            }
            if (style.containsKey(Constants.Name.TEXT_DECORATION)) {
                this.mTextDecoration = WXStyle.getTextDecoration(style);
            }
            if (style.containsKey(Constants.Name.FONT_FAMILY)) {
                this.mFontFamily = WXStyle.getFontFamily(style);
            }
            this.mAlignment = WXStyle.getTextAlignment(style, this.mComponent.isLayoutRTL());
            this.textOverflow = WXStyle.getTextOverflow(style);
            int lineHeight = WXStyle.getLineHeight(style, this.mComponent.getViewPortWidthForFloat());
            if (lineHeight != -1) {
                this.mLineHeight = lineHeight;
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public Spanned createSpanned(String text) {
        if (!TextUtils.isEmpty(text)) {
            SpannableString spannableString = new SpannableString(text);
            updateSpannable(spannableString, 17);
            return spannableString;
        }
        return new SpannableString("");
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void updateSpannable(Spannable spannable, int spanFlag) {
        int length = spannable.length();
        int i = this.mFontSize;
        if (i == -1) {
            this.mTextPaint.setTextSize(this.mComponent.getInstance().getDefaultFontSize());
        } else {
            this.mTextPaint.setTextSize(i);
        }
        int i2 = this.mLineHeight;
        if (i2 != -1) {
            setSpan(spannable, new WXLineHeightSpan(i2), 0, length, spanFlag);
        }
        setSpan(spannable, new AlignmentSpan.Standard(this.mAlignment), 0, length, spanFlag);
        if (this.mFontStyle != -1 || this.mFontWeight != -1 || this.mFontFamily != null) {
            setSpan(spannable, new WXCustomStyleSpan(this.mFontStyle, this.mFontWeight, this.mFontFamily), 0, length, spanFlag);
        }
        if (this.mIsColorSet) {
            this.mTextPaint.setColor(this.mColor);
        }
        if (this.mTextDecoration == WXTextDecoration.UNDERLINE || this.mTextDecoration == WXTextDecoration.LINETHROUGH) {
            setSpan(spannable, new TextDecorationSpan(this.mTextDecoration), 0, length, spanFlag);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void setSpan(Spannable spannable, Object what, int start, int end, int spanFlag) {
        spannable.setSpan(what, start, end, spanFlag);
    }

    private float getTextWidth(TextPaint textPaint, float outerWidth, boolean forceToDesired) {
        if (this.mText == null) {
            if (forceToDesired) {
                return outerWidth;
            }
            return 0.0f;
        } else if (forceToDesired) {
            return outerWidth;
        } else {
            float desiredWidth = Layout.getDesiredWidth(this.spanned, textPaint);
            return (WXUtils.isUndefined(outerWidth) || desiredWidth < outerWidth) ? desiredWidth : outerWidth;
        }
    }

    private Layout createLayout(final float textWidth, Layout previousLayout) {
        SpannableStringBuilder spannableStringBuilder;
        if (this.previousWidth != textWidth || previousLayout == null) {
            previousLayout = new StaticLayout(this.spanned, this.mTextPaint, (int) Math.ceil(textWidth), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
        }
        int i = this.mNumberOfLines;
        if (i != -1 && i > 0 && i < previousLayout.getLineCount()) {
            int i2 = this.mNumberOfLines;
            if (i2 > 1) {
                int lineStart = previousLayout.getLineStart(i2 - 1);
                int lineEnd = previousLayout.getLineEnd(this.mNumberOfLines - 1);
                if (lineStart < lineEnd) {
                    if (lineStart > 0) {
                        spannableStringBuilder = new SpannableStringBuilder(this.spanned.subSequence(0, lineStart));
                    } else {
                        spannableStringBuilder = new SpannableStringBuilder();
                    }
                    double d = textWidth;
                    spannableStringBuilder.append((CharSequence) truncate(new SpannableStringBuilder(this.spanned.subSequence(lineStart, lineEnd)), this.mTextPaint, (int) Math.ceil(d), this.textOverflow));
                    adjustSpansRange(this.spanned, spannableStringBuilder);
                    this.spanned = spannableStringBuilder;
                    return new StaticLayout(this.spanned, this.mTextPaint, (int) Math.ceil(d), Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false);
                }
            } else {
                int ceil = (int) Math.ceil(textWidth);
                Spanned spanned = this.spanned;
                return StaticLayout.Builder.obtain(spanned, 0, spanned.length(), this.mTextPaint, ceil).setMaxLines(1).setEllipsize(TextUtils.TruncateAt.END).setEllipsizedWidth(ceil).build();
            }
        }
        return previousLayout;
    }

    private Spanned truncate(Editable source, TextPaint paint, int desired, TextUtils.TruncateAt truncateAt) {
        Object[] spans;
        SpannedString spannedString = new SpannedString("");
        if (!TextUtils.isEmpty(source) && source.length() > 0) {
            if (truncateAt != null) {
                source.append(ELLIPSIS);
                for (Object obj : source.getSpans(0, source.length(), Object.class)) {
                    int spanStart = source.getSpanStart(obj);
                    int spanEnd = source.getSpanEnd(obj);
                    if (spanStart == 0 && spanEnd == source.length() - 1) {
                        source.removeSpan(obj);
                        source.setSpan(obj, 0, source.length(), source.getSpanFlags(obj));
                    }
                }
            }
            while (source.length() > 1) {
                int length = source.length() - 1;
                if (truncateAt != null) {
                    length--;
                }
                source.delete(length, length + 1);
                if (new StaticLayout(source, paint, desired, Layout.Alignment.ALIGN_NORMAL, 1.0f, 0.0f, false).getLineCount() <= 1) {
                    return source;
                }
            }
        }
        return spannedString;
    }

    private void adjustSpansRange(Spanned beforeTruncate, Spannable afterTruncate) {
        Object[] spans;
        for (Object obj : beforeTruncate.getSpans(0, beforeTruncate.length(), Object.class)) {
            int spanStart = beforeTruncate.getSpanStart(obj);
            int spanEnd = beforeTruncate.getSpanEnd(obj);
            if (spanStart == 0 && spanEnd == beforeTruncate.length()) {
                afterTruncate.removeSpan(obj);
                afterTruncate.setSpan(obj, 0, afterTruncate.length(), beforeTruncate.getSpanFlags(obj));
            }
        }
    }

    private void recalculateLayout(float computedWidth) {
        float contentWidth = WXDomUtils.getContentWidth(this.mComponent.getPadding(), this.mComponent.getBorder(), computedWidth);
        if (contentWidth > 0.0f) {
            Spanned createSpanned = createSpanned(this.mText);
            this.spanned = createSpanned;
            if (createSpanned != null) {
                Layout createLayout = createLayout(contentWidth, this.layout);
                this.layout = createLayout;
                this.previousWidth = createLayout.getWidth();
                return;
            }
            this.previousWidth = 0.0f;
        }
    }

    private boolean warmUpTextLayoutCache(Layout layout) {
        try {
            layout.draw(DUMMY_CANVAS);
            return true;
        } catch (Exception e) {
            WXLogUtils.eTag("TextWarmUp", e);
            return false;
        }
    }

    private void swap() {
        Layout layout = this.layout;
        if (layout != null) {
            this.atomicReference.set(layout);
            this.layout = null;
        }
        this.hasBeenMeasured = false;
    }
}
