package com.taobao.weex.performance;

import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.utils.WXUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.ConcurrentLinkedQueue;
/* loaded from: classes.dex */
public class WXStateRecord {
    private long jsThreadTime;
    private Runnable jsThreadWatchTask;
    private RecordList<Info> mActionHistory;
    private RecordList<Info> mExceptionHistory;
    private RecordList<Info> mIPCExceptionHistory;
    private RecordList<Info> mJsThradWatchHistory;
    private RecordList<Info> mJscCrashHistory;
    private RecordList<Info> mJscReloadHistory;
    private RecordList<Info> mJsfmInitHistory;

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class SingleTonHolder {
        private static final WXStateRecord S_INSTANCE = new WXStateRecord();

        private SingleTonHolder() {
        }
    }

    public static WXStateRecord getInstance() {
        return SingleTonHolder.S_INSTANCE;
    }

    private WXStateRecord() {
        this.jsThreadTime = -1L;
        this.jsThreadWatchTask = new Runnable() { // from class: com.taobao.weex.performance.WXStateRecord.1
            @Override // java.lang.Runnable
            public void run() {
                if (WXStateRecord.this.jsThreadTime == -1) {
                    WXStateRecord.this.jsThreadTime = WXUtils.getFixUnixTime();
                }
                long fixUnixTime = WXUtils.getFixUnixTime() - WXStateRecord.this.jsThreadTime;
                WXStateRecord wXStateRecord = WXStateRecord.this;
                wXStateRecord.recordJsThreadWatch("diff:" + fixUnixTime);
                WXStateRecord.this.jsThreadTime = WXUtils.getFixUnixTime();
                WXBridgeManager.getInstance().postDelay(WXStateRecord.this.jsThreadWatchTask, 500L);
            }
        };
        this.mExceptionHistory = new RecordList<>(10);
        this.mActionHistory = new RecordList<>(20);
        this.mJsfmInitHistory = new RecordList<>(10);
        this.mJscCrashHistory = new RecordList<>(10);
        this.mJscReloadHistory = new RecordList<>(10);
        this.mJsThradWatchHistory = new RecordList<>(20);
        this.mIPCExceptionHistory = new RecordList<>(20);
    }

    public void recordException(String instanceId, String exception) {
        if (exception.length() > 200) {
            exception = exception.substring(0, 200);
        }
        recordCommon(this.mExceptionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, exception));
    }

    public void recordAction(String instanceId, String action) {
        recordCommon(this.mActionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, action));
    }

    public void recordIPCException(String instanceId, String exception) {
        if (exception.length() > 200) {
            exception = exception.substring(0, 200);
        }
        recordCommon(this.mIPCExceptionHistory, new Info(WXUtils.getFixUnixTime(), instanceId, exception));
    }

    public void onJSFMInit() {
        recoreJsfmInitHistory("setJsfmVersion");
    }

    public void recoreJsfmInitHistory(String msg) {
        recordCommon(this.mJsfmInitHistory, new Info(WXUtils.getFixUnixTime(), "JSFM", msg));
    }

    public void recordJsThreadWatch(String msg) {
        recordCommon(this.mJsThradWatchHistory, new Info(WXUtils.getFixUnixTime(), "jsWatch", msg));
    }

    public void onJSEngineReload(String instanceId) {
        recordCommon(this.mJscReloadHistory, new Info(WXUtils.getFixUnixTime(), instanceId, "onJSEngineReload"));
    }

    public void onJSCCrash(String instanceId) {
        recordCommon(this.mJscCrashHistory, new Info(WXUtils.getFixUnixTime(), instanceId, "onJSCCrash"));
    }

    private void recordCommon(RecordList<Info> list, Info info) {
        if (list == null || info == null) {
            return;
        }
        try {
            list.add(info);
            if (list.isEmpty() || list.size() <= ((RecordList) list).maxSize) {
                return;
            }
            list.poll();
        } catch (Throwable th) {
            th.getStackTrace();
        }
    }

    public Map<String, String> getStateInfo() {
        HashMap hashMap = new HashMap(5);
        hashMap.put("reInitCount", String.valueOf(WXBridgeManager.reInitCount));
        ArrayList arrayList = new ArrayList(this.mExceptionHistory.size() + this.mActionHistory.size() + this.mJsfmInitHistory.size() + this.mJscCrashHistory.size() + this.mJscReloadHistory.size() + this.mJsThradWatchHistory.size());
        arrayList.addAll(this.mExceptionHistory);
        arrayList.addAll(this.mActionHistory);
        arrayList.addAll(this.mJsfmInitHistory);
        arrayList.addAll(this.mJscCrashHistory);
        arrayList.addAll(this.mJscReloadHistory);
        arrayList.addAll(this.mJsThradWatchHistory);
        arrayList.addAll(this.mIPCExceptionHistory);
        Collections.sort(arrayList);
        hashMap.put("stateInfoList", arrayList.toString());
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (wxConfigAdapter != null && AbsoluteConst.TRUE.equalsIgnoreCase(wxConfigAdapter.getConfig("wxapm", "dumpIpcPageInfo", AbsoluteConst.TRUE))) {
            hashMap.put("pageQueueInfo", WXBridgeManager.getInstance().dumpIpcPageInfo());
        }
        return hashMap;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class RecordList<E> extends ConcurrentLinkedQueue<E> {
        private int maxSize;

        public RecordList(int maxSize) {
            this.maxSize = maxSize;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class Info implements Comparable<Info> {
        private String instanceId;
        private String msg;
        private long time;

        public Info(long time, String instance, String msg) {
            this.time = time;
            this.instanceId = instance;
            this.msg = msg;
        }

        public String toString() {
            return Operators.ARRAY_START + this.instanceId + Operators.ARRAY_SEPRATOR + this.time + Operators.ARRAY_SEPRATOR + this.msg + "]->";
        }

        @Override // java.lang.Comparable
        public int compareTo(Info next) {
            long j = this.time;
            long j2 = next.time;
            if (j == j2) {
                return 0;
            }
            return j > j2 ? 1 : -1;
        }
    }

    public void startJSThreadWatchDog() {
        WXBridgeManager.getInstance().post(this.jsThreadWatchTask);
    }
}
