package com.taobao.weex.performance;

import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXConfigAdapter;
import com.taobao.weex.common.Constants;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class WhiteScreenUtils {
    public static boolean doWhiteScreenCheck() {
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (wxConfigAdapter == null) {
            return false;
        }
        double d = 100.0d;
        double random = Math.random() * 100.0d;
        try {
            d = Double.valueOf(wxConfigAdapter.getConfig("wxapm", "new_ws_sampling", "100")).doubleValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return random < d;
    }

    public static boolean isWhiteScreen(WXSDKInstance instance) {
        if (instance == null) {
            return false;
        }
        View containerView = instance.getContainerView();
        if ((containerView instanceof ViewGroup) && !isInWhiteList(instance)) {
            return !hasLeafViewOrSizeIgnore(containerView, 3);
        }
        return false;
    }

    private static boolean isInWhiteList(WXSDKInstance instance) {
        String[] split;
        IWXConfigAdapter wxConfigAdapter = WXSDKManager.getInstance().getWxConfigAdapter();
        if (wxConfigAdapter == null) {
            return false;
        }
        String config = wxConfigAdapter.getConfig("wxapm", "ws_white_list", null);
        if (TextUtils.isEmpty(config)) {
            return false;
        }
        try {
            for (String str : config.split(";")) {
                if (instance.getBundleUrl() != null && instance.getBundleUrl().contains(str)) {
                    return true;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    private static boolean hasLeafViewOrSizeIgnore(View v, int checkDeep) {
        if (v instanceof ViewGroup) {
            if (checkDeep > 0) {
                if (v.getHeight() < 10 || v.getWidth() < 10) {
                    return true;
                }
                checkDeep--;
            }
            ViewGroup viewGroup = (ViewGroup) v;
            for (int i = 0; i < viewGroup.getChildCount(); i++) {
                if (hasLeafViewOrSizeIgnore(viewGroup.getChildAt(i), checkDeep)) {
                    return true;
                }
            }
            return false;
        }
        return true;
    }

    public static String takeViewTreeSnapShot(WXSDKInstance instance) {
        if (instance == null) {
            return "nullInstance";
        }
        JSONObject geViewDetailTreeMsg = geViewDetailTreeMsg(instance.getContainerView());
        return geViewDetailTreeMsg != null ? geViewDetailTreeMsg.toString() : "";
    }

    private static JSONObject geViewDetailTreeMsg(View view) {
        if (view == null) {
            return null;
        }
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("width", view.getWidth());
            jSONObject.put("height", view.getHeight());
            int[] iArr = {-1, -1};
            view.getLocationOnScreen(iArr);
            jSONObject.put(Constants.Name.X, iArr[0]);
            jSONObject.put(Constants.Name.Y, iArr[1]);
            if (view instanceof ViewGroup) {
                jSONObject.put("type", view.getClass().getSimpleName());
                ViewGroup viewGroup = (ViewGroup) view;
                for (int i = 0; i < viewGroup.getChildCount(); i++) {
                    jSONObject.put("child_" + i, geViewDetailTreeMsg(viewGroup.getChildAt(i)));
                }
            } else {
                jSONObject.put("type", view.getClass().getSimpleName());
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return jSONObject;
    }
}
