package com.taobao.weex.ui;

import android.text.TextUtils;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.WXException;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.cache.RegisterCache;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;
/* loaded from: classes.dex */
public class WXComponentRegistry {
    private static Map<String, IFComponentHolder> sTypeComponentMap = new ConcurrentHashMap();
    private static ArrayList<Map<String, Object>> sComponentInfos = new ArrayList<>();

    public static synchronized boolean registerComponent(Map<String, RegisterCache.ComponentCache> componentCacheMap) {
        synchronized (WXComponentRegistry.class) {
            if (componentCacheMap.isEmpty()) {
                return true;
            }
            final Iterator<Map.Entry<String, RegisterCache.ComponentCache>> it = componentCacheMap.entrySet().iterator();
            WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.ui.WXComponentRegistry.1
                @Override // java.lang.Runnable
                public void run() {
                    ArrayList arrayList = new ArrayList();
                    while (it.hasNext()) {
                        try {
                            RegisterCache.ComponentCache componentCache = (RegisterCache.ComponentCache) ((Map.Entry) it.next()).getValue();
                            Map map = componentCache.componentInfo;
                            if (map == null) {
                                map = new HashMap();
                            }
                            map.put("type", componentCache.type);
                            map.put("methods", componentCache.holder.getMethods());
                            WXComponentRegistry.registerNativeComponent(componentCache.type, componentCache.holder);
                            WXComponentRegistry.sComponentInfos.add(map);
                            arrayList.add(map);
                        } catch (WXException e) {
                            e.printStackTrace();
                        }
                    }
                    WXSDKManager.getInstance().registerComponents(arrayList);
                }
            });
            return true;
        }
    }

    public static synchronized boolean registerComponent(final String type, final IFComponentHolder holder, final Map<String, Object> componentInfo) throws WXException {
        synchronized (WXComponentRegistry.class) {
            if (holder != null) {
                if (!TextUtils.isEmpty(type)) {
                    if (RegisterCache.getInstance().cacheComponent(type, holder, componentInfo)) {
                        return true;
                    }
                    WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.ui.WXComponentRegistry.2
                        @Override // java.lang.Runnable
                        public void run() {
                            try {
                                Map map = componentInfo;
                                if (map == null) {
                                    map = new HashMap();
                                }
                                map.put("type", type);
                                map.put("methods", holder.getMethods());
                                WXComponentRegistry.registerNativeComponent(type, holder);
                                WXComponentRegistry.registerJSComponent(map);
                                WXComponentRegistry.sComponentInfos.add(map);
                            } catch (WXException e) {
                                WXLogUtils.e("register component error:", e);
                            }
                        }
                    });
                    return true;
                }
            }
            return false;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean registerNativeComponent(String type, IFComponentHolder holder) throws WXException {
        try {
            holder.loadIfNonLazy();
            sTypeComponentMap.put(type, holder);
            return true;
        } catch (ArrayStoreException e) {
            e.printStackTrace();
            return true;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static boolean registerJSComponent(Map<String, Object> componentInfo) throws WXException {
        ArrayList arrayList = new ArrayList();
        arrayList.add(componentInfo);
        WXSDKManager.getInstance().registerComponents(arrayList);
        return true;
    }

    public static IFComponentHolder getComponent(String type) {
        return sTypeComponentMap.get(type);
    }

    public static void reload() {
        WXBridgeManager.getInstance().post(new Runnable() { // from class: com.taobao.weex.ui.WXComponentRegistry.3
            @Override // java.lang.Runnable
            public void run() {
                try {
                    Iterator it = WXComponentRegistry.sComponentInfos.iterator();
                    while (it.hasNext()) {
                        WXComponentRegistry.registerJSComponent((Map) it.next());
                    }
                } catch (WXException e) {
                    WXLogUtils.e("", e);
                }
            }
        });
    }
}
