package com.taobao.weex.ui.animation;

import android.animation.PropertyValuesHolder;
import android.text.TextUtils;
import android.util.Pair;
import android.util.Property;
import android.view.View;
import androidx.collection.ArrayMap;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXErrorCode;
import com.taobao.weex.utils.FunctionParser;
import com.taobao.weex.utils.WXDataStructureUtil;
import com.taobao.weex.utils.WXExceptionUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class TransformParser {
    public static final String BACKGROUND_COLOR = "backgroundColor";
    public static final String BOTTOM = "bottom";
    public static final String CENTER = "center";
    private static final String DEG = "deg";
    private static final String FULL = "100%";
    private static final String HALF = "50%";
    public static final String HEIGHT = "height";
    public static final String LEFT = "left";
    private static final String PX = "px";
    public static final String RIGHT = "right";
    public static final String TOP = "top";
    public static final String WIDTH = "width";
    public static final String WX_ROTATE = "rotate";
    public static final String WX_ROTATE_X = "rotateX";
    public static final String WX_ROTATE_Y = "rotateY";
    public static final String WX_ROTATE_Z = "rotateZ";
    public static final String WX_SCALE = "scale";
    public static final String WX_SCALE_X = "scaleX";
    public static final String WX_SCALE_Y = "scaleY";
    public static final String WX_TRANSLATE = "translate";
    public static final String WX_TRANSLATE_X = "translateX";
    public static final String WX_TRANSLATE_Y = "translateY";
    private static final String ZERO = "0%";
    public static Map<String, List<Property<View, Float>>> wxToAndroidMap;

    static {
        ArrayMap arrayMap = new ArrayMap();
        wxToAndroidMap = arrayMap;
        arrayMap.put("translate", Arrays.asList(View.TRANSLATION_X, View.TRANSLATION_Y));
        wxToAndroidMap.put("translateX", Collections.singletonList(View.TRANSLATION_X));
        wxToAndroidMap.put("translateY", Collections.singletonList(View.TRANSLATION_Y));
        wxToAndroidMap.put("rotate", Collections.singletonList(View.ROTATION));
        wxToAndroidMap.put(WX_ROTATE_Z, Collections.singletonList(View.ROTATION));
        wxToAndroidMap.put("rotateX", Collections.singletonList(View.ROTATION_X));
        wxToAndroidMap.put("rotateY", Collections.singletonList(View.ROTATION_Y));
        wxToAndroidMap.put("scale", Arrays.asList(View.SCALE_X, View.SCALE_Y));
        wxToAndroidMap.put("scaleX", Collections.singletonList(View.SCALE_X));
        wxToAndroidMap.put("scaleY", Collections.singletonList(View.SCALE_Y));
        wxToAndroidMap.put(Constants.Name.PERSPECTIVE, Collections.singletonList(CameraDistanceProperty.getInstance()));
        wxToAndroidMap = Collections.unmodifiableMap(wxToAndroidMap);
    }

    public static PropertyValuesHolder[] toHolders(Map<Property<View, Float>, Float> transformMap) {
        PropertyValuesHolder[] propertyValuesHolderArr = new PropertyValuesHolder[transformMap.size()];
        int i = 0;
        for (Map.Entry<Property<View, Float>, Float> entry : transformMap.entrySet()) {
            propertyValuesHolderArr[i] = PropertyValuesHolder.ofFloat(entry.getKey(), entry.getValue().floatValue());
            i++;
        }
        return propertyValuesHolderArr;
    }

    public static Map<Property<View, Float>, Float> parseTransForm(String instanceId, String rawTransform, final int width, final int height, final float viewportW) {
        try {
            if (!TextUtils.isEmpty(rawTransform)) {
                return new FunctionParser(rawTransform, new FunctionParser.Mapper<Property<View, Float>, Float>() { // from class: com.taobao.weex.ui.animation.TransformParser.1
                    @Override // com.taobao.weex.utils.FunctionParser.Mapper
                    public Map<Property<View, Float>, Float> map(String functionName, List<String> raw) {
                        if (raw != null && !raw.isEmpty() && TransformParser.wxToAndroidMap.containsKey(functionName)) {
                            return convertParam(width, height, viewportW, TransformParser.wxToAndroidMap.get(functionName), raw);
                        }
                        return new HashMap();
                    }

                    private Map<Property<View, Float>, Float> convertParam(int width2, int height2, float viewportW2, List<Property<View, Float>> propertyList, List<String> rawValue) {
                        HashMap newHashMapWithExpectedSize = WXDataStructureUtil.newHashMapWithExpectedSize(propertyList.size());
                        ArrayList arrayList = new ArrayList(propertyList.size());
                        if (propertyList.contains(View.ROTATION) || propertyList.contains(View.ROTATION_X) || propertyList.contains(View.ROTATION_Y)) {
                            arrayList.addAll(parseRotationZ(rawValue));
                        } else if (propertyList.contains(View.TRANSLATION_X) || propertyList.contains(View.TRANSLATION_Y)) {
                            arrayList.addAll(parseTranslation(propertyList, width2, height2, rawValue, viewportW2));
                        } else if (propertyList.contains(View.SCALE_X) || propertyList.contains(View.SCALE_Y)) {
                            arrayList.addAll(parseScale(propertyList.size(), rawValue));
                        } else if (propertyList.contains(CameraDistanceProperty.getInstance())) {
                            arrayList.add(parseCameraDistance(rawValue));
                        }
                        if (propertyList.size() == arrayList.size()) {
                            for (int i = 0; i < propertyList.size(); i++) {
                                newHashMapWithExpectedSize.put(propertyList.get(i), (Float) arrayList.get(i));
                            }
                        }
                        return newHashMapWithExpectedSize;
                    }

                    private List<Float> parseScale(int size, List<String> rawValue) {
                        ArrayList arrayList = new ArrayList(rawValue.size() * 2);
                        ArrayList arrayList2 = new ArrayList(rawValue.size());
                        for (String str : rawValue) {
                            arrayList2.add(Float.valueOf(WXUtils.fastGetFloat(str)));
                        }
                        arrayList.addAll(arrayList2);
                        if (size != 1 && rawValue.size() == 1) {
                            arrayList.addAll(arrayList2);
                        }
                        return arrayList;
                    }

                    private List<Float> parseRotationZ(List<String> rawValue) {
                        ArrayList arrayList = new ArrayList(1);
                        for (String str : rawValue) {
                            int lastIndexOf = str.lastIndexOf(TransformParser.DEG);
                            if (lastIndexOf != -1) {
                                arrayList.add(Float.valueOf(WXUtils.fastGetFloat(str.substring(0, lastIndexOf))));
                            } else {
                                arrayList.add(Float.valueOf((float) Math.toDegrees(WXUtils.fastGetFloat(str))));
                            }
                        }
                        return arrayList;
                    }

                    private List<Float> parseTranslation(List<Property<View, Float>> propertyList, int width2, int height2, List<String> rawValue, float viewportW2) {
                        ArrayList arrayList = new ArrayList(2);
                        String str = rawValue.get(0);
                        if (propertyList.size() == 1) {
                            parseSingleTranslation(propertyList, width2, height2, arrayList, str, viewportW2);
                        } else {
                            parseDoubleTranslation(width2, height2, rawValue, arrayList, str, viewportW2);
                        }
                        return arrayList;
                    }

                    private void parseSingleTranslation(List<Property<View, Float>> propertyList, int width2, int height2, List<Float> convertedList, String first, float viewportW2) {
                        if (propertyList.contains(View.TRANSLATION_X)) {
                            convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, width2, viewportW2)));
                        } else if (propertyList.contains(View.TRANSLATION_Y)) {
                            convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, height2, viewportW2)));
                        }
                    }

                    private void parseDoubleTranslation(int width2, int height2, List<String> rawValue, List<Float> convertedList, String first, float viewportW2) {
                        String str = rawValue.size() == 1 ? first : rawValue.get(1);
                        convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(first, width2, viewportW2)));
                        convertedList.add(Float.valueOf(TransformParser.parsePercentOrPx(str, height2, viewportW2)));
                    }

                    private Float parseCameraDistance(List<String> rawValue) {
                        float f;
                        if (rawValue.size() == 1) {
                            float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(rawValue.get(0)), viewportW);
                            float f2 = WXEnvironment.getApplication().getResources().getDisplayMetrics().density;
                            if (!Float.isNaN(realPxByWidth) && realPxByWidth > 0.0f) {
                                f = realPxByWidth * f2;
                                return Float.valueOf(f);
                            }
                        }
                        f = Float.MAX_VALUE;
                        return Float.valueOf(f);
                    }
                }).parse();
            }
        } catch (Exception e) {
            WXLogUtils.e("TransformParser", e);
            WXErrorCode wXErrorCode = WXErrorCode.WX_RENDER_ERR_TRANSITION;
            WXExceptionUtils.commitCriticalExceptionRT(instanceId, wXErrorCode, "parse animation transition", WXErrorCode.WX_RENDER_ERR_TRANSITION.getErrorMsg() + "parse transition error: " + e.getMessage(), null);
        }
        return new LinkedHashMap();
    }

    private static Pair<Float, Float> parsePivot(String transformOrigin, int width, int height, float viewportW) {
        int indexOf;
        if (TextUtils.isEmpty(transformOrigin) || (indexOf = transformOrigin.indexOf(32)) == -1) {
            return null;
        }
        int i = indexOf;
        while (i < transformOrigin.length() && transformOrigin.charAt(i) == ' ') {
            i++;
        }
        if (i >= transformOrigin.length() || transformOrigin.charAt(i) == ' ') {
            return null;
        }
        ArrayList arrayList = new ArrayList(2);
        arrayList.add(transformOrigin.substring(0, indexOf).trim());
        arrayList.add(transformOrigin.substring(i, transformOrigin.length()).trim());
        return parsePivot(arrayList, width, height, viewportW);
    }

    private static Pair<Float, Float> parsePivot(List<String> list, int width, int height, float viewportW) {
        return new Pair<>(Float.valueOf(parsePivotX(list.get(0), width, viewportW)), Float.valueOf(parsePivotY(list.get(1), height, viewportW)));
    }

    private static float parsePivotX(String x, int width, float viewportW) {
        if ("left".equals(x)) {
            x = ZERO;
        } else if ("right".equals(x)) {
            x = FULL;
        } else if ("center".equals(x)) {
            x = HALF;
        }
        return parsePercentOrPx(x, width, viewportW);
    }

    private static float parsePivotY(String y, int height, float viewportW) {
        if ("top".equals(y)) {
            y = ZERO;
        } else if ("bottom".equals(y)) {
            y = FULL;
        } else if ("center".equals(y)) {
            y = HALF;
        }
        return parsePercentOrPx(y, height, viewportW);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static float parsePercentOrPx(String raw, int unit, float viewportW) {
        int lastIndexOf = raw.lastIndexOf(37);
        if (lastIndexOf != -1) {
            return parsePercent(raw.substring(0, lastIndexOf), unit, 1);
        }
        int lastIndexOf2 = raw.lastIndexOf(PX);
        if (lastIndexOf2 != -1) {
            return WXViewUtils.getRealPxByWidth(WXUtils.fastGetFloat(raw.substring(0, lastIndexOf2), 1.0f), viewportW);
        }
        return WXViewUtils.getRealPxByWidth(WXUtils.fastGetFloat(raw, 1.0f), viewportW);
    }

    private static float parsePercent(String percent, int unit, int precision) {
        return (WXUtils.fastGetFloat(percent, precision) / 100.0f) * unit;
    }
}
