package com.taobao.weex.ui.component;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.text.Editable;
import android.text.InputFilter;
import android.text.SpannableString;
import android.text.TextPaint;
import android.text.TextUtils;
import android.text.TextWatcher;
import android.text.method.PasswordTransformationMethod;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.BackgroundColorSpan;
import android.text.style.ForegroundColorSpan;
import android.text.style.StyleSpan;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.view.ViewTreeObserver;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.TextView;
import androidx.core.view.GravityCompat;
import androidx.localbroadcastmanager.content.LocalBroadcastManager;
import com.alibaba.fastjson.JSONObject;
import com.facebook.common.callercontext.ContextChain;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.dom.CSSConstants;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.WXEditText;
import com.taobao.weex.utils.FontDO;
import com.taobao.weex.utils.TypefaceUtil;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.core.ui.DCKeyboardManager;
import io.dcloud.common.core.ui.keyboard.DCEditText;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.feature.uniapp.annotation.UniJSMethod;
import io.dcloud.feature.uniapp.common.UniConstants;
import io.dcloud.feature.uniapp.utils.UniUtils;
import io.dcloud.feature.uniapp.utils.UniViewUtils;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.regex.Pattern;
import java.util.regex.PatternSyntaxException;
/* loaded from: classes.dex */
public class DCWXInput extends WXComponent<WXEditText> {
    private static final int MAX_TEXT_FORMAT_REPEAT = 3;
    final String ADJUST_POSITION;
    final String PASSWORD;
    private int cursor;
    boolean isConfirmHold;
    private AtomicBoolean isLayoutFinished;
    public boolean isNeedConfirm;
    private boolean isPassword;
    float keyboardHeight;
    private String mBeforeText;
    private int mEditorAction;
    private List<TextView.OnEditorActionListener> mEditorActionListeners;
    private String mFontFamily;
    private int mFormatRepeatCount;
    private TextFormatter mFormatter;
    private WXSDKInstance.FrameViewEventListener mFrameViewEventListener;
    private boolean mIgnoreNextOnInputEvent;
    private final InputMethodManager mInputMethodManager;
    private int mLineHeight;
    private boolean mListeningConfirm;
    private WXComponent.OnFocusChangeListener mOnFocusChangeListener;
    private TextPaint mPaint;
    private String mReturnKeyType;
    private TextWatcher mTextChangedEventDispatcher;
    private List<TextWatcher> mTextChangedListeners;
    protected String mType;
    private BroadcastReceiver mTypefaceObserver;
    private float measureHeight;
    private float measureWidht;
    private JSONObject placeholderStyle;
    private String placeholderTextAlign;
    private int selectionEnd;
    private int selectionStart;
    private String textAlign;

    /* loaded from: classes.dex */
    private interface ReturnTypes {
        public static final String DEFAULT = "default";
        public static final String DONE = "done";
        public static final String GO = "go";
        public static final String NEXT = "next";
        public static final String SEARCH = "search";
        public static final String SEND = "send";
    }

    protected int getVerticalGravity() {
        return 16;
    }

    public DCWXInput(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        this.mBeforeText = "";
        this.mType = "text";
        this.isPassword = false;
        this.mEditorAction = 6;
        this.mReturnKeyType = null;
        this.mListeningConfirm = false;
        this.mIgnoreNextOnInputEvent = false;
        this.mFormatter = null;
        this.mFormatRepeatCount = 0;
        this.mPaint = new TextPaint();
        this.mLineHeight = -1;
        this.ADJUST_POSITION = "adjustPosition";
        this.PASSWORD = Constants.Value.PASSWORD;
        this.keyboardHeight = 0.0f;
        this.isConfirmHold = false;
        this.isNeedConfirm = true;
        this.cursor = -1;
        this.selectionStart = Integer.MAX_VALUE;
        this.selectionEnd = Integer.MAX_VALUE;
        this.textAlign = "left";
        this.placeholderStyle = new JSONObject();
        this.measureHeight = -1.0f;
        this.measureWidht = -1.0f;
        this.mOnFocusChangeListener = new AnonymousClass6();
        this.isLayoutFinished = new AtomicBoolean(false);
        interceptFocusAndBlurEvent();
        this.mInputMethodManager = (InputMethodManager) getContext().getSystemService("input_method");
        setContentBoxMeasurement(new ContentBoxMeasurement() { // from class: com.taobao.weex.ui.component.DCWXInput.1
            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                if (DCWXInput.this.getBasicComponentData().getStyles() == null || DCWXInput.this.getBasicComponentData().getStyles().size() == 0) {
                    DCWXInput.this.measureWidht = width;
                }
                if (CSSConstants.isUndefined(height)) {
                    this.mMeasureHeight = WXViewUtils.getRealPxByWidth(DCWXInput.this.getInstance().getDefaultFontSize() * 1.4f, DCWXInput.this.getInstance().getInstanceViewPortWidthWithFloat());
                    DCWXInput.this.measureHeight = this.mMeasureHeight;
                }
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
                DCWXInput.this.updateStyleAndAttrs();
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't rename method to resolve collision */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void setHostLayoutParams(WXEditText host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((DCWXInput) host, width, height, left, right, top, bottom);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void setLayoutSize(GraphicSize mLayoutSize) {
        super.setLayoutSize(mLayoutSize);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected void layoutDirectionDidChanged(boolean isRTL) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        if (getHostView() != null) {
            getHostView().setGravity(textAlign | getVerticalGravity());
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final float getMeasuredLineHeight() {
        int i = this.mLineHeight;
        return (i == -1 || i <= 0) ? this.mPaint.getFontMetrics(null) : i;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public float getMeasureHeight() {
        return WXViewUtils.getRealPxByWidth(getMeasuredLineHeight() >= 50.0f ? getMeasureHeight() : 50.0f, getInstance().getInstanceViewPortWidthWithFloat());
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateStyleAndAttrs() {
        if (getStyles().size() > 0) {
            int fontSize = getStyles().containsKey(Constants.Name.FONT_SIZE) ? WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getViewPortWidth()) : -1;
            String fontFamily = getStyles().containsKey(Constants.Name.FONT_FAMILY) ? WXStyle.getFontFamily(getStyles()) : null;
            int fontStyle = getStyles().containsKey(Constants.Name.FONT_STYLE) ? WXStyle.getFontStyle(getStyles()) : -1;
            int fontWeight = getStyles().containsKey(Constants.Name.FONT_WEIGHT) ? WXStyle.getFontWeight(getStyles()) : -1;
            int lineHeight = WXStyle.getLineHeight(getStyles(), getViewPortWidth());
            if (lineHeight != -1) {
                this.mLineHeight = lineHeight;
            }
            if (fontSize != -1) {
                this.mPaint.setTextSize(fontSize);
            }
            if (fontFamily != null) {
                TypefaceUtil.applyFontStyle(this.mPaint, fontStyle, fontWeight, fontFamily);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXEditText initComponentHostView(Context context) {
        WXEditText wXEditText = new WXEditText(context, getInstanceId());
        appleStyleAfterCreated(wXEditText);
        wXEditText.setImeOptions(6);
        return wXEditText;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't rename method to resolve collision */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onHostViewInitialized(WXEditText host) {
        super.onHostViewInitialized((DCWXInput) host);
        if (this.measureWidht > 0.0f) {
            WXBridgeManager.getInstance().setStyleWidth(getInstanceId(), getRef(), this.measureWidht);
        }
        if (this.measureHeight > 0.0f) {
            WXBridgeManager.getInstance().setStyleHeight(getInstanceId(), getRef(), this.measureHeight);
        }
        addFocusChangeListener(new WXComponent.OnFocusChangeListener() { // from class: com.taobao.weex.ui.component.DCWXInput.2
            @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
            public void onFocusChange(boolean hasFocus) {
                if (!hasFocus) {
                    DCWXInput.this.decideSoftKeyboard();
                }
                DCWXInput.this.setPseudoClassStatus(Constants.PSEUDO.FOCUS, hasFocus);
                if (hasFocus) {
                    DCWXInput dCWXInput = DCWXInput.this;
                    dCWXInput.setTextAlign(dCWXInput.textAlign);
                } else if (DCWXInput.this.getHostView() == null || !PdrUtil.isEmpty(DCWXInput.this.getHostView().getText().toString())) {
                } else {
                    DCWXInput dCWXInput2 = DCWXInput.this;
                    int textAlign = dCWXInput2.getTextAlign(dCWXInput2.placeholderTextAlign == null ? DCWXInput.this.textAlign : DCWXInput.this.placeholderTextAlign);
                    if (textAlign > 0) {
                        DCWXInput.this.getHostView().setGravity(textAlign | DCWXInput.this.getVerticalGravity());
                    }
                }
            }
        });
        addKeyboardListener(host);
        if (this.isNeedConfirm) {
            addEditorChangeListener();
        }
    }

    private void addEditorChangeListener() {
        addEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.taobao.weex.ui.component.DCWXInput.3
            @Override // android.widget.TextView.OnEditorActionListener
            public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                if (DCWXInput.this.mListeningConfirm && actionId == DCWXInput.this.mEditorAction) {
                    HashMap hashMap = new HashMap(1);
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("value", v.getText().toString());
                    hashMap.put("detail", hashMap2);
                    DCWXInput.this.fireEvent("confirm", hashMap);
                    if (!DCWXInput.this.isConfirmHold) {
                        DCWXInput.this.blur();
                    }
                    return true;
                }
                return DCWXInput.this.isConfirmHold;
            }
        });
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected boolean isConsumeTouch() {
        return !isDisabled();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void appleStyleAfterCreated(final WXEditText editText) {
        int textAlign = getTextAlign((String) getStyles().get(Constants.Name.TEXT_ALIGN));
        if (textAlign <= 0) {
            textAlign = GravityCompat.START;
        }
        editText.setGravity(textAlign | getVerticalGravity());
        int color = WXResourceUtils.getColor("#999999");
        if (color != Integer.MIN_VALUE) {
            editText.setHintTextColor(color);
        }
        TextWatcher textWatcher = new TextWatcher() { // from class: com.taobao.weex.ui.component.DCWXInput.4
            @Override // android.text.TextWatcher
            public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                if (DCWXInput.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : DCWXInput.this.mTextChangedListeners) {
                        textWatcher2.beforeTextChanged(s, start, count, after);
                    }
                }
            }

            @Override // android.text.TextWatcher
            public void onTextChanged(CharSequence s, int start, int before, int count) {
                if (DCWXInput.this.mFormatter != null) {
                    String format = DCWXInput.this.mFormatter.format(DCWXInput.this.mFormatter.recover(s.toString()));
                    if (format.equals(s.toString()) || DCWXInput.this.mFormatRepeatCount >= 3) {
                        DCWXInput.this.mFormatRepeatCount = 0;
                    } else {
                        DCWXInput.this.mFormatRepeatCount++;
                        int length = DCWXInput.this.mFormatter.format(DCWXInput.this.mFormatter.recover(s.subSequence(0, editText.getSelectionStart()).toString())).length();
                        editText.setText(format);
                        editText.setSelection(length);
                        return;
                    }
                }
                if (DCWXInput.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : DCWXInput.this.mTextChangedListeners) {
                        textWatcher2.onTextChanged(s, start, before, count);
                    }
                }
            }

            @Override // android.text.TextWatcher
            public void afterTextChanged(Editable s) {
                if (DCWXInput.this.mTextChangedListeners != null) {
                    for (TextWatcher textWatcher2 : DCWXInput.this.mTextChangedListeners) {
                        textWatcher2.afterTextChanged(s);
                    }
                }
            }
        };
        this.mTextChangedEventDispatcher = textWatcher;
        editText.addTextChangedListener(textWatcher);
        editText.setTextSize(0, WXStyle.getFontSize(getStyles(), getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
        editText.setSingleLine(true);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(final String type) {
        if (getHostView() == null || TextUtils.isEmpty(type)) {
            return;
        }
        if (type.equals("input")) {
            addTextChangedListener(new TextWatcher() { // from class: com.taobao.weex.ui.component.DCWXInput.5
                @Override // android.text.TextWatcher
                public void afterTextChanged(Editable s) {
                }

                @Override // android.text.TextWatcher
                public void beforeTextChanged(CharSequence s, int start, int count, int after) {
                }

                @Override // android.text.TextWatcher
                public void onTextChanged(CharSequence s, int start, int before, int count) {
                    if (DCWXInput.this.mIgnoreNextOnInputEvent) {
                        DCWXInput.this.mIgnoreNextOnInputEvent = false;
                        DCWXInput.this.mBeforeText = s.toString();
                        return;
                    }
                    HashMap hashMap = new HashMap(1);
                    HashMap hashMap2 = new HashMap(3);
                    hashMap2.put("value", s.toString());
                    hashMap2.put("cursor", Integer.valueOf(DCWXInput.this.getHostView().getSelectionEnd()));
                    try {
                    } catch (Exception unused) {
                        hashMap2.put("keyCode", WXInstanceApm.VALUE_ERROR_CODE_DEFAULT);
                    }
                    if (before == 0 && count != 0) {
                        String charSequence = s.subSequence(start, count + start).toString();
                        hashMap2.put("keyCode", Integer.valueOf(Character.codePointAt(charSequence, charSequence.length() - 1)));
                    } else {
                        if (before != 0 && count == 0) {
                            String charSequence2 = DCWXInput.this.mBeforeText.subSequence(start, before + start).toString();
                            hashMap2.put("keyCode", Integer.valueOf(Character.codePointAt(charSequence2, charSequence2.length() - 1)));
                        }
                        DCWXInput.this.mBeforeText = s.toString();
                        hashMap.put("detail", hashMap2);
                        DCWXInput.this.fireEvent("input", hashMap);
                    }
                    DCWXInput.this.mBeforeText = s.toString();
                    hashMap.put("detail", hashMap2);
                    DCWXInput.this.fireEvent("input", hashMap);
                }
            });
        }
        if ("confirm".equals(type)) {
            this.mListeningConfirm = true;
        }
        if (Constants.Event.FOCUS.equals(type) || Constants.Event.BLUR.equals(type)) {
            setFocusAndBlur();
        }
        super.addEvent(type);
    }

    /* renamed from: com.taobao.weex.ui.component.DCWXInput$6  reason: invalid class name */
    /* loaded from: classes.dex */
    class AnonymousClass6 implements WXComponent.OnFocusChangeListener {
        int count = 0;

        AnonymousClass6() {
        }

        @Override // com.taobao.weex.ui.component.WXComponent.OnFocusChangeListener
        public void onFocusChange(boolean hasFocus) {
            WXEditText hostView = DCWXInput.this.getHostView();
            if (hostView == null) {
                return;
            }
            HashMap hashMap = new HashMap(1);
            HashMap hashMap2 = new HashMap(1);
            hashMap2.put("value", hostView.getText().toString());
            if (hasFocus) {
                if (DCWXInput.this.keyboardHeight == 0.0f) {
                    fireEventForFocus(hostView);
                    return;
                }
                hashMap2.put("height", Float.valueOf(DCWXInput.this.keyboardHeight));
                hashMap2.put("value", hostView.getText().toString());
                hashMap.put("detail", hashMap2);
                DCWXInput.this.fireEvent(Constants.Event.FOCUS, hashMap);
                return;
            }
            hashMap.put("detail", hashMap2);
            DCWXInput.this.fireEvent(Constants.Event.BLUR, hashMap);
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void fireEventForFocus(final TextView text) {
            DCWXInput.this.getHostView().postDelayed(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXInput.6.1
                @Override // java.lang.Runnable
                public void run() {
                    if (DCWXInput.this.keyboardHeight == 0.0f) {
                        AnonymousClass6.this.count++;
                        if (AnonymousClass6.this.count <= 3) {
                            AnonymousClass6.this.fireEventForFocus(text);
                            return;
                        }
                        HashMap hashMap = new HashMap(1);
                        HashMap hashMap2 = new HashMap(1);
                        hashMap2.put("value", text.getText().toString());
                        hashMap2.put("height", Float.valueOf(DCWXInput.this.keyboardHeight));
                        hashMap.put("detail", hashMap2);
                        DCWXInput.this.fireEvent(Constants.Event.FOCUS, hashMap);
                        return;
                    }
                    AnonymousClass6.this.count = 0;
                    HashMap hashMap3 = new HashMap(1);
                    HashMap hashMap4 = new HashMap(1);
                    hashMap4.put("value", text.getText().toString());
                    hashMap4.put("height", Float.valueOf(DCWXInput.this.keyboardHeight));
                    hashMap3.put("detail", hashMap4);
                    DCWXInput.this.fireEvent(Constants.Event.FOCUS, hashMap3);
                }
            }, 200L);
        }
    }

    protected void setFocusAndBlur() {
        if (ismHasFocusChangeListener(this.mOnFocusChangeListener)) {
            return;
        }
        addFocusChangeListener(this.mOnFocusChangeListener);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Code restructure failed: missing block: B:90:0x0128, code lost:
        if (r6.equals(com.taobao.weex.common.Constants.Name.SELECTION_START) == false) goto L3;
     */
    @Override // com.taobao.weex.ui.component.WXComponent
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 0;
        switch (key.hashCode()) {
            case -2137753034:
                break;
            case -1898657397:
                if (key.equals(Constants.Name.KEEP_SELECTION_INDEX)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case -1629051985:
                if (key.equals(Constants.Name.SELECTION_END)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case -1576785488:
                if (key.equals(Constants.Name.PLACEHOLDER_COLOR)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case -1349119146:
                if (key.equals("cursor")) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case -1224696685:
                if (key.equals(Constants.Name.FONT_FAMILY)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            case -1065511464:
                if (key.equals(Constants.Name.TEXT_ALIGN)) {
                    c = 6;
                    break;
                }
                c = 65535;
                break;
            case -791400086:
                if (key.equals(Constants.Name.MAX_LENGTH)) {
                    c = 7;
                    break;
                }
                c = 65535;
                break;
            case 107876:
                if (key.equals("max")) {
                    c = '\b';
                    break;
                }
                c = 65535;
                break;
            case 108114:
                if (key.equals(Constants.Name.MIN)) {
                    c = '\t';
                    break;
                }
                c = 65535;
                break;
            case 94842723:
                if (key.equals("color")) {
                    c = '\n';
                    break;
                }
                c = 65535;
                break;
            case 97604824:
                if (key.equals(Constants.Event.FOCUS)) {
                    c = 11;
                    break;
                }
                c = 65535;
                break;
            case 102977279:
                if (key.equals(Constants.Name.LINES)) {
                    c = '\f';
                    break;
                }
                c = 65535;
                break;
            case 124732746:
                if (key.equals(Constants.Name.MAXLENGTH)) {
                    c = '\r';
                    break;
                }
                c = 65535;
                break;
            case 270940796:
                if (key.equals(Constants.Name.DISABLED)) {
                    c = 14;
                    break;
                }
                c = 65535;
                break;
            case 344059807:
                if (key.equals("confirmHold")) {
                    c = 15;
                    break;
                }
                c = 65535;
                break;
            case 365601008:
                if (key.equals(Constants.Name.FONT_SIZE)) {
                    c = 16;
                    break;
                }
                c = 65535;
                break;
            case 598246771:
                if (key.equals(Constants.Name.PLACEHOLDER)) {
                    c = 17;
                    break;
                }
                c = 65535;
                break;
            case 914346044:
                if (key.equals(Constants.Name.SINGLELINE)) {
                    c = 18;
                    break;
                }
                c = 65535;
                break;
            case 947486441:
                if (key.equals(Constants.Name.RETURN_KEY_TYPE)) {
                    c = 19;
                    break;
                }
                c = 65535;
                break;
            case 1625554645:
                if (key.equals(Constants.Name.ALLOW_COPY_PASTE)) {
                    c = 20;
                    break;
                }
                c = 65535;
                break;
            case 1638055017:
                if (key.equals("autoFocus")) {
                    c = 21;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        switch (c) {
            case 0:
                int intValue = WXUtils.getInteger(param, Integer.MAX_VALUE).intValue();
                this.selectionStart = intValue;
                setSelectionRange(intValue, this.selectionEnd);
                return super.setProperty(key, param);
            case 1:
                return true;
            case 2:
                int intValue2 = WXUtils.getInteger(param, Integer.MAX_VALUE).intValue();
                this.selectionEnd = intValue2;
                setSelectionRange(this.selectionStart, intValue2);
                return super.setProperty(key, param);
            case 3:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setPlaceholderColor(string);
                }
                return true;
            case 4:
                int i = WXUtils.getInt(param);
                if (i > 0 && i <= getHostView().getText().length()) {
                    getHostView().setSelection(i);
                } else if (i > getHostView().getText().length()) {
                    getHostView().setSelection(getHostView().getText().length());
                }
                return true;
            case 5:
                if (param != null) {
                    try {
                        FontDO fontDO = TypefaceUtil.getFontDO(param.toString());
                        if (fontDO != null && fontDO.getTypeface() != null && getHostView() != null) {
                            getHostView().setTypeface(fontDO.getTypeface());
                        } else {
                            registerTypefaceObserver(param.toString());
                        }
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
                return true;
            case 6:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setTextAlign(string2);
                }
                return true;
            case 7:
                Integer integer = WXUtils.getInteger(param, null);
                if (integer != null) {
                    setMaxLength(integer.intValue());
                }
                return true;
            case '\b':
            case '\t':
                return true;
            case '\n':
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setColor(string3);
                }
                return true;
            case 11:
            case 21:
                setAutofocus(WXUtils.getBoolean(param, false).booleanValue());
                return true;
            case '\f':
                Integer integer2 = WXUtils.getInteger(param, null);
                if (integer2 != null) {
                    setLines(integer2.intValue());
                }
                return true;
            case '\r':
                Integer integer3 = WXUtils.getInteger(param, null);
                if (integer3 != null) {
                    setMaxLength(integer3.intValue());
                }
                return true;
            case 14:
                Boolean bool = WXUtils.getBoolean(param, false);
                getHostView().setFocusable(!bool.booleanValue());
                getHostView().setFocusableInTouchMode(!bool.booleanValue());
                getHostView().setCursorVisible(!bool.booleanValue());
                return true;
            case 15:
                this.isConfirmHold = WXUtils.getBoolean(param, false).booleanValue();
                return super.setProperty(key, param);
            case 16:
                String string4 = WXUtils.getString(param, null);
                if (string4 != null) {
                    setFontSize(string4);
                }
                return true;
            case 17:
                return true;
            case 18:
                Boolean bool2 = WXUtils.getBoolean(param, null);
                if (bool2 != null) {
                    setSingleLine(bool2.booleanValue());
                }
                return true;
            case 19:
                setReturnKeyType(String.valueOf(param));
                return true;
            case 20:
                boolean booleanValue = WXUtils.getBoolean(param, true).booleanValue();
                if (getHostView() != null) {
                    getHostView().setAllowCopyPaste(booleanValue);
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    private void registerTypefaceObserver(String desiredFontFamily) {
        if (WXEnvironment.getApplication() == null) {
            WXLogUtils.w("WXText", "ApplicationContent is null on register typeface observer");
            return;
        }
        this.mFontFamily = desiredFontFamily;
        if (this.mTypefaceObserver != null) {
            return;
        }
        this.mTypefaceObserver = new BroadcastReceiver() { // from class: com.taobao.weex.ui.component.DCWXInput.7
            @Override // android.content.BroadcastReceiver
            public void onReceive(Context context, Intent intent) {
                FontDO fontDO;
                String stringExtra = intent.getStringExtra(Constants.Name.FONT_FAMILY);
                if (!DCWXInput.this.mFontFamily.equals(stringExtra) || (fontDO = TypefaceUtil.getFontDO(stringExtra)) == null || fontDO.getTypeface() == null || DCWXInput.this.getHostView() == null) {
                    return;
                }
                DCWXInput.this.getHostView().setTypeface(fontDO.getTypeface());
            }
        };
        LocalBroadcastManager.getInstance(WXEnvironment.getApplication()).registerReceiver(this.mTypefaceObserver, new IntentFilter(TypefaceUtil.ACTION_TYPE_FACE_AVAILABLE));
    }

    @WXComponentProp(name = Constants.Name.RETURN_KEY_TYPE)
    public void setReturnKeyType(String type) {
        if (getHostView() == null || type.equals(this.mReturnKeyType)) {
            return;
        }
        this.mReturnKeyType = type;
        type.hashCode();
        char c = 65535;
        switch (type.hashCode()) {
            case -906336856:
                if (type.equals("search")) {
                    c = 0;
                    break;
                }
                break;
            case 3304:
                if (type.equals("go")) {
                    c = 1;
                    break;
                }
                break;
            case 3089282:
                if (type.equals("done")) {
                    c = 2;
                    break;
                }
                break;
            case 3377907:
                if (type.equals("next")) {
                    c = 3;
                    break;
                }
                break;
            case 3526536:
                if (type.equals("send")) {
                    c = 4;
                    break;
                }
                break;
            case 1544803905:
                if (type.equals("default")) {
                    c = 5;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                this.mEditorAction = 3;
                break;
            case 1:
                this.mEditorAction = 2;
                break;
            case 2:
                this.mEditorAction = 6;
                break;
            case 3:
                this.mEditorAction = 5;
                break;
            case 4:
                this.mEditorAction = 4;
                break;
            case 5:
                this.mEditorAction = 0;
                break;
        }
        blur();
        getHostView().setImeOptions(this.mEditorAction);
    }

    public void setPlaceholder(String placeholder) {
        if (placeholder == null || getHostView() == null) {
            return;
        }
        getHostView().setHint(placeholder);
        setPlaceholderStyle(this.placeholderStyle);
    }

    @WXComponentProp(name = Constants.Name.PLACEHOLDER_COLOR)
    public void setPlaceholderColor(String color) {
        int color2;
        if (getHostView() == null || TextUtils.isEmpty(color) || (color2 = WXResourceUtils.getColor(color)) == Integer.MIN_VALUE) {
            return;
        }
        getHostView().setHintTextColor(color2);
    }

    public void setType(String type) {
        Log.e("weex", "setType=" + type);
        if (type == null || getHostView() == null || this.mType.equals(type)) {
            return;
        }
        this.mType = type;
        getHostView().setInputType(getInputType(this.mType));
    }

    @WXComponentProp(name = Constants.Name.AUTOFOCUS)
    public void setAutofocus(final boolean autofocus) {
        if (getHostView() == null) {
            return;
        }
        final WXEditText hostView = getHostView();
        if (!this.isLayoutFinished.get()) {
            if (getInstance().isFrameViewShow()) {
                getHostView().getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.DCWXInput.8
                    @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
                    public void onGlobalLayout() {
                        if (DCWXInput.this.getInstance() == null) {
                            return;
                        }
                        if (autofocus) {
                            DCWXInput.this.isLayoutFinished.set(true);
                            DCWXInput.this.hostViewFocus(hostView);
                            DCWXInput dCWXInput = DCWXInput.this;
                            dCWXInput.setSelectionRange(dCWXInput.selectionStart, DCWXInput.this.selectionEnd);
                        } else {
                            hostView.clearFocus();
                        }
                        DCWXInput.this.getHostView().getViewTreeObserver().removeOnGlobalLayoutListener(this);
                    }
                });
                return;
            }
            if (this.mFrameViewEventListener != null) {
                getInstance().removeFrameViewEventListener(this.mFrameViewEventListener);
            }
            this.mFrameViewEventListener = new WXSDKInstance.FrameViewEventListener() { // from class: com.taobao.weex.ui.component.DCWXInput.9
                @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
                public void onShowAnimationEnd() {
                    if (DCWXInput.this.getInstance() == null) {
                        return;
                    }
                    if (autofocus) {
                        DCWXInput.this.isLayoutFinished.set(true);
                        DCWXInput.this.hostViewFocus(hostView);
                        DCWXInput dCWXInput = DCWXInput.this;
                        dCWXInput.setSelectionRange(dCWXInput.selectionStart, DCWXInput.this.selectionEnd);
                    } else {
                        hostView.clearFocus();
                    }
                    DCWXInput.this.getInstance().removeFrameViewEventListener(this);
                    DCWXInput.this.mFrameViewEventListener = null;
                }
            };
            getInstance().addFrameViewEventListener(this.mFrameViewEventListener);
            return;
        }
        if (autofocus) {
            hostViewFocus(hostView);
        } else {
            hideSoftKeyboard();
        }
        hostView.clearFocus();
    }

    @WXComponentProp(name = "adjustPosition")
    public void setAdjustPosition(Object value) {
        if (getHostView() != null) {
            getHostView().setInputSoftMode(WXUtils.getBoolean(value, true).booleanValue() ? DCKeyboardManager.SOFT_INPUT_MODE_ADJUST_PAN : DCKeyboardManager.SOFT_INPUT_MODE_ADJUST_NOTHING);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void hostViewFocus(EditText inputView) {
        inputView.setFocusable(true);
        inputView.setFocusableInTouchMode(true);
        inputView.setCursorVisible(true);
        inputView.requestFocus();
        showSoftKeyboard();
    }

    @WXComponentProp(name = "value")
    public void setText(String value) {
        WXEditText hostView = getHostView();
        if (hostView == null || TextUtils.equals(hostView.getText(), value)) {
            return;
        }
        this.mIgnoreNextOnInputEvent = true;
        hostView.setText(value);
        int i = this.cursor;
        if (i <= 0) {
            i = value.length();
        }
        if (value == null) {
            i = 0;
        }
        hostView.setSelection(i);
    }

    @WXComponentProp(name = "color")
    public void setColor(String color) {
        int color2;
        if (getHostView() == null || TextUtils.isEmpty(color) || (color2 = WXResourceUtils.getColor(color)) == Integer.MIN_VALUE) {
            return;
        }
        getHostView().setTextColor(color2);
    }

    @WXComponentProp(name = Constants.Name.FONT_SIZE)
    public void setFontSize(String fontSize) {
        if (getHostView() == null || fontSize == null) {
            return;
        }
        HashMap hashMap = new HashMap(1);
        hashMap.put(Constants.Name.FONT_SIZE, fontSize);
        getHostView().setTextSize(0, WXStyle.getFontSize(hashMap, getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat()));
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    @WXComponentProp(name = "placeholderStyle")
    public void setPlaceholderStyle(JSONObject styleStr1) {
        char c;
        JSONObject jSONObject = this.placeholderStyle;
        if (jSONObject == null || jSONObject.isEmpty()) {
            return;
        }
        CharSequence hint = getHostView().getHint();
        if (hint == null && getAttrs().containsKey(Constants.Name.PLACEHOLDER)) {
            hint = WXUtils.getString(getAttrs().get(Constants.Name.PLACEHOLDER), "");
        }
        SpannableString spannableString = new SpannableString(hint);
        AbsoluteSizeSpan absoluteSizeSpan = new AbsoluteSizeSpan((int) getHostView().getTextSize());
        ForegroundColorSpan foregroundColorSpan = new ForegroundColorSpan(getHostView().getCurrentHintTextColor());
        BackgroundColorSpan backgroundColorSpan = null;
        StyleSpan styleSpan = null;
        for (Map.Entry<String, Object> entry : this.placeholderStyle.entrySet()) {
            String key = entry.getKey();
            key.hashCode();
            char c2 = 65535;
            switch (key.hashCode()) {
                case -1586082113:
                    if (key.equals("font-size")) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -1065511464:
                    if (key.equals(Constants.Name.TEXT_ALIGN)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -734428249:
                    if (key.equals(Constants.Name.FONT_WEIGHT)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 94842723:
                    if (key.equals("color")) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case 365601008:
                    if (key.equals(Constants.Name.FONT_SIZE)) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                case 598800822:
                    if (key.equals("font-weight")) {
                        c = 5;
                        break;
                    }
                    c = 65535;
                    break;
                case 605322756:
                    if (key.equals("background-color")) {
                        c = 6;
                        break;
                    }
                    c = 65535;
                    break;
                case 746232421:
                    if (key.equals("text-align")) {
                        c = 7;
                        break;
                    }
                    c = 65535;
                    break;
                case 1287124693:
                    if (key.equals("backgroundColor")) {
                        c = '\b';
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                case 4:
                    String valueOf = String.valueOf(entry.getValue());
                    if (valueOf.endsWith("px")) {
                        valueOf = valueOf.replaceAll("px", "");
                    } else if (valueOf.endsWith("wx")) {
                        valueOf = valueOf.replaceAll("wx", "");
                    }
                    HashMap hashMap = new HashMap(1);
                    hashMap.put(Constants.Name.FONT_SIZE, valueOf);
                    absoluteSizeSpan = new AbsoluteSizeSpan(WXUtils.getInteger(Integer.valueOf(WXStyle.getFontSize(hashMap, getInstance().getDefaultFontSize(), getInstance().getInstanceViewPortWidthWithFloat())), Integer.valueOf(getInstance().getDefaultFontSize())).intValue());
                    break;
                case 1:
                case 7:
                    this.placeholderTextAlign = String.valueOf(entry.getValue());
                    int textAlign = getTextAlign(String.valueOf(entry.getValue()));
                    if (textAlign > 0) {
                        getHostView().setGravity(textAlign | getVerticalGravity());
                        break;
                    } else {
                        break;
                    }
                case 2:
                case 5:
                    String valueOf2 = String.valueOf(entry.getValue());
                    valueOf2.hashCode();
                    switch (valueOf2.hashCode()) {
                        case 53430:
                            if (valueOf2.equals("600")) {
                                c2 = 0;
                                break;
                            }
                            break;
                        case 54391:
                            if (valueOf2.equals("700")) {
                                c2 = 1;
                                break;
                            }
                            break;
                        case 55352:
                            if (valueOf2.equals("800")) {
                                c2 = 2;
                                break;
                            }
                            break;
                        case 56313:
                            if (valueOf2.equals("900")) {
                                c2 = 3;
                                break;
                            }
                            break;
                        case 3029637:
                            if (valueOf2.equals(Constants.Value.BOLD)) {
                                c2 = 4;
                                break;
                            }
                            break;
                    }
                    switch (c2) {
                        case 0:
                        case 1:
                        case 2:
                        case 3:
                        case 4:
                            styleSpan = new StyleSpan(1);
                            continue;
                        default:
                            styleSpan = new StyleSpan(0);
                            continue;
                    }
                case 3:
                    int color = WXResourceUtils.getColor(String.valueOf(entry.getValue()));
                    if (color != Integer.MIN_VALUE) {
                        foregroundColorSpan = new ForegroundColorSpan(color);
                        break;
                    } else {
                        break;
                    }
                case 6:
                case '\b':
                    int color2 = WXResourceUtils.getColor(String.valueOf(entry.getValue()));
                    if (color2 != Integer.MIN_VALUE) {
                        backgroundColorSpan = new BackgroundColorSpan(color2);
                        break;
                    } else {
                        break;
                    }
            }
        }
        spannableString.setSpan(absoluteSizeSpan, 0, spannableString.length(), 33);
        if (backgroundColorSpan != null) {
            spannableString.setSpan(backgroundColorSpan, 0, spannableString.length(), 33);
        }
        if (styleSpan != null) {
            spannableString.setSpan(styleSpan, 0, spannableString.length(), 33);
        }
        spannableString.setSpan(foregroundColorSpan, 0, spannableString.length(), 33);
        getHostView().setHint(spannableString);
    }

    @WXComponentProp(name = "placeholderClass")
    public void setPlaceholderClass(JSONObject styles) {
        setPlaceholderStyle(styles);
    }

    @WXComponentProp(name = Constants.Name.TEXT_ALIGN)
    public void setTextAlign(String textAlign) {
        this.textAlign = textAlign;
        int textAlign2 = getTextAlign(textAlign);
        if (textAlign2 > 0) {
            getHostView().setGravity(textAlign2 | getVerticalGravity());
        }
    }

    @WXComponentProp(name = Constants.Name.SINGLELINE)
    public void setSingleLine(boolean singleLine) {
        if (getHostView() == null) {
            return;
        }
        getHostView().setSingleLine(singleLine);
    }

    @WXComponentProp(name = Constants.Name.LINES)
    public void setLines(int lines) {
        if (getHostView() == null) {
            return;
        }
        getHostView().setLines(lines);
    }

    @WXComponentProp(name = Constants.Name.MAX_LENGTH)
    public void setMaxLength(int maxLength) {
        if (getHostView() == null) {
            return;
        }
        if (maxLength == -1) {
            maxLength = Integer.MAX_VALUE;
        }
        getHostView().setFilters(new InputFilter[]{new InputFilter.LengthFilter(maxLength)});
    }

    @WXComponentProp(name = Constants.Name.MAXLENGTH)
    @Deprecated
    public void setMaxlength(int maxLength) {
        setMaxLength(maxLength);
    }

    private int getInputType(String type) {
        type.hashCode();
        char c = 65535;
        switch (type.hashCode()) {
            case -1034364087:
                if (type.equals("number")) {
                    c = 0;
                    break;
                }
                break;
            case 114715:
                if (type.equals(Constants.Value.TEL)) {
                    c = 1;
                    break;
                }
                break;
            case 116079:
                if (type.equals("url")) {
                    c = 2;
                    break;
                }
                break;
            case 3076014:
                if (type.equals("date")) {
                    c = 3;
                    break;
                }
                break;
            case 3556653:
                if (type.equals("text")) {
                    c = 4;
                    break;
                }
                break;
            case 3560141:
                if (type.equals(Constants.Value.TIME)) {
                    c = 5;
                    break;
                }
                break;
            case 95582509:
                if (type.equals("digit")) {
                    c = 6;
                    break;
                }
                break;
            case 96619420:
                if (type.equals("email")) {
                    c = 7;
                    break;
                }
                break;
            case 1216985755:
                if (type.equals(Constants.Value.PASSWORD)) {
                    c = '\b';
                    break;
                }
                break;
            case 1793702779:
                if (type.equals(Constants.Value.DATETIME)) {
                    c = '\t';
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                return 2;
            case 1:
                return 3;
            case 2:
                return 17;
            case 3:
                getHostView().setFocusable(false);
                break;
            case 4:
            default:
                return 1;
            case 5:
                if (getHostView() != null) {
                    getHostView().setFocusable(false);
                    break;
                }
                break;
            case 6:
                return 8194;
            case 7:
                return 33;
            case '\b':
                if (getHostView() != null) {
                    getHostView().setTransformationMethod(PasswordTransformationMethod.getInstance());
                    return 129;
                }
                return 129;
            case '\t':
                return 4;
        }
        return 0;
    }

    @WXComponentProp(name = UniConstants.Name.CURSOR_SPACING)
    public void setCursorSpacing(String v) {
        if (getHostView() != null) {
            getHostView().setCursorSpacing(UniViewUtils.getRealPxByWidth(UniUtils.getFloat(v), getInstance().getInstanceViewPortWidthWithFloat()));
        }
    }

    private void showSoftKeyboard() {
        if (getHostView() == null) {
            return;
        }
        getHostView().postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXInput.10
            @Override // java.lang.Runnable
            public void run() {
                DCWXInput.this.mInputMethodManager.showSoftInput(DCWXInput.this.getHostView(), 1);
            }
        }), 100L);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void hideSoftKeyboard() {
        if (getHostView() != null) {
            getHostView().postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXInput.11
                @Override // java.lang.Runnable
                public void run() {
                    DCWXInput.this.mInputMethodManager.hideSoftInputFromWindow(DCWXInput.this.getHostView().getWindowToken(), 0);
                }
            }), 16L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public int getTextAlign(String textAlign) {
        int i = isLayoutRTL() ? GravityCompat.END : GravityCompat.START;
        if (TextUtils.isEmpty(textAlign)) {
            return i;
        }
        textAlign.hashCode();
        char c = 65535;
        switch (textAlign.hashCode()) {
            case -1364013995:
                if (textAlign.equals("center")) {
                    c = 0;
                    break;
                }
                break;
            case 3317767:
                if (textAlign.equals("left")) {
                    c = 1;
                    break;
                }
                break;
            case 108511772:
                if (textAlign.equals("right")) {
                    c = 2;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                return 17;
            case 1:
                return GravityCompat.START;
            case 2:
                return GravityCompat.END;
            default:
                return i;
        }
    }

    @JSMethod
    public void blur() {
        WXEditText hostView = getHostView();
        if (hostView == null || !hostView.hasFocus()) {
            return;
        }
        if (getParent() != null) {
            getParent().interceptFocus();
        }
        hostView.clearFocus();
        hideSoftKeyboard();
    }

    public String getValue() {
        return getHostView().getText().toString();
    }

    @JSMethod
    public void setValue(String text) {
        getHostView().setText(text);
    }

    @JSMethod
    public void focus() {
        WXEditText hostView = getHostView();
        if (hostView == null || hostView.hasFocus()) {
            return;
        }
        if (getParent() != null) {
            getParent().ignoreFocus();
        }
        hostView.requestFocus();
        hostView.setFocusable(true);
        hostView.setFocusableInTouchMode(true);
        showSoftKeyboard();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public Object convertEmptyProperty(String propName, Object originalValue) {
        propName.hashCode();
        if (propName.equals("color")) {
            return "black";
        }
        if (propName.equals(Constants.Name.FONT_SIZE)) {
            return Integer.valueOf(getInstance().getDefaultFontSize());
        }
        return super.convertEmptyProperty(propName, originalValue);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void decideSoftKeyboard() {
        WXEditText hostView = getHostView();
        if (hostView != null) {
            final Context context = getContext();
            if (context instanceof Activity) {
                hostView.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.DCWXInput.12
                    @Override // java.lang.Runnable
                    public void run() {
                        View currentFocus = ((Activity) context).getCurrentFocus();
                        if (currentFocus == null || (currentFocus instanceof EditText) || currentFocus.isFocused()) {
                            return;
                        }
                        DCWXInput.this.mInputMethodManager.hideSoftInputFromWindow(DCWXInput.this.getHostView().getWindowToken(), 0);
                    }
                }), 16L);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void setSelectionRange(int selectionStart, int selectionEnd) {
        WXEditText hostView;
        if (selectionEnd == Integer.MAX_VALUE || selectionStart == Integer.MAX_VALUE || (hostView = getHostView()) == null) {
            return;
        }
        int length = getHostView().length();
        if (selectionStart > selectionEnd) {
            return;
        }
        if (selectionStart < 0) {
            selectionStart = 0;
        }
        if (selectionEnd > length) {
            selectionEnd = length;
        }
        hostView.setSelection(selectionStart, selectionEnd >= 0 ? selectionEnd : 0);
    }

    @UniJSMethod
    public void getSelectionRange(String callbackId) {
        HashMap hashMap = new HashMap(2);
        WXEditText hostView = getHostView();
        if (hostView != null) {
            int selectionStart = hostView.getSelectionStart();
            int selectionEnd = hostView.getSelectionEnd();
            if (!hostView.hasFocus()) {
                selectionStart = 0;
                selectionEnd = 0;
            }
            hashMap.put(Constants.Name.SELECTION_START, Integer.valueOf(selectionStart));
            hashMap.put(Constants.Name.SELECTION_END, Integer.valueOf(selectionEnd));
        }
        WXBridgeManager.getInstance().callback(getInstanceId(), callbackId, hashMap, false);
    }

    @UniJSMethod
    public void getCursor(JSCallback callback) {
        HashMap hashMap = new HashMap(1);
        if (getHostView() != null && getHostView().isFocused()) {
            hashMap.put("cursor", Integer.valueOf(getHostView().getSelectionEnd()));
        } else {
            hashMap.put("cursor", 0);
        }
        callback.invoke(hashMap);
    }

    @JSMethod
    public void setTextFormatter(JSONObject params) {
        try {
            String string = params.getString("formatRule");
            String string2 = params.getString("formatReplace");
            String string3 = params.getString("recoverRule");
            String string4 = params.getString("recoverReplace");
            PatternWrapper parseToPattern = parseToPattern(string, string2);
            PatternWrapper parseToPattern2 = parseToPattern(string3, string4);
            if (parseToPattern == null || parseToPattern2 == null) {
                return;
            }
            this.mFormatter = new TextFormatter(parseToPattern, parseToPattern2);
        } catch (Throwable th) {
            th.printStackTrace();
        }
    }

    private final void addEditorActionListener(TextView.OnEditorActionListener listener) {
        WXEditText hostView;
        if (listener == null || (hostView = getHostView()) == null) {
            return;
        }
        if (this.mEditorActionListeners == null) {
            this.mEditorActionListeners = new ArrayList();
            hostView.setOnEditorActionListener(new TextView.OnEditorActionListener() { // from class: com.taobao.weex.ui.component.DCWXInput.13
                private boolean handled = true;

                @Override // android.widget.TextView.OnEditorActionListener
                public boolean onEditorAction(TextView v, int actionId, KeyEvent event) {
                    for (TextView.OnEditorActionListener onEditorActionListener : DCWXInput.this.mEditorActionListeners) {
                        if (onEditorActionListener != null) {
                            this.handled = onEditorActionListener.onEditorAction(v, actionId, event) & this.handled;
                        }
                    }
                    return this.handled;
                }
            });
        }
        this.mEditorActionListeners.add(listener);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public void addTextChangedListener(TextWatcher watcher) {
        if (this.mTextChangedListeners == null) {
            this.mTextChangedListeners = new ArrayList();
        }
        this.mTextChangedListeners.add(watcher);
    }

    private void addKeyboardListener(final WXEditText host) {
        if (host != null && (host.getContext() instanceof Activity)) {
            getHostView().setkeyBoardHeightChangeListener(new DCEditText.OnKeyboardHeightChangeListener() { // from class: com.taobao.weex.ui.component.DCWXInput.14
                @Override // io.dcloud.common.core.ui.keyboard.DCEditText.OnKeyboardHeightChangeListener
                public void onChange(boolean isShown, int keyBoardHeight) {
                    if (DCWXInput.this.getInstance() == null || DCWXInput.this.getInstance().isDestroy() || host == null) {
                        return;
                    }
                    DCWXInput dCWXInput = DCWXInput.this;
                    dCWXInput.keyboardHeight = (int) WXViewUtils.getWebPxByWidth(keyBoardHeight, dCWXInput.getInstance().getInstanceViewPortWidthWithFloat());
                    HashMap hashMap = new HashMap(2);
                    hashMap.put("height", Float.valueOf(DCWXInput.this.keyboardHeight));
                    hashMap.put("duration", 0);
                    HashMap hashMap2 = new HashMap(1);
                    hashMap2.put("detail", hashMap);
                    DCWXInput.this.fireEvent("keyboardheightchange", hashMap2);
                    if (host.isFocused()) {
                        String str = DCWXInput.this.isPassword ? Constants.Value.PASSWORD : DCWXInput.this.mType;
                        if (!isShown && !DCWXInput.this.isConfirmHold && !str.equalsIgnoreCase(Constants.Value.PASSWORD) && !DCKeyboardManager.getInstance().getFrontInputType().equals(Constants.Value.PASSWORD)) {
                            DCWXInput.this.blur();
                        }
                        if (isShown) {
                            DCKeyboardManager.getInstance().setFrontInputType(str);
                        }
                    }
                    if (isShown) {
                        DCWXInput dCWXInput2 = DCWXInput.this;
                        dCWXInput2.keyboardHeight = dCWXInput2.keyboardHeight;
                    }
                }
            });
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        String str;
        if (props != null && props.size() > 0) {
            setType(props.containsKey("type") ? String.valueOf(props.get("type")) : this.mType);
            String str2 = this.mType;
            if (str2 != null && str2.equals("text") && props.containsKey("confirmType")) {
                if (props.containsKey("confirmType")) {
                    str = String.valueOf(props.get("confirmType"));
                } else {
                    str = this.mReturnKeyType;
                    if (str == null) {
                        str = "done";
                    }
                }
                setReturnKeyType(str);
            }
            WXAttr attrs = getAttrs();
            String str3 = Constants.Value.PASSWORD;
            if (attrs.containsKey(Constants.Value.PASSWORD)) {
                boolean booleanValue = WXUtils.getBoolean(getAttrs().get(Constants.Value.PASSWORD), false).booleanValue();
                this.isPassword = booleanValue;
                if (!booleanValue) {
                    str3 = this.mType;
                }
                if (str3 == null || getHostView() == null) {
                    return;
                }
                getHostView().setInputType(getInputType(str3));
            }
            if (props.containsKey("cursor")) {
                this.cursor = WXUtils.getInteger(props.get("cursor"), 0).intValue();
            }
            if (props.containsKey(Constants.Name.SELECTION_START)) {
                this.selectionStart = WXUtils.getInteger(props.get(Constants.Name.SELECTION_START), Integer.MAX_VALUE).intValue();
            }
            if (props.containsKey(Constants.Name.SELECTION_END)) {
                this.selectionEnd = WXUtils.getInteger(props.get(Constants.Name.SELECTION_END), Integer.MAX_VALUE).intValue();
            }
            if (props.containsKey(Constants.Name.PLACEHOLDER)) {
                setPlaceholder(WXUtils.getString(props.get(Constants.Name.PLACEHOLDER), ""));
            }
            if (props.containsKey("placeholderClass")) {
                this.placeholderStyle.putAll((JSONObject) JSONObject.parse(WXUtils.getString(props.get("placeholderClass"), "{}")));
            }
            if (props.containsKey("placeholderStyle")) {
                this.placeholderStyle.putAll((JSONObject) JSONObject.parse(WXUtils.getString(props.get("placeholderStyle"), "{}")));
            }
            if (props.containsKey("adjustPosition")) {
                setAdjustPosition(props.get("adjustPosition"));
            }
        }
        super.updateProperties(props);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        List<TextView.OnEditorActionListener> list = this.mEditorActionListeners;
        if (list != null) {
            list.clear();
        }
        List<TextWatcher> list2 = this.mTextChangedListeners;
        if (list2 != null) {
            list2.clear();
        }
        if (this.mTextChangedEventDispatcher != null) {
            this.mTextChangedEventDispatcher = null;
        }
        if (getHostView() != null) {
            getHostView().destroy();
        }
    }

    private PatternWrapper parseToPattern(String jsPattern, String replace) {
        Pattern pattern;
        if (jsPattern == null || replace == null) {
            return null;
        }
        if (!Pattern.compile("/[\\S]+/[i]?[m]?[g]?").matcher(jsPattern).matches()) {
            WXLogUtils.w("WXInput", "Illegal js pattern syntax: " + jsPattern);
            return null;
        }
        String substring = jsPattern.substring(jsPattern.lastIndexOf("/") + 1);
        String substring2 = jsPattern.substring(jsPattern.indexOf("/") + 1, jsPattern.lastIndexOf("/"));
        int i = substring.contains(ContextChain.TAG_INFRA) ? 2 : 0;
        if (substring.contains(WXComponent.PROP_FS_MATCH_PARENT)) {
            i |= 32;
        }
        boolean contains = substring.contains("g");
        try {
            pattern = Pattern.compile(substring2, i);
        } catch (PatternSyntaxException unused) {
            WXLogUtils.w("WXInput", "Pattern syntax error: " + substring2);
            pattern = null;
        }
        if (pattern == null) {
            return null;
        }
        PatternWrapper patternWrapper = new PatternWrapper();
        patternWrapper.global = contains;
        patternWrapper.matcher = pattern;
        patternWrapper.replace = replace;
        return patternWrapper;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class PatternWrapper {
        private boolean global;
        private Pattern matcher;
        private String replace;

        private PatternWrapper() {
            this.global = false;
        }
    }

    /* loaded from: classes.dex */
    public static class TextFormatter {
        private PatternWrapper format;
        private PatternWrapper recover;

        private TextFormatter(PatternWrapper format, PatternWrapper recover) {
            this.format = format;
            this.recover = recover;
        }

        String format(String src) {
            try {
                PatternWrapper patternWrapper = this.format;
                if (patternWrapper != null) {
                    return patternWrapper.global ? this.format.matcher.matcher(src).replaceAll(this.format.replace) : this.format.matcher.matcher(src).replaceFirst(this.format.replace);
                }
            } catch (Throwable th) {
                WXLogUtils.w("WXInput", "[format] " + th.getMessage());
            }
            return src;
        }

        String recover(String formatted) {
            try {
                PatternWrapper patternWrapper = this.recover;
                if (patternWrapper != null) {
                    return patternWrapper.global ? this.recover.matcher.matcher(formatted).replaceAll(this.recover.replace) : this.recover.matcher.matcher(formatted).replaceFirst(this.recover.replace);
                }
            } catch (Throwable th) {
                WXLogUtils.w("WXInput", "[formatted] " + th.getMessage());
            }
            return formatted;
        }
    }
}
