package com.taobao.weex.ui.component;

import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.WXEditText;
import com.taobao.weex.utils.WXUtils;
/* loaded from: classes.dex */
public class Textarea extends AbstractEditComponent {
    public static final int DEFAULT_ROWS = 2;
    private int mNumberOfLines;

    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    protected int getVerticalGravity() {
        return 48;
    }

    public Textarea(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
        super(instance, parent, isLazy, basicComponentData);
        this.mNumberOfLines = 2;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.AbstractEditComponent, com.taobao.weex.ui.component.WXComponent
    public void onHostViewInitialized(WXEditText host) {
        host.setAllowDisableMovement(false);
        super.onHostViewInitialized(host);
    }

    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    protected void appleStyleAfterCreated(WXEditText editText) {
        super.appleStyleAfterCreated(editText);
        String str = (String) getStyles().get(Constants.Name.ROWS);
        int i = 2;
        try {
            if (!TextUtils.isEmpty(str)) {
                i = Integer.parseInt(str);
            }
        } catch (NumberFormatException e) {
            e.printStackTrace();
        }
        editText.setLines(i);
        editText.setMinLines(i);
    }

    @Override // com.taobao.weex.ui.component.AbstractEditComponent, com.taobao.weex.ui.component.WXComponent
    protected boolean setProperty(String key, Object param) {
        key.hashCode();
        if (key.equals(Constants.Name.ROWS)) {
            Integer integer = WXUtils.getInteger(param, null);
            if (integer != null) {
                setRows(integer.intValue());
                return true;
            }
            return true;
        }
        return super.setProperty(key, param);
    }

    @WXComponentProp(name = Constants.Name.ROWS)
    public void setRows(int rows) {
        WXEditText hostView = getHostView();
        if (hostView == null || rows <= 0) {
            return;
        }
        hostView.setLines(rows);
    }

    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    protected float getMeasureHeight() {
        return getMeasuredLineHeight() * this.mNumberOfLines;
    }

    @Override // com.taobao.weex.ui.component.AbstractEditComponent
    protected void updateStyleAndAttrs() {
        super.updateStyleAndAttrs();
        Object obj = getAttrs().get(Constants.Name.ROWS);
        if (obj == null) {
            return;
        }
        if (obj instanceof String) {
            try {
                int parseInt = Integer.parseInt((String) obj);
                if (parseInt > 0) {
                    this.mNumberOfLines = parseInt;
                }
            } catch (NumberFormatException e) {
                e.printStackTrace();
            }
        } else if (obj instanceof Integer) {
            this.mNumberOfLines = ((Integer) obj).intValue();
        }
    }
}
