package com.taobao.weex.ui.component;

import android.app.Activity;
import android.content.Context;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.text.TextUtils;
import android.view.ViewGroup;
import android.widget.ImageView;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.WXImageSharpen;
import com.taobao.weex.common.WXImageStrategy;
import com.taobao.weex.common.WXRuntimeException;
import com.taobao.weex.dom.WXImageQuality;
import com.taobao.weex.performance.WXAnalyzerDataTransfer;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.WXImageView;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.ImageDrawable;
import com.taobao.weex.utils.ImgURIUtil;
import com.taobao.weex.utils.SingleFunctionParser;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewToImageUtil;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.DHInterface.IApp;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import java.lang.ref.WeakReference;
import java.lang.reflect.InvocationTargetException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
@Component(lazyload = false)
/* loaded from: classes.dex */
public class WXImage extends WXComponent<ImageView> {
    private static SingleFunctionParser.FlatMapper<Integer> BLUR_RADIUS_MAPPER = new SingleFunctionParser.FlatMapper<Integer>() { // from class: com.taobao.weex.ui.component.WXImage.1
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // com.taobao.weex.utils.SingleFunctionParser.FlatMapper
        public Integer map(String raw) {
            return WXUtils.getInteger(raw, 0);
        }
    };
    public static final String ERRORDESC = "errorDesc";
    public static final String SUCCEED = "success";
    private static final int WRITE_EXTERNAL_STORAGE_PERMISSION_REQUEST_CODE = 2;
    private boolean mAutoRecycle;
    private int mBlurRadius;
    private WXSDKInstance.FrameViewEventListener mFrameViewEventListener;
    protected boolean mIsUni;
    private String mSrc;
    private String preImgUrlStr;

    /* loaded from: classes.dex */
    public interface Measurable {
        int getNaturalHeight();

        int getNaturalWidth();
    }

    public void onImageFinish(boolean result, Map extra) {
    }

    /* loaded from: classes.dex */
    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXImage(instance, parent, basicComponentData);
        }
    }

    @Deprecated
    public WXImage(WXSDKInstance instance, WXVContainer parent, String instanceId, boolean isLazy, BasicComponentData basicComponentData) {
        this(instance, parent, basicComponentData);
    }

    public WXImage(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mAutoRecycle = true;
        this.mIsUni = false;
        this.preImgUrlStr = "";
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public ImageView initComponentHostView(Context context) {
        WXImageView wXImageView = new WXImageView(context);
        wXImageView.setScaleType(ImageView.ScaleType.FIT_XY);
        if (Build.VERSION.SDK_INT >= 16) {
            wXImageView.setCropToPadding(true);
        }
        wXImageView.holdComponent(this);
        return wXImageView;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        int i = 0;
        char c = 65535;
        switch (key.hashCode()) {
            case -1285653259:
                if (key.equals(Constants.Name.AUTO_RECYCLE)) {
                    c = 0;
                    break;
                }
                break;
            case -1274492040:
                if (key.equals(Constants.Name.FILTER)) {
                    c = 1;
                    break;
                }
                break;
            case -934437708:
                if (key.equals("resize")) {
                    c = 2;
                    break;
                }
                break;
            case 114148:
                if (key.equals("src")) {
                    c = 3;
                    break;
                }
                break;
            case 1249477412:
                if (key.equals(Constants.Name.IMAGE_QUALITY)) {
                    c = 4;
                    break;
                }
                break;
            case 2049757303:
                if (key.equals(Constants.Name.RESIZE_MODE)) {
                    c = 5;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                boolean booleanValue = WXUtils.getBoolean(param, Boolean.valueOf(this.mAutoRecycle)).booleanValue();
                this.mAutoRecycle = booleanValue;
                if (!booleanValue && getInstance() != null) {
                    getInstance().getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_IMG_UN_RECYCLE_NUM, 1.0d);
                }
                return true;
            case 1:
                if (param != null && (param instanceof String)) {
                    i = parseBlurRadius((String) param);
                }
                if (!TextUtils.isEmpty(this.mSrc)) {
                    setBlurRadius(this.mSrc, i);
                }
                return true;
            case 2:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setResize(string);
                }
                return true;
            case 3:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setSrc(string2);
                }
                return true;
            case 4:
                break;
            case 5:
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setResizeMode(string3);
                    break;
                }
                break;
            default:
                return super.setProperty(key, param);
        }
        return true;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void refreshData(WXComponent component) {
        super.refreshData(component);
        if (component instanceof WXImage) {
            setSrc(component.getAttrs().getImageSrc());
        }
    }

    @WXComponentProp(name = Constants.Name.RESIZE_MODE)
    public void setResizeMode(String resizeMode) {
        getHostView().setScaleType(getResizeMode(resizeMode));
        getHostView().setImageDrawable(getHostView().getDrawable());
    }

    protected ImageView.ScaleType getResizeMode(String resizeMode) {
        ImageView.ScaleType scaleType = ImageView.ScaleType.FIT_XY;
        if (TextUtils.isEmpty(resizeMode)) {
            return scaleType;
        }
        resizeMode.hashCode();
        char c = 65535;
        switch (resizeMode.hashCode()) {
            case -1881872635:
                if (resizeMode.equals("stretch")) {
                    c = 0;
                    break;
                }
                break;
            case 94852023:
                if (resizeMode.equals(IApp.ConfigProperty.CONFIG_COVER)) {
                    c = 1;
                    break;
                }
                break;
            case 951526612:
                if (resizeMode.equals("contain")) {
                    c = 2;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                return ImageView.ScaleType.FIT_XY;
            case 1:
                return ImageView.ScaleType.CENTER_CROP;
            case 2:
                return ImageView.ScaleType.FIT_CENTER;
            default:
                return scaleType;
        }
    }

    @WXComponentProp(name = "resize")
    public void setResize(String resize) {
        setResizeMode(resize);
    }

    private void setLocalSrc(Uri rewrited) {
        ImageView hostView;
        Drawable drawableFromLoaclSrc = ImgURIUtil.getDrawableFromLoaclSrc(getContext(), rewrited);
        if (drawableFromLoaclSrc == null || (hostView = getHostView()) == null) {
            return;
        }
        hostView.setImageDrawable(drawableFromLoaclSrc);
    }

    @WXComponentProp(name = "src")
    public void setSrc(final String src) {
        runSrc(src);
    }

    private void runSrc(String src) {
        if (getHostView() == null || getInstance() == null) {
            return;
        }
        if (getInstance().getImageNetworkHandler() != null) {
            String fetchLocal = getInstance().getImageNetworkHandler().fetchLocal(src);
            if (!TextUtils.isEmpty(fetchLocal)) {
                src = fetchLocal;
            }
        }
        if (PdrUtil.isEmpty(src)) {
            return;
        }
        ImageView hostView = getHostView();
        if (hostView != null && hostView.getDrawable() != null && !TextUtils.equals(this.mSrc, src)) {
            hostView.setImageDrawable(null);
        }
        this.mSrc = src;
        Uri rewriteUri = getInstance().rewriteUri(Uri.parse(src), "image");
        if (Constants.Scheme.LOCAL.equals(rewriteUri.getScheme())) {
            setLocalSrc(rewriteUri);
        } else {
            setRemoteSrc(rewriteUri, parseBlurRadius(getStyles().getBlur()));
        }
    }

    private void setBlurRadius(String src, int blurRadius) {
        if (getInstance() == null || blurRadius == this.mBlurRadius) {
            return;
        }
        Uri rewriteUri = getInstance().rewriteUri(Uri.parse(src), "image");
        if (Constants.Scheme.LOCAL.equals(rewriteUri.getScheme())) {
            return;
        }
        setRemoteSrc(rewriteUri, blurRadius);
    }

    private int parseBlurRadius(String rawRadius) {
        if (rawRadius == null) {
            return 0;
        }
        try {
            List parse = new SingleFunctionParser(rawRadius, BLUR_RADIUS_MAPPER).parse(Constants.Event.BLUR);
            if (parse != null && !parse.isEmpty()) {
                return ((Integer) parse.get(0)).intValue();
            }
        } catch (Exception unused) {
        }
        return 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void recycled() {
        super.recycled();
        if (getHostView() != null && getInstance() != null && getInstance().getImgLoaderAdapter() != null) {
            getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
        } else if (WXEnvironment.isApkDebugable()) {
            throw new WXRuntimeException("getImgLoaderAdapter() == null");
        } else {
            WXLogUtils.e("Error getImgLoaderAdapter() == null");
        }
    }

    public void autoReleaseImage() {
        if (!this.mAutoRecycle || getHostView() == null || getInstance() == null || getInstance().getImgLoaderAdapter() == null) {
            return;
        }
        getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
    }

    public void autoRecoverImage() {
        if (this.mAutoRecycle) {
            setSrc(this.mSrc);
        }
    }

    private void setRemoteSrc(Uri rewrited, int blurRadius) {
        WXImageStrategy wXImageStrategy = new WXImageStrategy(getInstanceId());
        wXImageStrategy.isClipping = true;
        wXImageStrategy.isSharpen = getAttrs().getImageSharpen() == WXImageSharpen.SHARPEN;
        wXImageStrategy.blurRadius = Math.max(0, blurRadius);
        this.mBlurRadius = blurRadius;
        String uri = rewrited.toString();
        wXImageStrategy.setImageListener(new MyImageListener(this, uri));
        if (getAttrs().containsKey("autoCompression")) {
            wXImageStrategy.setAutoCompression(WXUtils.getBoolean(getAttrs().get("autoCompression"), true).booleanValue());
        }
        String str = null;
        if (getAttrs().containsKey(Constants.Name.PLACEHOLDER)) {
            str = (String) getAttrs().get(Constants.Name.PLACEHOLDER);
        } else if (getAttrs().containsKey(Constants.Name.PLACE_HOLDER)) {
            str = (String) getAttrs().get(Constants.Name.PLACE_HOLDER);
        }
        if (str != null) {
            wXImageStrategy.placeHolder = getInstance().rewriteUri(Uri.parse(str), "image").toString();
        }
        wXImageStrategy.instanceId = getInstanceId();
        setImage(uri, wXImageStrategy);
    }

    protected void setImage(String rewritedStr, WXImageStrategy imageStrategy) {
        IWXImgLoaderAdapter imgLoaderAdapter = getInstance().getImgLoaderAdapter();
        if (imgLoaderAdapter != null) {
            imgLoaderAdapter.setImage(rewritedStr, getHostView(), getImageQuality(), imageStrategy);
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public WXImageQuality getImageQuality() {
        return getAttrs().getImageQuality();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void onFinishLayout() {
        super.onFinishLayout();
        updateBorderRadius();
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        updateBorderRadius();
    }

    private void updateBorderRadius() {
        if (getHostView() instanceof WXImageView) {
            WXImageView wXImageView = (WXImageView) getHostView();
            BorderDrawable borderDrawable = WXViewUtils.getBorderDrawable(getHostView());
            float[] borderInnerRadius = borderDrawable != null ? borderDrawable.getBorderInnerRadius(new RectF(0.0f, 0.0f, WXDomUtils.getContentWidth(this), WXDomUtils.getContentHeight(this))) : new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f};
            wXImageView.setBorderRadius(borderInnerRadius);
            if (wXImageView.getDrawable() instanceof ImageDrawable) {
                ImageDrawable imageDrawable = (ImageDrawable) wXImageView.getDrawable();
                if (Arrays.equals(imageDrawable.getCornerRadii(), borderInnerRadius)) {
                    return;
                }
                imageDrawable.setCornerRadii(borderInnerRadius);
            }
        }
    }

    @JSMethod(uiThread = false)
    public void save(final JSCallback saveStatuCallback) {
        if (ContextCompat.checkSelfPermission(getContext(), "android.permission.WRITE_EXTERNAL_STORAGE") != 0 && (getContext() instanceof Activity)) {
            ActivityCompat.requestPermissions((Activity) getContext(), new String[]{"android.permission.WRITE_EXTERNAL_STORAGE"}, 2);
        }
        if (ContextCompat.checkSelfPermission(getContext(), "android.permission.WRITE_EXTERNAL_STORAGE") != 0) {
            if (saveStatuCallback != null) {
                HashMap hashMap = new HashMap();
                hashMap.put(SUCCEED, false);
                hashMap.put(ERRORDESC, "Permission denied: android.permission.WRITE_EXTERNAL_STORAGE");
                saveStatuCallback.invoke(hashMap);
            }
        } else if (this.mHost == 0) {
            if (saveStatuCallback != null) {
                HashMap hashMap2 = new HashMap();
                hashMap2.put(SUCCEED, false);
                hashMap2.put(ERRORDESC, "Image component not initialized");
                saveStatuCallback.invoke(hashMap2);
            }
        } else {
            String str = this.mSrc;
            if (str != null && !str.equals("")) {
                WXViewToImageUtil.generateImage(this.mHost, 0, -460552, new WXViewToImageUtil.OnImageSavedCallback() { // from class: com.taobao.weex.ui.component.WXImage.2
                    @Override // com.taobao.weex.utils.WXViewToImageUtil.OnImageSavedCallback
                    public void onSaveSucceed(String path) {
                        if (saveStatuCallback != null) {
                            HashMap hashMap3 = new HashMap();
                            hashMap3.put(WXImage.SUCCEED, true);
                            saveStatuCallback.invoke(hashMap3);
                        }
                    }

                    @Override // com.taobao.weex.utils.WXViewToImageUtil.OnImageSavedCallback
                    public void onSaveFailed(String errorDesc) {
                        if (saveStatuCallback != null) {
                            HashMap hashMap3 = new HashMap();
                            hashMap3.put(WXImage.SUCCEED, false);
                            hashMap3.put(WXImage.ERRORDESC, errorDesc);
                            saveStatuCallback.invoke(hashMap3);
                        }
                    }
                });
            } else if (saveStatuCallback != null) {
                HashMap hashMap3 = new HashMap();
                hashMap3.put(SUCCEED, false);
                hashMap3.put(ERRORDESC, "Image does not have the correct src");
                saveStatuCallback.invoke(hashMap3);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void monitorImgSize(ImageView imageView, String currentImgUrlStr) {
        WXSDKInstance wXImage;
        if (imageView == null || (wXImage = getInstance()) == null) {
            return;
        }
        ViewGroup.LayoutParams layoutParams = imageView.getLayoutParams();
        Drawable drawable = imageView.getDrawable();
        if (layoutParams == null || drawable == null) {
            return;
        }
        int intrinsicHeight = drawable.getIntrinsicHeight();
        int intrinsicWidth = drawable.getIntrinsicWidth();
        if (this.preImgUrlStr.equals(currentImgUrlStr)) {
            return;
        }
        this.preImgUrlStr = currentImgUrlStr;
        if (intrinsicHeight > 1081 && intrinsicWidth > 721) {
            wXImage.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_LARGE_IMG_COUNT, 1.0d);
            if (WXAnalyzerDataTransfer.isOpenPerformance) {
                WXAnalyzerDataTransfer.transferPerformance(getInstanceId(), "details", WXInstanceApm.KEY_PAGE_STATS_LARGE_IMG_COUNT, intrinsicWidth + "*" + intrinsicHeight + "," + currentImgUrlStr);
            }
        }
        long j = intrinsicHeight * intrinsicWidth;
        long measuredHeight = imageView.getMeasuredHeight() * imageView.getMeasuredWidth();
        if (measuredHeight == 0) {
            return;
        }
        double d = j;
        double d2 = measuredHeight;
        Double.isNaN(d);
        Double.isNaN(d2);
        if (d / d2 <= 1.2d || j - measuredHeight <= 1600) {
            return;
        }
        wXImage.getWXPerformance().wrongImgSizeCount += 1.0d;
        wXImage.getApmForInstance().updateDiffStats(WXInstanceApm.KEY_PAGE_STATS_WRONG_IMG_SIZE_COUNT, 1.0d);
        if (WXAnalyzerDataTransfer.isOpenPerformance) {
            WXAnalyzerDataTransfer.transferPerformance(getInstanceId(), "details", WXInstanceApm.KEY_PAGE_STATS_WRONG_IMG_SIZE_COUNT, StringUtil.format("imgSize:[%d,%d],viewSize:[%d,%d],urL:%s", Integer.valueOf(intrinsicWidth), Integer.valueOf(intrinsicHeight), Integer.valueOf(imageView.getMeasuredWidth()), Integer.valueOf(imageView.getMeasuredHeight()), currentImgUrlStr));
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (getHostView() != null && getInstance() != null && (getHostView() instanceof WXImageView) && getInstance().getImgLoaderAdapter() != null) {
            getInstance().getImgLoaderAdapter().setImage(null, (ImageView) this.mHost, null, null);
        }
        super.destroy();
    }

    /* loaded from: classes.dex */
    public class MyImageListener implements WXImageStrategy.ImageListener {
        private String rewritedStr;
        private WeakReference<WXImage> wxImageWeakReference;

        MyImageListener(WXImage image, String rewritedStr) {
            this.wxImageWeakReference = new WeakReference<>(image);
            this.rewritedStr = rewritedStr;
        }

        @Override // com.taobao.weex.common.WXImageStrategy.ImageListener
        public void onImageFinish(String url, ImageView imageView, boolean result, Map extra) {
            WXImage wXImage = this.wxImageWeakReference.get();
            if (wXImage == null) {
                return;
            }
            if (extra == null) {
                HashMap hashMap = new HashMap();
                hashMap.put(WXImage.SUCCEED, false);
                wXImage.fireEvent("error", hashMap);
                return;
            }
            wXImage.onImageFinish(result, extra);
            HashMap hashMap2 = new HashMap();
            HashMap hashMap3 = new HashMap(2);
            hashMap3.put("width", extra.get("width"));
            hashMap3.put("height", extra.get("height"));
            if (WXImage.this.mIsUni) {
                if (!result && wXImage.containsEvent("error")) {
                    hashMap2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                    hashMap2.put("detail", hashMap3);
                    wXImage.fireEvent("error", hashMap2);
                }
                if (result && wXImage.containsEvent("load")) {
                    hashMap2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                    hashMap2.put("detail", hashMap3);
                    wXImage.fireEvent("load", hashMap2);
                }
            } else if (wXImage.containsEvent("load")) {
                hashMap2.put(WXImage.SUCCEED, Boolean.valueOf(result));
                hashMap2.put("detail", hashMap3);
                wXImage.fireEvent("load", hashMap2);
            }
            wXImage.monitorImgSize(imageView, this.rewritedStr);
        }
    }
}
