package com.taobao.weex.ui.component;

import android.content.Context;
import android.text.TextUtils;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.WXThread;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.view.BaseFrameLayout;
import com.taobao.weex.ui.view.WXCircleIndicator;
import com.taobao.weex.ui.view.WXCirclePageAdapter;
import com.taobao.weex.ui.view.WXCircleViewPager;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.lang.reflect.InvocationTargetException;
import java.util.List;
/* loaded from: classes.dex */
public class WXSliderNeighbor extends WXSlider {
    public static final String CURRENT_ITEM_SCALE = "currentItemScale";
    private static final float DEFAULT_CURRENT_ITEM_SCALE = 0.9f;
    private static final float DEFAULT_NEIGHBOR_ALPHA = 0.6f;
    private static final float DEFAULT_NEIGHBOR_SCALE = 0.8f;
    private static final int DEFAULT_NEIGHBOR_SPACE = 25;
    public static final String NEIGHBOR_ALPHA = "neighborAlpha";
    public static final String NEIGHBOR_SCALE = "neighborScale";
    public static final String NEIGHBOR_SPACE = "neighborSpace";
    private ZoomTransformer mCachedTransformer;
    private float mCurrentItemScale;
    private float mNeighborAlpha;
    private float mNeighborScale;
    private float mNeighborSpace;

    public WXSliderNeighbor(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mNeighborScale = DEFAULT_NEIGHBOR_SCALE;
        this.mNeighborAlpha = DEFAULT_NEIGHBOR_ALPHA;
        this.mNeighborSpace = 25.0f;
        this.mCurrentItemScale = DEFAULT_CURRENT_ITEM_SCALE;
    }

    /* loaded from: classes.dex */
    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXSliderNeighbor(instance, parent, basicComponentData);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void bindData(WXComponent component) {
        super.bindData(component);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXSlider, com.taobao.weex.ui.component.WXComponent
    public BaseFrameLayout initComponentHostView(Context context) {
        BaseFrameLayout baseFrameLayout = new BaseFrameLayout(context);
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-1, -1);
        layoutParams.gravity = 17;
        this.mViewPager = new WXCircleViewPager(getContext());
        this.mViewPager.setLayoutParams(layoutParams);
        this.mAdapter = new WXCirclePageAdapter();
        this.mViewPager.setAdapter(this.mAdapter);
        baseFrameLayout.addView(this.mViewPager);
        this.mViewPager.addOnPageChangeListener(this.mPageChangeListener);
        this.mViewPager.setOverScrollMode(2);
        registerActivityStateListener();
        this.mViewPager.setPageTransformer(false, createTransformer());
        return baseFrameLayout;
    }

    ZoomTransformer createTransformer() {
        if (this.mCachedTransformer == null) {
            this.mCachedTransformer = new ZoomTransformer();
        }
        return this.mCachedTransformer;
    }

    @Override // com.taobao.weex.ui.component.WXSlider, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View view, final int index) {
        if (view == null || this.mAdapter == null || (view instanceof WXCircleIndicator)) {
            return;
        }
        FrameLayout frameLayout = new FrameLayout(getContext());
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(-2, -2);
        layoutParams.gravity = 17;
        view.setLayoutParams(layoutParams);
        frameLayout.addView(view);
        super.addSubView(frameLayout, index);
        updateAdapterScaleAndAlpha(this.mNeighborAlpha, this.mNeighborScale);
        this.mViewPager.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.WXSliderNeighbor.1
            @Override // java.lang.Runnable
            public void run() {
                WXSliderNeighbor wXSliderNeighbor;
                try {
                    try {
                        if (WXSliderNeighbor.this.mViewPager.getRealCount() > 0 && index > 2) {
                            WXSliderNeighbor.this.mViewPager.beginFakeDrag();
                            WXSliderNeighbor.this.mViewPager.fakeDragBy(1.0f);
                        }
                        wXSliderNeighbor = WXSliderNeighbor.this;
                    } catch (IndexOutOfBoundsException unused) {
                        wXSliderNeighbor = WXSliderNeighbor.this;
                    } catch (Throwable th) {
                        try {
                            WXSliderNeighbor.this.mViewPager.endFakeDrag();
                        } catch (Exception unused2) {
                        }
                        throw th;
                    }
                    wXSliderNeighbor.mViewPager.endFakeDrag();
                } catch (Exception unused3) {
                }
            }
        }), 50L);
    }

    private void updateScaleAndAlpha(View view, float alpha, float scale) {
        if (view == null) {
            return;
        }
        if (alpha >= 0.0f && view.getAlpha() != alpha) {
            view.setAlpha(alpha);
        }
        if (scale < 0.0f || view.getScaleX() == scale) {
            return;
        }
        view.setScaleX(scale);
        view.setScaleY(scale);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateAdapterScaleAndAlpha(final float alpha, final float scale) {
        List<View> views = this.mAdapter.getViews();
        int currentItem = this.mViewPager.getCurrentItem();
        if (views.size() > 0) {
            final View view = views.get(currentItem);
            updateScaleAndAlpha(((ViewGroup) view).getChildAt(0), 1.0f, this.mCurrentItemScale);
            if (views.size() < 2) {
                return;
            }
            view.postDelayed(WXThread.secure(new Runnable() { // from class: com.taobao.weex.ui.component.WXSliderNeighbor.2
                @Override // java.lang.Runnable
                public void run() {
                    WXSliderNeighbor.this.updateNeighbor(view, alpha, scale);
                }
            }), 17L);
            int size = currentItem == 0 ? views.size() - 1 : currentItem - 1;
            int i = currentItem == views.size() + (-1) ? 0 : currentItem + 1;
            for (int i2 = 0; i2 < this.mAdapter.getRealCount(); i2++) {
                if (i2 != size && i2 != currentItem && i2 != i) {
                    ((ViewGroup) views.get(i2)).getChildAt(0).setAlpha(0.0f);
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void updateNeighbor(View currentPage, final float alpha, final float scale) {
        List<View> views = this.mAdapter.getViews();
        int currentItem = this.mViewPager.getCurrentItem();
        float calculateTranslation = calculateTranslation(currentPage);
        View view = views.get(currentItem == 0 ? views.size() - 1 : currentItem - 1);
        View view2 = views.get(currentItem == views.size() - 1 ? 0 : currentItem + 1);
        if (views.size() != 2) {
            moveLeft(view, calculateTranslation, alpha, scale);
            moveRight(view2, calculateTranslation, alpha, scale);
        } else if (currentItem == 0) {
            moveRight(view2, calculateTranslation, alpha, scale);
        } else if (currentItem == 1) {
            moveLeft(view, calculateTranslation, alpha, scale);
        }
    }

    private void moveLeft(View page, float translation, float alpha, float scale) {
        ViewGroup viewGroup = (ViewGroup) page;
        updateScaleAndAlpha(viewGroup.getChildAt(0), alpha, scale);
        page.setTranslationX(translation);
        viewGroup.getChildAt(0).setTranslationX(translation);
    }

    private void moveRight(View page, float translation, float alpha, float scale) {
        moveLeft(page, -translation, alpha, scale);
    }

    /* JADX WARN: Removed duplicated region for block: B:14:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0014  */
    @WXComponentProp(name = NEIGHBOR_SCALE)
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void setNeighborScale(String input) {
        float parseFloat;
        if (!TextUtils.isEmpty(input)) {
            try {
                parseFloat = Float.parseFloat(input);
            } catch (NumberFormatException unused) {
            }
            if (this.mNeighborScale == parseFloat) {
                this.mNeighborScale = parseFloat;
                updateAdapterScaleAndAlpha(-1.0f, parseFloat);
                return;
            }
            return;
        }
        parseFloat = DEFAULT_NEIGHBOR_SCALE;
        if (this.mNeighborScale == parseFloat) {
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:14:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0014  */
    @WXComponentProp(name = NEIGHBOR_ALPHA)
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void setNeighborAlpha(String input) {
        float parseFloat;
        if (!TextUtils.isEmpty(input)) {
            try {
                parseFloat = Float.parseFloat(input);
            } catch (NumberFormatException unused) {
            }
            if (this.mNeighborAlpha == parseFloat) {
                this.mNeighborAlpha = parseFloat;
                updateAdapterScaleAndAlpha(parseFloat, -1.0f);
                return;
            }
            return;
        }
        parseFloat = DEFAULT_NEIGHBOR_ALPHA;
        if (this.mNeighborAlpha == parseFloat) {
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:14:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0013  */
    @WXComponentProp(name = NEIGHBOR_SPACE)
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void setNeighborSpace(String input) {
        float parseFloat;
        if (!TextUtils.isEmpty(input)) {
            try {
                parseFloat = Float.parseFloat(input);
            } catch (NumberFormatException unused) {
            }
            if (this.mNeighborSpace == parseFloat) {
                this.mNeighborSpace = parseFloat;
                return;
            }
            return;
        }
        parseFloat = 25.0f;
        if (this.mNeighborSpace == parseFloat) {
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:14:? A[RETURN, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:9:0x0014  */
    @WXComponentProp(name = CURRENT_ITEM_SCALE)
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void setCurrentItemScale(String input) {
        float parseFloat;
        if (!TextUtils.isEmpty(input)) {
            try {
                parseFloat = Float.parseFloat(input);
            } catch (NumberFormatException unused) {
            }
            if (this.mCurrentItemScale == parseFloat) {
                this.mCurrentItemScale = parseFloat;
                updateAdapterScaleAndAlpha(-1.0f, -1.0f);
                return;
            }
            return;
        }
        parseFloat = DEFAULT_CURRENT_ITEM_SCALE;
        if (this.mCurrentItemScale == parseFloat) {
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXSlider, com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -1763701364:
                if (key.equals(NEIGHBOR_ALPHA)) {
                    c = 0;
                    break;
                }
                break;
            case -1747360392:
                if (key.equals(NEIGHBOR_SCALE)) {
                    c = 1;
                    break;
                }
                break;
            case -1746973388:
                if (key.equals(NEIGHBOR_SPACE)) {
                    c = 2;
                    break;
                }
                break;
            case -1013904258:
                if (key.equals(CURRENT_ITEM_SCALE)) {
                    c = 3;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setNeighborAlpha(string);
                }
                return true;
            case 1:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setNeighborScale(string2);
                }
                return true;
            case 2:
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setNeighborSpace(string3);
                }
                return true;
            case 3:
                String string4 = WXUtils.getString(param, null);
                if (string4 != null) {
                    setCurrentItemScale(string4);
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public float calculateTranslation(View hostPage) {
        if (hostPage instanceof ViewGroup) {
            View childAt = ((ViewGroup) hostPage).getChildAt(0);
            return ((hostPage.getMeasuredWidth() - (childAt.getMeasuredWidth() * this.mNeighborScale)) / 4.0f) + ((((hostPage.getMeasuredWidth() - (childAt.getMeasuredWidth() * this.mCurrentItemScale)) / 2.0f) - WXViewUtils.getRealPxByWidth(this.mNeighborSpace, getInstance().getInstanceViewPortWidthWithFloat())) / 2.0f);
        }
        return 0.0f;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public class ZoomTransformer implements ViewPager.PageTransformer {
        ZoomTransformer() {
        }

        @Override // androidx.viewpager.widget.ViewPager.PageTransformer
        public void transformPage(View page, float position) {
            View childAt;
            int pagePosition = WXSliderNeighbor.this.mAdapter.getPagePosition(page);
            int currentItem = WXSliderNeighbor.this.mViewPager.getCurrentItem();
            int realCount = WXSliderNeighbor.this.mAdapter.getRealCount();
            boolean z = (currentItem == 0 || currentItem == realCount + (-1) || Math.abs(pagePosition - currentItem) <= 1) ? false : true;
            if (currentItem == 0 && pagePosition < realCount - 1 && pagePosition > 1) {
                z = true;
            }
            int i = realCount - 1;
            if (currentItem == i && pagePosition < realCount - 2 && pagePosition > 0) {
                z = true;
            }
            if (z || (childAt = ((ViewGroup) page).getChildAt(0)) == null) {
                return;
            }
            if (position <= (-realCount) + 1) {
                position += realCount;
            }
            if (position >= i) {
                position -= realCount;
            }
            if (position < -1.0f || position > 1.0f) {
                return;
            }
            float abs = Math.abs(Math.abs(position) - 1.0f);
            float f = WXSliderNeighbor.this.mNeighborScale + ((WXSliderNeighbor.this.mCurrentItemScale - WXSliderNeighbor.this.mNeighborScale) * abs);
            float f2 = ((1.0f - WXSliderNeighbor.this.mNeighborAlpha) * abs) + WXSliderNeighbor.this.mNeighborAlpha;
            float calculateTranslation = WXSliderNeighbor.this.calculateTranslation(page);
            if (position > 0.0f) {
                float f3 = -(position * calculateTranslation);
                childAt.setTranslationX(f3);
                page.setTranslationX(f3);
            } else if (position == 0.0f) {
                page.setTranslationX(0.0f);
                childAt.setTranslationX(0.0f);
                WXSliderNeighbor wXSliderNeighbor = WXSliderNeighbor.this;
                wXSliderNeighbor.updateAdapterScaleAndAlpha(wXSliderNeighbor.mNeighborAlpha, WXSliderNeighbor.this.mNeighborScale);
            } else if (realCount == 2 && Math.abs(position) == 1.0f) {
                return;
            } else {
                float f4 = (-position) * calculateTranslation;
                childAt.setTranslationX(f4);
                page.setTranslationX(f4);
            }
            childAt.setScaleX(f);
            childAt.setScaleY(f);
            childAt.setAlpha(f2);
        }
    }
}
