package com.taobao.weex.ui.component.binding;

import android.os.Looper;
import android.text.TextUtils;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.dom.WXAttr;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.dom.binding.ELUtils;
import com.taobao.weex.dom.binding.JSONUtils;
import com.taobao.weex.dom.binding.WXStatement;
import com.taobao.weex.el.parse.ArrayStack;
import com.taobao.weex.el.parse.Operators;
import com.taobao.weex.el.parse.Token;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.action.GraphicPosition;
import com.taobao.weex.ui.action.GraphicSize;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentFactory;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.list.WXCell;
import com.taobao.weex.ui.component.list.template.CellDataManager;
import com.taobao.weex.ui.component.list.template.CellRenderContext;
import com.taobao.weex.ui.component.list.template.TemplateDom;
import com.taobao.weex.ui.component.list.template.VirtualComponentLifecycle;
import com.taobao.weex.ui.component.list.template.WXRecyclerTemplateList;
import com.taobao.weex.ui.component.list.template.jni.NativeRenderObjectUtils;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
/* loaded from: classes.dex */
public class Statements {
    private static final ThreadLocal<Map<String, Object>> dynamicLocal = new ThreadLocal<>();

    public static void parseStatementsToken(WXComponent component) {
        if (component.getBasicComponentData().isRenderPtrEmpty()) {
            component.getBasicComponentData().setRenderObjectPr(component.getRenderObjectPtr());
        }
        if (component.getBasicComponentData() != null) {
            BasicComponentData basicComponentData = component.getBasicComponentData();
            basicComponentData.getAttrs().parseStatements();
            basicComponentData.getStyles().parseStatements();
            basicComponentData.getEvents().parseStatements();
        }
        if (component instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) component;
            int childCount = wXVContainer.getChildCount();
            for (int i = 0; i < childCount; i++) {
                parseStatementsToken(wXVContainer.getChild(i));
            }
        }
    }

    public static void initLazyComponent(WXComponent component, WXVContainer mParent) {
        if (component.isLazy() || component.getHostView() == null) {
            component.lazy(false);
            if (mParent != null) {
                mParent.createChildViewAt(mParent.indexOf(component));
            } else {
                component.createView();
            }
            component.applyLayoutAndEvent(component);
            component.bindData(component);
        }
    }

    public static WXComponent copyComponentTree(WXComponent component) {
        return copyComponentTree(component, component.getParent());
    }

    private static final WXComponent copyComponentTree(WXComponent source, WXVContainer parent) {
        BasicComponentData basicComponentData;
        try {
            basicComponentData = source.getBasicComponentData().clone();
        } catch (CloneNotSupportedException e) {
            e.printStackTrace();
            basicComponentData = null;
        }
        WXComponent newInstance = WXComponentFactory.newInstance(source.getInstance(), parent, basicComponentData);
        GraphicPosition layoutPosition = source.getLayoutPosition();
        GraphicSize layoutSize = source.getLayoutSize();
        newInstance.updateDemission(layoutPosition.getTop(), layoutPosition.getBottom(), layoutPosition.getLeft(), layoutPosition.getRight(), layoutSize.getHeight(), layoutSize.getWidth());
        newInstance.updateExtra(source.getExtra());
        if (source instanceof WXVContainer) {
            WXVContainer wXVContainer = (WXVContainer) source;
            WXVContainer wXVContainer2 = (WXVContainer) newInstance;
            int childCount = wXVContainer.getChildCount();
            for (int i = 0; i < childCount; i++) {
                WXComponent child = wXVContainer.getChild(i);
                if (child != null) {
                    WXComponent copyComponentTree = copyComponentTree(child, wXVContainer2);
                    wXVContainer2.addChild(copyComponentTree);
                    NativeRenderObjectUtils.nativeAddChildRenderObject(wXVContainer2.getRenderObjectPtr(), copyComponentTree.getRenderObjectPtr());
                }
            }
        }
        if (source.isWaste()) {
            newInstance.setWaste(true);
        }
        return newInstance;
    }

    public static final List<WXComponent> doRender(WXComponent component, CellRenderContext stack) {
        ArrayList arrayList = new ArrayList(4);
        try {
            doRenderComponent(component, stack, arrayList);
        } catch (Exception e) {
            WXLogUtils.e("WeexStatementRender", e);
        }
        return arrayList;
    }

    public static final void doInitCompontent(List<WXComponent> updates) {
        if (updates == null || updates.size() == 0) {
            return;
        }
        for (WXComponent wXComponent : updates) {
            if (wXComponent.getParent() == null) {
                throw new IllegalArgumentException("render node parent cann't find");
            }
            WXVContainer parent = wXComponent.getParent();
            int indexOf = parent.indexOf(wXComponent);
            if (indexOf < 0) {
                throw new IllegalArgumentException("render node cann't find");
            }
            parent.createChildViewAt(indexOf);
            wXComponent.applyLayoutAndEvent(wXComponent);
            wXComponent.bindData(wXComponent);
        }
    }

    private static final int doRenderComponent(WXComponent component, CellRenderContext context, List<WXComponent> updates) {
        int i;
        Collection keySet;
        Map map;
        Object obj;
        boolean z;
        WXComponent wXComponent;
        Map map2;
        String str;
        Iterator it;
        String str2;
        WXVContainer parent = component.getParent();
        WXStatement statement = component.getAttrs().getStatement();
        if (statement != null) {
            Token token = statement.get(WXStatement.WX_IF) instanceof Token ? (Token) statement.get(WXStatement.WX_IF) : null;
            String str3 = WXStatement.WX_FOR;
            JSONObject jSONObject = statement.get(WXStatement.WX_FOR) instanceof JSONObject ? (JSONObject) statement.get(WXStatement.WX_FOR) : null;
            if (jSONObject != null) {
                int indexOf = parent.indexOf(component);
                if (jSONObject.get(WXStatement.WX_FOR_LIST) instanceof Token) {
                    Token token2 = (Token) jSONObject.get(WXStatement.WX_FOR_LIST);
                    String string = jSONObject.getString(WXStatement.WX_FOR_INDEX);
                    String string2 = jSONObject.getString(WXStatement.WX_FOR_ITEM);
                    Object execute = token2 != null ? token2.execute(context.stack) : null;
                    boolean z2 = execute instanceof List;
                    if (z2 || (execute instanceof Map)) {
                        if (z2) {
                            keySet = (List) execute;
                            map = null;
                        } else {
                            Map map3 = (Map) execute;
                            keySet = map3.keySet();
                            map = map3;
                        }
                        HashMap hashMap = new HashMap();
                        Iterator it2 = keySet.iterator();
                        int i2 = 0;
                        while (it2.hasNext()) {
                            Object next = it2.next();
                            if (map == null) {
                                Integer valueOf = Integer.valueOf(i2);
                                i2++;
                                obj = next;
                                next = valueOf;
                            } else {
                                obj = map.get(next);
                            }
                            int i3 = i2;
                            if (string != null) {
                                hashMap.put(string, next);
                            }
                            if (string2 != null) {
                                hashMap.put(string2, obj);
                            } else {
                                context.stack.push(obj);
                            }
                            if (hashMap.size() > 0) {
                                context.stack.push(hashMap);
                            }
                            if (token == null || Operators.isTrue(token.execute(context.stack))) {
                                if (indexOf < parent.getChildCount()) {
                                    wXComponent = parent.getChild(indexOf);
                                    if (!isCreateFromNodeStatement(wXComponent, component)) {
                                        wXComponent = null;
                                    }
                                    if (wXComponent == null || !wXComponent.isWaste()) {
                                        z = false;
                                    } else {
                                        z = false;
                                        wXComponent.setWaste(false);
                                    }
                                } else {
                                    z = false;
                                    wXComponent = null;
                                }
                                if (wXComponent == null) {
                                    long currentTimeMillis = System.currentTimeMillis();
                                    wXComponent = copyComponentTree(component, parent);
                                    wXComponent.setWaste(z);
                                    if (wXComponent.getAttrs().getStatement() != null) {
                                        wXComponent.getAttrs().getStatement().remove(str3);
                                        wXComponent.getAttrs().getStatement().remove(WXStatement.WX_IF);
                                    }
                                    parent.addChild(wXComponent, indexOf);
                                    map2 = map;
                                    str = str3;
                                    it = it2;
                                    str2 = string;
                                    NativeRenderObjectUtils.nativeAddChildRenderObject(parent.getRenderObjectPtr(), wXComponent.getRenderObjectPtr());
                                    updates.add(wXComponent);
                                    if (WXEnvironment.isApkDebugable()) {
                                        WXLogUtils.d(WXRecyclerTemplateList.TAG, Thread.currentThread().getName() + wXComponent.getRef() + wXComponent.getComponentType() + "statements copy component tree used " + (System.currentTimeMillis() - currentTimeMillis));
                                    }
                                } else {
                                    map2 = map;
                                    str = str3;
                                    it = it2;
                                    str2 = string;
                                }
                                doBindingAttrsEventAndRenderChildNode(wXComponent, context, updates);
                                indexOf++;
                                if (hashMap.size() > 0) {
                                    context.stack.push(hashMap);
                                }
                                if (string2 == null) {
                                    context.stack.pop();
                                }
                                str3 = str;
                                i2 = i3;
                                map = map2;
                                string = str2;
                                it2 = it;
                            } else {
                                i2 = i3;
                            }
                        }
                    }
                } else {
                    WXLogUtils.e(WXRecyclerTemplateList.TAG, jSONObject.toJSONString() + " not call vfor block, for pre compile");
                }
                while (indexOf < parent.getChildCount()) {
                    WXComponent child = parent.getChild(indexOf);
                    if (!isCreateFromNodeStatement(child, component)) {
                        break;
                    }
                    child.setWaste(true);
                    indexOf++;
                }
                return indexOf - parent.indexOf(component);
            } else if (token != null) {
                if (!Operators.isTrue(token.execute(context.stack))) {
                    component.setWaste(true);
                    return 1;
                }
                i = 1;
                component.setWaste(false);
                doBindingAttrsEventAndRenderChildNode(component, context, updates);
                return i;
            }
        }
        i = 1;
        doBindingAttrsEventAndRenderChildNode(component, context, updates);
        return i;
    }

    private static void doBindingAttrsEventAndRenderChildNode(WXComponent component, CellRenderContext context, List<WXComponent> updates) {
        boolean z;
        String str;
        Map<String, Object> map;
        Map<String, Object> map2;
        Map<String, Object> map3;
        WXAttr attrs = component.getAttrs();
        ArrayStack arrayStack = context.stack;
        if (attrs.get(ELUtils.IS_COMPONENT_ROOT) == null || !WXUtils.getBoolean(attrs.get(ELUtils.IS_COMPONENT_ROOT), false).booleanValue() || attrs.get(ELUtils.COMPONENT_PROPS) == null || !JSONUtils.isJSON(attrs.get(ELUtils.COMPONENT_PROPS))) {
            z = false;
            str = null;
        } else {
            String str2 = (String) attrs.get(CellDataManager.SUB_COMPONENT_TEMPLATE_ID);
            if (!TextUtils.isEmpty(str2)) {
                String str3 = context.getRenderState().getVirtualComponentIds().get(component.getViewTreeKey());
                if (str3 == null) {
                    str3 = CellDataManager.createVirtualComponentId(context.templateList.getRef(), component.getViewTreeKey(), context.templateList.getItemId(context.position));
                    Map<String, Object> renderProps = renderProps(JSONUtils.toJSON(attrs.get(ELUtils.COMPONENT_PROPS)), context.stack);
                    EventResult syncCallJSEventWithResult = WXBridgeManager.getInstance().syncCallJSEventWithResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, str2, VirtualComponentLifecycle.LIFECYCLE, "create", new Object[]{str3, renderProps}, null);
                    if (syncCallJSEventWithResult != null && syncCallJSEventWithResult.getResult() != null && (syncCallJSEventWithResult.getResult() instanceof Map)) {
                        renderProps.putAll((Map) syncCallJSEventWithResult.getResult());
                    }
                    context.getRenderState().getVirtualComponentIds().put(component.getViewTreeKey(), str3);
                    context.templateList.getCellDataManager().createVirtualComponentData(context.position, str3, renderProps);
                    z = true;
                    map3 = renderProps;
                } else {
                    Object obj = context.getRenderState().getVirtualComponentDatas().get(str3);
                    if (context.getRenderState().isHasDataUpdate()) {
                        Map<String, Object> renderProps2 = renderProps((JSONObject) attrs.get(ELUtils.COMPONENT_PROPS), context.stack);
                        EventResult syncCallJSEventWithResult2 = WXBridgeManager.getInstance().syncCallJSEventWithResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, str3, VirtualComponentLifecycle.LIFECYCLE, VirtualComponentLifecycle.SYNSTATE, new Object[]{str3, renderProps2}, null);
                        if (syncCallJSEventWithResult2 != null && syncCallJSEventWithResult2.getResult() != null && (syncCallJSEventWithResult2.getResult() instanceof Map)) {
                            renderProps2.putAll((Map) syncCallJSEventWithResult2.getResult());
                            context.templateList.getCellDataManager().updateVirtualComponentData(str3, renderProps2);
                            map2 = renderProps2;
                            z = false;
                            map3 = map2;
                        }
                    }
                    map2 = obj;
                    z = false;
                    map3 = map2;
                }
                component.getAttrs().put(CellDataManager.VIRTUAL_COMPONENT_ID, (Object) str3);
                str = str3;
                map = map3;
            } else {
                z = false;
                str = null;
                map = renderProps((JSONObject) attrs.get(ELUtils.COMPONENT_PROPS), context.stack);
            }
            context.stack = new ArrayStack();
            if (map != null) {
                context.stack.push(map);
            }
        }
        if ((attrs.getStatement() != null ? attrs.getStatement().get(WXStatement.WX_ONCE) : null) != null) {
            ArrayStack arrayStack2 = context.getRenderState().getOnceComponentStates().get(component.getViewTreeKey());
            if (arrayStack2 == null) {
                arrayStack2 = context.templateList.copyStack(context, arrayStack);
                context.getRenderState().getOnceComponentStates().put(component.getViewTreeKey(), arrayStack2);
            }
            context.stack = arrayStack2;
        }
        doRenderBindingAttrsAndEvent(component, context);
        if (component instanceof WXVContainer) {
            if (component.isWaste() && !(component instanceof WXCell)) {
                return;
            }
            WXVContainer wXVContainer = (WXVContainer) component;
            int i = 0;
            while (i < wXVContainer.getChildCount()) {
                i += doRenderComponent(wXVContainer.getChild(i), context, updates);
            }
        }
        if (arrayStack != context.stack) {
            context.stack = arrayStack;
        }
        if (!z || str == null) {
            return;
        }
        WXBridgeManager.getInstance().asyncCallJSEventVoidResult(WXBridgeManager.METHD_COMPONENT_HOOK_SYNC, component.getInstanceId(), null, str, VirtualComponentLifecycle.LIFECYCLE, "attach", new Object[]{TemplateDom.findAllComponentRefs(context.templateList.getRef(), context.position, component)});
    }

    private static boolean isCreateFromNodeStatement(WXComponent renderNode, WXComponent component) {
        return renderNode.getRef() != null && renderNode.getRef().equals(component.getRef());
    }

    private static void doRenderBindingAttrsAndEvent(WXComponent component, CellRenderContext context) {
        ArrayStack arrayStack = context.stack;
        component.setWaste(false);
        WXAttr attrs = component.getAttrs();
        if (attrs != null && attrs.getBindingAttrs() != null && attrs.getBindingAttrs().size() > 0) {
            Map<String, Object> renderBindingAttrs = renderBindingAttrs(component.getAttrs().getBindingAttrs(), arrayStack);
            Iterator<Map.Entry<String, Object>> it = renderBindingAttrs.entrySet().iterator();
            while (it.hasNext()) {
                Map.Entry<String, Object> next = it.next();
                Object value = next.getValue();
                Object obj = attrs.get(next.getKey());
                if (value == null) {
                    if (obj == null) {
                        it.remove();
                    }
                } else if (value.equals(obj)) {
                    it.remove();
                }
            }
            if (renderBindingAttrs.size() > 0) {
                if (renderBindingAttrs.size() == 1 && renderBindingAttrs.get("src") != null && (component instanceof WXImage)) {
                    component.getAttrs().put("src", renderBindingAttrs.get("src"));
                } else {
                    component.nativeUpdateAttrs(renderBindingAttrs);
                }
                if (isMainThread()) {
                    component.updateProperties(renderBindingAttrs);
                }
                renderBindingAttrs.clear();
            }
        }
        WXStyle styles = component.getStyles();
        if (styles != null && styles.getBindingStyle() != null) {
            Map<String, Object> renderBindingAttrs2 = renderBindingAttrs(styles.getBindingStyle(), arrayStack);
            Iterator<Map.Entry<String, Object>> it2 = renderBindingAttrs2.entrySet().iterator();
            while (it2.hasNext()) {
                Map.Entry<String, Object> next2 = it2.next();
                Object value2 = next2.getValue();
                Object obj2 = styles.get(next2.getKey());
                if (value2 == null) {
                    if (obj2 == null) {
                        it2.remove();
                    }
                } else if (value2.equals(obj2)) {
                    it2.remove();
                }
            }
            if (renderBindingAttrs2.size() > 0) {
                component.updateNativeStyles(renderBindingAttrs2);
                if (isMainThread()) {
                    component.updateProperties(renderBindingAttrs2);
                }
            }
        }
        WXEvent events = component.getEvents();
        if (events == null || events.getEventBindingArgs() == null) {
            return;
        }
        for (Map.Entry entry : events.getEventBindingArgs().entrySet()) {
            List<Object> bindingEventArgs = getBindingEventArgs(arrayStack, entry.getValue());
            if (bindingEventArgs != null) {
                events.putEventBindingArgsValue((String) entry.getKey(), bindingEventArgs);
            }
        }
    }

    public static Map<String, Object> renderBindingAttrs(ArrayMap bindAttrs, ArrayStack stack) {
        Set<Map.Entry> entrySet = bindAttrs.entrySet();
        ThreadLocal<Map<String, Object>> threadLocal = dynamicLocal;
        Map<String, Object> map = threadLocal.get();
        if (map == null) {
            map = new HashMap<>();
            threadLocal.set(map);
        }
        if (map.size() > 0) {
            map.clear();
        }
        for (Map.Entry entry : entrySet) {
            Object value = entry.getValue();
            String str = (String) entry.getKey();
            if (value instanceof JSONObject) {
                JSONObject jSONObject = (JSONObject) value;
                if (jSONObject.get(ELUtils.BINDING) instanceof Token) {
                    map.put(str, ((Token) jSONObject.get(ELUtils.BINDING)).execute(stack));
                }
            }
            if (value instanceof JSONArray) {
                JSONArray jSONArray = (JSONArray) value;
                StringBuilder sb = new StringBuilder();
                for (int i = 0; i < jSONArray.size(); i++) {
                    Object obj = jSONArray.get(i);
                    if (obj instanceof CharSequence) {
                        sb.append(obj);
                    } else if (obj instanceof JSONObject) {
                        JSONObject jSONObject2 = (JSONObject) obj;
                        if (jSONObject2.get(ELUtils.BINDING) instanceof Token) {
                            Object execute = ((Token) jSONObject2.get(ELUtils.BINDING)).execute(stack);
                            if (execute == null) {
                                execute = "";
                            }
                            sb.append(execute);
                        }
                    }
                }
                String sb2 = sb.toString();
                if (sb2.length() > 256 && WXEnvironment.isApkDebugable()) {
                    WXLogUtils.w(WXRecyclerTemplateList.TAG, " warn too big string " + sb2);
                }
                map.put(str, sb2);
            }
        }
        return map;
    }

    public static Map<String, Object> renderProps(JSONObject props, ArrayStack stack) {
        Set<Map.Entry<String, Object>> entrySet = props.entrySet();
        ArrayMap arrayMap = new ArrayMap(4);
        for (Map.Entry<String, Object> entry : entrySet) {
            Object value = entry.getValue();
            String key = entry.getKey();
            if (value instanceof JSONObject) {
                JSONObject jSONObject = (JSONObject) value;
                if (jSONObject.get(ELUtils.BINDING) instanceof Token) {
                    arrayMap.put(key, ((Token) jSONObject.get(ELUtils.BINDING)).execute(stack));
                }
            }
            arrayMap.put(key, value);
        }
        return arrayMap;
    }

    public static List<Object> getBindingEventArgs(ArrayStack stack, Object bindings) {
        ArrayList arrayList = new ArrayList(4);
        if (bindings instanceof JSONArray) {
            JSONArray jSONArray = (JSONArray) bindings;
            for (int i = 0; i < jSONArray.size(); i++) {
                Object obj = jSONArray.get(i);
                if (obj instanceof JSONObject) {
                    JSONObject jSONObject = (JSONObject) obj;
                    if (jSONObject.get(ELUtils.BINDING) instanceof Token) {
                        arrayList.add(((Token) jSONObject.get(ELUtils.BINDING)).execute(stack));
                    }
                }
                arrayList.add(obj);
            }
        } else if (bindings instanceof JSONObject) {
            JSONObject jSONObject2 = (JSONObject) bindings;
            if (jSONObject2.get(ELUtils.BINDING) instanceof Token) {
                arrayList.add(((Token) jSONObject2.get(ELUtils.BINDING)).execute(stack));
            } else {
                arrayList.add(bindings.toString());
            }
        } else {
            arrayList.add(bindings.toString());
        }
        return arrayList;
    }

    private static boolean isMainThread() {
        return Thread.currentThread() == Looper.getMainLooper().getThread();
    }

    public static String getComponentId(WXComponent component) {
        if ((component instanceof WXCell) || component == null) {
            return null;
        }
        WXAttr attrs = component.getAttrs();
        if (attrs.get(ELUtils.IS_COMPONENT_ROOT) != null && WXUtils.getBoolean(attrs.get(ELUtils.IS_COMPONENT_ROOT), false).booleanValue() && attrs.get(ELUtils.COMPONENT_PROPS) != null && (attrs.get(ELUtils.COMPONENT_PROPS) instanceof JSONObject)) {
            Object obj = attrs.get(CellDataManager.VIRTUAL_COMPONENT_ID);
            if (obj == null) {
                return null;
            }
            return obj.toString();
        }
        return getComponentId(component.getParent());
    }
}
