package com.taobao.weex.ui.component.list;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.os.Build;
import android.text.TextUtils;
import android.util.SparseArray;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewTreeObserver;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import androidx.collection.ArrayMap;
import androidx.core.view.MotionEventCompat;
import androidx.core.view.ViewCompat;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.recyclerview.widget.StaggeredGridLayoutManager;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.bridge.JSCallback;
import com.taobao.weex.common.Constants;
import com.taobao.weex.common.ICheckBindingScroller;
import com.taobao.weex.common.IWXObject;
import com.taobao.weex.common.OnWXScrollListener;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.AppearanceHelper;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXBaseRefresh;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXHeader;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXLoading;
import com.taobao.weex.ui.component.WXRefresh;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.helper.ScrollStartEndHelper;
import com.taobao.weex.ui.component.helper.WXStickyHelper;
import com.taobao.weex.ui.component.list.ListComponentView;
import com.taobao.weex.ui.view.listview.WXRecyclerView;
import com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener;
import com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener;
import com.taobao.weex.ui.view.listview.adapter.ListBaseViewHolder;
import com.taobao.weex.ui.view.listview.adapter.RecyclerViewBaseAdapter;
import com.taobao.weex.ui.view.listview.adapter.WXRecyclerViewOnScrollListener;
import com.taobao.weex.ui.view.refresh.wrapper.BounceRecyclerView;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public abstract class BasicListComponent<T extends ViewGroup & ListComponentView> extends WXVContainer<T> implements IRecyclerAdapterListener<ListBaseViewHolder>, IOnLoadMoreListener, Scrollable {
    private static final boolean DEFAULT_EXCLUDED = false;
    private static final String DEFAULT_TRIGGER_TYPE = "longpress";
    private static final String DRAG_ANCHOR = "dragAnchor";
    private static final String DRAG_TRIGGER_TYPE = "dragTriggerType";
    private static final String EXCLUDED = "dragExcluded";
    public static final String LOADMOREOFFSET = "loadmoreoffset";
    private static final int MAX_VIEWTYPE_ALLOW_CACHE = 9;
    public static final String TRANSFORM = "transform";
    private String TAG;
    private boolean isScrollable;
    boolean isThisGroupFinished;
    private WXComponent keepPositionCell;
    private Runnable keepPositionCellRunnable;
    private long keepPositionLayoutDelay;
    ListStanceCell listStanceObject;
    private Runnable mAppearChangeRunnable;
    private long mAppearChangeRunnableDelay;
    private Map<String, AppearanceHelper> mAppearComponents;
    protected int mColumnCount;
    protected float mColumnGap;
    protected float mColumnWidth;
    private DragHelper mDragHelper;
    private boolean mForceLoadmoreNextTime;
    private boolean mHasAddScrollEvent;
    private RecyclerView.ItemAnimator mItemAnimator;
    private Point mLastReport;
    protected int mLayoutType;
    protected float mLeftGap;
    private int mListCellCount;
    private int mOffsetAccuracy;
    private ArrayMap<String, Long> mRefToViewType;
    protected float mRightGap;
    private ScrollStartEndHelper mScrollStartEndHelper;
    private Map<String, Map<String, WXComponent>> mStickyMap;
    private String mTriggerType;
    private WXRecyclerViewOnScrollListener mViewOnScrollListener;
    private SparseArray<ArrayList<WXComponent>> mViewTypes;
    private WXStickyHelper stickyHelper;
    private static final Pattern transformPattern = Pattern.compile("([a-z]+)\\(([0-9\\.]+),?([0-9\\.]+)?\\)");
    private static boolean mAllowCacheViewHolder = true;
    private static boolean mDownForBidCacheViewHolder = false;

    /* loaded from: classes.dex */
    interface DragTriggerType {
        public static final String LONG_PRESS = "longpress";
        public static final String PAN = "pan";
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addSubView(View child, int index) {
    }

    abstract T generateListView(Context context, int orientation);

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXVContainer, io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildrenLayoutTopOffset() {
        return 0;
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getOrientation() {
        return 1;
    }

    protected boolean isRenderFromBottom() {
        return false;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected /* bridge */ /* synthetic */ View initComponentHostView(Context context) {
        return (T) initComponentHostView(context);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.taobao.weex.ui.component.WXComponent
    public /* bridge */ /* synthetic */ void onHostViewInitialized(View host) {
        onHostViewInitialized((BasicListComponent<T>) ((ViewGroup) host));
    }

    public BasicListComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.TAG = "BasicListComponent";
        this.mListCellCount = 0;
        this.mForceLoadmoreNextTime = false;
        this.mAppearComponents = new HashMap();
        this.mAppearChangeRunnable = null;
        this.mAppearChangeRunnableDelay = 50L;
        this.isScrollable = true;
        this.mViewOnScrollListener = new WXRecyclerViewOnScrollListener(this);
        this.mLayoutType = 1;
        this.mColumnCount = 1;
        this.mColumnGap = 0.0f;
        this.mColumnWidth = 0.0f;
        this.mLeftGap = 0.0f;
        this.mRightGap = 0.0f;
        this.mOffsetAccuracy = 10;
        this.mLastReport = new Point(-1, -1);
        this.mHasAddScrollEvent = false;
        this.mStickyMap = new HashMap();
        this.keepPositionCell = null;
        this.keepPositionCellRunnable = null;
        this.keepPositionLayoutDelay = 150L;
        this.isThisGroupFinished = false;
        this.stickyHelper = new WXStickyHelper(this);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setMarginsSupportRTL(ViewGroup.MarginLayoutParams lp, int left, int top, int right, int bottom) {
        if (Build.VERSION.SDK_INT >= 17) {
            lp.setMargins(left, top, right, bottom);
            lp.setMarginStart(left);
            lp.setMarginEnd(right);
        } else if (lp instanceof FrameLayout.LayoutParams) {
            FrameLayout.LayoutParams layoutParams = (FrameLayout.LayoutParams) lp;
            if (isLayoutRTL()) {
                layoutParams.gravity = 53;
                lp.setMargins(right, top, left, bottom);
                return;
            }
            layoutParams.gravity = 51;
            lp.setMargins(left, top, right, bottom);
        } else {
            lp.setMargins(left, top, right, bottom);
        }
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void setLayout(WXComponent component) {
        if (component.getHostView() != null) {
            ViewCompat.setLayoutDirection(component.getHostView(), component.isLayoutRTL() ? 1 : 0);
        }
        super.setLayout(component);
    }

    protected void onHostViewInitialized(T host) {
        super.onHostViewInitialized((BasicListComponent<T>) host);
        WXRecyclerView innerView = host.getInnerView();
        if (innerView == null || innerView.getAdapter() == null) {
            WXLogUtils.e(this.TAG, "RecyclerView is not found or Adapter is not bound");
            return;
        }
        if (WXUtils.getBoolean(getAttrs().get("prefetchGapDisable"), false).booleanValue() && innerView.getLayoutManager() != null) {
            innerView.getLayoutManager().setItemPrefetchEnabled(false);
        }
        if (this.mChildren == null) {
            WXLogUtils.e(this.TAG, "children is null");
            return;
        }
        this.mDragHelper = new DefaultDragHelper(this.mChildren, innerView, new EventTrigger() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.1
            @Override // com.taobao.weex.ui.component.list.EventTrigger
            public void triggerEvent(String type, Map<String, Object> args) {
                BasicListComponent.this.fireEvent(type, args);
            }
        });
        this.mTriggerType = getTriggerType(this);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public WXComponent.MeasureOutput measure(int width, int height) {
        return super.measure(width, height);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer, com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        if (this.mAppearChangeRunnable != null && getHostView() != 0) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            this.mAppearChangeRunnable = null;
        }
        if (getHostView() != 0 && ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() != null) {
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().clearOnScrollListeners();
        }
        super.destroy();
        Map<String, Map<String, WXComponent>> map = this.mStickyMap;
        if (map != null) {
            map.clear();
        }
        SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
        if (sparseArray != null) {
            sparseArray.clear();
        }
        ArrayMap<String, Long> arrayMap = this.mRefToViewType;
        if (arrayMap != null) {
            arrayMap.clear();
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public ViewGroup.LayoutParams getChildLayoutParams(WXComponent child, View hostView, int width, int height, int left, int right, int top, int bottom) {
        ViewGroup.MarginLayoutParams marginLayoutParams = (ViewGroup.MarginLayoutParams) hostView.getLayoutParams();
        if ((child instanceof WXBaseRefresh) && marginLayoutParams == null) {
            return new LinearLayout.LayoutParams(width, height);
        }
        if (marginLayoutParams == null) {
            return new RecyclerView.LayoutParams(width, height);
        }
        marginLayoutParams.width = width;
        marginLayoutParams.height = height;
        setMarginsSupportRTL(marginLayoutParams, left, 0, right, 0);
        return marginLayoutParams;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    protected T initComponentHostView(Context context) {
        T generateListView = generateListView(context, getOrientation());
        String attrByKey = getAttrByKey("transform");
        if (attrByKey != null) {
            generateListView.getInnerView().addItemDecoration(RecyclerTransform.parseTransforms(getOrientation(), attrByKey));
        }
        if (getAttrs().get(Constants.Name.KEEP_POSITION_LAYOUT_DELAY) != null) {
            this.keepPositionLayoutDelay = WXUtils.getNumberInt(getAttrs().get(Constants.Name.KEEP_POSITION_LAYOUT_DELAY), (int) this.keepPositionLayoutDelay);
        }
        if (getAttrs().get("appearActionDelay") != null) {
            this.mAppearChangeRunnableDelay = WXUtils.getNumberInt(getAttrs().get("appearActionDelay"), (int) this.mAppearChangeRunnableDelay);
        }
        T t = generateListView;
        this.mItemAnimator = t.getInnerView().getItemAnimator();
        RecyclerViewBaseAdapter recyclerViewBaseAdapter = new RecyclerViewBaseAdapter(this);
        recyclerViewBaseAdapter.setHasStableIds(true);
        t.setRecyclerViewBaseAdapter(recyclerViewBaseAdapter);
        t.getInnerView().addOnScrollListener(this.mViewOnScrollListener);
        if (getAttrs().get(Constants.Name.HAS_FIXED_SIZE) != null) {
            t.getInnerView().setHasFixedSize(WXUtils.getBoolean(getAttrs().get(Constants.Name.HAS_FIXED_SIZE), false).booleanValue());
        }
        t.getInnerView().addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.2
            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrollStateChanged(RecyclerView recyclerView, int newState) {
                int size;
                View childAt;
                super.onScrollStateChanged(recyclerView, newState);
                BasicListComponent.this.getScrollStartEndHelper().onScrollStateChanged(newState);
                List<OnWXScrollListener> wXScrollListeners = BasicListComponent.this.getInstance().getWXScrollListeners();
                if (wXScrollListeners == null || (size = wXScrollListeners.size()) <= 0) {
                    return;
                }
                for (int i = 0; i < size && i < wXScrollListeners.size(); i++) {
                    OnWXScrollListener onWXScrollListener = wXScrollListeners.get(i);
                    if (onWXScrollListener != null && (childAt = recyclerView.getChildAt(0)) != null) {
                        onWXScrollListener.onScrollStateChanged(recyclerView, 0, childAt.getTop(), newState);
                    }
                }
            }

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);
                List<OnWXScrollListener> wXScrollListeners = BasicListComponent.this.getInstance().getWXScrollListeners();
                if (wXScrollListeners == null || wXScrollListeners.size() <= 0) {
                    return;
                }
                try {
                    for (OnWXScrollListener onWXScrollListener : wXScrollListeners) {
                        if (onWXScrollListener != null) {
                            if (onWXScrollListener instanceof ICheckBindingScroller) {
                                if (((ICheckBindingScroller) onWXScrollListener).isNeedScroller(BasicListComponent.this.getRef(), null)) {
                                    onWXScrollListener.onScrolled(recyclerView, dx, dy);
                                }
                            } else {
                                onWXScrollListener.onScrolled(recyclerView, dx, dy);
                            }
                        }
                    }
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
        generateListView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.3
            @Override // android.view.ViewTreeObserver.OnGlobalLayoutListener
            public void onGlobalLayout() {
                ViewGroup viewGroup = (ViewGroup) BasicListComponent.this.getHostView();
                if (viewGroup == null) {
                    return;
                }
                BasicListComponent.this.mViewOnScrollListener.onScrolled(((ListComponentView) viewGroup).getInnerView(), 0, 0);
                if (Build.VERSION.SDK_INT >= 16) {
                    viewGroup.getViewTreeObserver().removeOnGlobalLayoutListener(this);
                } else {
                    viewGroup.getViewTreeObserver().removeGlobalOnLayoutListener(this);
                }
            }
        });
        return generateListView;
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindStickStyle(WXComponent component) {
        this.stickyHelper.bindStickStyle(component, this.mStickyMap);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindStickStyle(WXComponent component) {
        this.stickyHelper.unbindStickStyle(component, this.mStickyMap);
        WXHeader wXHeader = (WXHeader) findTypeParent(component, WXHeader.class);
        if (wXHeader == null || getHostView() == 0) {
            return;
        }
        ((ListComponentView) ((ViewGroup) getHostView())).notifyStickyRemove(wXHeader);
    }

    private WXComponent findDirectListChild(WXComponent comp) {
        WXVContainer parent;
        if (comp == null || (parent = comp.getParent()) == null) {
            return null;
        }
        return parent instanceof BasicListComponent ? comp : findDirectListChild(parent);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    @Override // com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -304480883:
                if (key.equals(Constants.Name.DRAGGABLE)) {
                    c = 0;
                    break;
                }
                break;
            case -223520855:
                if (key.equals(Constants.Name.SHOW_SCROLLBAR)) {
                    c = 1;
                    break;
                }
                break;
            case -112563826:
                if (key.equals("loadmoreoffset")) {
                    c = 2;
                    break;
                }
                break;
            case -5620052:
                if (key.equals(Constants.Name.OFFSET_ACCURACY)) {
                    c = 3;
                    break;
                }
                break;
            case 66669991:
                if (key.equals(Constants.Name.SCROLLABLE)) {
                    c = 4;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                setDraggable(WXUtils.getBoolean(param, false).booleanValue());
                return true;
            case 1:
                Boolean bool = WXUtils.getBoolean(param, null);
                if (bool != null) {
                    setShowScrollbar(bool.booleanValue());
                }
                return true;
            case 2:
                break;
            case 3:
                setOffsetAccuracy(WXUtils.getInteger(param, 10).intValue());
                break;
            case 4:
                setScrollable(WXUtils.getBoolean(param, true).booleanValue());
                return true;
            default:
                return super.setProperty(key, param);
        }
        return true;
    }

    @WXComponentProp(name = Constants.Name.SCROLLABLE)
    public void setScrollable(boolean scrollable) {
        this.isScrollable = scrollable;
        WXRecyclerView innerView = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        if (innerView != null) {
            innerView.setScrollable(scrollable);
        }
    }

    @WXComponentProp(name = Constants.Name.OFFSET_ACCURACY)
    public void setOffsetAccuracy(int accuracy) {
        this.mOffsetAccuracy = (int) WXViewUtils.getRealPxByWidth(accuracy, getInstance().getInstanceViewPortWidthWithFloat());
    }

    @WXComponentProp(name = Constants.Name.DRAGGABLE)
    public void setDraggable(boolean isDraggable) {
        DragHelper dragHelper = this.mDragHelper;
        if (dragHelper != null) {
            dragHelper.setDraggable(isDraggable);
        }
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("set draggable : " + isDraggable);
        }
    }

    @WXComponentProp(name = Constants.Name.SHOW_SCROLLBAR)
    public void setShowScrollbar(boolean show) {
        if (getHostView() == 0 || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null) {
            return;
        }
        if (getOrientation() == 1) {
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setVerticalScrollBarEnabled(show);
        } else {
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setHorizontalScrollBarEnabled(show);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public boolean isScrollable() {
        return this.isScrollable;
    }

    private void setAppearanceWatch(WXComponent component, int event, boolean enable) {
        AppearanceHelper appearanceHelper = this.mAppearComponents.get(component.getRef());
        if (appearanceHelper != null) {
            appearanceHelper.setWatchEvent(event, enable);
        } else if (enable) {
            int indexOf = this.mChildren.indexOf(findDirectListChild(component));
            if (indexOf != -1) {
                AppearanceHelper appearanceHelper2 = new AppearanceHelper(component, indexOf);
                appearanceHelper2.setWatchEvent(event, true);
                this.mAppearComponents.put(component.getRef(), appearanceHelper2);
            }
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, true);
        if (this.mAppearChangeRunnable == null) {
            this.mAppearChangeRunnable = new Runnable() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.4
                @Override // java.lang.Runnable
                public void run() {
                    if (BasicListComponent.this.mAppearChangeRunnable != null) {
                        BasicListComponent.this.notifyAppearStateChange(0, 0, 0, 0);
                    }
                }
            };
        }
        if (getHostView() != 0) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            ((ViewGroup) getHostView()).postDelayed(this.mAppearChangeRunnable, this.mAppearChangeRunnableDelay);
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void bindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, true);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindAppearEvent(WXComponent component) {
        setAppearanceWatch(component, 0, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void unbindDisappearEvent(WXComponent component) {
        setAppearanceWatch(component, 1, false);
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public void scrollTo(WXComponent component, Map<String, Object> options) {
        int indexOf;
        boolean z = true;
        float f = 0.0f;
        if (options != null) {
            String obj = options.get("offset") == null ? WXInstanceApm.VALUE_ERROR_CODE_DEFAULT : options.get("offset").toString();
            z = WXUtils.getBoolean(options.get(Constants.Name.ANIMATED), true).booleanValue();
            if (obj != null) {
                try {
                    f = WXViewUtils.getRealPxByWidth(Float.parseFloat(obj), getInstance().getInstanceViewPortWidthWithFloat());
                } catch (Exception e) {
                    WXLogUtils.e("Float parseFloat error :" + e.getMessage());
                }
            }
        }
        int i = (int) f;
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return;
        }
        WXCell wXCell = null;
        while (true) {
            if (component == null) {
                break;
            } else if (component instanceof WXCell) {
                wXCell = (WXCell) component;
                break;
            } else {
                component = component.getParent();
            }
        }
        if (wXCell == null || (indexOf = this.mChildren.indexOf(wXCell)) == -1) {
            return;
        }
        ((ListComponentView) viewGroup).getInnerView().scrollTo(z, indexOf, i, getOrientation());
    }

    /* JADX WARN: Removed duplicated region for block: B:52:0x00e1  */
    /* JADX WARN: Removed duplicated region for block: B:61:0x00fc  */
    /* JADX WARN: Removed duplicated region for block: B:67:0x0108  */
    /* JADX WARN: Removed duplicated region for block: B:68:0x010f  */
    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void onBeforeScroll(int dx, int dy) {
        Map<String, WXComponent> map;
        boolean z;
        boolean z2;
        boolean z3;
        ViewGroup viewGroup = (ViewGroup) getHostView();
        Map<String, Map<String, WXComponent>> map2 = this.mStickyMap;
        if (map2 == null || viewGroup == null || (map = map2.get(getRef())) == null) {
            return;
        }
        int i = -1;
        for (Map.Entry<String, WXComponent> entry : map.entrySet()) {
            WXComponent value = entry.getValue();
            if (value != null && (value instanceof WXCell)) {
                WXCell wXCell = (WXCell) value;
                if (wXCell.getHostView() == 0) {
                    return;
                }
                int[] iArr = new int[2];
                value.getHostView().getLocationOnScreen(iArr);
                int[] iArr2 = new int[2];
                value.getParentScroller().getView().getLocationOnScreen(iArr2);
                boolean z4 = true;
                int i2 = iArr[1] - iArr2[1];
                RecyclerView.LayoutManager layoutManager = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getLayoutManager();
                if ((layoutManager instanceof LinearLayoutManager) || (layoutManager instanceof GridLayoutManager)) {
                    LinearLayoutManager linearLayoutManager = (LinearLayoutManager) layoutManager;
                    int findFirstVisibleItemPosition = linearLayoutManager.findFirstVisibleItemPosition();
                    int findLastVisibleItemPosition = linearLayoutManager.findLastVisibleItemPosition();
                    int indexOf = this.mChildren.indexOf(wXCell);
                    wXCell.setScrollPositon(indexOf);
                    if (indexOf <= findFirstVisibleItemPosition || (wXCell.getStickyOffset() > 0 && findFirstVisibleItemPosition < indexOf && indexOf <= findLastVisibleItemPosition && i2 <= wXCell.getStickyOffset())) {
                        if (indexOf > i) {
                            i = indexOf;
                        }
                        z = true;
                        z2 = false;
                        z3 = !z && wXCell.getLocationFromStart() >= 0 && i2 <= wXCell.getStickyOffset() && dy >= 0;
                        z4 = (wXCell.getLocationFromStart() <= wXCell.getStickyOffset() || i2 <= wXCell.getStickyOffset() || dy > 0) ? false : false;
                        if (z3) {
                            ((ListComponentView) viewGroup).notifyStickyShow(wXCell);
                        } else if (z4 || z2) {
                            ((ListComponentView) viewGroup).notifyStickyRemove(wXCell);
                        }
                        wXCell.setLocationFromStart(i2);
                    }
                    z = false;
                    z2 = true;
                    if (z) {
                    }
                    if (wXCell.getLocationFromStart() <= wXCell.getStickyOffset()) {
                    }
                    if (z3) {
                    }
                    wXCell.setLocationFromStart(i2);
                } else if (layoutManager instanceof StaggeredGridLayoutManager) {
                    int[] iArr3 = new int[3];
                    StaggeredGridLayoutManager staggeredGridLayoutManager = (StaggeredGridLayoutManager) layoutManager;
                    int i3 = staggeredGridLayoutManager.findFirstVisibleItemPositions(iArr3)[0];
                    int i4 = staggeredGridLayoutManager.findLastVisibleItemPositions(iArr3)[0];
                    int indexOf2 = this.mChildren.indexOf(wXCell);
                    if (indexOf2 <= i3 || (wXCell.getStickyOffset() > 0 && i3 < indexOf2 && indexOf2 <= i4 && i2 <= wXCell.getStickyOffset())) {
                        if (indexOf2 > i) {
                            i = indexOf2;
                        }
                        z = true;
                        z2 = false;
                        if (z) {
                        }
                        if (wXCell.getLocationFromStart() <= wXCell.getStickyOffset()) {
                        }
                        if (z3) {
                        }
                        wXCell.setLocationFromStart(i2);
                    }
                    z = false;
                    z2 = true;
                    if (z) {
                    }
                    if (wXCell.getLocationFromStart() <= wXCell.getStickyOffset()) {
                    }
                    if (z3) {
                    }
                    wXCell.setLocationFromStart(i2);
                } else {
                    z = false;
                    z2 = false;
                    if (z) {
                    }
                    if (wXCell.getLocationFromStart() <= wXCell.getStickyOffset()) {
                    }
                    if (z3) {
                    }
                    wXCell.setLocationFromStart(i2);
                }
            }
        }
        if (i >= 0) {
            ((ListComponentView) viewGroup).updateStickyView(i);
        } else if (viewGroup instanceof BounceRecyclerView) {
            ((BounceRecyclerView) viewGroup).getStickyHeaderHelper().clearStickyHeaders();
        }
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollY() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return 0;
        }
        return ((ListComponentView) viewGroup).getInnerView().getScrollY();
    }

    @Override // com.taobao.weex.ui.component.Scrollable
    public int getScrollX() {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return 0;
        }
        return ((ListComponentView) viewGroup).getInnerView().getScrollX();
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child) {
        addChild(child, -1);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void addChild(WXComponent child, int index) {
        boolean z;
        super.addChild(child, index);
        if (child == null || index < -1) {
            return;
        }
        if (index >= this.mChildren.size()) {
            index = -1;
        }
        bindViewType(child);
        boolean z2 = false;
        if (this.isThisGroupFinished || !isRenderFromBottom()) {
            z = false;
        } else if (!child.getAttrs().containsKey("renderReversePosition")) {
            return;
        } else {
            z = true;
        }
        this.isThisGroupFinished = true;
        int size = index == -1 ? this.mChildren.size() - 1 : index;
        final ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup != null) {
            if (getBasicComponentData() != null && "default".equals(getAttrs().get(Constants.Name.INSERT_CELL_ANIMATION))) {
                ((ListComponentView) viewGroup).getInnerView().setItemAnimator(this.mItemAnimator);
            } else {
                ((ListComponentView) viewGroup).getInnerView().setItemAnimator(null);
            }
            if (child.getBasicComponentData() != null && WXUtils.getBoolean(child.getAttrs().get(Constants.Name.KEEP_SCROLL_POSITION), false).booleanValue() && index <= getChildCount() && index > -1) {
                z2 = true;
            }
            if (!z2 && z) {
                z2 = true;
            }
            if (z2) {
                ListComponentView listComponentView = (ListComponentView) viewGroup;
                if (listComponentView.getInnerView().getLayoutManager() instanceof LinearLayoutManager) {
                    if (this.keepPositionCell == null) {
                        ListBaseViewHolder listBaseViewHolder = (ListBaseViewHolder) listComponentView.getInnerView().findViewHolderForAdapterPosition(((LinearLayoutManager) listComponentView.getInnerView().getLayoutManager()).findLastCompletelyVisibleItemPosition());
                        if (listBaseViewHolder != null) {
                            this.keepPositionCell = listBaseViewHolder.getComponent();
                        }
                        if (this.keepPositionCell != null) {
                            if (!listComponentView.getInnerView().isLayoutFrozen()) {
                                listComponentView.getInnerView().setLayoutFrozen(true);
                            }
                            Runnable runnable = this.keepPositionCellRunnable;
                            if (runnable != null) {
                                viewGroup.removeCallbacks(runnable);
                            }
                            this.keepPositionCellRunnable = new Runnable() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.5
                                @Override // java.lang.Runnable
                                public void run() {
                                    if (BasicListComponent.this.keepPositionCell != null) {
                                        BasicListComponent basicListComponent = BasicListComponent.this;
                                        int indexOf = basicListComponent.indexOf(basicListComponent.keepPositionCell);
                                        int top = BasicListComponent.this.keepPositionCell.getHostView() != null ? BasicListComponent.this.keepPositionCell.getHostView().getTop() : 0;
                                        if (top > 0) {
                                            ((LinearLayoutManager) ((ListComponentView) viewGroup).getInnerView().getLayoutManager()).scrollToPositionWithOffset(indexOf, top);
                                        } else {
                                            ((ListComponentView) viewGroup).getInnerView().getLayoutManager().scrollToPosition(indexOf);
                                        }
                                        ((ListComponentView) viewGroup).getInnerView().setLayoutFrozen(false);
                                        BasicListComponent.this.keepPositionCell = null;
                                        BasicListComponent.this.keepPositionCellRunnable = null;
                                    }
                                }
                            };
                        }
                    }
                    if (this.keepPositionCellRunnable == null) {
                        int findLastVisibleItemPosition = ((LinearLayoutManager) listComponentView.getInnerView().getLayoutManager()).findLastVisibleItemPosition();
                        if (!z) {
                            index = findLastVisibleItemPosition;
                        }
                        listComponentView.getInnerView().scrollToPosition(index);
                    }
                }
                listComponentView.getRecyclerViewBaseAdapter().notifyItemRangeInserted(size, 20);
                Runnable runnable2 = this.keepPositionCellRunnable;
                if (runnable2 != null) {
                    viewGroup.removeCallbacks(runnable2);
                    viewGroup.postDelayed(this.keepPositionCellRunnable, this.keepPositionLayoutDelay);
                }
            } else {
                ((ListComponentView) viewGroup).getRecyclerViewBaseAdapter().notifyDataSetChanged();
            }
        }
        relocateAppearanceHelper();
    }

    private void relocateAppearanceHelper() {
        for (Map.Entry<String, AppearanceHelper> entry : this.mAppearComponents.entrySet()) {
            AppearanceHelper value = entry.getValue();
            value.setCellPosition(this.mChildren.indexOf(findDirectListChild(value.getAwareChild())));
        }
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public void remove(WXComponent child, boolean destroy) {
        int indexOf = this.mChildren.indexOf(child);
        if (destroy) {
            child.detachViewAndClearPreInfo();
        }
        unBindViewType(child);
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return;
        }
        if ("default".equals(child.getAttrs().get(Constants.Name.DELETE_CELL_ANIMATION))) {
            ((ListComponentView) viewGroup).getInnerView().setItemAnimator(this.mItemAnimator);
        } else {
            ((ListComponentView) viewGroup).getInnerView().setItemAnimator(null);
        }
        ((ListComponentView) viewGroup).getRecyclerViewBaseAdapter().notifyItemRemoved(indexOf);
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.d(str, "removeChild child at " + indexOf);
        }
        super.remove(child, destroy);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void computeVisiblePointInViewCoordinate(PointF pointF) {
        WXRecyclerView innerView = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        pointF.set(innerView.computeHorizontalScrollOffset(), innerView.computeVerticalScrollOffset());
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public void onViewRecycled(ListBaseViewHolder holder) {
        long currentTimeMillis = System.currentTimeMillis();
        holder.setComponentUsing(false);
        if (holder != null && holder.canRecycled() && holder.getComponent() != null && !holder.getComponent().isUsing()) {
            holder.recycled();
        } else {
            WXLogUtils.w(this.TAG, "this holder can not be allowed to  recycled");
        }
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.d(str, "Recycle holder " + (System.currentTimeMillis() - currentTimeMillis) + "  Thread:" + Thread.currentThread().getName());
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public void onBindViewHolder(final ListBaseViewHolder holder, int position) {
        int color;
        if (holder == null) {
            return;
        }
        holder.setComponentUsing(true);
        IWXObject listChild = getListChild(position);
        if (listChild instanceof ListStanceCell) {
            holder.getView().setBackgroundColor(WXResourceUtils.getColor(((ListStanceCell) listChild).getBackgroundColor(), -1));
            holder.getView().setVisibility(0);
            holder.getView().postInvalidate();
        } else if (listChild instanceof WXComponent) {
            WXComponent wXComponent = (WXComponent) listChild;
            if (wXComponent == null || (wXComponent instanceof WXRefresh) || (wXComponent instanceof WXLoading) || wXComponent.isFixed()) {
                if (WXEnvironment.isApkDebugable()) {
                    String str = this.TAG;
                    WXLogUtils.d(str, "Bind WXRefresh & WXLoading " + holder);
                }
                if (!(wXComponent instanceof WXBaseRefresh) || holder.getView() == null) {
                    return;
                }
                if (wXComponent.getAttrs().get("holderBackground") != null || wXComponent.getStyles().containsKey("backgroundColor")) {
                    Object obj = wXComponent.getAttrs().get("holderBackground");
                    if (obj != null) {
                        color = WXResourceUtils.getColor(obj.toString(), -1);
                    } else {
                        color = WXResourceUtils.getColor(wXComponent.getStyles().getBackgroundColor(), -1);
                    }
                    holder.getView().setBackgroundColor(color);
                    holder.getView().setVisibility(0);
                    holder.getView().postInvalidate();
                }
            } else if (holder.getComponent() == null || !(holder.getComponent() instanceof WXCell)) {
            } else {
                if (holder.isRecycled()) {
                    holder.bindData(wXComponent);
                    wXComponent.onRenderFinish(1);
                }
                DragHelper dragHelper = this.mDragHelper;
                if (dragHelper == null || !dragHelper.isDraggable()) {
                    return;
                }
                String str2 = this.mTriggerType;
                if (str2 == null) {
                    str2 = "longpress";
                }
                this.mTriggerType = str2;
                WXCell wXCell = (WXCell) holder.getComponent();
                boolean booleanValue = WXUtils.getBoolean(wXCell.getAttrs().get(EXCLUDED), false).booleanValue();
                this.mDragHelper.setDragExcluded(holder, booleanValue);
                if ("pan".equals(this.mTriggerType)) {
                    this.mDragHelper.setLongPressDragEnabled(false);
                    WXComponent findComponentByAnchorName = findComponentByAnchorName(wXCell, DRAG_ANCHOR);
                    if (findComponentByAnchorName != null && findComponentByAnchorName.getHostView() != null && !booleanValue) {
                        findComponentByAnchorName.getHostView().setOnTouchListener(new View.OnTouchListener() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.6
                            @Override // android.view.View.OnTouchListener
                            public boolean onTouch(View v, MotionEvent event) {
                                if (MotionEventCompat.getActionMasked(event) == 0) {
                                    BasicListComponent.this.mDragHelper.startDrag(holder);
                                    return true;
                                }
                                return true;
                            }
                        });
                    } else if (WXEnvironment.isApkDebugable()) {
                        if (!booleanValue) {
                            WXLogUtils.e(this.TAG, "[error] onBindViewHolder: the anchor component or view is not found");
                            return;
                        }
                        String str3 = this.TAG;
                        WXLogUtils.d(str3, "onBindViewHolder: position " + position + " is drag excluded");
                    }
                } else if ("longpress".equals(this.mTriggerType)) {
                    this.mDragHelper.setLongPressDragEnabled(true);
                }
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void markComponentUsable() {
        Iterator<WXComponent> it = this.mChildren.iterator();
        while (it.hasNext()) {
            it.next().setUsing(false);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public ListBaseViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        if (viewType == -1) {
            return createVHForRefreshComponent(viewType);
        }
        if (this.mChildren != null) {
            SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
            if (sparseArray == null) {
                return createVHForFakeComponent(viewType);
            }
            ArrayList<WXComponent> arrayList = sparseArray.get(viewType);
            checkRecycledViewPool(viewType);
            if (arrayList == null) {
                return createVHForFakeComponent(viewType);
            }
            for (int i = 0; i < arrayList.size(); i++) {
                WXComponent wXComponent = arrayList.get(i);
                if (wXComponent != null && !wXComponent.isUsing()) {
                    if (wXComponent.isFixed()) {
                        return createVHForFakeComponent(viewType);
                    }
                    if (wXComponent instanceof WXCell) {
                        if (wXComponent.getRealView() != null) {
                            return new ListBaseViewHolder(wXComponent, viewType);
                        }
                        wXComponent.lazy(false);
                        wXComponent.createView();
                        wXComponent.applyLayoutAndEvent(wXComponent);
                        return new ListBaseViewHolder(wXComponent, viewType, true);
                    } else if (wXComponent instanceof WXBaseRefresh) {
                        return createVHForRefreshComponent(viewType);
                    } else {
                        WXLogUtils.e(this.TAG, "List cannot include element except cell、header、fixed、refresh and loading");
                        return createVHForFakeComponent(viewType);
                    }
                }
            }
        }
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.e(str, "Cannot find request viewType: " + viewType);
        }
        return createVHForFakeComponent(viewType);
    }

    private void checkRecycledViewPool(int viewType) {
        try {
            if (this.mViewTypes.size() > 9) {
                mAllowCacheViewHolder = false;
            }
            if (mDownForBidCacheViewHolder && getHostView() != 0 && ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() != null) {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getRecycledViewPool().setMaxRecycledViews(viewType, 0);
            }
            if (mDownForBidCacheViewHolder || mAllowCacheViewHolder || getHostView() == 0 || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null) {
                return;
            }
            for (int i = 0; i < this.mViewTypes.size(); i++) {
                ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().getRecycledViewPool().setMaxRecycledViews(this.mViewTypes.keyAt(i), 0);
            }
            mDownForBidCacheViewHolder = true;
        } catch (Exception unused) {
            WXLogUtils.e(this.TAG, "Clear recycledViewPool error!");
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemViewType(int position) {
        return generateViewType(getListChild(position));
    }

    private WXComponent findComponentByAnchorName(WXComponent root, String anchorName) {
        String string;
        long currentTimeMillis = WXEnvironment.isApkDebugable() ? System.currentTimeMillis() : 0L;
        ArrayDeque arrayDeque = new ArrayDeque();
        arrayDeque.add(root);
        while (!arrayDeque.isEmpty()) {
            WXComponent wXComponent = (WXComponent) arrayDeque.removeFirst();
            if (wXComponent != null && (string = WXUtils.getString(wXComponent.getAttrs().get(anchorName), null)) != null && string.equals(AbsoluteConst.TRUE)) {
                if (WXEnvironment.isApkDebugable()) {
                    WXLogUtils.d("dragPerf", "findComponentByAnchorName time: " + (System.currentTimeMillis() - currentTimeMillis) + "ms");
                }
                return wXComponent;
            } else if (wXComponent instanceof WXVContainer) {
                WXVContainer wXVContainer = (WXVContainer) wXComponent;
                int childCount = wXVContainer.childCount();
                for (int i = 0; i < childCount; i++) {
                    arrayDeque.add(wXVContainer.getChild(i));
                }
            }
        }
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("dragPerf", "findComponentByAnchorName elapsed time: " + (System.currentTimeMillis() - currentTimeMillis) + "ms");
        }
        return null;
    }

    private String getTriggerType(WXComponent component) {
        String str = "longpress";
        if (component == null) {
            return "longpress";
        }
        String string = WXUtils.getString(component.getAttrs().get(DRAG_TRIGGER_TYPE), "longpress");
        if ("longpress".equals(string) || "pan".equals(string)) {
            str = string;
        }
        if (WXEnvironment.isApkDebugable()) {
            String str2 = this.TAG;
            WXLogUtils.d(str2, "trigger type is " + str);
        }
        return str;
    }

    private void bindViewType(WXComponent component) {
        int generateViewType = generateViewType(component);
        if (this.mViewTypes == null) {
            this.mViewTypes = new SparseArray<>();
        }
        ArrayList<WXComponent> arrayList = this.mViewTypes.get(generateViewType);
        if (arrayList == null) {
            arrayList = new ArrayList<>();
            this.mViewTypes.put(generateViewType, arrayList);
        }
        arrayList.add(component);
    }

    private void unBindViewType(WXComponent component) {
        ArrayList<WXComponent> arrayList;
        int generateViewType = generateViewType(component);
        SparseArray<ArrayList<WXComponent>> sparseArray = this.mViewTypes;
        if (sparseArray == null || (arrayList = sparseArray.get(generateViewType)) == null) {
            return;
        }
        arrayList.remove(component);
    }

    private int generateViewType(IWXObject object) {
        long j = -1;
        try {
            if (!(object instanceof ListStanceCell) && (object instanceof WXComponent)) {
                WXComponent wXComponent = (WXComponent) object;
                long parseInt = Integer.parseInt(wXComponent.getRef());
                String scope = wXComponent.getAttrs().getScope();
                if (TextUtils.isEmpty(scope)) {
                    j = parseInt;
                } else {
                    if (this.mRefToViewType == null) {
                        this.mRefToViewType = new ArrayMap<>();
                    }
                    if (!this.mRefToViewType.containsKey(scope)) {
                        this.mRefToViewType.put(scope, Long.valueOf(parseInt));
                    }
                    j = this.mRefToViewType.get(scope).longValue();
                }
            }
        } catch (RuntimeException e) {
            WXLogUtils.eTag(this.TAG, e);
            WXLogUtils.e(this.TAG, "getItemViewType: NO ID, this will crash the whole render system of WXListRecyclerView");
        }
        return (int) j;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public int getItemCount() {
        if (this.isThisGroupFinished) {
            return getChildCount();
        }
        return 0;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public boolean onFailedToRecycleView(ListBaseViewHolder holder) {
        if (WXEnvironment.isApkDebugable()) {
            String str = this.TAG;
            WXLogUtils.d(str, "Failed to recycle " + holder);
            return false;
        }
        return false;
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IRecyclerAdapterListener
    public long getItemId(int position) {
        try {
            IWXObject listChild = getListChild(position);
            if (!(listChild instanceof ListStanceCell) && (listChild instanceof WXComponent)) {
                return Long.parseLong(((WXComponent) listChild).getRef());
            }
            return -1L;
        } catch (RuntimeException e) {
            WXLogUtils.e(this.TAG, WXLogUtils.getStackTrace(e));
            return -1L;
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void onLoadMore(int offScreenY) {
        try {
            String loadMoreOffset = getAttrs().getLoadMoreOffset();
            if (TextUtils.isEmpty(loadMoreOffset)) {
                loadMoreOffset = WXInstanceApm.VALUE_ERROR_CODE_DEFAULT;
            }
            if (offScreenY > WXViewUtils.getRealPxByWidth(WXUtils.getInt(loadMoreOffset), getInstance().getInstanceViewPortWidthWithFloat()) || !getEvents().contains(Constants.Event.LOADMORE)) {
                return;
            }
            if (this.mListCellCount != this.mChildren.size() || this.mForceLoadmoreNextTime) {
                fireEvent(Constants.Event.LOADMORE);
                this.mListCellCount = this.mChildren.size();
                this.mForceLoadmoreNextTime = false;
            }
        } catch (Exception e) {
            WXLogUtils.d(this.TAG + "onLoadMore :", e);
        }
    }

    @Override // com.taobao.weex.ui.view.listview.adapter.IOnLoadMoreListener
    public void notifyAppearStateChange(int firstVisible, int lastVisible, int directionX, int directionY) {
        View hostView;
        String str = null;
        if (this.mAppearChangeRunnable != null) {
            ((ViewGroup) getHostView()).removeCallbacks(this.mAppearChangeRunnable);
            this.mAppearChangeRunnable = null;
        }
        if (directionY > 0) {
            str = "up";
        } else if (directionY < 0) {
            str = "down";
        }
        if (getOrientation() == 0 && directionX != 0) {
            str = directionX > 0 ? "left" : "right";
        }
        for (AppearanceHelper appearanceHelper : this.mAppearComponents.values()) {
            WXComponent awareChild = appearanceHelper.getAwareChild();
            if (appearanceHelper.isWatch() && (hostView = awareChild.getHostView()) != null) {
                int appearStatus = appearanceHelper.setAppearStatus(!(ViewCompat.isAttachedToWindow(hostView) ^ true) && appearanceHelper.isViewVisible(true));
                if (appearStatus != 0) {
                    boolean isApkDebugable = WXEnvironment.isApkDebugable();
                    String str2 = Constants.Event.APPEAR;
                    if (isApkDebugable) {
                        WXLogUtils.d(Constants.Event.APPEAR, "item " + appearanceHelper.getCellPositionINScollable() + " result " + appearStatus);
                    }
                    if (appearStatus != 1) {
                        str2 = Constants.Event.DISAPPEAR;
                    }
                    awareChild.notifyAppearStateChange(str2, str);
                }
            }
        }
    }

    private ListBaseViewHolder createVHForFakeComponent(int viewType) {
        FrameLayout frameLayout = new FrameLayout(getContext());
        frameLayout.setBackgroundColor(-1);
        frameLayout.setLayoutParams(new FrameLayout.LayoutParams(0, 0));
        return new ListBaseViewHolder(frameLayout, viewType);
    }

    private ListBaseViewHolder createVHForRefreshComponent(int viewType) {
        FrameLayout frameLayout = new FrameLayout(getContext());
        frameLayout.setLayoutParams(new FrameLayout.LayoutParams(-1, 1));
        return new ListBaseViewHolder(frameLayout, viewType);
    }

    @JSMethod
    public void resetLoadmore() {
        this.mForceLoadmoreNextTime = true;
        this.mListCellCount = 0;
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void addEvent(String type) {
        super.addEvent(type);
        if (!ScrollStartEndHelper.isScrollEvent(type) || getHostView() == 0 || ((ListComponentView) ((ViewGroup) getHostView())).getInnerView() == null || this.mHasAddScrollEvent) {
            return;
        }
        this.mHasAddScrollEvent = true;
        ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().addOnScrollListener(new RecyclerView.OnScrollListener() { // from class: com.taobao.weex.ui.component.list.BasicListComponent.7
            private boolean mFirstEvent = true;
            private int offsetXCorrection;
            private int offsetYCorrection;

            @Override // androidx.recyclerview.widget.RecyclerView.OnScrollListener
            public void onScrolled(RecyclerView recyclerView, int dx, int dy) {
                int i;
                int i2;
                super.onScrolled(recyclerView, dx, dy);
                int computeHorizontalScrollOffset = recyclerView.computeHorizontalScrollOffset();
                int computeVerticalScrollOffset = recyclerView.computeVerticalScrollOffset();
                if (dx == 0 && dy == 0) {
                    this.offsetXCorrection = computeHorizontalScrollOffset;
                    this.offsetYCorrection = computeVerticalScrollOffset;
                    i = 0;
                    i2 = 0;
                } else {
                    i = computeHorizontalScrollOffset - this.offsetXCorrection;
                    i2 = computeVerticalScrollOffset - this.offsetYCorrection;
                }
                BasicListComponent.this.getScrollStartEndHelper().onScrolled(i, i2);
                if (BasicListComponent.this.getEvents().contains("scroll")) {
                    if (this.mFirstEvent) {
                        this.mFirstEvent = false;
                        return;
                    }
                    RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
                    if (BasicListComponent.this.getOrientation() == 1) {
                        if (!layoutManager.canScrollVertically()) {
                            return;
                        }
                    } else if (BasicListComponent.this.getOrientation() == 0 && !layoutManager.canScrollHorizontally()) {
                        return;
                    }
                    if (BasicListComponent.this.shouldReport(i, i2)) {
                        BasicListComponent.this.fireScrollEvent(recyclerView, i, i2);
                    }
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void fireScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        if (getInstance() != null) {
            fireEvent("scroll", getScrollEvent(recyclerView, offsetX, offsetY));
        }
    }

    public Map<String, Object> getScrollEvent(RecyclerView recyclerView, int offsetX, int offsetY) {
        if (getOrientation() == 1) {
            offsetY = -calcContentOffset(recyclerView);
        }
        int measuredWidth = recyclerView.getMeasuredWidth() + recyclerView.computeHorizontalScrollRange();
        int i = 0;
        for (int i2 = 0; i2 < getChildCount(); i2++) {
            i = (int) (i + getListChildLayoutHeight(i2));
        }
        HashMap hashMap = new HashMap(3);
        HashMap hashMap2 = new HashMap(3);
        HashMap hashMap3 = new HashMap(3);
        hashMap2.put("width", Float.valueOf(WXViewUtils.getWebPxByWidth(measuredWidth, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap2.put("height", Float.valueOf(WXViewUtils.getWebPxByWidth(i, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap3.put(Constants.Name.X, Float.valueOf(-WXViewUtils.getWebPxByWidth(offsetX, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap3.put(Constants.Name.Y, Float.valueOf(-WXViewUtils.getWebPxByWidth(offsetY, getInstance().getInstanceViewPortWidthWithFloat())));
        hashMap.put(Constants.Name.CONTENT_SIZE, hashMap2);
        hashMap.put(Constants.Name.CONTENT_OFFSET, hashMap3);
        hashMap.put(Constants.Name.ISDRAGGING, Boolean.valueOf(recyclerView.getScrollState() == 1));
        return hashMap;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public boolean shouldReport(int offsetX, int offsetY) {
        if (this.mLastReport.x == -1 && this.mLastReport.y == -1) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        int abs = Math.abs(this.mLastReport.x - offsetX);
        int abs2 = Math.abs(this.mLastReport.y - offsetY);
        int i = this.mOffsetAccuracy;
        if (abs >= i || abs2 >= i) {
            this.mLastReport.x = offsetX;
            this.mLastReport.y = offsetY;
            return true;
        }
        return false;
    }

    public int calcContentOffset(RecyclerView recyclerView) {
        RecyclerView.LayoutManager layoutManager = recyclerView.getLayoutManager();
        int i = 0;
        if (layoutManager instanceof LinearLayoutManager) {
            int findFirstVisibleItemPosition = ((LinearLayoutManager) layoutManager).findFirstVisibleItemPosition();
            if (findFirstVisibleItemPosition == -1) {
                return 0;
            }
            View findViewByPosition = layoutManager.findViewByPosition(findFirstVisibleItemPosition);
            int top = findViewByPosition != null ? findViewByPosition.getTop() : 0;
            int i2 = 0;
            while (i < findFirstVisibleItemPosition) {
                i2 = (int) (i2 - getListChildLayoutHeight(i));
                i++;
            }
            if (layoutManager instanceof GridLayoutManager) {
                i2 /= ((GridLayoutManager) layoutManager).getSpanCount();
            }
            return i2 + top;
        } else if (layoutManager instanceof StaggeredGridLayoutManager) {
            StaggeredGridLayoutManager staggeredGridLayoutManager = (StaggeredGridLayoutManager) layoutManager;
            int spanCount = staggeredGridLayoutManager.getSpanCount();
            int i3 = staggeredGridLayoutManager.findFirstVisibleItemPositions(null)[0];
            if (i3 == -1) {
                return 0;
            }
            View findViewByPosition2 = layoutManager.findViewByPosition(i3);
            int top2 = findViewByPosition2 != null ? findViewByPosition2.getTop() : 0;
            int i4 = 0;
            while (i < i3) {
                i4 = (int) (i4 - getListChildLayoutHeight(i));
                i++;
            }
            return (i4 / spanCount) + top2;
        } else {
            return -1;
        }
    }

    public ScrollStartEndHelper getScrollStartEndHelper() {
        if (this.mScrollStartEndHelper == null) {
            this.mScrollStartEndHelper = new ScrollStartEndHelper(this);
        }
        return this.mScrollStartEndHelper;
    }

    @JSMethod
    public void setSpecialEffects(JSONObject info) {
        if (getHostView() == 0 || !(getHostView() instanceof BounceRecyclerView)) {
            return;
        }
        if (info != null && info.containsKey("id")) {
            String string = info.getString("id");
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("isNestParent", (Object) false);
            jSONObject.put("instanceId", (Object) getInstance().getInstanceId());
            jSONObject.put("listParentId", (Object) string);
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setNestInfo(jSONObject);
            ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().callBackNestParent(getRef(), getInstance().getInstanceId(), WXViewUtils.getRealPxByWidth(WXUtils.getFloat(info.getString("headerHeight")), getInstance().getInstanceViewPortWidthWithFloat()));
            return;
        }
        ((ListComponentView) ((ViewGroup) getHostView())).getInnerView().setNestInfo(null);
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsVContainer
    public int getChildCount() {
        WXComponent child = super.getChild(0);
        if (child != null && (child instanceof WXRefresh) && this.mColumnCount > 1) {
            return super.getChildCount() + (this.mColumnCount - 1);
        }
        return super.getChildCount();
    }

    public IWXObject getListChild(int index) {
        int i;
        WXComponent child = super.getChild(0);
        if (index == 0) {
            return child;
        }
        if (child == null || !(child instanceof WXRefresh) || (i = this.mColumnCount) <= 1) {
            return super.getChild(index);
        }
        if (index - i < 0) {
            return getListStanceCell(child.getStyles().getBackgroundColor());
        }
        return super.getChild(index - (i - 1));
    }

    private IWXObject getListStanceCell(String backgroundColor) {
        if (this.listStanceObject == null) {
            this.listStanceObject = new ListStanceCell(backgroundColor);
        }
        return this.listStanceObject;
    }

    private float getListChildLayoutHeight(int index) {
        WXComponent wXComponent;
        IWXObject listChild = getListChild(index);
        if (listChild != null) {
            if (listChild instanceof ListStanceCell) {
                return 1.0f;
            }
            if ((listChild instanceof WXComponent) && (wXComponent = (WXComponent) listChild) != null) {
                return wXComponent.getLayoutHeight();
            }
        }
        return 0.0f;
    }

    @WXComponentProp(name = "bounce")
    public void setBounce(String isBounce) {
        WXRecyclerView innerView = ((ListComponentView) ((ViewGroup) getHostView())).getInnerView();
        if (Boolean.valueOf(isBounce).booleanValue()) {
            innerView.setOverScrollMode(0);
        } else {
            innerView.setOverScrollMode(2);
        }
    }

    @JSMethod
    public void scrollTo(String op, JSCallback callback) {
        float realPxByWidth = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(JSON.parseObject(op).getString(Constants.Name.SCROLL_TOP)), getInstance().getInstanceViewPortWidthWithFloat());
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return;
        }
        WXRecyclerView innerView = ((ListComponentView) viewGroup).getInnerView();
        if (getOrientation() == 1) {
            innerView.scrollTo(0, (int) realPxByWidth, getOrientation());
        } else {
            innerView.scrollTo((int) realPxByWidth, 0, getOrientation());
        }
        if (callback != null) {
            HashMap hashMap = new HashMap();
            hashMap.put("type", WXImage.SUCCEED);
            callback.invoke(hashMap);
        }
    }

    @WXComponentProp(name = Constants.Name.SCROLL_TOP)
    public void setScrollTop(String topStr) {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return;
        }
        ((ListComponentView) viewGroup).getInnerView().scrollTo(0, (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(topStr), getInstance().getInstanceViewPortWidthWithFloat()), getOrientation());
    }

    @WXComponentProp(name = Constants.Name.SCROLL_LEFT)
    public void setScrollLeft(String leftStr) {
        ViewGroup viewGroup = (ViewGroup) getHostView();
        if (viewGroup == null) {
            return;
        }
        ((ListComponentView) viewGroup).getInnerView().scrollTo((int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(leftStr), getInstance().getInstanceViewPortWidthWithFloat()), 0, getOrientation());
    }

    @Override // io.dcloud.feature.uniapp.ui.component.AbsBasicComponent
    public void setIsLayoutRTL(boolean isRTL) {
        super.setIsLayoutRTL(isRTL);
        this.mViewOnScrollListener.setLayoutRTL(isRTL);
    }
}
