package com.taobao.weex.ui.component.richtext;

import android.content.Context;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.text.SpannedString;
import android.text.TextUtils;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement;
import com.taobao.weex.ui.ComponentCreator;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXText;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.richtext.node.RichTextNode;
import com.taobao.weex.ui.component.richtext.node.RichTextNodeManager;
import com.taobao.weex.ui.view.WXTextView;
import java.lang.reflect.InvocationTargetException;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class WXRichText extends WXText {
    private List<RichTextNode> nodes;

    /* loaded from: classes.dex */
    static class RichTextContentBoxMeasurement extends TextContentBoxMeasurement {
        public RichTextContentBoxMeasurement(WXComponent component) {
            super(component);
        }

        @Override // com.taobao.weex.layout.measurefunc.TextContentBoxMeasurement
        protected Spanned createSpanned(String text) {
            if (TextUtils.isEmpty(text)) {
                Spannable span = ((WXRichText) this.mComponent).toSpan();
                updateSpannable(span, RichTextNode.createSpanFlag(0));
                return span;
            }
            if (((this.mComponent.getInstance() != null) & (this.mComponent.getInstance().getUIContext() != null)) && !TextUtils.isEmpty(this.mComponent.getInstanceId())) {
                Spannable parse = RichTextNode.parse(this.mComponent.getInstance().getUIContext(), this.mComponent.getInstanceId(), this.mComponent.getRef(), text);
                updateSpannable(parse, RichTextNode.createSpanFlag(0));
                return parse;
            }
            return new SpannedString("");
        }
    }

    /* loaded from: classes.dex */
    public static class Creator implements ComponentCreator {
        @Override // com.taobao.weex.ui.ComponentCreator
        public WXComponent createInstance(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) throws IllegalAccessException, InvocationTargetException, InstantiationException {
            return new WXRichText(instance, parent, basicComponentData);
        }
    }

    public WXRichText(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.nodes = new LinkedList();
        setContentBoxMeasurement(new RichTextContentBoxMeasurement(this));
    }

    public void AddChildNode(String ref, String nodeType, String parentRef, Map<String, String> styles, Map<String, String> attrs) {
        if (getInstance() == null || getInstance().getUIContext() == null || TextUtils.isEmpty(getInstanceId()) || TextUtils.isEmpty(ref) || TextUtils.isEmpty(nodeType)) {
            return;
        }
        RichTextNode createRichTextNode = RichTextNodeManager.createRichTextNode(getInstance().getUIContext(), getInstanceId(), getRef(), ref, nodeType, styles, attrs);
        if (TextUtils.isEmpty(parentRef)) {
            this.nodes.add(createRichTextNode);
            return;
        }
        RichTextNode findRichNode = findRichNode(parentRef);
        if (findRichNode != null) {
            findRichNode.addChildNode(createRichTextNode);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public Spannable toSpan() {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        List<RichTextNode> list = this.nodes;
        if (list != null && !list.isEmpty()) {
            for (RichTextNode richTextNode : this.nodes) {
                spannableStringBuilder.append((CharSequence) richTextNode.toSpan(1));
            }
        }
        return spannableStringBuilder;
    }

    public void removeChildNode(String parentRef, String ref) {
        List<RichTextNode> list = this.nodes;
        if (list == null || list.isEmpty()) {
            return;
        }
        if (parentRef.equals("")) {
            for (RichTextNode richTextNode : this.nodes) {
                if (TextUtils.equals(richTextNode.getRef(), ref)) {
                    this.nodes.remove(richTextNode);
                }
            }
            return;
        }
        RichTextNode findRichNode = findRichNode(parentRef);
        if (findRichNode != null) {
            findRichNode.removeChildNode(ref);
        }
    }

    public void updateChildNodeStyles(String ref, Map<String, Object> styles) {
        RichTextNode findRichNode = findRichNode(ref);
        if (findRichNode != null) {
            findRichNode.updateStyles(styles);
        }
    }

    public void updateChildNodeAttrs(String ref, Map<String, Object> attrs) {
        RichTextNode findRichNode = findRichNode(ref);
        if (findRichNode != null) {
            findRichNode.updateAttrs(attrs);
        }
    }

    private RichTextNode findRichNode(String ref) {
        List<RichTextNode> list;
        if (TextUtils.isEmpty(ref) || (list = this.nodes) == null || list.isEmpty()) {
            return null;
        }
        for (RichTextNode richTextNode : this.nodes) {
            RichTextNode findRichNode = richTextNode.findRichNode(ref);
            if (findRichNode != null) {
                return findRichNode;
            }
        }
        return null;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXText, com.taobao.weex.ui.component.WXComponent
    public WXTextView initComponentHostView(Context context) {
        return new WXRichTextView(context);
    }
}
