package com.taobao.weex.ui.component.richtext.node;

import android.content.Context;
import android.net.Uri;
import android.text.SpannableStringBuilder;
import com.taobao.weex.WXSDKEngine;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.DrawableStrategy;
import com.taobao.weex.common.Constants;
import com.taobao.weex.ui.component.richtext.span.ImgSpan;
import com.taobao.weex.ui.component.richtext.span.ItemClickSpan;
import com.taobao.weex.utils.ImgURIUtil;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import java.util.LinkedList;
import java.util.Map;
/* JADX INFO: Access modifiers changed from: package-private */
/* loaded from: classes.dex */
public class ImgNode extends RichTextNode {
    public static final String NODE_TYPE = "image";

    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    protected boolean isInternalNode() {
        return false;
    }

    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    public String toString() {
        return "\ufeff";
    }

    /* loaded from: classes.dex */
    static class ImgNodeCreator implements RichTextNodeCreator<ImgNode> {
        @Override // com.taobao.weex.ui.component.richtext.node.RichTextNodeCreator
        public /* bridge */ /* synthetic */ ImgNode createRichTextNode(Context context, String instanceId, String componentRef, String ref, Map styles, Map attrs) {
            return createRichTextNode(context, instanceId, componentRef, ref, (Map<String, Object>) styles, (Map<String, Object>) attrs);
        }

        /* JADX WARN: Can't rename method to resolve collision */
        @Override // com.taobao.weex.ui.component.richtext.node.RichTextNodeCreator
        public ImgNode createRichTextNode(Context context, String instanceId, String componentRef) {
            return new ImgNode(context, instanceId, componentRef);
        }

        /* JADX WARN: Can't rename method to resolve collision */
        @Override // com.taobao.weex.ui.component.richtext.node.RichTextNodeCreator
        public ImgNode createRichTextNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
            return new ImgNode(context, instanceId, componentRef, ref, styles, attrs);
        }
    }

    private ImgNode(Context context, String instanceId, String componentRef) {
        super(context, instanceId, componentRef);
    }

    private ImgNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
        super(context, instanceId, componentRef, ref, styles, attrs);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.richtext.node.RichTextNode
    public void updateSpans(SpannableStringBuilder spannableStringBuilder, int level) {
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(this.mInstanceId);
        if (WXSDKEngine.getDrawableLoader() != null) {
            if (((this.style.containsKey("width") && this.style.containsKey("height")) || (this.attr.containsKey("width") && this.attr.containsKey("height"))) && this.attr.containsKey("src") && sDKInstance != null) {
                LinkedList<Object> linkedList = new LinkedList();
                linkedList.add(createImgSpan(sDKInstance));
                if (this.attr.containsKey(RichTextNode.PSEUDO_REF)) {
                    linkedList.add(new ItemClickSpan(this.mInstanceId, this.mComponentRef, this.attr.get(RichTextNode.PSEUDO_REF).toString()));
                }
                for (Object obj : linkedList) {
                    spannableStringBuilder.setSpan(obj, 0, spannableStringBuilder.length(), createSpanFlag(level));
                }
            }
        }
    }

    private ImgSpan createImgSpan(WXSDKInstance instance) {
        Object obj = (this.style.containsKey("width") ? this.style : this.attr).get("width");
        Object obj2 = (this.style.containsKey("height") ? this.style : this.attr).get("height");
        int realPxByWidth = (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(obj), instance.getInstanceViewPortWidthWithFloat());
        int realPxByWidth2 = (int) WXViewUtils.getRealPxByWidth(WXUtils.getFloat(obj2), instance.getInstanceViewPortWidthWithFloat());
        ImgSpan imgSpan = new ImgSpan(realPxByWidth, realPxByWidth2, this.mInstanceId, this.mComponentRef);
        Uri rewriteUri = instance.rewriteUri(Uri.parse(this.attr.get("src").toString()), "image");
        if (Constants.Scheme.LOCAL.equals(rewriteUri.getScheme())) {
            imgSpan.setDrawable(ImgURIUtil.getDrawableFromLoaclSrc(this.mContext, rewriteUri), false);
        } else {
            DrawableStrategy drawableStrategy = new DrawableStrategy();
            drawableStrategy.width = realPxByWidth;
            drawableStrategy.height = realPxByWidth2;
            WXSDKEngine.getDrawableLoader().setDrawable(rewriteUri.toString(), imgSpan, drawableStrategy);
        }
        return imgSpan;
    }
}
