package com.taobao.weex.ui.component.richtext.node;

import android.content.Context;
import android.text.Spannable;
import android.text.SpannableString;
import android.text.SpannableStringBuilder;
import android.text.TextUtils;
import android.text.style.AbsoluteSizeSpan;
import android.text.style.BackgroundColorSpan;
import android.text.style.ForegroundColorSpan;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXCustomStyleSpan;
import com.taobao.weex.dom.WXStyle;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public abstract class RichTextNode {
    public static final String ATTR = "attr";
    public static final String CHILDREN = "children";
    public static final String ITEM_CLICK = "itemclick";
    private static final int MAX_LEVEL = 255;
    public static final String PSEUDO_REF = "pseudoRef";
    public static final String STYLE = "style";
    public static final String TYPE = "type";
    public static final String VALUE = "value";
    protected Map<String, Object> attr;
    protected List<RichTextNode> children;
    protected final String mComponentRef;
    protected final Context mContext;
    protected final String mInstanceId;
    protected final String mRef;
    protected Map<String, Object> style;

    private static int createPriorityFlag(int level) {
        if (level <= 255) {
            return (255 - level) << 16;
        }
        return 16711680;
    }

    protected abstract boolean isInternalNode();

    public abstract String toString();

    /* JADX INFO: Access modifiers changed from: protected */
    public RichTextNode(Context context, String instanceId, String componentRef) {
        this.mContext = context;
        this.mInstanceId = instanceId;
        this.mComponentRef = componentRef;
        this.mRef = null;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public RichTextNode(Context context, String instanceId, String componentRef, String ref, Map<String, Object> styles, Map<String, Object> attrs) {
        this.mContext = context;
        this.mInstanceId = instanceId;
        this.mComponentRef = componentRef;
        this.mRef = ref;
        if (styles != null) {
            this.style = styles;
        } else {
            this.style = new ArrayMap(0);
        }
        if (attrs != null) {
            this.attr = attrs;
        } else {
            this.attr = new ArrayMap(0);
        }
        this.children = new LinkedList();
    }

    public static Spannable parse(Context context, String instanceId, String componentRef, String json) {
        RichTextNode createRichTextNode;
        JSONArray parseArray = JSON.parseArray(json);
        if (parseArray != null && !parseArray.isEmpty()) {
            ArrayList arrayList = new ArrayList(parseArray.size());
            for (int i = 0; i < parseArray.size(); i++) {
                JSONObject jSONObject = parseArray.getJSONObject(i);
                if (jSONObject != null && (createRichTextNode = RichTextNodeManager.createRichTextNode(context, instanceId, componentRef, jSONObject)) != null) {
                    arrayList.add(createRichTextNode);
                }
            }
            return parse(arrayList);
        }
        return new SpannableString("");
    }

    public static int createSpanFlag(int level) {
        return createPriorityFlag(level) | 17;
    }

    public String getRef() {
        return this.mRef;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void parse(Context context, String instanceId, String componentRef, JSONObject jsonObject) {
        JSONObject jSONObject = jsonObject.getJSONObject("style");
        if (jSONObject != null) {
            ArrayMap arrayMap = new ArrayMap();
            this.style = arrayMap;
            arrayMap.putAll(jSONObject);
        } else {
            this.style = new ArrayMap(0);
        }
        JSONObject jSONObject2 = jsonObject.getJSONObject(ATTR);
        if (jSONObject2 != null) {
            ArrayMap arrayMap2 = new ArrayMap(jSONObject2.size());
            this.attr = arrayMap2;
            arrayMap2.putAll(jSONObject2);
        } else {
            this.attr = new ArrayMap(0);
        }
        JSONArray jSONArray = jsonObject.getJSONArray(CHILDREN);
        if (jSONArray != null) {
            this.children = new ArrayList(jSONArray.size());
            for (int i = 0; i < jSONArray.size(); i++) {
                RichTextNode createRichTextNode = RichTextNodeManager.createRichTextNode(context, instanceId, componentRef, jSONArray.getJSONObject(i));
                if (createRichTextNode != null) {
                    this.children.add(createRichTextNode);
                }
            }
            return;
        }
        this.children = new ArrayList(0);
    }

    public void addChildNode(RichTextNode child) {
        if (this.children == null) {
            this.children = new LinkedList();
        }
        if (child == null || !isInternalNode()) {
            return;
        }
        this.children.add(child);
    }

    public void removeChildNode(String ref) {
        List<RichTextNode> list = this.children;
        if (list == null || list.isEmpty() || TextUtils.isEmpty(ref)) {
            return;
        }
        try {
            for (RichTextNode richTextNode : this.children) {
                if (TextUtils.equals(richTextNode.mRef, ref)) {
                    this.children.remove(richTextNode);
                }
            }
        } catch (Exception e) {
            WXLogUtils.getStackTrace(e);
        }
    }

    public void updateStyles(Map<String, Object> styles) {
        if (styles == null || styles.isEmpty()) {
            return;
        }
        this.style.putAll(styles);
    }

    public void updateAttrs(Map<String, Object> attrs) {
        if (this.attr == null || attrs.isEmpty()) {
            return;
        }
        this.attr.putAll(attrs);
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void updateSpans(SpannableStringBuilder spannableStringBuilder, int level) {
        int color;
        WXSDKInstance sDKInstance = WXSDKManager.getInstance().getSDKInstance(this.mInstanceId);
        if (this.style == null || sDKInstance == null) {
            return;
        }
        LinkedList<Object> linkedList = new LinkedList();
        WXCustomStyleSpan createCustomStyleSpan = createCustomStyleSpan();
        if (createCustomStyleSpan != null) {
            linkedList.add(createCustomStyleSpan);
        }
        if (this.style.containsKey(Constants.Name.FONT_SIZE)) {
            linkedList.add(new AbsoluteSizeSpan(WXStyle.getFontSize(this.style, sDKInstance.getDefaultFontSize(), sDKInstance.getInstanceViewPortWidthWithFloat())));
        }
        if (this.style.containsKey("backgroundColor") && (color = WXResourceUtils.getColor(this.style.get("backgroundColor").toString(), 0)) != 0) {
            linkedList.add(new BackgroundColorSpan(color));
        }
        if (this.style.containsKey("color")) {
            linkedList.add(new ForegroundColorSpan(WXResourceUtils.getColor(WXStyle.getTextColor(this.style))));
        }
        int createSpanFlag = createSpanFlag(level);
        for (Object obj : linkedList) {
            spannableStringBuilder.setSpan(obj, 0, spannableStringBuilder.length(), createSpanFlag);
        }
    }

    private static Spannable parse(List<RichTextNode> list) {
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        for (RichTextNode richTextNode : list) {
            spannableStringBuilder.append((CharSequence) richTextNode.toSpan(1));
        }
        return spannableStringBuilder;
    }

    public Spannable toSpan(int level) {
        List<RichTextNode> list;
        SpannableStringBuilder spannableStringBuilder = new SpannableStringBuilder();
        spannableStringBuilder.append((CharSequence) toString());
        if (isInternalNode() && (list = this.children) != null) {
            for (RichTextNode richTextNode : list) {
                spannableStringBuilder.append((CharSequence) richTextNode.toSpan(level + 1));
            }
        }
        updateSpans(spannableStringBuilder, level);
        return spannableStringBuilder;
    }

    private WXCustomStyleSpan createCustomStyleSpan() {
        int fontWeight = this.style.containsKey(Constants.Name.FONT_WEIGHT) ? WXStyle.getFontWeight(this.style) : -1;
        int fontStyle = this.style.containsKey(Constants.Name.FONT_STYLE) ? WXStyle.getFontStyle(this.style) : -1;
        String fontFamily = this.style.containsKey(Constants.Name.FONT_FAMILY) ? WXStyle.getFontFamily(this.style) : null;
        if (fontWeight == -1 && fontStyle == -1 && fontFamily == null) {
            return null;
        }
        return new WXCustomStyleSpan(fontStyle, fontWeight, fontFamily);
    }

    public RichTextNode findRichNode(String ref) {
        String str = this.mRef;
        if (str == null || !TextUtils.equals(str, ref)) {
            List<RichTextNode> list = this.children;
            if (list == null || list.isEmpty()) {
                return null;
            }
            for (RichTextNode richTextNode : this.children) {
                RichTextNode findRichNode = richTextNode.findRichNode(ref);
                if (findRichNode != null) {
                    return findRichNode;
                }
            }
            return null;
        }
        return this;
    }
}
