package com.taobao.weex.ui.component.richtext.node;

import android.content.Context;
import androidx.collection.ArrayMap;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.ui.component.richtext.node.ANode;
import com.taobao.weex.ui.component.richtext.node.ImgNode;
import com.taobao.weex.ui.component.richtext.node.SpanNode;
import com.taobao.weex.utils.WXLogUtils;
import java.util.Map;
/* loaded from: classes.dex */
public class RichTextNodeManager {
    private static final Map<String, RichTextNodeCreator> registeredTextNodes;

    static {
        ArrayMap arrayMap = new ArrayMap();
        registeredTextNodes = arrayMap;
        arrayMap.put(SpanNode.NODE_TYPE, new SpanNode.SpanNodeCreator());
        arrayMap.put("image", new ImgNode.ImgNodeCreator());
        arrayMap.put("a", new ANode.ANodeCreator());
    }

    public static void registerTextNode(String text, RichTextNodeCreator type) {
        registeredTextNodes.put(text, type);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static RichTextNode createRichTextNode(Context context, String instanceId, String componentRef, JSONObject jsonObject) {
        if (jsonObject != null) {
            try {
                RichTextNode createRichTextNode = registeredTextNodes.get(jsonObject.getString("type")).createRichTextNode(context, instanceId, componentRef);
                createRichTextNode.parse(context, instanceId, componentRef, jsonObject);
                return createRichTextNode;
            } catch (Exception e) {
                WXLogUtils.e("Richtext", WXLogUtils.getStackTrace(e));
                return null;
            }
        }
        return null;
    }

    public static RichTextNode createRichTextNode(Context context, String instanceId, String componentRef, String ref, String nodeType, Map<String, String> styles, Map<String, String> attrs) {
        try {
            return registeredTextNodes.get(nodeType).createRichTextNode(context, instanceId, componentRef, ref, styles, attrs);
        } catch (Exception e) {
            WXLogUtils.e("Richtext", WXLogUtils.getStackTrace(e));
            return null;
        }
    }
}
