package com.taobao.weex.ui.module;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.common.WXModule;
import com.taobao.weex.dom.binding.JSONUtils;
import com.taobao.weex.ui.action.ActionAddRule;
import com.taobao.weex.ui.action.ActionGetComponentRect;
import com.taobao.weex.ui.action.ActionGetLayoutDirection;
import com.taobao.weex.ui.action.ActionInvokeMethod;
import com.taobao.weex.ui.action.GraphicActionBatchBegin;
import com.taobao.weex.ui.action.GraphicActionBatchEnd;
import com.taobao.weex.ui.action.GraphicActionScrollToElement;
import com.taobao.weex.ui.action.UpdateComponentDataAction;
import com.taobao.weex.utils.WXLogUtils;
/* loaded from: classes.dex */
public final class WXDomModule extends WXModule {
    public static final String UPDATE_COMPONENT_DATA = "updateComponentData";
    public static final String WXDOM = "dom";
    public static final String SCROLL_TO_ELEMENT = "scrollToElement";
    public static final String ADD_RULE = "addRule";
    public static final String GET_COMPONENT_RECT = "getComponentRect";
    public static final String INVOKE_METHOD = "invokeMethod";
    public static final String GET_COMPONENT_DIRECTION = "getLayoutDirection";
    public static final String BATCH_BEGIN = "beginBatchMark";
    public static final String BATCH_END = "endBatchMark";
    public static final String[] METHODS = {SCROLL_TO_ELEMENT, ADD_RULE, GET_COMPONENT_RECT, INVOKE_METHOD, GET_COMPONENT_DIRECTION, BATCH_BEGIN, BATCH_END};

    public WXDomModule(WXSDKInstance instance) {
        this.mWXSDKInstance = instance;
        this.mUniSDKInstance = instance;
    }

    public void callDomMethod(JSONObject task, long... parseNanos) {
        if (task == null) {
            return;
        }
        callDomMethod((String) task.get("method"), (JSONArray) task.get("args"), parseNanos);
    }

    public Object callDomMethod(String method, JSONArray args, long... parseNanos) {
        if (method == null) {
            return null;
        }
        char c = 65535;
        try {
            switch (method.hashCode()) {
                case -1390247284:
                    if (method.equals(BATCH_END)) {
                        c = 7;
                        break;
                    }
                    break;
                case -1148630211:
                    if (method.equals(ADD_RULE)) {
                        c = 2;
                        break;
                    }
                    break;
                case -748746828:
                    if (method.equals(SCROLL_TO_ELEMENT)) {
                        c = 1;
                        break;
                    }
                    break;
                case -658126983:
                    if (method.equals(INVOKE_METHOD)) {
                        c = 4;
                        break;
                    }
                    break;
                case -276465026:
                    if (method.equals(BATCH_BEGIN)) {
                        c = 6;
                        break;
                    }
                    break;
                case 588570827:
                    if (method.equals(GET_COMPONENT_RECT)) {
                        c = 3;
                        break;
                    }
                    break;
                case 1653342206:
                    if (method.equals(UPDATE_COMPONENT_DATA)) {
                        c = 5;
                        break;
                    }
                    break;
                case 1875897663:
                    if (method.equals(GET_COMPONENT_DIRECTION)) {
                        c = 0;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    if (args != null) {
                        new ActionGetLayoutDirection(this.mWXSDKInstance, args.getString(0), args.getString(1)).executeActionOnRender();
                        break;
                    } else {
                        return null;
                    }
                case 1:
                    if (args != null) {
                        new GraphicActionScrollToElement(this.mWXSDKInstance, args.size() >= 1 ? args.getString(0) : null, args.size() >= 2 ? args.getJSONObject(1) : null).executeActionOnRender();
                        break;
                    } else {
                        return null;
                    }
                case 2:
                    if (args != null) {
                        new ActionAddRule(this.mWXSDKInstance.getInstanceId(), args.getString(0), args.getJSONObject(1)).executeAction();
                        break;
                    } else {
                        return null;
                    }
                case 3:
                    if (args != null) {
                        new ActionGetComponentRect(this.mWXSDKInstance, args.getString(0), args.getString(1)).executeActionOnRender();
                        break;
                    } else {
                        return null;
                    }
                case 4:
                    if (args != null) {
                        new ActionInvokeMethod(this.mWXSDKInstance.getInstanceId(), args.getString(0), args.getString(1), args.getJSONArray(2)).executeAction();
                        break;
                    } else {
                        return null;
                    }
                case 5:
                    if (args != null && args.size() >= 3) {
                        new UpdateComponentDataAction(this.mWXSDKInstance, args.getString(0), JSONUtils.toJSON(args.get(1)), args.getString(2)).executeAction();
                        break;
                    }
                    return null;
                case 6:
                    if (args != null) {
                        new GraphicActionBatchBegin(this.mWXSDKInstance, args.size() >= 1 ? args.getString(0) : null).executeActionOnRender();
                        break;
                    } else {
                        return null;
                    }
                case 7:
                    new GraphicActionBatchEnd(this.mWXSDKInstance, args.size() >= 1 ? args.getString(0) : null).executeActionOnRender();
                    break;
                default:
                    WXLogUtils.e("Unknown dom action.");
                    break;
            }
        } catch (ClassCastException unused) {
            WXLogUtils.e("Dom module call arguments format error!!");
        } catch (IndexOutOfBoundsException e) {
            e.printStackTrace();
            WXLogUtils.e("Dom module call miss arguments.");
        }
        return null;
    }

    public void invokeMethod(String ref, String method, JSONArray args) {
        if (ref == null || method == null) {
            return;
        }
        new ActionInvokeMethod(this.mWXSDKInstance.getInstanceId(), ref, method, args).executeAction();
    }
}
