package com.taobao.weex.ui.view;

import android.view.View;
import android.view.ViewGroup;
import androidx.viewpager.widget.PagerAdapter;
import com.taobao.weex.WXEnvironment;
import com.taobao.weex.utils.WXLogUtils;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
/* loaded from: classes.dex */
public class WXCirclePageAdapter extends PagerAdapter {
    public boolean isRTL;
    private boolean needLoop;
    private List<View> originalViews;
    private List<View> shadow;
    private List<View> views;

    @Override // androidx.viewpager.widget.PagerAdapter
    public int getItemPosition(Object object) {
        return -2;
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public boolean isViewFromObject(View view, Object object) {
        return view == object;
    }

    public WXCirclePageAdapter(List<View> views, boolean needLoop) {
        this.views = new ArrayList();
        this.shadow = new ArrayList();
        this.needLoop = true;
        this.isRTL = false;
        this.originalViews = new ArrayList();
        this.views = new ArrayList(views);
        this.originalViews = new ArrayList(views);
        this.needLoop = needLoop;
    }

    public void setLayoutDirectionRTL(boolean isRTL) {
        if (isRTL == this.isRTL) {
            return;
        }
        this.isRTL = isRTL;
        ArrayList arrayList = new ArrayList(this.originalViews);
        this.views = arrayList;
        if (isRTL) {
            Collections.reverse(arrayList);
        }
        ensureShadow();
    }

    public WXCirclePageAdapter() {
        this(true);
    }

    public WXCirclePageAdapter(boolean needLoop) {
        this.views = new ArrayList();
        this.shadow = new ArrayList();
        this.needLoop = true;
        this.isRTL = false;
        this.originalViews = new ArrayList();
        this.needLoop = needLoop;
    }

    public void addPageView(View view) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> addPageView");
        }
        this.originalViews.add(view);
        if (this.isRTL) {
            this.views.add(0, view);
        } else {
            this.views.add(view);
        }
        ensureShadow();
    }

    public void removePageView(View view) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> removePageView");
        }
        this.views.remove(view);
        this.originalViews.remove(view);
        ensureShadow();
    }

    public void replacePageView(View oldView, View newView) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> replacePageView");
        }
        int indexOf = this.views.indexOf(oldView);
        this.views.remove(indexOf);
        this.views.add(indexOf, newView);
        ensureShadow();
        int indexOf2 = this.originalViews.indexOf(oldView);
        this.originalViews.remove(indexOf2);
        this.originalViews.add(indexOf2, newView);
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public int getCount() {
        return this.shadow.size();
    }

    public int getRealCount() {
        return this.views.size();
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public Object instantiateItem(ViewGroup container, int position) {
        View view;
        View view2 = null;
        try {
            view = this.shadow.get(position);
        } catch (Exception e) {
            e = e;
        }
        try {
            if (WXEnvironment.isApkDebugable()) {
                WXLogUtils.d("onPageSelected >>>> instantiateItem >>>>> position:" + position + ",position % getRealCount()" + (position % getRealCount()));
            }
            if (view.getParent() == null) {
                container.addView(view);
                return view;
            }
            ((ViewGroup) view.getParent()).removeView(view);
            container.addView(view);
            return view;
        } catch (Exception e2) {
            e = e2;
            view2 = view;
            WXLogUtils.e("[CirclePageAdapter] instantiateItem: ", e);
            return view2;
        }
    }

    @Override // androidx.viewpager.widget.PagerAdapter
    public void destroyItem(ViewGroup container, int position, Object object) {
        if (WXEnvironment.isApkDebugable()) {
            WXLogUtils.d("onPageSelected >>>> destroyItem >>>>> position:" + position);
        }
        if (this.needLoop) {
            return;
        }
        container.removeView((View) object);
    }

    public int getPagePosition(View page) {
        return this.views.indexOf(page);
    }

    public int getItemIndex(Object object) {
        if (object instanceof View) {
            return this.views.indexOf(object);
        }
        return -1;
    }

    public List<View> getViews() {
        return this.views;
    }

    private void ensureShadow() {
        ArrayList arrayList = new ArrayList();
        if (this.needLoop && this.views.size() > 2) {
            List<View> list = this.views;
            arrayList.add(0, list.get(list.size() - 1));
            for (View view : this.views) {
                if (view.getParent() != null) {
                    ((ViewGroup) view.getParent()).removeView(view);
                }
                arrayList.add(view);
            }
            arrayList.add(this.views.get(0));
        } else {
            arrayList.addAll(this.views);
        }
        this.shadow.clear();
        notifyDataSetChanged();
        this.shadow.addAll(arrayList);
        notifyDataSetChanged();
    }

    public int getRealPosition(int shadowPosition) {
        if (shadowPosition < 0 || shadowPosition >= this.shadow.size()) {
            return -1;
        }
        return getItemIndex(this.shadow.get(shadowPosition));
    }

    public int getFirst() {
        return (!this.needLoop || this.views.size() <= 2) ? 0 : 1;
    }
}
