package com.taobao.weex.ui.view;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.animation.Interpolator;
import androidx.viewpager.widget.ViewPager;
import com.taobao.weex.ui.view.gesture.WXGesture;
import com.taobao.weex.ui.view.gesture.WXGestureObservable;
import com.taobao.weex.utils.WXLogUtils;
import java.lang.reflect.Field;
/* loaded from: classes.dex */
public class WXCircleViewPager extends ViewPager implements WXGestureObservable {
    private final int SCROLL_TO_NEXT;
    private long intervalTime;
    private boolean isAutoScroll;
    private Handler mAutoScrollHandler;
    private WXSmoothScroller mScroller;
    private int mState;
    private boolean needLoop;
    private boolean scrollable;
    private WXGesture wxGesture;

    public WXCircleViewPager(Context context) {
        super(context);
        this.SCROLL_TO_NEXT = 1;
        this.intervalTime = 3000L;
        this.needLoop = true;
        this.scrollable = true;
        this.mState = 0;
        this.mAutoScrollHandler = new Handler(Looper.getMainLooper()) { // from class: com.taobao.weex.ui.view.WXCircleViewPager.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                if (msg.what == 1) {
                    WXLogUtils.d("[CircleViewPager] trigger auto play action");
                    WXCircleViewPager.this.showNextItem();
                    sendEmptyMessageDelayed(1, WXCircleViewPager.this.intervalTime);
                    return;
                }
                super.handleMessage(msg);
            }
        };
        init();
    }

    private void init() {
        setOverScrollMode(2);
        addOnPageChangeListener(new ViewPager.OnPageChangeListener() { // from class: com.taobao.weex.ui.view.WXCircleViewPager.2
            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageScrolled(int position, float positionOffset, int positionOffsetPixels) {
            }

            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageSelected(int position) {
            }

            @Override // androidx.viewpager.widget.ViewPager.OnPageChangeListener
            public void onPageScrollStateChanged(int state) {
                WXCircleViewPager.this.mState = state;
                WXCirclePageAdapter circlePageAdapter = WXCircleViewPager.this.getCirclePageAdapter();
                int currentItem = WXCircleViewPager.super.getCurrentItem();
                if (WXCircleViewPager.this.needLoop && state == 0 && circlePageAdapter.getCount() > 1) {
                    if (currentItem == circlePageAdapter.getCount() - 1) {
                        WXCircleViewPager.this.superSetCurrentItem(1, false);
                        circlePageAdapter.getViews().get(0).setTranslationY(0.0f);
                        circlePageAdapter.getViews().get(0).setTranslationX(0.0f);
                    } else if (currentItem == 0) {
                        WXCircleViewPager.this.superSetCurrentItem(circlePageAdapter.getCount() - 2, false);
                        try {
                            circlePageAdapter.getViews().get((circlePageAdapter.getCount() - 2) - 1).setTranslationY(0.0f);
                            circlePageAdapter.getViews().get((circlePageAdapter.getCount() - 2) - 1).setTranslationX(0.0f);
                        } catch (Exception unused) {
                        }
                    }
                }
            }
        });
        postInitViewPager();
    }

    private void postInitViewPager() {
        if (isInEditMode()) {
            return;
        }
        try {
            Field declaredField = ViewPager.class.getDeclaredField("mScroller");
            declaredField.setAccessible(true);
            Field declaredField2 = ViewPager.class.getDeclaredField("sInterpolator");
            declaredField2.setAccessible(true);
            WXSmoothScroller wXSmoothScroller = new WXSmoothScroller(getContext(), (Interpolator) declaredField2.get(null));
            this.mScroller = wXSmoothScroller;
            declaredField.set(this, wXSmoothScroller);
        } catch (Exception e) {
            WXLogUtils.e("[CircleViewPager] postInitViewPager: ", e);
        }
    }

    public WXSmoothScroller getmScroller() {
        return this.mScroller;
    }

    public WXCircleViewPager(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.SCROLL_TO_NEXT = 1;
        this.intervalTime = 3000L;
        this.needLoop = true;
        this.scrollable = true;
        this.mState = 0;
        this.mAutoScrollHandler = new Handler(Looper.getMainLooper()) { // from class: com.taobao.weex.ui.view.WXCircleViewPager.1
            @Override // android.os.Handler
            public void handleMessage(Message msg) {
                if (msg.what == 1) {
                    WXLogUtils.d("[CircleViewPager] trigger auto play action");
                    WXCircleViewPager.this.showNextItem();
                    sendEmptyMessageDelayed(1, WXCircleViewPager.this.intervalTime);
                    return;
                }
                super.handleMessage(msg);
            }
        };
        init();
    }

    @Override // androidx.viewpager.widget.ViewPager
    public int getCurrentItem() {
        return getRealCurrentItem();
    }

    public int superGetCurrentItem() {
        return super.getCurrentItem();
    }

    @Override // androidx.viewpager.widget.ViewPager, android.view.ViewGroup
    public boolean onInterceptTouchEvent(MotionEvent ev) {
        try {
            if (this.scrollable) {
                return super.onInterceptTouchEvent(ev);
            }
            return false;
        } catch (ArrayIndexOutOfBoundsException e) {
            e.printStackTrace();
            return false;
        } catch (IllegalArgumentException e2) {
            e2.printStackTrace();
            return false;
        }
    }

    @Override // androidx.viewpager.widget.ViewPager, android.view.View
    public boolean onTouchEvent(MotionEvent ev) {
        if (this.scrollable) {
            return super.onTouchEvent(ev);
        }
        return true;
    }

    @Override // android.view.View
    public void scrollTo(int x, int y) {
        if (this.scrollable || this.mState != 1) {
            super.scrollTo(x, y);
        }
    }

    public void startAutoScroll() {
        this.isAutoScroll = true;
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
        this.mAutoScrollHandler.sendEmptyMessageDelayed(1, this.intervalTime);
    }

    public void pauseAutoScroll() {
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    public void stopAutoScroll() {
        this.isAutoScroll = false;
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    public boolean isAutoScroll() {
        return this.isAutoScroll;
    }

    @Override // androidx.viewpager.widget.ViewPager
    public void setCurrentItem(int item) {
        setRealCurrentItem(item, true);
    }

    @Override // androidx.viewpager.widget.ViewPager
    public void setCurrentItem(int item, boolean smooth) {
        setRealCurrentItem(item, smooth);
    }

    public WXCirclePageAdapter getCirclePageAdapter() {
        return (WXCirclePageAdapter) getAdapter();
    }

    public void setCirclePageAdapter(WXCirclePageAdapter circlePageAdapter) {
        setAdapter(circlePageAdapter);
    }

    public long getIntervalTime() {
        return this.intervalTime;
    }

    public void setIntervalTime(long intervalTime) {
        this.intervalTime = intervalTime;
    }

    public void setCircle(boolean circle) {
        this.needLoop = circle;
    }

    /* JADX WARN: Code restructure failed: missing block: B:9:0x000d, code lost:
        if (r0 != 3) goto L9;
     */
    /* JADX WARN: Removed duplicated region for block: B:17:0x002c A[Catch: Exception -> 0x0032, TRY_LEAVE, TryCatch #0 {Exception -> 0x0032, blocks: (B:15:0x0024, B:17:0x002c), top: B:22:0x0024 }] */
    /* JADX WARN: Removed duplicated region for block: B:24:? A[RETURN, SYNTHETIC] */
    @Override // android.view.ViewGroup, android.view.View
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean dispatchTouchEvent(MotionEvent ev) {
        int action = ev.getAction();
        try {
            if (action != 0) {
                if (action != 1) {
                    if (action != 2) {
                    }
                }
                if (isAutoScroll()) {
                    this.mAutoScrollHandler.sendEmptyMessageDelayed(1, this.intervalTime);
                }
                boolean dispatchTouchEvent = super.dispatchTouchEvent(ev);
                WXGesture wXGesture = this.wxGesture;
                return wXGesture == null ? dispatchTouchEvent | wXGesture.onTouch(this, ev) : dispatchTouchEvent;
            }
            boolean dispatchTouchEvent2 = super.dispatchTouchEvent(ev);
            WXGesture wXGesture2 = this.wxGesture;
            if (wXGesture2 == null) {
            }
        } catch (Exception unused) {
            return false;
        }
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    public void destory() {
        this.mAutoScrollHandler.removeCallbacksAndMessages(null);
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public void registerGestureListener(WXGesture wxGesture) {
        this.wxGesture = wxGesture;
    }

    @Override // com.taobao.weex.ui.view.gesture.WXGestureObservable
    public WXGesture getGestureListener() {
        return this.wxGesture;
    }

    public int getRealCurrentItem() {
        return ((WXCirclePageAdapter) getAdapter()).getRealPosition(super.getCurrentItem());
    }

    private void setRealCurrentItem(int item, boolean smooth) {
        superSetCurrentItem(((WXCirclePageAdapter) getAdapter()).getFirst() + item, smooth);
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void superSetCurrentItem(int item, boolean smooth) {
        try {
            if (Math.abs(item - getRealCurrentItem()) > 3 && this.needLoop && getRealCount() > 2 && item == getCirclePageAdapter().getCount() - 2) {
                super.setCurrentItem(item - 2, false);
            }
        } catch (Exception unused) {
        }
        try {
            super.setCurrentItem(item, smooth);
        } catch (IllegalStateException e) {
            WXLogUtils.e(e.toString());
            if (getAdapter() != null) {
                getAdapter().notifyDataSetChanged();
                super.setCurrentItem(item, smooth);
            }
        }
    }

    public int getRealCount() {
        return ((WXCirclePageAdapter) getAdapter()).getRealCount();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // androidx.viewpager.widget.ViewPager, android.view.View
    public void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        try {
            super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        } catch (IllegalStateException e) {
            WXLogUtils.e(e.toString());
            if (getAdapter() != null) {
                getAdapter().notifyDataSetChanged();
                super.onMeasure(widthMeasureSpec, heightMeasureSpec);
            }
        }
    }

    public boolean isScrollable() {
        return this.scrollable;
    }

    public void setScrollable(boolean scrollable) {
        this.scrollable = scrollable;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void showNextItem() {
        if (getCirclePageAdapter() != null && getCirclePageAdapter().isRTL) {
            if (this.needLoop || superGetCurrentItem() != 0) {
                if (getRealCount() == 2 && superGetCurrentItem() == 0) {
                    superSetCurrentItem(1, true);
                } else {
                    superSetCurrentItem(superGetCurrentItem() - 1, true);
                }
            }
        } else if (this.needLoop || superGetCurrentItem() != getRealCount() - 1) {
            if (getRealCount() == 2 && superGetCurrentItem() == 1) {
                superSetCurrentItem(0, true);
            } else {
                superSetCurrentItem(superGetCurrentItem() + 1, true);
            }
        }
    }
}
