package com.taobao.weex.ui.view.gesture;

import android.content.Context;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.os.Handler;
import android.os.Looper;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.bridge.EventResult;
import com.taobao.weex.common.Constants;
import com.taobao.weex.dom.WXEvent;
import com.taobao.weex.ui.component.Scrollable;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.view.gesture.WXGestureType;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.constant.AbsoluteConst;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
/* loaded from: classes.dex */
public class WXGesture extends GestureDetector.SimpleOnGestureListener implements View.OnTouchListener {
    private static final int CUR_EVENT = -1;
    public static final String DOWN = "down";
    public static final String END = "end";
    public static final String LEFT = "left";
    public static final String MOVE = "move";
    public static final String RIGHT = "right";
    public static final String START = "start";
    private static final String TAG = "Gesture";
    public static final String UNKNOWN = "unknown";
    public static final String UP = "up";
    private WXComponent component;
    private GestureDetector mGestureDetector;
    private int mParentOrientation;
    private int shouldBubbleInterval;
    private boolean shouldBubbleResult;
    private long swipeDownTime = -1;
    private long panDownTime = -1;
    private WXGestureType mPendingPan = null;
    private boolean mIsPreventMoveEvent = false;
    private boolean mIsTouchEventConsumed = false;
    private boolean requestDisallowInterceptTouchEvent = false;
    private int shouldBubbleCallRemainTimes = 0;
    private final List<View.OnTouchListener> mTouchListeners = new LinkedList();
    private Rect globalRect = new Rect();
    private Point globalOffset = new Point();
    private Point globalEventOffset = new Point();
    private PointF locEventOffset = new PointF();
    private PointF locLeftTop = new PointF();

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onDown(MotionEvent e) {
        return true;
    }

    public WXGesture(WXComponent wxComponent, Context context) {
        this.mParentOrientation = -1;
        this.shouldBubbleResult = true;
        this.shouldBubbleInterval = 0;
        this.component = wxComponent;
        this.mGestureDetector = new GestureDetector(context, this, new GestureHandler());
        Scrollable parentScroller = wxComponent.getParentScroller();
        if (parentScroller != null) {
            this.mParentOrientation = parentScroller.getOrientation();
        }
        this.shouldBubbleResult = WXUtils.getBoolean(wxComponent.getAttrs().get(Constants.Name.SHOULD_STOP_PROPAGATION_INIT_RESULT), true).booleanValue();
        this.shouldBubbleInterval = WXUtils.getNumberInt(wxComponent.getAttrs().get(Constants.Name.SHOULD_STOP_PROPAGATION_INTERVAL), 0);
    }

    private boolean isParentScrollable() {
        Scrollable parentScroller;
        WXComponent wXComponent = this.component;
        return wXComponent == null || (parentScroller = wXComponent.getParentScroller()) == null || parentScroller.isScrollable();
    }

    private boolean hasSameOrientationWithParent() {
        if (this.mParentOrientation == 0 && this.component.containsGesture(WXGestureType.HighLevelGesture.HORIZONTALPAN)) {
            return true;
        }
        return this.mParentOrientation == 1 && this.component.containsGesture(WXGestureType.HighLevelGesture.VERTICALPAN);
    }

    public void setPreventMoveEvent(boolean preventMoveEvent) {
        this.mIsPreventMoveEvent = preventMoveEvent;
    }

    public boolean isTouchEventConsumedByAdvancedGesture() {
        return this.mIsTouchEventConsumed;
    }

    public static boolean isStopPropagation(String type) {
        return Constants.Event.STOP_PROPAGATION.equals(type) || Constants.Event.STOP_PROPAGATION_RAX.equals(type);
    }

    public static boolean hasStopPropagation(WXComponent component) {
        WXEvent events = component.getEvents();
        if (events == null) {
            return false;
        }
        int size = events.size();
        for (int i = 0; i < size && i < events.size(); i++) {
            if (isStopPropagation((String) events.get(i))) {
                return true;
            }
        }
        return false;
    }

    private boolean shouldBubbleTouchEvent(MotionEvent event) {
        int i;
        if (hasStopPropagation(this.component)) {
            if (this.shouldBubbleInterval > 0 && (i = this.shouldBubbleCallRemainTimes) > 0) {
                this.shouldBubbleCallRemainTimes = i - 1;
                return this.shouldBubbleResult;
            }
            Map<String, Object> createFireEventParam = createFireEventParam(event, -1, null);
            createFireEventParam.put("type", "touch");
            if (event.getAction() == 0) {
                createFireEventParam.put("action", "start");
            } else if (event.getAction() == 3 || event.getAction() == 1) {
                createFireEventParam.put("action", "end");
            } else {
                createFireEventParam.put("action", MOVE);
            }
            WXEvent events = this.component.getEvents();
            String str = Constants.Event.STOP_PROPAGATION;
            if (!events.contains(Constants.Event.STOP_PROPAGATION)) {
                str = Constants.Event.STOP_PROPAGATION_RAX;
            }
            EventResult fireEventWait = this.component.fireEventWait(str, createFireEventParam);
            if (fireEventWait.isSuccess() && fireEventWait.getResult() != null) {
                this.shouldBubbleResult = !WXUtils.getBoolean(fireEventWait.getResult(), Boolean.valueOf(!this.shouldBubbleResult)).booleanValue();
            }
            this.shouldBubbleCallRemainTimes = this.shouldBubbleInterval;
            return this.shouldBubbleResult;
        }
        return true;
    }

    public void addOnTouchListener(View.OnTouchListener listener) {
        if (listener != null) {
            this.mTouchListeners.add(listener);
        }
    }

    public boolean removeTouchListener(View.OnTouchListener listener) {
        if (listener != null) {
            return this.mTouchListeners.remove(listener);
        }
        return false;
    }

    /* JADX WARN: Removed duplicated region for block: B:44:0x00f9 A[Catch: Exception -> 0x013e, TryCatch #0 {Exception -> 0x013e, blocks: (B:6:0x0008, B:8:0x0012, B:10:0x0018, B:11:0x001e, B:13:0x0024, B:14:0x0030, B:42:0x00f1, B:44:0x00f9, B:46:0x0101, B:48:0x010b, B:50:0x0113, B:51:0x011c, B:53:0x0120, B:55:0x013a, B:25:0x0047, B:27:0x005e, B:28:0x0077, B:29:0x007f, B:31:0x0096, B:32:0x00ae, B:34:0x00b6, B:36:0x00bc, B:38:0x00c8, B:39:0x00cb, B:41:0x00da), top: B:60:0x0008 }] */
    @Override // android.view.View.OnTouchListener
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public boolean onTouch(View v, MotionEvent event) {
        ViewParent parent;
        boolean z;
        if (this.requestDisallowInterceptTouchEvent) {
            this.requestDisallowInterceptTouchEvent = false;
            return false;
        }
        try {
            boolean onTouchEvent = this.mGestureDetector.onTouchEvent(event);
            List<View.OnTouchListener> list = this.mTouchListeners;
            if (list != null && !list.isEmpty()) {
                for (View.OnTouchListener onTouchListener : this.mTouchListeners) {
                    onTouchEvent |= onTouchListener.onTouch(v, event);
                }
            }
            int actionMasked = event.getActionMasked();
            if (actionMasked != 0) {
                if (actionMasked != 1) {
                    if (actionMasked == 2) {
                        onTouchEvent |= handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_MOVE, event);
                    } else if (actionMasked == 3) {
                        finishDisallowInterceptTouchEvent(v);
                        onTouchEvent = onTouchEvent | handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_CANCEL, event) | handlePanMotionEvent(event);
                        if (this.component.isPreventGesture()) {
                            WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), true, this.component.getRef());
                        }
                    } else if (actionMasked != 5) {
                        if (actionMasked != 6) {
                        }
                    }
                    if (hasStopPropagation(this.component)) {
                        ViewGroup viewGroup = (ViewGroup) v.getParent();
                        if (viewGroup != null) {
                            z = !shouldBubbleTouchEvent(event);
                            viewGroup.requestDisallowInterceptTouchEvent(z);
                        } else {
                            z = false;
                        }
                        if (this.component.getParent() != null) {
                            this.component.getParent().requestDisallowInterceptTouchEvent(z);
                        }
                        if (this.mIsTouchEventConsumed && WXUtils.getBoolean(this.component.getAttrs().get("cancelTouchOnConsume"), false).booleanValue()) {
                            event.setAction(3);
                        }
                    }
                    return onTouchEvent;
                }
                finishDisallowInterceptTouchEvent(v);
                onTouchEvent = onTouchEvent | handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_UP, event) | handlePanMotionEvent(event);
                if (this.component.isPreventGesture()) {
                    WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), true, this.component.getRef());
                }
                if (hasStopPropagation(this.component)) {
                }
                return onTouchEvent;
            }
            this.mIsTouchEventConsumed = false;
            if (hasSameOrientationWithParent() && !isParentScrollable() && (parent = this.component.getRealView().getParent()) != null) {
                parent.requestDisallowInterceptTouchEvent(true);
            }
            onTouchEvent |= handleMotionEvent(WXGestureType.LowLevelGesture.ACTION_DOWN, event);
            if (this.component.isPreventGesture()) {
                WXSDKManager.getInstance().getWXRenderManager().setScrollable(this.component.getInstanceId(), false, this.component.getRef());
            }
            if (hasStopPropagation(this.component)) {
            }
            return onTouchEvent;
        } catch (Exception e) {
            WXLogUtils.e("Gesture RunTime Error ", e);
            return false;
        }
    }

    private String getPanEventAction(MotionEvent event) {
        int action = event.getAction();
        return action != 0 ? action != 1 ? action != 2 ? action != 3 ? "unknown" : "end" : MOVE : "end" : "start";
    }

    private void finishDisallowInterceptTouchEvent(View v) {
        if (v.getParent() != null) {
            v.getParent().requestDisallowInterceptTouchEvent(false);
        }
    }

    private boolean handlePanMotionEvent(MotionEvent motionEvent) {
        WXGestureType wXGestureType = this.mPendingPan;
        if (wXGestureType == null) {
            return false;
        }
        String panEventAction = (wXGestureType == WXGestureType.HighLevelGesture.HORIZONTALPAN || this.mPendingPan == WXGestureType.HighLevelGesture.VERTICALPAN) ? getPanEventAction(motionEvent) : null;
        if (this.component.containsGesture(this.mPendingPan)) {
            if (this.mIsPreventMoveEvent && MOVE.equals(panEventAction)) {
                return true;
            }
            for (Map<String, Object> map : createMultipleFireEventParam(motionEvent, panEventAction)) {
                this.component.fireEvent(this.mPendingPan.toString(), map);
            }
            if (motionEvent.getAction() == 1 || motionEvent.getAction() == 3) {
                this.mPendingPan = null;
            }
            return true;
        }
        return false;
    }

    private boolean handleMotionEvent(WXGestureType WXGestureType, MotionEvent motionEvent) {
        if (this.component.getHover() != null) {
            this.component.getHover().handleMotionEvent(WXGestureType, motionEvent);
        }
        if (this.component.containsGesture(WXGestureType)) {
            for (Map<String, Object> map : createMultipleFireEventParam(motionEvent, null)) {
                this.component.fireEvent(WXGestureType.toString(), map);
            }
            return true;
        }
        return false;
    }

    private List<Map<String, Object>> createMultipleFireEventParam(MotionEvent motionEvent, String state) {
        ArrayList arrayList = new ArrayList(motionEvent.getHistorySize() + 1);
        arrayList.add(createFireEventParam(motionEvent, -1, state));
        return arrayList;
    }

    private List<Map<String, Object>> getHistoricalEvents(MotionEvent motionEvent) {
        ArrayList arrayList = new ArrayList(motionEvent.getHistorySize());
        if (motionEvent.getActionMasked() == 2) {
            for (int i = 0; i < motionEvent.getHistorySize(); i++) {
                arrayList.add(createFireEventParam(motionEvent, i, null));
            }
        }
        return arrayList;
    }

    private Map<String, Object> createFireEventParam(MotionEvent motionEvent, int pos, String state) {
        JSONArray jSONArray = new JSONArray(motionEvent.getPointerCount());
        if (motionEvent.getActionMasked() == 2) {
            for (int i = 0; i < motionEvent.getPointerCount(); i++) {
                jSONArray.add(createJSONObject(motionEvent, pos, i));
            }
        } else if (isPointerNumChanged(motionEvent)) {
            jSONArray.add(createJSONObject(motionEvent, -1, motionEvent.getActionIndex()));
        }
        HashMap hashMap = new HashMap();
        hashMap.put(WXGestureType.GestureInfo.HISTORICAL_XY, jSONArray);
        if (state != null) {
            hashMap.put("state", state);
        }
        return hashMap;
    }

    private boolean isPointerNumChanged(MotionEvent event) {
        return event.getActionMasked() == 0 || event.getActionMasked() == 5 || event.getActionMasked() == 1 || event.getActionMasked() == 6 || event.getActionMasked() == 3;
    }

    private boolean containsSimplePan() {
        return this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_START) || this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_MOVE) || this.component.containsGesture(WXGestureType.HighLevelGesture.PAN_END);
    }

    private JSONObject createJSONObject(MotionEvent motionEvent, int pos, int pointerIndex) {
        PointF eventLocInScreenCoordinate;
        PointF pointF;
        if (pos == -1) {
            pointF = getEventLocInPageCoordinate(motionEvent, pointerIndex);
            eventLocInScreenCoordinate = getEventLocInScreenCoordinate(motionEvent, pointerIndex);
        } else {
            PointF eventLocInPageCoordinate = getEventLocInPageCoordinate(motionEvent, pointerIndex, pos);
            eventLocInScreenCoordinate = getEventLocInScreenCoordinate(motionEvent, pointerIndex, pos);
            pointF = eventLocInPageCoordinate;
        }
        JSONObject createJSONObject = createJSONObject(eventLocInScreenCoordinate, pointF, motionEvent.getPointerId(pointerIndex));
        float pressure = motionEvent.getPressure();
        if (pressure > 0.0f && pressure < 1.0f) {
            createJSONObject.put(AbsoluteConst.INSTALL_OPTIONS_FORCE, (Object) Float.valueOf(motionEvent.getPressure()));
        }
        return createJSONObject;
    }

    private JSONObject createJSONObject(PointF screenXY, PointF pageXY, float pointerId) {
        JSONObject jSONObject = new JSONObject();
        jSONObject.put(WXGestureType.GestureInfo.PAGE_X, (Object) Float.valueOf(pageXY.x));
        jSONObject.put(WXGestureType.GestureInfo.PAGE_Y, (Object) Float.valueOf(pageXY.y));
        jSONObject.put(WXGestureType.GestureInfo.SCREEN_X, (Object) Float.valueOf(screenXY.x));
        jSONObject.put(WXGestureType.GestureInfo.SCREEN_Y, (Object) Float.valueOf(screenXY.y));
        jSONObject.put(WXGestureType.GestureInfo.POINTER_ID, (Object) Float.valueOf(pointerId));
        return jSONObject;
    }

    private PointF getEventLocInScreenCoordinate(MotionEvent motionEvent, int pointerIndex) {
        return getEventLocInScreenCoordinate(motionEvent, pointerIndex, -1);
    }

    private PointF getEventLocInScreenCoordinate(MotionEvent motionEvent, int pointerIndex, int position) {
        float historicalY;
        float f;
        if (position == -1) {
            f = motionEvent.getX(pointerIndex);
            historicalY = motionEvent.getY(pointerIndex);
        } else {
            float historicalX = motionEvent.getHistoricalX(pointerIndex, position);
            historicalY = motionEvent.getHistoricalY(pointerIndex, position);
            f = historicalX;
        }
        return getEventLocInScreenCoordinate(f, historicalY);
    }

    private PointF getEventLocInScreenCoordinate(float eventX, float eventY) {
        this.globalRect.set(0, 0, 0, 0);
        this.globalOffset.set(0, 0);
        this.globalEventOffset.set((int) eventX, (int) eventY);
        this.component.getRealView().getGlobalVisibleRect(this.globalRect, this.globalOffset);
        this.globalEventOffset.offset(this.globalOffset.x, this.globalOffset.y);
        return new PointF(WXViewUtils.getWebPxByWidth(this.globalEventOffset.x, this.component.getInstance().getInstanceViewPortWidthWithFloat()), WXViewUtils.getWebPxByWidth(this.globalEventOffset.y, this.component.getInstance().getInstanceViewPortWidthWithFloat()));
    }

    private PointF getEventLocInPageCoordinate(MotionEvent motionEvent, int pointerIndex) {
        return getEventLocInPageCoordinate(motionEvent, pointerIndex, -1);
    }

    private PointF getEventLocInPageCoordinate(MotionEvent motionEvent, int pointerIndex, int position) {
        float historicalY;
        float f;
        if (position == -1) {
            f = motionEvent.getX(pointerIndex);
            historicalY = motionEvent.getY(pointerIndex);
        } else {
            float historicalX = motionEvent.getHistoricalX(pointerIndex, position);
            historicalY = motionEvent.getHistoricalY(pointerIndex, position);
            f = historicalX;
        }
        return getEventLocInPageCoordinate(f, historicalY);
    }

    private PointF getEventLocInPageCoordinate(float eventX, float eventY) {
        this.locEventOffset.set(eventX, eventY);
        this.locLeftTop.set(0.0f, 0.0f);
        this.component.computeVisiblePointInViewCoordinate(this.locLeftTop);
        this.locEventOffset.offset(this.locLeftTop.x, this.locLeftTop.y);
        return new PointF(WXViewUtils.getWebPxByWidth(this.locEventOffset.x, this.component.getInstance().getInstanceViewPortWidthWithFloat()), WXViewUtils.getWebPxByWidth(this.locEventOffset.y, this.component.getInstance().getInstanceViewPortWidthWithFloat()));
    }

    /* loaded from: classes.dex */
    private static class GestureHandler extends Handler {
        public GestureHandler() {
            super(Looper.getMainLooper());
        }
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public void onLongPress(MotionEvent e) {
        if (this.component.containsGesture(WXGestureType.HighLevelGesture.LONG_PRESS)) {
            List<Map<String, Object>> createMultipleFireEventParam = createMultipleFireEventParam(e, null);
            this.component.getInstance().fireEvent(this.component.getRef(), WXGestureType.HighLevelGesture.LONG_PRESS.toString(), createMultipleFireEventParam.get(createMultipleFireEventParam.size() - 1));
            this.mIsTouchEventConsumed = true;
        }
    }

    @Override // android.view.GestureDetector.SimpleOnGestureListener, android.view.GestureDetector.OnGestureListener
    public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
        WXGestureType.HighLevelGesture highLevelGesture;
        boolean handlePanMotionEvent;
        boolean z = false;
        if (e1 == null || e2 == null) {
            return false;
        }
        if (Math.abs(e2.getX() - e1.getX()) > Math.abs(e2.getY() - e1.getY())) {
            highLevelGesture = WXGestureType.HighLevelGesture.HORIZONTALPAN;
        } else {
            highLevelGesture = WXGestureType.HighLevelGesture.VERTICALPAN;
        }
        if (this.mPendingPan == WXGestureType.HighLevelGesture.HORIZONTALPAN || this.mPendingPan == WXGestureType.HighLevelGesture.VERTICALPAN) {
            handlePanMotionEvent = handlePanMotionEvent(e2);
        } else {
            if (this.component.containsGesture(highLevelGesture)) {
                ViewParent parent = this.component.getRealView().getParent();
                if (parent != null) {
                    parent.requestDisallowInterceptTouchEvent(true);
                }
                WXGestureType wXGestureType = this.mPendingPan;
                if (wXGestureType != null) {
                    handleMotionEvent(wXGestureType, e2);
                }
                this.mPendingPan = highLevelGesture;
                this.component.fireEvent(highLevelGesture.toString(), createFireEventParam(e2, -1, "start"));
            } else if (containsSimplePan()) {
                if (this.panDownTime != e1.getEventTime()) {
                    this.panDownTime = e1.getEventTime();
                    this.mPendingPan = WXGestureType.HighLevelGesture.PAN_END;
                    this.component.fireEvent(WXGestureType.HighLevelGesture.PAN_START.toString(), createFireEventParam(e1, -1, null));
                } else {
                    this.component.fireEvent(WXGestureType.HighLevelGesture.PAN_MOVE.toString(), createFireEventParam(e2, -1, null));
                }
            } else if (!this.component.containsGesture(WXGestureType.HighLevelGesture.SWIPE) || this.swipeDownTime == e1.getEventTime()) {
                handlePanMotionEvent = false;
            } else {
                this.swipeDownTime = e1.getEventTime();
                List<Map<String, Object>> createMultipleFireEventParam = createMultipleFireEventParam(e2, null);
                Map<String, Object> map = createMultipleFireEventParam.get(createMultipleFireEventParam.size() - 1);
                if (Math.abs(distanceX) > Math.abs(distanceY)) {
                    map.put("direction", distanceX > 0.0f ? "left" : "right");
                } else {
                    map.put("direction", distanceY > 0.0f ? "up" : "down");
                }
                this.component.getInstance().fireEvent(this.component.getRef(), WXGestureType.HighLevelGesture.SWIPE.toString(), map);
            }
            handlePanMotionEvent = true;
        }
        this.mIsTouchEventConsumed = (this.mIsTouchEventConsumed || handlePanMotionEvent) ? true : true;
        return handlePanMotionEvent;
    }

    public boolean isRequestDisallowInterceptTouchEvent() {
        return this.requestDisallowInterceptTouchEvent;
    }

    public void setRequestDisallowInterceptTouchEvent(boolean requestDisallowInterceptTouchEvent) {
        this.requestDisallowInterceptTouchEvent = requestDisallowInterceptTouchEvent;
    }
}
