package com.taobao.weex.ui.view.listview.adapter;

import android.view.View;
import androidx.recyclerview.widget.RecyclerView;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXHeader;
import java.lang.ref.WeakReference;
/* loaded from: classes.dex */
public class ListBaseViewHolder extends RecyclerView.ViewHolder {
    private boolean isRecycled;
    private WeakReference<WXComponent> mComponent;
    private int mViewType;

    public ListBaseViewHolder(WXComponent component, int viewType) {
        super(component.getHostView());
        this.mViewType = viewType;
        this.mComponent = new WeakReference<>(component);
        this.isRecycled = component.canRecycled();
    }

    public ListBaseViewHolder(WXComponent component, int viewType, boolean forceBindData) {
        this(component, viewType);
        this.isRecycled = this.isRecycled || forceBindData;
    }

    public ListBaseViewHolder(View view, int viewType) {
        super(view);
        this.mViewType = viewType;
    }

    public boolean isRecycled() {
        return this.isRecycled;
    }

    public void recycled() {
        WeakReference<WXComponent> weakReference = this.mComponent;
        if (weakReference == null || weakReference.get() == null) {
            return;
        }
        this.mComponent.get().recycled();
        this.isRecycled = true;
    }

    public void bindData(WXComponent component) {
        WeakReference<WXComponent> weakReference = this.mComponent;
        if (weakReference == null || weakReference.get() == null) {
            return;
        }
        this.mComponent.get().bindData(component);
        this.isRecycled = false;
    }

    public boolean isFullSpan() {
        WeakReference<WXComponent> weakReference = this.mComponent;
        return weakReference != null && (weakReference.get() instanceof WXHeader);
    }

    public boolean canRecycled() {
        WeakReference<WXComponent> weakReference = this.mComponent;
        if (weakReference == null || weakReference.get() == null) {
            return true;
        }
        return this.mComponent.get().canRecycled();
    }

    public View getView() {
        return this.itemView;
    }

    public int getViewType() {
        return this.mViewType;
    }

    public void setComponentUsing(boolean using) {
        WeakReference<WXComponent> weakReference = this.mComponent;
        if (weakReference == null || weakReference.get() == null) {
            return;
        }
        this.mComponent.get().setUsing(using);
    }

    public WXComponent getComponent() {
        WeakReference<WXComponent> weakReference = this.mComponent;
        if (weakReference != null) {
            return weakReference.get();
        }
        return null;
    }
}
