package com.taobao.weex.utils;

import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.PaintDrawable;
import android.graphics.drawable.shapes.Shape;
import android.os.Build;
import android.widget.ImageView;
/* loaded from: classes.dex */
public class ImageDrawable extends PaintDrawable {
    private int bitmapHeight;
    private int bitmapWidth;
    private float[] radii;

    public static Drawable createImageDrawable(Drawable original, ImageView.ScaleType scaleType, float[] borderRadius, int vWidth, int vHeight, boolean gif) {
        Bitmap bitmap;
        if (!gif && vWidth > 0 && vHeight > 0) {
            if ((original instanceof BitmapDrawable) && (bitmap = ((BitmapDrawable) original).getBitmap()) != null) {
                ImageDrawable imageDrawable = new ImageDrawable();
                imageDrawable.getPaint().setFilterBitmap(true);
                imageDrawable.bitmapWidth = bitmap.getWidth();
                imageDrawable.bitmapHeight = bitmap.getHeight();
                BitmapShader bitmapShader = new BitmapShader(bitmap, Shader.TileMode.CLAMP, Shader.TileMode.CLAMP);
                updateShaderAndSize(scaleType, vWidth, vHeight, imageDrawable, bitmapShader);
                imageDrawable.getPaint().setShader(bitmapShader);
                return imageDrawable;
            } else if (original instanceof ImageDrawable) {
                ImageDrawable imageDrawable2 = (ImageDrawable) original;
                if (imageDrawable2.getPaint() != null && (imageDrawable2.getPaint().getShader() instanceof BitmapShader)) {
                    updateShaderAndSize(scaleType, vWidth, vHeight, imageDrawable2, (BitmapShader) imageDrawable2.getPaint().getShader());
                    return imageDrawable2;
                }
            }
        }
        return original;
    }

    private static void updateShaderAndSize(ImageView.ScaleType scaleType, int vWidth, int vHeight, ImageDrawable imageDrawable, BitmapShader bitmapShader) {
        Matrix createShaderMatrix = createShaderMatrix(scaleType, vWidth, vHeight, imageDrawable.bitmapWidth, imageDrawable.bitmapHeight);
        if (scaleType == ImageView.ScaleType.FIT_CENTER) {
            RectF rectF = new RectF(0.0f, 0.0f, imageDrawable.bitmapWidth, imageDrawable.bitmapHeight);
            RectF rectF2 = new RectF();
            createShaderMatrix.mapRect(rectF2, rectF);
            vWidth = (int) rectF2.width();
            vHeight = (int) rectF2.height();
            createShaderMatrix = createShaderMatrix(scaleType, vWidth, vHeight, imageDrawable.bitmapWidth, imageDrawable.bitmapHeight);
        }
        imageDrawable.setIntrinsicWidth(vWidth);
        imageDrawable.setIntrinsicHeight(vHeight);
        bitmapShader.setLocalMatrix(createShaderMatrix);
    }

    private static Matrix createShaderMatrix(ImageView.ScaleType scaleType, int vWidth, int vHeight, int bmWidth, int bmHeight) {
        float f;
        float f2;
        float f3;
        if (bmWidth * vHeight > bmHeight * vWidth) {
            f = vHeight / bmHeight;
            f3 = (vWidth - (bmWidth * f)) * 0.5f;
            f2 = 0.0f;
        } else {
            f = vWidth / bmWidth;
            f2 = (vHeight - (bmHeight * f)) * 0.5f;
            f3 = 0.0f;
        }
        Matrix matrix = new Matrix();
        if (scaleType == ImageView.ScaleType.FIT_XY) {
            matrix.setScale(vWidth / bmWidth, vHeight / bmHeight);
        } else if (scaleType == ImageView.ScaleType.FIT_CENTER) {
            matrix.setRectToRect(new RectF(0.0f, 0.0f, bmWidth, bmHeight), new RectF(0.0f, 0.0f, vWidth, vHeight), Matrix.ScaleToFit.CENTER);
        } else if (scaleType == ImageView.ScaleType.CENTER_CROP) {
            matrix.setScale(f, f);
            matrix.postTranslate(f3 + 0.5f, f2 + 0.5f);
        }
        return matrix;
    }

    private ImageDrawable() {
    }

    @Override // android.graphics.drawable.PaintDrawable
    public void setCornerRadii(float[] radii) {
        this.radii = radii;
        super.setCornerRadii(radii);
    }

    @Override // android.graphics.drawable.ShapeDrawable
    protected void onDraw(Shape shape, Canvas canvas, Paint paint) {
        if (Build.VERSION.SDK_INT == 21) {
            paint.setAntiAlias(false);
        }
        super.onDraw(shape, canvas, paint);
    }

    public float[] getCornerRadii() {
        return this.radii;
    }

    public int getBitmapHeight() {
        return this.bitmapHeight;
    }

    public int getBitmapWidth() {
        return this.bitmapWidth;
    }
}
