package com.taobao.weex.utils;

import android.util.Log;
/* loaded from: classes.dex */
public class Trace {
    private static final String TAG = "Weex_Trace";
    private static final boolean sEnabled = false;
    private static final AbstractTrace sTrace;

    /* loaded from: classes.dex */
    private static abstract class AbstractTrace {
        abstract void beginSection(String sectionName);

        abstract void endSection();

        private AbstractTrace() {
        }
    }

    static {
        if (0 == 1 && OsVersion.isAtLeastJB_MR2()) {
            sTrace = new TraceJBMR2();
        } else {
            sTrace = new TraceDummy();
        }
    }

    public static final boolean getTraceEnabled() {
        return sEnabled;
    }

    public static void beginSection(String sectionName) {
        Log.i(TAG, "beginSection() " + sectionName);
        sTrace.beginSection(sectionName);
    }

    public static void endSection() {
        sTrace.endSection();
        Log.i(TAG, "endSection()");
    }

    /* loaded from: classes.dex */
    private static final class TraceJBMR2 extends AbstractTrace {
        private TraceJBMR2() {
            super();
        }

        @Override // com.taobao.weex.utils.Trace.AbstractTrace
        void beginSection(String sectionName) {
            android.os.Trace.beginSection(sectionName);
        }

        @Override // com.taobao.weex.utils.Trace.AbstractTrace
        void endSection() {
            android.os.Trace.endSection();
        }
    }

    /* loaded from: classes.dex */
    private static final class TraceDummy extends AbstractTrace {
        @Override // com.taobao.weex.utils.Trace.AbstractTrace
        void beginSection(String sectionName) {
        }

        @Override // com.taobao.weex.utils.Trace.AbstractTrace
        void endSection() {
        }

        private TraceDummy() {
            super();
        }
    }
}
