package dc.squareup.okio;

import java.io.IOException;
/* loaded from: classes.dex */
final class PeekSource implements Source {
    private final Buffer buffer;
    private boolean closed;
    private int expectedPos;
    private Segment expectedSegment;
    private long pos;
    private final BufferedSource upstream;

    /* JADX INFO: Access modifiers changed from: package-private */
    public PeekSource(BufferedSource bufferedSource) {
        this.upstream = bufferedSource;
        Buffer buffer = bufferedSource.buffer();
        this.buffer = buffer;
        Segment segment = buffer.head;
        this.expectedSegment = segment;
        this.expectedPos = segment != null ? segment.pos : -1;
    }

    @Override // dc.squareup.okio.Source, java.io.Closeable, java.lang.AutoCloseable
    public void close() throws IOException {
        this.closed = true;
    }

    @Override // dc.squareup.okio.Source
    public long read(Buffer buffer, long j) throws IOException {
        Segment segment;
        Segment segment2;
        int i = (j > 0L ? 1 : (j == 0L ? 0 : -1));
        if (i >= 0) {
            if (!this.closed) {
                Segment segment3 = this.expectedSegment;
                if (segment3 == null || (segment3 == (segment2 = this.buffer.head) && this.expectedPos == segment2.pos)) {
                    if (i == 0) {
                        return 0L;
                    }
                    if (this.upstream.request(this.pos + 1)) {
                        if (this.expectedSegment == null && (segment = this.buffer.head) != null) {
                            this.expectedSegment = segment;
                            this.expectedPos = segment.pos;
                        }
                        long min = Math.min(j, this.buffer.size - this.pos);
                        this.buffer.copyTo(buffer, this.pos, min);
                        this.pos += min;
                        return min;
                    }
                    return -1L;
                }
                throw new IllegalStateException("Peek source is invalid because upstream source was used");
            }
            throw new IllegalStateException("closed");
        }
        throw new IllegalArgumentException("byteCount < 0: " + j);
    }

    @Override // dc.squareup.okio.Source
    public Timeout timeout() {
        return this.upstream.timeout();
    }
}
