package io.dcloud.feature.payment.weixin;

import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import com.taobao.weex.el.parse.Operators;
import com.tencent.mm.opensdk.modelbase.BaseResp;
import com.tencent.mm.opensdk.modelpay.PayReq;
import com.tencent.mm.opensdk.modelpay.PayResp;
import com.tencent.mm.opensdk.openapi.IWXAPI;
import com.tencent.mm.opensdk.openapi.WXAPIFactory;
import io.dcloud.ProcessMediator;
import io.dcloud.application.DCLoudApplicationImpl;
import io.dcloud.common.DHInterface.FeatureMessageDispatcher;
import io.dcloud.common.DHInterface.IActivityHandler;
import io.dcloud.common.DHInterface.ISysEventListener;
import io.dcloud.common.adapter.util.AndroidResources;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.common.constant.DOMException;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.payment.AbsPaymentChannel;
import io.dcloud.feature.payment.PaymentResult;
import java.util.Set;
import org.json.JSONObject;
/* loaded from: classes.dex */
public class WeiXinPay extends AbsPaymentChannel implements ISysEventListener {
    private static String APPID = null;
    private static final String ERR_MSG_AUTH_DENIED = "Authentication failed";
    private static final String ERR_MSG_COMM = "General errors";
    private static final String ERR_MSG_SENT_FAILED = "Unable to send";
    private static final String ERR_MSG_UNSUPPORT = "Unsupport error";
    private static final String ERR_MSG_USER_CANCEL = "User canceled";
    private static final String PNAME_MM = "com.tencent.mm";
    private static final String URL_MARKET_DETAILS = "market://search?q=pname:%s";
    private IWXAPI api;
    private boolean isInstallingService = false;
    private String statement = null;
    FeatureMessageDispatcher.MessageListener sPayCallbackMessageListener = new FeatureMessageDispatcher.MessageListener() { // from class: io.dcloud.feature.payment.weixin.WeiXinPay.2
        @Override // io.dcloud.common.DHInterface.FeatureMessageDispatcher.MessageListener
        public void onReceiver(Object msg) {
            if (msg instanceof BaseResp) {
                WeiXinPay.this.executePayCallbackMsg((BaseResp) msg);
                FeatureMessageDispatcher.unregisterListener(WeiXinPay.this.sPayCallbackMessageListener);
            }
        }
    };

    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    public void init(Context context) {
        super.init(context);
        this.id = "wxpay";
        this.description = DCLoudApplicationImpl.self().getContext().getString(R.string.dcloud_feature_wxpay_plugin_description);
        this.serviceReady = PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm");
        String metaValue = AndroidResources.getMetaValue("WX_APPID");
        APPID = metaValue;
        IWXAPI createWXAPI = WXAPIFactory.createWXAPI(context, metaValue);
        this.api = createWXAPI;
        createWXAPI.registerApp(APPID);
    }

    private boolean hasFullConfigData() {
        return !TextUtils.isEmpty(APPID);
    }

    private boolean hasGeneralError() {
        if (!hasFullConfigData()) {
            this.mListener.onError(-7, DOMException.toString(DOMException.MSG_BUSINESS_PARAMETER_HAS_NOT));
            return true;
        } else if (PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm")) {
            return false;
        } else {
            this.mListener.onError(-8, DOMException.toString(DOMException.MSG_CLIENT_UNINSTALLED));
            return true;
        }
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    public void installService() {
        try {
            PlatformUtil.openURL(this.mContext, StringUtil.format(URL_MARKET_DETAILS, "com.tencent.mm"), null);
            this.isInstallingService = true;
            this.mWebview.obtainApp().registerSysEventListener(this, ISysEventListener.SysEventType.onResume);
        } catch (Exception e) {
            e.printStackTrace();
            this.mWebview.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onResume);
        }
    }

    @Override // io.dcloud.common.DHInterface.ISysEventListener
    public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
        if (pEventType == ISysEventListener.SysEventType.onResume) {
            this.serviceReady = PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm");
            this.isInstallingService = false;
            this.mWebview.obtainApp().unregisterSysEventListener(this, ISysEventListener.SysEventType.onResume);
            if (this.serviceReady) {
                if (!PdrUtil.isEmpty(this.statement)) {
                    request(this.statement);
                    this.statement = null;
                }
            } else {
                this.mListener.onError(-8, DOMException.MSG_CLIENT_UNINSTALLED);
            }
        }
        return false;
    }

    private void startWXPayMediator(PayReq req) {
        Intent intent = new Intent();
        intent.putExtra(ProcessMediator.LOGIC_CLASS, WXPayMediator.class.getName());
        Bundle bundle = new Bundle();
        req.toBundle(bundle);
        intent.putExtra(ProcessMediator.REQ_DATA, bundle);
        intent.putExtra("transaction", req.prepayId);
        intent.putExtra(ProcessMediator.PROCESS_ACTIVITY_SOURCE, this.mWebview.getActivity().getClass().getName());
        intent.setClassName(this.mWebview.getActivity(), WXPayProcessMeadiatorActivity.class.getName());
        this.mWebview.getActivity().startActivityForResult(intent, 1000);
        this.mWebview.getActivity().overridePendingTransition(0, 0);
        this.mWebview.obtainApp().registerSysEventListener(new ISysEventListener() { // from class: io.dcloud.feature.payment.weixin.WeiXinPay.1
            @Override // io.dcloud.common.DHInterface.ISysEventListener
            public boolean onExecute(ISysEventListener.SysEventType pEventType, Object pArgs) {
                Object[] objArr = (Object[]) pArgs;
                int intValue = ((Integer) objArr[0]).intValue();
                ((Integer) objArr[1]).intValue();
                Intent intent2 = (Intent) objArr[2];
                if (intent2 != null && pEventType == ISysEventListener.SysEventType.onActivityResult && intValue == 1000 && intent2.hasExtra("result")) {
                    Bundle bundleExtra = intent2.getBundleExtra("result");
                    String string = bundleExtra.getString("style");
                    if ("BaseResp".equals(string)) {
                        PayResp payResp = new PayResp();
                        payResp.fromBundle(bundleExtra);
                        WeiXinPay.this.sPayCallbackMessageListener.onReceiver(payResp);
                    } else if ("BaseReq".equals(string)) {
                        PayReq payReq = new PayReq();
                        payReq.fromBundle(bundleExtra);
                        WeiXinPay.this.sPayCallbackMessageListener.onReceiver(payReq);
                    }
                    return false;
                }
                return false;
            }
        }, ISysEventListener.SysEventType.onActivityResult);
    }

    @Override // io.dcloud.feature.payment.AbsPaymentChannel
    protected void request(String pStatement) {
        if (hasGeneralError()) {
            return;
        }
        if (!PlatformUtil.isAppInstalled(this.mContext, "com.tencent.mm")) {
            if (this.isInstallingService) {
                this.statement = pStatement;
                return;
            } else {
                this.mListener.onError(-8, DOMException.MSG_CLIENT_UNINSTALLED);
                return;
            }
        }
        PayInfoResult payInfoResult = new PayInfoResult();
        payInfoResult.parseFrom(pStatement);
        PayReq payReq = new PayReq();
        payReq.appId = payInfoResult.appid;
        payReq.partnerId = payInfoResult.partnerid;
        payReq.prepayId = payInfoResult.prepayid;
        payReq.nonceStr = payInfoResult.noncestr;
        payReq.timeStamp = payInfoResult.timestamp;
        payReq.packageValue = payInfoResult.result_package;
        payReq.sign = payInfoResult.sign;
        if ((this.mWebview.getActivity() instanceof IActivityHandler) && ((IActivityHandler) this.mWebview.getActivity()).isMultiProcessMode()) {
            startWXPayMediator(payReq);
            return;
        }
        boolean sendReq = this.api.sendReq(payReq);
        if (sendReq && hasWXPayEntryActivity(this.mWebview.getContext())) {
            FeatureMessageDispatcher.registerListener(this.sPayCallbackMessageListener);
            Logger.d("wxpay", "will pay");
            return;
        }
        onPayCallback(sendReq ? 0 : -1, null);
    }

    void executePayCallbackMsg(BaseResp resp) {
        if (resp != null) {
            int i = resp.errCode;
            StringBuffer stringBuffer = new StringBuffer(Operators.BLOCK_START_STR);
            Bundle bundle = new Bundle();
            resp.toBundle(bundle);
            Set<String> keySet = bundle.keySet();
            if (keySet != null) {
                int size = keySet.size();
                String[] strArr = new String[size];
                keySet.toArray(strArr);
                for (int i2 = 0; i2 < size; i2++) {
                    String str = strArr[i2];
                    stringBuffer.append("'");
                    stringBuffer.append(str);
                    stringBuffer.append("':");
                    stringBuffer.append("'");
                    stringBuffer.append(bundle.get(str));
                    stringBuffer.append("'");
                    if (i2 != size - 1) {
                        stringBuffer.append(",");
                    }
                }
            }
            stringBuffer.append(Operators.BLOCK_END_STR);
            onPayCallback(i, stringBuffer.toString());
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:23:0x0029  */
    /* JADX WARN: Removed duplicated region for block: B:24:0x003b  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    void onPayCallback(int code, String rawData) {
        String str;
        boolean z = false;
        if (code != 0) {
            if (code == -4) {
                str = ERR_MSG_AUTH_DENIED;
            } else if (code == -1) {
                str = ERR_MSG_COMM;
            } else if (code == -3) {
                str = ERR_MSG_SENT_FAILED;
            } else if (code == -5) {
                str = ERR_MSG_UNSUPPORT;
            } else if (code == -2) {
                str = ERR_MSG_USER_CANCEL;
            }
            if (!z) {
                Logger.d("wxpay", "pay success");
                PaymentResult paymentResult = new PaymentResult(this);
                paymentResult.rawDataJson = rawData;
                this.mListener.onSuccess(paymentResult);
                return;
            }
            Logger.d("wxpay", "pay failed code=" + code);
            this.mListener.onError(-100, DOMException.toString(code, getFullDescription(), str, (String) null));
            return;
        }
        z = true;
        str = null;
        if (!z) {
        }
    }

    private static boolean hasWXPayEntryActivity(Context context) {
        try {
            Class.forName(context.getPackageName() + ".wxapi.WXPayEntryActivity");
            return true;
        } catch (ClassNotFoundException unused) {
            return false;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class PayInfoResult {
        private static final String KEY_APPID = "appid";
        private static final String KEY_NONCESTR = "noncestr";
        private static final String KEY_PACKAGE = "package";
        private static final String KEY_PARTNERID = "partnerid";
        private static final String KEY_PREPAYID = "prepayid";
        private static final String KEY_RETCODE = "retcode";
        private static final String KEY_RETMSG = "retmsg";
        private static final String KEY_SIGN = "sign";
        private static final String KEY_TIMESTAMP = "timestamp";
        public String appid;
        public String noncestr;
        public String partnerid;
        public String prepayid;
        public String result_package;
        public int retcode;
        public String retmsg;
        public String sign;
        public String timestamp;

        private PayInfoResult() {
        }

        public void parseFrom(String content) {
            try {
                JSONObject jSONObject = new JSONObject(content);
                this.appid = jSONObject.optString("appid");
                if (jSONObject.has("nonceStr")) {
                    this.noncestr = jSONObject.optString("nonceStr");
                } else {
                    this.noncestr = jSONObject.optString(KEY_NONCESTR);
                }
                this.result_package = jSONObject.optString(KEY_PACKAGE, "Sign=WXPay");
                this.partnerid = jSONObject.optString(KEY_PARTNERID);
                this.prepayid = jSONObject.optString(KEY_PREPAYID);
                this.timestamp = jSONObject.optString(KEY_TIMESTAMP);
                this.sign = jSONObject.optString(KEY_SIGN);
            } catch (Exception unused) {
                this.retcode = -1000;
            }
        }
    }
}
