package io.dcloud.feature.uniapp.dom;

import android.text.TextUtils;
import java.lang.Enum;
import java.util.Arrays;
/* loaded from: classes.dex */
public abstract class AbsCSSShorthand<T extends Enum<? extends CSSProperty>> implements Cloneable {
    private float[] values;

    /* loaded from: classes.dex */
    public enum CORNER implements CSSProperty {
        BORDER_TOP_LEFT,
        BORDER_TOP_RIGHT,
        BORDER_BOTTOM_RIGHT,
        BORDER_BOTTOM_LEFT,
        ALL
    }

    /* loaded from: classes.dex */
    protected interface CSSProperty {
    }

    /* loaded from: classes.dex */
    public enum EDGE implements CSSProperty {
        TOP,
        BOTTOM,
        LEFT,
        RIGHT,
        ALL
    }

    /* loaded from: classes.dex */
    public enum TYPE {
        MARGIN,
        PADDING,
        BORDER
    }

    public AbsCSSShorthand(float[] values) {
        replace(values);
    }

    public AbsCSSShorthand() {
        this(false);
    }

    AbsCSSShorthand(boolean fillWithNaN) {
        float[] fArr = new float[Math.max(EDGE.values().length, CORNER.values().length)];
        this.values = fArr;
        if (fillWithNaN) {
            Arrays.fill(fArr, Float.NaN);
        }
    }

    public void set(Enum<? extends CSSProperty> edge, float value) {
        setInternal(edge, value);
    }

    public void set(CORNER edge, float value) {
        setInternal(edge, value);
    }

    public float get(Enum<? extends CSSProperty> edge) {
        return getInternal(edge);
    }

    public float get(CORNER edge) {
        return getInternal(edge);
    }

    public final void replace(float[] values) {
        this.values = values;
    }

    /* renamed from: clone */
    public AbsCSSShorthand m17clone() throws CloneNotSupportedException {
        return (AbsCSSShorthand) super.clone();
    }

    private void setInternal(Enum<? extends CSSProperty> edge, float value) {
        if (edge.name().equals(EDGE.ALL.name()) || edge.name().equals(CORNER.ALL.name())) {
            Arrays.fill(this.values, value);
        } else {
            this.values[edge.ordinal()] = value;
        }
    }

    private float getInternal(Enum<? extends CSSProperty> edge) {
        if (edge.name().equals(EDGE.ALL.name()) || edge.name().equals(CORNER.ALL.name())) {
            return 0.0f;
        }
        return this.values[edge.ordinal()];
    }

    public String toString() {
        return TextUtils.isEmpty(this.values.toString()) ? "" : Arrays.toString(this.values);
    }
}
