package io.dcloud.feature.uniapp.utils;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BlurMaskFilter;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PaintFlagsDrawFilter;
import android.graphics.Path;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Region;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.text.TextUtils;
import com.taobao.weex.performance.WXInstanceApm;
import com.taobao.weex.utils.WXLogUtils;
import com.taobao.weex.utils.WXResourceUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.StringUtil;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowData;
import io.dcloud.feature.uniapp.ui.shadow.UniBoxShadowOptions;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowDrawable;
import io.dcloud.feature.uniapp.ui.shadow.UniInsetBoxShadowLayer;
import io.dcloud.feature.uniapp.ui.shadow.UniNormalBoxShadowDrawable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes.dex */
public class UniBoxShadowUtil {
    private static final String TAG = "UniBoxShadowUtil";
    private static boolean sBoxShadowEnabled = true;
    private static Pattern sColorPattern;

    public static void setBoxShadowEnabled(boolean enabled) {
        sBoxShadowEnabled = enabled;
        WXLogUtils.w(TAG, "Switch box-shadow status: " + enabled);
    }

    public static boolean isBoxShadowEnabled() {
        return sBoxShadowEnabled;
    }

    public static UniBoxShadowData parseBoxShadow(int width, int height, String style, float[] radii, float viewPort, float quality) {
        if (!sBoxShadowEnabled) {
            WXLogUtils.w(TAG, "box-shadow was disabled by config");
            return null;
        }
        UniBoxShadowOptions[] parseBoxShadows = parseBoxShadows(style, viewPort);
        if (parseBoxShadows == null || parseBoxShadows.length == 0) {
            WXLogUtils.w(TAG, "Failed to parse box-shadow: " + style);
            return null;
        }
        ArrayList<UniBoxShadowOptions> arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        int i = 0;
        for (UniBoxShadowOptions uniBoxShadowOptions : parseBoxShadows) {
            if (uniBoxShadowOptions != null) {
                if (uniBoxShadowOptions.isInset) {
                    arrayList2.add(0, uniBoxShadowOptions);
                } else {
                    arrayList.add(0, uniBoxShadowOptions);
                }
            }
        }
        if (radii != null && radii.length != 8) {
            WXLogUtils.w(TAG, "Length of radii must be 8");
        }
        UniBoxShadowData uniBoxShadowData = new UniBoxShadowData(arrayList, arrayList2, radii, quality);
        uniBoxShadowData.setStyle(style);
        if (arrayList.size() > 0) {
            int i2 = 0;
            for (UniBoxShadowOptions uniBoxShadowOptions2 : arrayList) {
                uniBoxShadowOptions2.viewWidth = width;
                uniBoxShadowOptions2.viewHeight = height;
                uniBoxShadowOptions2.radii = radii;
                Rect targetCanvasRect = uniBoxShadowOptions2.getTargetCanvasRect();
                if (i < targetCanvasRect.width()) {
                    i = targetCanvasRect.width();
                }
                if (i2 < targetCanvasRect.height()) {
                    i2 = targetCanvasRect.height();
                }
            }
            uniBoxShadowData.setNormalMaxWidth(i);
            uniBoxShadowData.setNormalMaxHeight(i2);
            uniBoxShadowData.setNormalLeft(i - width);
            uniBoxShadowData.setNormalTop(i2 - height);
        }
        uniBoxShadowData.setContentHeight(height);
        uniBoxShadowData.setContentWidth(width);
        return uniBoxShadowData;
    }

    public static UniBoxShadowOptions[] parseBoxShadows(String boxShadowStyle, float viewport) {
        int i;
        if (sColorPattern == null) {
            sColorPattern = Pattern.compile("([rR][gG][bB][aA]?)\\((\\d+\\s*),\\s*(\\d+\\s*),\\s*(\\d+\\s*)(?:,\\s*(\\d+(?:\\.\\d+)?))?\\)");
        }
        Matcher matcher = sColorPattern.matcher(boxShadowStyle);
        while (true) {
            if (!matcher.find()) {
                break;
            }
            String group = matcher.group();
            boxShadowStyle = boxShadowStyle.replace(group, "#" + StringUtil.format("%8s", Integer.toHexString(WXResourceUtils.getColor(group, -16777216))).replaceAll("\\s", WXInstanceApm.VALUE_ERROR_CODE_DEFAULT));
        }
        String[] split = boxShadowStyle.split(",");
        if (split == null || split.length <= 0) {
            return null;
        }
        UniBoxShadowOptions[] uniBoxShadowOptionsArr = new UniBoxShadowOptions[split.length];
        for (i = 0; i < split.length; i++) {
            uniBoxShadowOptionsArr[i] = parseBoxShadow(split[i], viewport);
        }
        return uniBoxShadowOptionsArr;
    }

    private static UniBoxShadowOptions parseBoxShadow(String boxShadow, float viewport) {
        int i;
        UniBoxShadowOptions uniBoxShadowOptions = new UniBoxShadowOptions(viewport);
        if (TextUtils.isEmpty(boxShadow)) {
            return null;
        }
        String replaceAll = boxShadow.replaceAll("\\s*,\\s+", ",");
        if (replaceAll.contains("inset")) {
            uniBoxShadowOptions.isInset = true;
            replaceAll = replaceAll.replace("inset", "");
        }
        ArrayList arrayList = new ArrayList(Arrays.asList(replaceAll.trim().split("\\s+")));
        String str = (String) arrayList.get(arrayList.size() - 1);
        if (!TextUtils.isEmpty(str) && (str.startsWith("#") || str.startsWith("rgb") || WXResourceUtils.isNamedColor(str))) {
            uniBoxShadowOptions.color = WXResourceUtils.getColor(str, -16777216);
            arrayList.remove(arrayList.size() - 1);
        }
        try {
        } catch (Throwable th) {
            th.printStackTrace();
        }
        if (arrayList.size() < 2) {
            return null;
        }
        if (!TextUtils.isEmpty((CharSequence) arrayList.get(0))) {
            uniBoxShadowOptions.hShadow = WXViewUtils.getRealSubPxByWidth(WXUtils.getFloat(((String) arrayList.get(0)).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
        }
        if (!TextUtils.isEmpty((CharSequence) arrayList.get(1))) {
            uniBoxShadowOptions.vShadow = WXViewUtils.getRealPxByWidth(WXUtils.getFloat(((String) arrayList.get(1)).trim(), Float.valueOf(0.0f)).floatValue(), viewport);
        }
        for (i = 2; i < arrayList.size(); i++) {
            uniBoxShadowOptions.optionParamParsers.get(i - 2).parse((String) arrayList.get(i));
        }
        return uniBoxShadowOptions;
    }

    public static UniNormalBoxShadowDrawable getNormalBoxShadowDrawable(UniBoxShadowData shadowData, Resources resources) {
        if (shadowData.getNormalShadows().size() <= 0) {
            return null;
        }
        Bitmap createBitmap = Bitmap.createBitmap(shadowData.getCanvasWidth(), shadowData.getCanvasHeight(), Bitmap.Config.ARGB_4444);
        if (Build.VERSION.SDK_INT >= 19) {
            Logger.e(TAG, "Allocation memory for box-shadow: " + (createBitmap.getAllocationByteCount() / 1024) + " KB");
        }
        Canvas canvas = new Canvas(createBitmap);
        canvas.setDrawFilter(new PaintFlagsDrawFilter(0, 3));
        for (UniBoxShadowOptions uniBoxShadowOptions : shadowData.getNormalShadows()) {
            drawShadow(canvas, uniBoxShadowOptions.scale(shadowData.getQuality()), shadowData.getNormalTop(), shadowData.getNormalLeft(), shadowData.getQuality());
        }
        return new UniNormalBoxShadowDrawable(resources, createBitmap);
    }

    private static void drawShadow(Canvas canvas, UniBoxShadowOptions options, float normalTop, float normalLeft, float quality) {
        RectF rectF = new RectF(0.0f, 0.0f, options.viewWidth + (options.spread * 2.0f), options.viewHeight + (options.spread * 2.0f));
        rectF.offset(options.hShadow >= 0.0f ? options.blur + (options.hShadow * 2.0f) : 0.0f, options.vShadow >= 0.0f ? options.blur + (options.vShadow * 2.0f) : 0.0f);
        Path path = new Path();
        RectF rectF2 = new RectF(0.0f, 0.0f, options.viewWidth, options.viewHeight);
        rectF2.offset(normalLeft > 0.0f ? (normalLeft * quality) / 2.0f : 0.0f, normalTop > 0.0f ? (normalTop * quality) / 2.0f : 0.0f);
        rectF2.inset(1.0f, 1.0f);
        path.addRoundRect(rectF2, options.radii, Path.Direction.CCW);
        canvas.clipPath(path, Region.Op.DIFFERENCE);
        Paint paint = new Paint();
        paint.setAntiAlias(true);
        paint.setColor(options.color);
        paint.setStyle(Paint.Style.FILL);
        if (options.blur > 0.0f) {
            paint.setMaskFilter(new BlurMaskFilter(options.blur, BlurMaskFilter.Blur.NORMAL));
        }
        float f = options.radii[0];
        if (f == options.radii[2] && f == options.radii[4] && f == options.radii[6]) {
            canvas.drawRoundRect(rectF, f, f, paint);
            return;
        }
        Path path2 = new Path();
        float[] fArr = new float[8];
        for (int i = 0; i < options.radii.length; i++) {
            if (options.radii[i] == 0.0f) {
                fArr[i] = 0.0f;
            } else {
                fArr[i] = options.radii[i] + options.spread;
            }
        }
        path2.addRoundRect(rectF, fArr, Path.Direction.CW);
        canvas.drawPath(path2, paint);
    }

    public static UniInsetBoxShadowLayer getInsetBoxShadowDrawable(UniBoxShadowData shadowData) {
        if (shadowData.getInsetShadows().size() <= 0) {
            return null;
        }
        if (Build.VERSION.SDK_INT >= 18) {
            Drawable[] drawableArr = new Drawable[shadowData.getInsetShadows().size()];
            for (int i = 0; i < shadowData.getInsetShadows().size(); i++) {
                UniBoxShadowOptions uniBoxShadowOptions = shadowData.getInsetShadows().get(i);
                drawableArr[i] = new UniInsetBoxShadowDrawable(shadowData.getContentWidth(), shadowData.getContentHeight(), uniBoxShadowOptions.hShadow, uniBoxShadowOptions.vShadow, uniBoxShadowOptions.blur, uniBoxShadowOptions.spread, uniBoxShadowOptions.color, shadowData.getRadii());
            }
            return new UniInsetBoxShadowLayer(drawableArr);
        }
        WXLogUtils.w(TAG, "Call setInsetBoxShadow() requires API level 18 or higher.");
        return null;
    }
}
