package io.dcloud.feature.weex.adapter;

import android.net.Uri;
import android.util.Base64;
import com.alibaba.fastjson.JSONArray;
import com.facebook.imagepipeline.producers.HttpUrlConnectionNetworkFetcher;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXHttpAdapter;
import com.taobao.weex.common.WXRequest;
import com.taobao.weex.common.WXResponse;
import com.taobao.weex.http.WXStreamModule;
import dc.squareup.okhttp3.ConnectionPool;
import dc.squareup.okhttp3.MediaType;
import dc.squareup.okhttp3.OkHttpClient;
import dc.squareup.okhttp3.Protocol;
import dc.squareup.okhttp3.Request;
import dc.squareup.okhttp3.RequestBody;
import dc.squareup.okhttp3.Response;
import dc.squareup.okhttp3.internal.tls.OkHostnameVerifier;
import io.dcloud.common.adapter.util.DCOKDns;
import io.dcloud.common.adapter.util.DCloudTrustManager;
import io.dcloud.common.util.net.NetWork;
import io.dcloud.feature.weex.config.AndroidTlsConfig;
import io.dcloud.feature.weex.config.UserCustomTrustManager;
import java.io.BufferedReader;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.security.KeyManagementException;
import java.security.NoSuchAlgorithmException;
import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.TimeUnit;
import javax.net.ssl.SSLSocketFactory;
import org.apache.http.conn.ssl.X509HostnameVerifier;
/* loaded from: classes.dex */
public class DCWXHttpAdapter implements IWXHttpAdapter {
    private static ConnectionPool mConnectPool;
    private static SSLSocketFactory sslSocketFactory;
    private ExecutorService mExecutorService;

    private void execute(Runnable runnable) {
        if (this.mExecutorService == null) {
            this.mExecutorService = Executors.newFixedThreadPool(10);
        }
        this.mExecutorService.execute(runnable);
    }

    @Override // com.taobao.weex.adapter.IWXHttpAdapter
    public void sendRequest(final WXRequest request, final IWXHttpAdapter.OnHttpListener listener) {
        if (listener != null) {
            listener.onHttpStart();
        }
        execute(new Runnable() { // from class: io.dcloud.feature.weex.adapter.DCWXHttpAdapter.1
            @Override // java.lang.Runnable
            public void run() {
                WXSDKInstance wXSDKInstance = WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId);
                if (wXSDKInstance != null && !wXSDKInstance.isDestroy()) {
                    wXSDKInstance.getApmForInstance().actionNetRequest();
                }
                boolean z = true;
                WXResponse wXResponse = new WXResponse();
                boolean z2 = false;
                try {
                    OkHttpClient.Builder builder = new OkHttpClient.Builder();
                    Response execute = builder.build().newCall(DCWXHttpAdapter.this.getOKRequest(builder, request, listener)).execute();
                    Map<String, List<String>> multimap = execute.headers().toMultimap();
                    int code = execute.code();
                    wXResponse.statusCode = String.valueOf(code);
                    IWXHttpAdapter.OnHttpListener onHttpListener = listener;
                    if (onHttpListener != null) {
                        onHttpListener.onHeadersReceived(code, multimap);
                    }
                    if (!execute.isSuccessful()) {
                        wXResponse.errorMsg = DCWXHttpAdapter.this.readInputStream(execute.body().byteStream(), listener);
                        z = false;
                    } else {
                        wXResponse.originalData = DCWXHttpAdapter.this.readInputStreamAsBytes(execute.body().byteStream(), listener);
                    }
                    IWXHttpAdapter.OnHttpListener onHttpListener2 = listener;
                    if (onHttpListener2 != null) {
                        onHttpListener2.onHttpFinish(wXResponse);
                    }
                    z2 = z;
                } catch (Exception e) {
                    e.printStackTrace();
                    wXResponse.statusCode = "-1";
                    wXResponse.errorCode = "-1";
                    wXResponse.errorMsg = e.getMessage();
                    IWXHttpAdapter.OnHttpListener onHttpListener3 = listener;
                    if (onHttpListener3 != null) {
                        onHttpListener3.onHttpFinish(wXResponse);
                    }
                }
                if (wXSDKInstance == null || wXSDKInstance.isDestroy()) {
                    return;
                }
                wXSDKInstance.getApmForInstance().actionNetResult(z2, null);
            }
        });
    }

    public Request getOKRequest(OkHttpClient.Builder httpBuilder, WXRequest request, IWXHttpAdapter.OnHttpListener listener) {
        httpBuilder.connectTimeout(request.timeoutMs, TimeUnit.MILLISECONDS).readTimeout(request.timeoutMs, TimeUnit.MILLISECONDS).writeTimeout(request.timeoutMs, TimeUnit.MILLISECONDS).callTimeout(request.timeoutMs, TimeUnit.MILLISECONDS).protocols(Collections.singletonList(Protocol.HTTP_1_1));
        if (request.isFirstIpv4) {
            httpBuilder.dns(new DCOKDns());
        }
        String host = Uri.parse(request.url).getHost();
        if (request.tls != null) {
            AndroidTlsConfig androidTlsConfig = new AndroidTlsConfig();
            androidTlsConfig.setKeystore(request.tls.getString("keystore"));
            androidTlsConfig.setStorePass(request.tls.getString("storePass"));
            JSONArray jSONArray = request.tls.getJSONArray("ca");
            androidTlsConfig.setCa(jSONArray != null ? (String[]) jSONArray.toArray(new String[0]) : null);
            httpBuilder.sslSocketFactory(UserCustomTrustManager.getSSLSocketFactory(androidTlsConfig, WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId)));
            httpBuilder.hostnameVerifier(OkHostnameVerifier.INSTANCE);
        } else if (WXStreamModule.certMap != null && WXStreamModule.certMap.containsKey(host)) {
            httpBuilder.sslSocketFactory(UserCustomTrustManager.getSSLSocketFactory(WXStreamModule.certMap.get(host), WXSDKManager.getInstance().getAllInstanceMap().get(request.instanceId)));
            httpBuilder.hostnameVerifier(OkHostnameVerifier.INSTANCE);
        } else if (request.sslVerify) {
            try {
                if (sslSocketFactory == null) {
                    sslSocketFactory = DCloudTrustManager.getSSLSocketFactory();
                }
                SSLSocketFactory sSLSocketFactory = sslSocketFactory;
                if (sSLSocketFactory != null) {
                    httpBuilder.sslSocketFactory(sSLSocketFactory);
                }
            } catch (KeyManagementException e) {
                e.printStackTrace();
            } catch (NoSuchAlgorithmException e2) {
                e2.printStackTrace();
            }
            httpBuilder.hostnameVerifier(getHostnameVerifier(request.sslVerify));
        }
        if (mConnectPool == null) {
            mConnectPool = new ConnectionPool();
        }
        httpBuilder.connectionPool(mConnectPool);
        Request.Builder builder = new Request.Builder();
        builder.url(request.url);
        String str = "application/x-www-form-urlencoded";
        if (request.paramMap != null) {
            for (String str2 : request.paramMap.keySet()) {
                if (str2.equalsIgnoreCase(NetWork.CONTENT_TYPE)) {
                    str = request.paramMap.get(str2);
                }
                builder.addHeader(str2, request.paramMap.get(str2));
            }
        }
        if ("POST".equals(request.method) || "PUT".equals(request.method) || "PATCH".equals(request.method) || "DELETE".equals(request.method)) {
            if (request.body != null && listener != null) {
                listener.onHttpUploadProgress(0);
            }
            if ("BASE64".equalsIgnoreCase(request.inputType)) {
                builder.method(request.method, RequestBody.createWithBytes(MediaType.parse(str), Base64.decode(request.body, 2)));
                if (listener != null) {
                    listener.onHttpUploadProgress(100);
                }
            } else {
                builder.method(request.method, RequestBody.create(MediaType.parse(str), request.body));
                if (listener != null) {
                    listener.onHttpUploadProgress(100);
                }
            }
        } else if ("HEAD".equals(request.method)) {
            builder.head();
        }
        return builder.build();
    }

    /* JADX INFO: Access modifiers changed from: private */
    public byte[] readInputStreamAsBytes(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        byte[] bArr = new byte[2048];
        int i = 0;
        while (true) {
            int read = inputStream.read(bArr, 0, 2048);
            if (read != -1) {
                byteArrayOutputStream.write(bArr, 0, read);
                i += read;
                if (listener != null) {
                    listener.onHttpResponseProgress(i);
                }
            } else {
                byteArrayOutputStream.flush();
                return byteArrayOutputStream.toByteArray();
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public String readInputStream(InputStream inputStream, IWXHttpAdapter.OnHttpListener listener) throws IOException {
        if (inputStream == null) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
        char[] cArr = new char[2048];
        while (true) {
            int read = bufferedReader.read(cArr);
            if (read != -1) {
                sb.append(cArr, 0, read);
                if (listener != null) {
                    listener.onHttpResponseProgress(sb.length());
                }
            } else {
                bufferedReader.close();
                return sb.toString();
            }
        }
    }

    public X509HostnameVerifier getHostnameVerifier(boolean sslVerify) {
        if (!sslVerify) {
            return org.apache.http.conn.ssl.SSLSocketFactory.BROWSER_COMPATIBLE_HOSTNAME_VERIFIER;
        }
        return org.apache.http.conn.ssl.SSLSocketFactory.ALLOW_ALL_HOSTNAME_VERIFIER;
    }

    public OkHttpClient getImageOkHttpClient() {
        OkHttpClient.Builder builder = new OkHttpClient.Builder();
        long j = (long) HttpUrlConnectionNetworkFetcher.HTTP_DEFAULT_TIMEOUT;
        builder.connectTimeout(j, TimeUnit.MILLISECONDS).readTimeout(j, TimeUnit.MILLISECONDS).writeTimeout(j, TimeUnit.MILLISECONDS).callTimeout(j, TimeUnit.MILLISECONDS).protocols(Collections.singletonList(Protocol.HTTP_1_1));
        return builder.build();
    }
}
