package io.dcloud.feature.weex.adapter;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.Animatable;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.text.TextUtils;
import android.widget.ImageView;
import com.facebook.common.executors.UiThreadImmediateExecutorService;
import com.facebook.common.internal.Preconditions;
import com.facebook.common.logging.FLog;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.drawee.controller.AbstractDraweeController;
import com.facebook.drawee.controller.BaseControllerListener;
import com.facebook.drawee.view.DraweeView;
import com.facebook.imagepipeline.common.ImageDecodeOptions;
import com.facebook.imagepipeline.common.ResizeOptions;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.image.CloseableStaticBitmap;
import com.facebook.imagepipeline.image.ImageInfo;
import com.facebook.imagepipeline.request.ImageRequest;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.adapter.IWXImgLoaderAdapter;
import com.taobao.weex.common.WXImageStrategy;
import com.taobao.weex.dom.WXImageQuality;
import io.dcloud.common.adapter.util.DeviceInfo;
import io.dcloud.common.adapter.util.Logger;
import io.dcloud.common.util.PdrUtil;
import io.dcloud.common.util.ThreadPool;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.HashMap;
/* loaded from: classes.dex */
public class FrescoImageAdapter implements IWXImgLoaderAdapter {
    @Override // com.taobao.weex.adapter.IWXImgLoaderAdapter
    public void setImage(final String url, final ImageView view, final WXImageQuality quality, final WXImageStrategy strategy) {
        if (PdrUtil.isEmpty(url)) {
            if (view != null) {
                view.setImageBitmap(null);
            }
        } else if (strategy != null && strategy.placeHolder != null) {
            ThreadPool.self().addThreadTask(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoImageAdapter.1
                @Override // java.lang.Runnable
                public void run() {
                    Bitmap bitmap;
                    Logger.d("FrescoImage", "Thread_setImage--" + url);
                    try {
                        if (strategy.placeHolder.startsWith("file")) {
                            bitmap = BitmapFactory.decodeFile(strategy.placeHolder.replaceFirst(DeviceInfo.FILE_PROTOCOL, ""));
                        } else {
                            HttpURLConnection httpURLConnection = (HttpURLConnection) new URL(strategy.placeHolder).openConnection();
                            httpURLConnection.connect();
                            bitmap = BitmapFactory.decodeStream(httpURLConnection.getInputStream());
                        }
                    } catch (IOException e) {
                        e.printStackTrace();
                        bitmap = null;
                    }
                    final BitmapDrawable bitmapDrawable = new BitmapDrawable(bitmap);
                    WXSDKManager.getInstance().postOnUiThread(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoImageAdapter.1.1
                        @Override // java.lang.Runnable
                        public void run() {
                            FrescoImageAdapter.setImage(url, view, quality, strategy, bitmapDrawable);
                        }
                    }, 0L);
                }
            }, true);
        } else {
            WXSDKManager.getInstance().postOnUiThread(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoImageAdapter.2
                @Override // java.lang.Runnable
                public void run() {
                    FrescoImageAdapter.setImage(url, view, quality, strategy, null);
                }
            }, 0L);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public static void setImage(final String url, final ImageView view, WXImageQuality quality, final WXImageStrategy strategy, Drawable placeholderDrawable) {
        String str;
        if (view == null || view.getLayoutParams() == null) {
            return;
        }
        if (TextUtils.isEmpty(url)) {
            view.setImageBitmap(null);
            return;
        }
        if (url.startsWith("//")) {
            str = "http:" + url;
        } else {
            str = url;
        }
        ImageRequestBuilder progressiveRenderingEnabled = ImageRequestBuilder.newBuilderWithSource(Uri.parse(str)).setImageDecodeOptions(ImageDecodeOptions.newBuilder().build()).setAutoRotateEnabled(true).setLocalThumbnailPreviewsEnabled(true).setLowestPermittedRequestLevel(ImageRequest.RequestLevel.FULL_FETCH).setProgressiveRenderingEnabled(false);
        if (!strategy.isAutoCompression()) {
            progressiveRenderingEnabled.setResizeOptions(new ResizeOptions(Integer.MAX_VALUE, Integer.MAX_VALUE));
        }
        ImageRequest build = progressiveRenderingEnabled.build();
        if (view instanceof DraweeView) {
            AbstractDraweeController build2 = Fresco.newDraweeControllerBuilder().setAutoPlayAnimations(true).setControllerListener(new BaseControllerListener<ImageInfo>() { // from class: io.dcloud.feature.weex.adapter.FrescoImageAdapter.3
                @Override // com.facebook.drawee.controller.BaseControllerListener, com.facebook.drawee.controller.ControllerListener
                public void onFinalImageSet(String id, ImageInfo imageInfo, Animatable anim) {
                    WXImageStrategy wXImageStrategy;
                    if (imageInfo == null || (wXImageStrategy = WXImageStrategy.this) == null || wXImageStrategy.getImageListener() == null) {
                        return;
                    }
                    HashMap hashMap = new HashMap();
                    hashMap.put("width", Integer.valueOf(imageInfo.getWidth()));
                    hashMap.put("height", Integer.valueOf(imageInfo.getHeight()));
                    if (imageInfo.getWidth() > 0) {
                        WXImageStrategy.this.getImageListener().onImageFinish(url, view, true, hashMap);
                    } else {
                        WXImageStrategy.this.getImageListener().onImageFinish(url, view, false, hashMap);
                    }
                }

                @Override // com.facebook.drawee.controller.BaseControllerListener, com.facebook.drawee.controller.ControllerListener
                public void onIntermediateImageSet(String id, ImageInfo imageInfo) {
                    FLog.d("", "Intermediate image received");
                }

                @Override // com.facebook.drawee.controller.BaseControllerListener, com.facebook.drawee.controller.ControllerListener
                public void onFailure(String id, Throwable throwable) {
                    FLog.e(getClass(), throwable, "Error loading %s", id);
                    WXImageStrategy wXImageStrategy = WXImageStrategy.this;
                    if (wXImageStrategy == null || wXImageStrategy.getImageListener() == null) {
                        return;
                    }
                    WXImageStrategy.this.getImageListener().onImageFinish(url, view, false, null);
                }
            }).setImageRequest(build).build();
            if (placeholderDrawable != null) {
                ((FrescoImageView) view).getHierarchy().setPlaceholderImage(placeholderDrawable);
            }
            ((DraweeView) view).setController(build2);
            return;
        }
        Fresco.getImagePipeline().fetchDecodedImage(build, new Object()).subscribe(new BaseDataSubscriber<CloseableReference<CloseableImage>>() { // from class: io.dcloud.feature.weex.adapter.FrescoImageAdapter.4
            @Override // com.facebook.datasource.BaseDataSubscriber
            public void onNewResultImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                CloseableReference<CloseableImage> result = dataSource.getResult();
                if (result != null) {
                    try {
                        Preconditions.checkState(CloseableReference.isValid(result));
                        CloseableImage closeableImage = result.get();
                        if (closeableImage instanceof CloseableStaticBitmap) {
                            view.setImageBitmap(((CloseableStaticBitmap) closeableImage).getUnderlyingBitmap());
                        }
                        WXImageStrategy wXImageStrategy = strategy;
                        if (wXImageStrategy != null && wXImageStrategy.getImageListener() != null) {
                            strategy.getImageListener().onImageFinish(url, view, true, null);
                        }
                    } finally {
                        result.close();
                    }
                }
            }

            @Override // com.facebook.datasource.BaseDataSubscriber
            public void onFailureImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                WXImageStrategy wXImageStrategy = strategy;
                if (wXImageStrategy == null || wXImageStrategy.getImageListener() == null) {
                    return;
                }
                strategy.getImageListener().onImageFinish(url, view, false, null);
            }
        }, UiThreadImmediateExecutorService.getInstance());
    }
}
