package io.dcloud.feature.weex.adapter;

import android.content.Context;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.RectF;
import android.text.TextUtils;
import android.widget.ImageView;
import com.facebook.drawee.drawable.ScalingUtils;
import com.facebook.drawee.generic.RoundingParams;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.bridge.WXBridgeManager;
import com.taobao.weex.common.Constants;
import com.taobao.weex.layout.ContentBoxMeasurement;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXImage;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.view.border.BorderDrawable;
import com.taobao.weex.utils.WXDomUtils;
import com.taobao.weex.utils.WXUtils;
import com.taobao.weex.utils.WXViewUtils;
import io.dcloud.common.DHInterface.IApp;
import java.util.Map;
/* loaded from: classes.dex */
public class FrescoImageComponent extends WXImage {
    private int mBitmapHeight;
    private int mBitmapWidth;
    private String mResizeMode;

    public FrescoImageComponent(final WXSDKInstance instance, WXVContainer parent, final BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.mResizeMode = "scaleToFill";
        this.mBitmapWidth = 0;
        this.mBitmapHeight = 0;
        setContentBoxMeasurement(new ContentBoxMeasurement() { // from class: io.dcloud.feature.weex.adapter.FrescoImageComponent.1
            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutAfter(float computedWidth, float computedHeight) {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void layoutBefore() {
            }

            @Override // com.taobao.weex.layout.ContentBoxMeasurement
            public void measureInternal(float width, float height, int widthMeasureMode, int heightMeasureMode) {
                boolean containsKey = basicComponentData.getStyles().containsKey(Constants.Name.FLEX);
                this.mMeasureExactly = false;
                if (widthMeasureMode == 0) {
                    if (FrescoImageComponent.this.mResizeMode.equals("heightFix") && FrescoImageComponent.this.mBitmapHeight > 0 && FrescoImageComponent.this.mBitmapWidth > 0 && !Float.isNaN(height)) {
                        this.mMeasureWidth = FrescoImageComponent.this.mBitmapWidth * (height / FrescoImageComponent.this.mBitmapHeight);
                        this.mMeasureExactly = true;
                    } else if (!containsKey) {
                        this.mMeasureWidth = (int) WXViewUtils.getRealPxByWidth(320.0f, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat());
                    }
                }
                if (heightMeasureMode == 0) {
                    if (!FrescoImageComponent.this.mResizeMode.equals("widthFix") || FrescoImageComponent.this.mBitmapHeight <= 0 || FrescoImageComponent.this.mBitmapWidth <= 0 || Float.isNaN(width)) {
                        if (containsKey) {
                            return;
                        }
                        this.mMeasureHeight = (int) WXViewUtils.getRealPxByWidth(240.0f, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat());
                        return;
                    }
                    this.mMeasureHeight = FrescoImageComponent.this.mBitmapHeight * (width / FrescoImageComponent.this.mBitmapWidth);
                    this.mMeasureExactly = true;
                }
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public ImageView initComponentHostView(Context context) {
        FrescoImageView frescoImageView = new FrescoImageView(context);
        frescoImageView.getHierarchy().setActualImageScaleType(ScalingUtils.ScaleType.FIT_XY);
        return frescoImageView;
    }

    @WXComponentProp(name = "fadeShow")
    public void setFadeAnim(String v) {
        if (TextUtils.isEmpty(v) || getHostView() == null) {
            return;
        }
        ((FrescoImageView) getHostView()).setFadeShow(Boolean.valueOf(v).booleanValue());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public boolean setProperty(String key, Object param) {
        key.hashCode();
        char c = 65535;
        switch (key.hashCode()) {
            case -934437708:
                if (key.equals("resize")) {
                    c = 0;
                    break;
                }
                break;
            case 3357091:
                if (key.equals("mode")) {
                    c = 1;
                    break;
                }
                break;
            case 2049757303:
                if (key.equals(Constants.Name.RESIZE_MODE)) {
                    c = 2;
                    break;
                }
                break;
        }
        switch (c) {
            case 0:
                String string = WXUtils.getString(param, null);
                if (string != null) {
                    setResizeMode(string);
                }
                return true;
            case 1:
                String string2 = WXUtils.getString(param, null);
                if (string2 != null) {
                    setResizeMode(string2);
                }
                return true;
            case 2:
                String string3 = WXUtils.getString(param, null);
                if (string3 != null) {
                    setResizeMode(string3);
                }
                return true;
            default:
                return super.setProperty(key, param);
        }
    }

    @Override // com.taobao.weex.ui.component.WXImage
    public void setResizeMode(String resizeMode) {
        FrescoImageView frescoImageView = (FrescoImageView) getHostView();
        ScalingUtils.ScaleType scaleType = ScalingUtils.ScaleType.FIT_XY;
        this.mResizeMode = resizeMode;
        if (!TextUtils.isEmpty(resizeMode)) {
            resizeMode.hashCode();
            char c = 65535;
            switch (resizeMode.hashCode()) {
                case -1881872635:
                    if (resizeMode.equals("stretch")) {
                        c = 0;
                        break;
                    }
                    break;
                case -1687059567:
                    if (resizeMode.equals("top right")) {
                        c = 1;
                        break;
                    }
                    break;
                case -1614504594:
                    if (resizeMode.equals("heightFix")) {
                        c = 2;
                        break;
                    }
                    break;
                case -1387149201:
                    if (resizeMode.equals("widthFix")) {
                        c = 3;
                        break;
                    }
                    break;
                case -1383228885:
                    if (resizeMode.equals("bottom")) {
                        c = 4;
                        break;
                    }
                    break;
                case -1364013995:
                    if (resizeMode.equals("center")) {
                        c = 5;
                        break;
                    }
                    break;
                case -1362001767:
                    if (resizeMode.equals("aspectFit")) {
                        c = 6;
                        break;
                    }
                    break;
                case -1024435214:
                    if (resizeMode.equals("top left")) {
                        c = 7;
                        break;
                    }
                    break;
                case -797304696:
                    if (resizeMode.equals("scaleToFill")) {
                        c = '\b';
                        break;
                    }
                    break;
                case -667379492:
                    if (resizeMode.equals("bottom left")) {
                        c = '\t';
                        break;
                    }
                    break;
                case 115029:
                    if (resizeMode.equals("top")) {
                        c = '\n';
                        break;
                    }
                    break;
                case 3317767:
                    if (resizeMode.equals("left")) {
                        c = 11;
                        break;
                    }
                    break;
                case 94852023:
                    if (resizeMode.equals(IApp.ConfigProperty.CONFIG_COVER)) {
                        c = '\f';
                        break;
                    }
                    break;
                case 108511772:
                    if (resizeMode.equals("right")) {
                        c = '\r';
                        break;
                    }
                    break;
                case 727618043:
                    if (resizeMode.equals("aspectFill")) {
                        c = 14;
                        break;
                    }
                    break;
                case 791733223:
                    if (resizeMode.equals("bottom right")) {
                        c = 15;
                        break;
                    }
                    break;
                case 951526612:
                    if (resizeMode.equals("contain")) {
                        c = 16;
                        break;
                    }
                    break;
            }
            switch (c) {
                case 0:
                    scaleType = ScalingUtils.ScaleType.FIT_XY;
                    break;
                case 1:
                    scaleType = new CustomScaleType(1.0f, 0.0f);
                    break;
                case 2:
                case 3:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
                case 4:
                    scaleType = new CustomScaleType(0.5f, 1.0f);
                    break;
                case 5:
                    scaleType = new CustomScaleType(0.5f, 0.5f);
                    break;
                case 6:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
                case 7:
                    scaleType = new CustomScaleType(0.0f, 0.0f);
                    break;
                case '\b':
                    scaleType = ScalingUtils.ScaleType.FIT_XY;
                    break;
                case '\t':
                    scaleType = new CustomScaleType(0.0f, 1.0f);
                    break;
                case '\n':
                    scaleType = new CustomScaleType(0.5f, 0.0f);
                    break;
                case 11:
                    scaleType = new CustomScaleType(0.0f, 0.5f);
                    break;
                case '\f':
                    scaleType = ScalingUtils.ScaleType.CENTER_CROP;
                    break;
                case '\r':
                    scaleType = new CustomScaleType(1.0f, 0.5f);
                    break;
                case 14:
                    scaleType = ScalingUtils.ScaleType.CENTER_CROP;
                    break;
                case 15:
                    scaleType = new CustomScaleType(1.0f, 1.0f);
                    break;
                case 16:
                    scaleType = ScalingUtils.ScaleType.FIT_CENTER;
                    break;
            }
        }
        frescoImageView.getHierarchy().setActualImageScaleType(scaleType);
    }

    @Override // com.taobao.weex.ui.component.WXImage
    public void onImageFinish(boolean result, Map extra) {
        super.onImageFinish(result, extra);
        if (extra != null) {
            String str = this.mResizeMode;
            str.hashCode();
            if (str.equals("heightFix")) {
                this.mBitmapWidth = Integer.parseInt(extra.get("width").toString());
                this.mBitmapHeight = Integer.parseInt(extra.get("height").toString());
                float layoutHeight = this.mBitmapWidth * (getLayoutHeight() / this.mBitmapHeight);
                if (getLayoutWidth() != layoutHeight) {
                    setStyleWidth(layoutHeight);
                }
            } else if (str.equals("widthFix")) {
                this.mBitmapWidth = Integer.parseInt(extra.get("width").toString());
                this.mBitmapHeight = Integer.parseInt(extra.get("height").toString());
                float layoutWidth = this.mBitmapHeight * (getLayoutWidth() / this.mBitmapWidth);
                if (getLayoutHeight() != layoutWidth) {
                    setStyleHeight(layoutWidth);
                }
            }
        }
    }

    private void setStyleHeight(final float height) {
        WXBridgeManager.getInstance().post(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoImageComponent.2
            @Override // java.lang.Runnable
            public void run() {
                if (FrescoImageComponent.this.getInstance() != null) {
                    WXBridgeManager.getInstance().setStyleHeight(FrescoImageComponent.this.getInstanceId(), FrescoImageComponent.this.getRef(), height);
                }
            }
        });
    }

    private void setStyleWidth(final float width) {
        WXBridgeManager.getInstance().post(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoImageComponent.3
            @Override // java.lang.Runnable
            public void run() {
                if (FrescoImageComponent.this.getInstance() != null) {
                    WXBridgeManager.getInstance().setStyleWidth(FrescoImageComponent.this.getInstanceId(), FrescoImageComponent.this.getRef(), width);
                }
            }
        });
    }

    /* loaded from: classes.dex */
    public class CustomScaleType implements ScalingUtils.ScaleType {
        private float dxf;
        private float dyf;

        public CustomScaleType(float dxf, float dyf) {
            this.dxf = dxf;
            this.dyf = dyf;
        }

        @Override // com.facebook.drawee.drawable.ScalingUtils.ScaleType
        public Matrix getTransform(Matrix outTransform, Rect parentRect, int childWidth, int childHeight, float focusX, float focusY) {
            float f = childWidth;
            float realPxByWidth = WXViewUtils.getRealPxByWidth(f, FrescoImageComponent.this.getInstance().getInstanceViewPortWidthWithFloat()) / f;
            outTransform.setScale(realPxByWidth, realPxByWidth);
            outTransform.postTranslate(parentRect.left + ((parentRect.width() - (f * realPxByWidth)) * this.dxf), parentRect.top + ((parentRect.height() - (childHeight * realPxByWidth)) * this.dyf));
            return outTransform;
        }
    }

    @Override // com.taobao.weex.ui.component.WXImage, com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        if (getHostView() != null) {
            super.updateProperties(props);
            updateBorderRadius();
        }
    }

    private void updateBorderRadius() {
        BorderDrawable borderDrawable = WXViewUtils.getBorderDrawable(getHostView());
        RoundingParams roundingParams = new RoundingParams();
        roundingParams.setCornersRadii(borderDrawable != null ? borderDrawable.getBorderInnerRadius(new RectF(0.0f, 0.0f, WXDomUtils.getContentWidth(this), WXDomUtils.getContentHeight(this))) : new float[]{0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f, 0.0f});
        ((FrescoImageView) getHostView()).getHierarchy().setRoundingParams(roundingParams);
    }
}
