package io.dcloud.feature.weex.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import com.facebook.cache.common.CacheKey;
import com.facebook.common.executors.UiThreadImmediateExecutorService;
import com.facebook.common.references.CloseableReference;
import com.facebook.datasource.BaseDataSubscriber;
import com.facebook.datasource.DataSource;
import com.facebook.drawee.backends.pipeline.Fresco;
import com.facebook.imagepipeline.bitmaps.PlatformBitmapFactory;
import com.facebook.imagepipeline.image.CloseableBitmap;
import com.facebook.imagepipeline.image.CloseableImage;
import com.facebook.imagepipeline.request.ImageRequestBuilder;
import com.facebook.imagepipeline.request.Postprocessor;
import io.dcloud.common.util.ThreadPool;
import io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter;
import io.dcloud.feature.uniapp.utils.bitmap.BitmapLoadCallback;
import java.lang.ref.SoftReference;
/* loaded from: classes.dex */
public class FrescoLoadUtil implements UniImageLoadAdapter {
    private static FrescoLoadUtil inst;
    Handler mHandler = new Handler(Looper.getMainLooper());

    public static UniImageLoadAdapter getInstance() {
        if (inst == null) {
            inst = new FrescoLoadUtil();
        }
        return inst;
    }

    @Override // io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter
    public final void loadImageBitmap(Context context, String url, BitmapLoadCallback<Bitmap> call) {
        loadImageBitmap(context, url, 0, 0, call);
    }

    @Override // io.dcloud.feature.uniapp.adapter.UniImageLoadAdapter
    public final void loadImageBitmap(Context context, String url, int width, int height, BitmapLoadCallback<Bitmap> call) {
        String str;
        if (TextUtils.isEmpty(url)) {
            return;
        }
        if (url.startsWith("//")) {
            str = "http:" + url;
        } else {
            str = url;
        }
        try {
            fetch(context, Uri.parse(str), width, height, call);
        } catch (Exception e) {
            e.printStackTrace();
            call.onFailure(url, e);
        }
    }

    private void fetch(final Context context, final Uri uri, final int newWidth, final int newHeight, final BitmapLoadCallback<Bitmap> callback) {
        ThreadPool.self().addThreadTask(new Runnable() { // from class: io.dcloud.feature.weex.adapter.FrescoLoadUtil.1
            @Override // java.lang.Runnable
            public void run() {
                ImageRequestBuilder progressiveRenderingEnabled = ImageRequestBuilder.newBuilderWithSource(uri).setProgressiveRenderingEnabled(false);
                progressiveRenderingEnabled.setPostprocessor(new Postprocessor() { // from class: io.dcloud.feature.weex.adapter.FrescoLoadUtil.1.1
                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public String getName() {
                        return null;
                    }

                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public CacheKey getPostprocessorCacheKey() {
                        return null;
                    }

                    @Override // com.facebook.imagepipeline.request.Postprocessor
                    public CloseableReference<Bitmap> process(Bitmap sourceBitmap, PlatformBitmapFactory bitmapFactory) {
                        if (newHeight > 0 && newHeight > 0) {
                            int width = sourceBitmap.getWidth();
                            int height = sourceBitmap.getHeight();
                            Matrix matrix = new Matrix();
                            matrix.postScale(newWidth / width, newHeight / height);
                            return bitmapFactory.createBitmap(sourceBitmap, 0, 0, width, height, matrix, true);
                        }
                        return bitmapFactory.createBitmap(sourceBitmap);
                    }
                });
                Fresco.getImagePipeline().fetchDecodedImage(progressiveRenderingEnabled.build(), context).subscribe(new BaseDataSubscriber<CloseableReference<CloseableImage>>() { // from class: io.dcloud.feature.weex.adapter.FrescoLoadUtil.1.2
                    @Override // com.facebook.datasource.BaseDataSubscriber
                    protected void onNewResultImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                        CloseableReference<CloseableImage> result;
                        if (dataSource.isFinished() && (result = dataSource.getResult()) != null) {
                            try {
                                Bitmap underlyingBitmap = result.get() instanceof CloseableBitmap ? ((CloseableBitmap) result.get()).getUnderlyingBitmap() : null;
                                if (underlyingBitmap != null && !underlyingBitmap.isRecycled()) {
                                    SoftReference softReference = new SoftReference(Bitmap.createBitmap(underlyingBitmap));
                                    if (callback != null) {
                                        callback.onSuccess(uri.toString(), (Bitmap) softReference.get());
                                    }
                                }
                            } finally {
                                result.close();
                                dataSource.close();
                            }
                        }
                    }

                    @Override // com.facebook.datasource.BaseDataSubscriber
                    protected void onFailureImpl(DataSource<CloseableReference<CloseableImage>> dataSource) {
                        if (callback != null) {
                            callback.onSuccess(uri.toString(), null);
                        }
                    }
                }, UiThreadImmediateExecutorService.getInstance());
            }
        }, true);
    }
}
