package io.dcloud.feature.weex_barcode;

import android.content.Context;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponent;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.utils.WXResourceUtils;
import io.dcloud.common.constant.AbsoluteConst;
import io.dcloud.common.util.AppRuntime;
import io.dcloud.common.util.PdrUtil;
import java.util.Map;
import java.util.concurrent.atomic.AtomicBoolean;
/* loaded from: classes.dex */
public class BarcodeComponent extends WXComponent<BarcodeView> {
    private boolean isAnimationEnd;
    private AtomicBoolean isLoad;

    @JSMethod
    public void close() {
    }

    public BarcodeComponent(WXSDKInstance instance, WXVContainer parent, BasicComponentData basicComponentData) {
        super(instance, parent, basicComponentData);
        this.isLoad = new AtomicBoolean(false);
        this.isAnimationEnd = false;
    }

    public BarcodeComponent(WXSDKInstance instance, WXVContainer parent, int type, BasicComponentData basicComponentData) {
        super(instance, parent, type, basicComponentData);
        this.isLoad = new AtomicBoolean(false);
        this.isAnimationEnd = false;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public BarcodeView initComponentHostView(final Context context) {
        AppRuntime.checkPrivacyComplianceAndPrompt(context, "nvue-Barcode");
        return new BarcodeView(context, this, getInstance());
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void updateProperties(Map<String, Object> props) {
        super.updateProperties(props);
        if (getHostView() == null || getAttrs().containsKey("background")) {
            return;
        }
        getHostView().setBackgroundColor(-16777216);
    }

    @WXComponentProp(name = "frameColor")
    public void setFrameColor(String color) {
        getHostView().setFrameColor(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "autoDecodeCharset")
    public void setAutoDecodeCharset(boolean autoDecodeCharset) {
        getHostView().setAutoDecodeCharset(autoDecodeCharset);
    }

    @WXComponentProp(name = "autoZoom")
    public void setAutoZoom(boolean autoZoom) {
        getHostView().setAutoZoom(autoZoom);
    }

    @WXComponentProp(name = "background")
    public void setBackground(String color) {
        getHostView().setBackground(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "scanbarColor")
    public void setScanbarColor(String color) {
        getHostView().setScanBarColor(WXResourceUtils.getColor(color));
    }

    @WXComponentProp(name = "filters")
    public void setFilters(JSONArray filters) {
        getHostView().initDecodeFormats(filters);
    }

    @WXComponentProp(name = "autostart")
    public void setSutoStart(final boolean isstart) {
        if (!this.isAnimationEnd) {
            getInstance().addFrameViewEventListener(new WXSDKInstance.FrameViewEventListener() { // from class: io.dcloud.feature.weex_barcode.BarcodeComponent.1
                @Override // com.taobao.weex.WXSDKInstance.FrameViewEventListener
                public void onShowAnimationEnd() {
                    BarcodeComponent.this.isAnimationEnd = true;
                    if (isstart) {
                        BarcodeComponent.this.start(null);
                    }
                    BarcodeComponent.this.getInstance().removeFrameViewEventListener(this);
                }
            });
        } else if (isstart) {
            start(null);
        }
    }

    @JSMethod
    public void start(JSONObject option) {
        if (option != null) {
            boolean z = false;
            getHostView().setConserve(option.containsKey("conserve") ? option.getBoolean("conserve").booleanValue() : false);
            getHostView().setFilename(PdrUtil.getDefaultPrivateDocPath(option.getString(AbsoluteConst.JSON_KEY_FILENAME), "png"));
            getHostView().setVibrate(option.containsKey("vibrate") ? option.getBoolean("vibrate").booleanValue() : true);
            getHostView().setPlayBeep((!option.containsKey("sound") || option.getString("sound").equals("default")) ? true : true);
        }
        getHostView().start();
    }

    /* JADX INFO: Access modifiers changed from: protected */
    @Override // com.taobao.weex.ui.component.WXComponent
    public void setHostLayoutParams(BarcodeView host, int width, int height, int left, int right, int top, int bottom) {
        super.setHostLayoutParams((BarcodeComponent) host, width, height, left, right, top, bottom);
        if (!this.isLoad.get()) {
            this.isLoad.set(true);
            getHostView().initBarcodeView(width, height);
            return;
        }
        getHostView().updateStyles(width, height);
    }

    @JSMethod
    public void cancel() {
        getHostView().cancelScan();
    }

    @JSMethod
    public void setFlash(boolean open) {
        if (PdrUtil.isEmpty(Boolean.valueOf(open))) {
            return;
        }
        getHostView().setFlash(open);
    }

    @Override // com.taobao.weex.ui.component.WXComponent
    public void destroy() {
        super.destroy();
        getHostView().closeScan();
        getHostView().onDestory();
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityResume() {
        super.onActivityResume();
        getHostView().onResume(true);
    }

    @Override // com.taobao.weex.ui.component.WXComponent, com.taobao.weex.IWXActivityStateListener
    public void onActivityPause() {
        super.onActivityPause();
        getHostView().onPause();
    }
}
